CREATE TABLE IF NOT EXISTS `academic_calendars` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `date` date NOT NULL,
  `title` varchar(512) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `academic_calendars_school_id_foreign` (`school_id`),
  KEY `academic_calendars_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `academic_calendars_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `academic_calendars_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `addon_subscriptions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `subscription_id` bigint(20) unsigned DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `feature_id` bigint(20) unsigned NOT NULL,
  `price` double(64,4) NOT NULL,
  `start_date` date NOT NULL,
  `end_date` date NOT NULL,
  `status` tinyint(4) NOT NULL DEFAULT 1 COMMENT '0 => Discontinue next billing, 1 => Continue',
  `payment_transaction_id` bigint(20) unsigned DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `addon_subscriptions_school_id_foreign` (`school_id`),
  KEY `addon_subscriptions_feature_id_foreign` (`feature_id`),
  KEY `addon_subscriptions_subscription_id_foreign` (`subscription_id`),
  KEY `addon_subscriptions_payment_transaction_id_foreign` (`payment_transaction_id`),
  CONSTRAINT `addon_subscriptions_feature_id_foreign` FOREIGN KEY (`feature_id`) REFERENCES `features` (`id`) ON DELETE CASCADE,
  CONSTRAINT `addon_subscriptions_payment_transaction_id_foreign` FOREIGN KEY (`payment_transaction_id`) REFERENCES `payment_transactions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `addon_subscriptions_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `addon_subscriptions_subscription_id_foreign` FOREIGN KEY (`subscription_id`) REFERENCES `subscriptions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `announcement_classes` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `announcement_id` bigint(20) unsigned DEFAULT NULL,
  `class_section_id` bigint(20) unsigned DEFAULT NULL,
  `class_subject_id` bigint(20) unsigned DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_columns` (`announcement_id`,`class_section_id`,`school_id`),
  KEY `announcement_classes_school_id_foreign` (`school_id`),
  KEY `announcement_classes_announcement_id_index` (`announcement_id`),
  KEY `announcement_classes_class_section_id_index` (`class_section_id`),
  KEY `announcement_classes_class_subject_id_foreign` (`class_subject_id`),
  CONSTRAINT `announcement_classes_announcement_id_foreign` FOREIGN KEY (`announcement_id`) REFERENCES `announcements` (`id`) ON DELETE CASCADE,
  CONSTRAINT `announcement_classes_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `announcement_classes_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `announcement_classes_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `announcement_classes` VALUES ('1', '1', '1', '10', '1', '2024-08-08 02:58:30', '2024-08-08 02:58:30');

CREATE TABLE IF NOT EXISTS `announcements` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(128) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `announcements_school_id_foreign` (`school_id`),
  KEY `announcements_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `announcements_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `announcements_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `announcements` VALUES ('1', 'Being math sets on Friday', 'please they and bring your maths sets on Friday', '1', '1', '2024-08-08 02:58:29', '2024-08-08 02:58:29');

CREATE TABLE IF NOT EXISTS `assignment_commons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `assignment_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `assignment_commons_assignment_id_foreign` (`assignment_id`),
  KEY `assignment_commons_class_section_id_foreign` (`class_section_id`),
  CONSTRAINT `assignment_commons_assignment_id_foreign` FOREIGN KEY (`assignment_id`) REFERENCES `assignments` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignment_commons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `assignment_commons` VALUES ('1', '1', '1', '2025-01-04 05:53:55', '2025-01-04 05:53:55');

CREATE TABLE IF NOT EXISTS `assignment_submissions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `assignment_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `feedback` text DEFAULT NULL,
  `points` int(11) DEFAULT NULL,
  `status` tinyint(4) NOT NULL DEFAULT 0 COMMENT '0 = Pending/In Review , 1 = Accepted , 2 = Rejected , 3 = Resubmitted',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `assignment_submissions_assignment_id_foreign` (`assignment_id`),
  KEY `assignment_submissions_school_id_foreign` (`school_id`),
  KEY `assignment_submissions_student_id_foreign` (`student_id`),
  KEY `assignment_submissions_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `assignment_submissions_assignment_id_foreign` FOREIGN KEY (`assignment_id`) REFERENCES `assignments` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignment_submissions_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignment_submissions_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignment_submissions_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `assignments` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `name` varchar(128) NOT NULL,
  `instructions` varchar(1024) DEFAULT NULL,
  `due_date` datetime NOT NULL,
  `points` int(11) DEFAULT NULL,
  `resubmission` tinyint(1) NOT NULL DEFAULT 0,
  `extra_days_for_resubmission` int(11) DEFAULT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_by` bigint(20) unsigned NOT NULL COMMENT 'teacher_user_id',
  `edited_by` bigint(20) unsigned DEFAULT NULL COMMENT 'teacher_user_id',
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `assignments_school_id_foreign` (`school_id`),
  KEY `assignments_class_section_id_foreign` (`class_section_id`),
  KEY `assignments_class_subject_id_foreign` (`class_subject_id`),
  KEY `assignments_session_year_id_foreign` (`session_year_id`),
  KEY `assignments_created_by_foreign` (`created_by`),
  KEY `assignments_edited_by_foreign` (`edited_by`),
  CONSTRAINT `assignments_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignments_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignments_created_by_foreign` FOREIGN KEY (`created_by`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignments_edited_by_foreign` FOREIGN KEY (`edited_by`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignments_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignments_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `assignments` VALUES ('1', '1', '10', 'Addition', 'What is the quickest way to add large numbers', '2024-08-05 14:25:00', '20', '0', NULL, '1', '1', '8', NULL, '2024-08-05 17:54:28', '2024-08-05 17:54:28');

CREATE TABLE IF NOT EXISTS `attendances` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `session_year_id` bigint(20) unsigned NOT NULL,
  `type` tinyint(4) NOT NULL COMMENT '0=Absent, 1=Present',
  `date` date NOT NULL,
  `remark` varchar(512) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `attendances_school_id_foreign` (`school_id`),
  KEY `attendances_class_section_id_foreign` (`class_section_id`),
  KEY `attendances_student_id_foreign` (`student_id`),
  KEY `attendances_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `attendances_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `attendances_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `attendances_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `attendances_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=30 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `attendances` VALUES ('1', '1', '11', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:49', '2024-08-06 00:00:49');
INSERT INTO `attendances` VALUES ('2', '1', '13', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:49', '2024-08-06 00:00:49');
INSERT INTO `attendances` VALUES ('3', '1', '15', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:49', '2024-08-06 00:00:49');
INSERT INTO `attendances` VALUES ('4', '1', '27', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:49', '2024-08-06 00:00:49');
INSERT INTO `attendances` VALUES ('5', '1', '33', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:49', '2024-08-06 00:00:49');
INSERT INTO `attendances` VALUES ('6', '1', '35', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:49', '2024-08-06 00:00:49');
INSERT INTO `attendances` VALUES ('7', '1', '37', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:49', '2024-08-06 00:00:49');
INSERT INTO `attendances` VALUES ('8', '1', '38', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:49', '2024-08-06 00:00:49');
INSERT INTO `attendances` VALUES ('9', '1', '40', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:49', '2024-08-06 00:00:49');
INSERT INTO `attendances` VALUES ('10', '1', '42', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('11', '1', '44', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('12', '1', '46', '1', '0', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('13', '1', '48', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('14', '1', '50', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('15', '1', '52', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('16', '1', '54', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('17', '1', '56', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('18', '1', '58', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('19', '1', '60', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('20', '1', '62', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('21', '1', '64', '1', '0', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('22', '1', '66', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('23', '1', '68', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('24', '1', '69', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('25', '1', '72', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('26', '1', '74', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('27', '1', '80', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('28', '1', '82', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');
INSERT INTO `attendances` VALUES ('29', '1', '382', '1', '1', '2024-08-05', '', '1', '2024-08-06 00:00:50', '2024-08-06 00:00:50');

CREATE TABLE IF NOT EXISTS `certificate_templates` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `page_layout` varchar(191) NOT NULL COMMENT 'A4 Portrait, A4 Landscape, Custom',
  `height` double(8,2) DEFAULT NULL,
  `width` double(8,2) DEFAULT NULL,
  `user_image_shape` varchar(191) NOT NULL COMMENT 'Round, Square',
  `image_size` double(8,2) DEFAULT NULL,
  `background_image` varchar(191) DEFAULT NULL,
  `description` text DEFAULT NULL,
  `fields` varchar(191) DEFAULT NULL,
  `style` longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_bin DEFAULT NULL CHECK (json_valid(`style`)),
  `type` varchar(191) DEFAULT NULL COMMENT 'Student, Staff',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `certificate_templates_school_id_foreign` (`school_id`),
  CONSTRAINT `certificate_templates_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `class_groups` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) DEFAULT NULL,
  `description` text DEFAULT NULL,
  `image` varchar(191) DEFAULT NULL,
  `class_ids` varchar(191) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `class_groups_school_id_foreign` (`school_id`),
  CONSTRAINT `class_groups_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `class_sections` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_id` bigint(20) unsigned NOT NULL,
  `section_id` bigint(20) unsigned NOT NULL,
  `medium_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_id` (`class_id`,`section_id`,`medium_id`),
  KEY `class_sections_school_id_foreign` (`school_id`),
  KEY `class_sections_section_id_foreign` (`section_id`),
  KEY `class_sections_medium_id_foreign` (`medium_id`),
  CONSTRAINT `class_sections_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_sections_medium_id_foreign` FOREIGN KEY (`medium_id`) REFERENCES `mediums` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_sections_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_sections_section_id_foreign` FOREIGN KEY (`section_id`) REFERENCES `sections` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `class_sections` VALUES ('1', '1', '1', '1', '1', '2024-07-10 14:53:21', '2024-07-10 14:53:21', NULL);
INSERT INTO `class_sections` VALUES ('2', '2', '2', '1', '1', '2024-07-10 14:53:54', '2024-07-10 14:53:54', NULL);
INSERT INTO `class_sections` VALUES ('3', '3', '1', '1', '1', '2024-07-11 14:57:58', '2024-07-11 14:57:58', NULL);
INSERT INTO `class_sections` VALUES ('4', '4', '2', '1', '1', '2024-07-11 14:58:23', '2024-07-11 14:58:23', NULL);
INSERT INTO `class_sections` VALUES ('5', '5', '1', '1', '1', '2024-07-11 14:58:56', '2024-07-11 14:58:56', NULL);
INSERT INTO `class_sections` VALUES ('6', '6', '2', '1', '1', '2024-07-11 14:59:27', '2024-07-11 14:59:27', NULL);

CREATE TABLE IF NOT EXISTS `class_subjects` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_id` bigint(20) unsigned NOT NULL,
  `subject_id` bigint(20) unsigned NOT NULL,
  `type` varchar(32) NOT NULL COMMENT 'Compulsory / Elective',
  `elective_subject_group_id` bigint(20) unsigned DEFAULT NULL COMMENT 'if type=Elective',
  `semester_id` bigint(20) unsigned DEFAULT NULL,
  `virtual_semester_id` int(11) GENERATED ALWAYS AS (case when `semester_id` is not null then `semester_id` else 0 end) VIRTUAL,
  `school_id` bigint(20) unsigned NOT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`class_id`,`subject_id`,`virtual_semester_id`),
  KEY `class_subjects_elective_subject_group_id_foreign` (`elective_subject_group_id`),
  KEY `class_subjects_school_id_foreign` (`school_id`),
  KEY `class_subjects_subject_id_foreign` (`subject_id`),
  KEY `class_subjects_semester_id_foreign` (`semester_id`),
  CONSTRAINT `class_subjects_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_subjects_elective_subject_group_id_foreign` FOREIGN KEY (`elective_subject_group_id`) REFERENCES `elective_subject_groups` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_subjects_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_subjects_semester_id_foreign` FOREIGN KEY (`semester_id`) REFERENCES `semesters` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_subjects_subject_id_foreign` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=49 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `class_subjects` VALUES ('1', '2', '1', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:56:43', '2024-07-10 14:56:43');
INSERT INTO `class_subjects` VALUES ('2', '2', '2', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:56:43', '2024-07-10 14:56:43');
INSERT INTO `class_subjects` VALUES ('3', '2', '3', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:56:43', '2024-07-10 14:56:43');
INSERT INTO `class_subjects` VALUES ('4', '2', '4', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:56:43', '2024-07-10 14:56:43');
INSERT INTO `class_subjects` VALUES ('5', '2', '5', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:56:43', '2024-07-10 14:56:43');
INSERT INTO `class_subjects` VALUES ('6', '2', '8', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:56:43', '2024-07-10 14:56:43');
INSERT INTO `class_subjects` VALUES ('7', '2', '9', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:56:43', '2024-07-10 14:56:43');
INSERT INTO `class_subjects` VALUES ('8', '2', '10', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:56:43', '2024-07-10 14:56:43');
INSERT INTO `class_subjects` VALUES ('9', '1', '1', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:58:20', '2024-07-10 14:58:20');
INSERT INTO `class_subjects` VALUES ('10', '1', '2', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:58:20', '2024-07-10 14:58:20');
INSERT INTO `class_subjects` VALUES ('11', '1', '3', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:58:20', '2024-07-10 14:58:20');
INSERT INTO `class_subjects` VALUES ('12', '1', '4', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:58:20', '2024-07-10 14:58:20');
INSERT INTO `class_subjects` VALUES ('13', '1', '5', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:58:20', '2024-07-10 14:58:20');
INSERT INTO `class_subjects` VALUES ('14', '1', '8', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:58:20', '2024-07-10 14:58:20');
INSERT INTO `class_subjects` VALUES ('15', '1', '9', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:58:20', '2024-07-10 14:58:20');
INSERT INTO `class_subjects` VALUES ('16', '1', '10', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-10 14:58:20', '2024-07-10 14:58:20');
INSERT INTO `class_subjects` VALUES ('17', '3', '1', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:01:20', '2024-07-11 15:01:20');
INSERT INTO `class_subjects` VALUES ('18', '3', '2', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:01:20', '2024-07-11 15:01:20');
INSERT INTO `class_subjects` VALUES ('19', '3', '3', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:01:20', '2024-07-11 15:01:20');
INSERT INTO `class_subjects` VALUES ('20', '3', '4', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:01:20', '2024-07-11 15:01:20');
INSERT INTO `class_subjects` VALUES ('21', '3', '5', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:01:20', '2024-07-11 15:01:20');
INSERT INTO `class_subjects` VALUES ('22', '3', '8', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:01:20', '2024-07-11 15:01:20');
INSERT INTO `class_subjects` VALUES ('23', '3', '9', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:01:20', '2024-07-11 15:01:20');
INSERT INTO `class_subjects` VALUES ('24', '3', '10', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:01:20', '2024-07-11 15:01:20');
INSERT INTO `class_subjects` VALUES ('25', '4', '1', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:02:43', '2024-07-11 15:02:43');
INSERT INTO `class_subjects` VALUES ('26', '4', '2', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:02:43', '2024-07-11 15:02:43');
INSERT INTO `class_subjects` VALUES ('27', '4', '3', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:02:43', '2024-07-11 15:02:43');
INSERT INTO `class_subjects` VALUES ('28', '4', '4', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:02:43', '2024-07-11 15:02:43');
INSERT INTO `class_subjects` VALUES ('29', '4', '5', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:02:43', '2024-07-11 15:02:43');
INSERT INTO `class_subjects` VALUES ('30', '4', '8', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:02:43', '2024-07-11 15:02:43');
INSERT INTO `class_subjects` VALUES ('31', '4', '9', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:02:43', '2024-07-11 15:02:43');
INSERT INTO `class_subjects` VALUES ('32', '4', '10', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:02:43', '2024-07-11 15:02:43');
INSERT INTO `class_subjects` VALUES ('33', '5', '1', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:03:55', '2024-07-11 15:03:55');
INSERT INTO `class_subjects` VALUES ('34', '5', '2', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:03:55', '2024-07-11 15:03:55');
INSERT INTO `class_subjects` VALUES ('35', '5', '3', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:03:55', '2024-07-11 15:03:55');
INSERT INTO `class_subjects` VALUES ('36', '5', '4', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:03:55', '2024-07-11 15:03:55');
INSERT INTO `class_subjects` VALUES ('37', '5', '5', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:03:55', '2024-07-11 15:03:55');
INSERT INTO `class_subjects` VALUES ('38', '5', '8', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:03:55', '2024-07-11 15:03:55');
INSERT INTO `class_subjects` VALUES ('39', '5', '9', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:03:55', '2024-07-11 15:03:55');
INSERT INTO `class_subjects` VALUES ('40', '5', '10', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:03:55', '2024-07-11 15:03:55');
INSERT INTO `class_subjects` VALUES ('41', '6', '1', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:05:14', '2024-07-11 15:05:14');
INSERT INTO `class_subjects` VALUES ('42', '6', '2', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:05:14', '2024-07-11 15:05:14');
INSERT INTO `class_subjects` VALUES ('43', '6', '3', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:05:14', '2024-07-11 15:05:14');
INSERT INTO `class_subjects` VALUES ('44', '6', '4', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:05:14', '2024-07-11 15:05:14');
INSERT INTO `class_subjects` VALUES ('45', '6', '5', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:05:14', '2024-07-11 15:05:14');
INSERT INTO `class_subjects` VALUES ('46', '6', '8', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:05:14', '2024-07-11 15:05:14');
INSERT INTO `class_subjects` VALUES ('47', '6', '9', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:05:14', '2024-07-11 15:05:14');
INSERT INTO `class_subjects` VALUES ('48', '6', '10', 'Compulsory', NULL, NULL, '0', '1', NULL, '2024-07-11 15:05:14', '2024-07-11 15:05:14');

CREATE TABLE IF NOT EXISTS `class_teachers` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `teacher_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_id` (`class_section_id`,`teacher_id`),
  KEY `class_teachers_school_id_foreign` (`school_id`),
  KEY `class_teachers_teacher_id_foreign` (`teacher_id`),
  CONSTRAINT `class_teachers_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_teachers_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_teachers_teacher_id_foreign` FOREIGN KEY (`teacher_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `class_teachers` VALUES ('1', '1', '8', '1', '2024-08-10 05:29:22', '2024-08-10 05:29:22');

CREATE TABLE IF NOT EXISTS `classes` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `include_semesters` tinyint(4) NOT NULL DEFAULT 0 COMMENT '0 - no 1 - yes',
  `medium_id` bigint(20) unsigned NOT NULL,
  `shift_id` bigint(20) unsigned DEFAULT NULL,
  `stream_id` bigint(20) unsigned DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `classes_school_id_foreign` (`school_id`),
  KEY `classes_medium_id_foreign` (`medium_id`),
  KEY `classes_shift_id_foreign` (`shift_id`),
  KEY `classes_stream_id_foreign` (`stream_id`),
  CONSTRAINT `classes_medium_id_foreign` FOREIGN KEY (`medium_id`) REFERENCES `mediums` (`id`) ON DELETE CASCADE,
  CONSTRAINT `classes_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `classes_shift_id_foreign` FOREIGN KEY (`shift_id`) REFERENCES `shifts` (`id`) ON DELETE CASCADE,
  CONSTRAINT `classes_stream_id_foreign` FOREIGN KEY (`stream_id`) REFERENCES `streams` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `classes` VALUES ('1', 'J.H.S 1', '0', '1', NULL, NULL, '1', '2024-07-10 14:53:21', '2024-08-06 04:08:39', NULL);
INSERT INTO `classes` VALUES ('2', 'J.H.S 1', '0', '1', NULL, NULL, '1', '2024-07-10 14:53:54', '2024-08-06 04:08:10', NULL);
INSERT INTO `classes` VALUES ('3', 'J.H.S 2', '0', '1', NULL, NULL, '1', '2024-07-11 14:57:58', '2024-08-06 04:07:43', NULL);
INSERT INTO `classes` VALUES ('4', 'J.H.S 2', '0', '1', NULL, NULL, '1', '2024-07-11 14:58:23', '2024-08-06 04:07:11', NULL);
INSERT INTO `classes` VALUES ('5', 'J.H.S 3', '0', '1', NULL, NULL, '1', '2024-07-11 14:58:56', '2024-08-06 04:06:43', NULL);
INSERT INTO `classes` VALUES ('6', 'J.H.S 3', '0', '1', NULL, NULL, '1', '2024-07-11 14:59:27', '2024-08-06 04:06:15', NULL);

CREATE TABLE IF NOT EXISTS `compulsory_fees` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `payment_transaction_id` bigint(20) unsigned DEFAULT NULL,
  `type` enum('Full Payment','Installment Payment') NOT NULL,
  `installment_id` bigint(20) unsigned DEFAULT NULL,
  `mode` enum('Cash','Cheque','Online') NOT NULL,
  `cheque_no` varchar(191) DEFAULT NULL,
  `amount` double(8,2) NOT NULL,
  `due_charges` double(8,2) DEFAULT NULL,
  `fees_paid_id` bigint(20) unsigned DEFAULT NULL,
  `status` enum('Success','Pending','Failed') NOT NULL,
  `date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `compulsory_fees_installment_id_foreign` (`installment_id`),
  KEY `compulsory_fees_school_id_foreign` (`school_id`),
  KEY `compulsory_fees_student_id_foreign` (`student_id`),
  KEY `compulsory_fees_payment_transaction_id_foreign` (`payment_transaction_id`),
  KEY `compulsory_fees_fees_paid_id_foreign` (`fees_paid_id`),
  CONSTRAINT `compulsory_fees_fees_paid_id_foreign` FOREIGN KEY (`fees_paid_id`) REFERENCES `fees_paids` (`id`) ON DELETE CASCADE,
  CONSTRAINT `compulsory_fees_installment_id_foreign` FOREIGN KEY (`installment_id`) REFERENCES `fees_installments` (`id`) ON DELETE CASCADE,
  CONSTRAINT `compulsory_fees_payment_transaction_id_foreign` FOREIGN KEY (`payment_transaction_id`) REFERENCES `payment_transactions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `compulsory_fees_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `compulsory_fees_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `elective_subject_groups` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `total_subjects` int(11) NOT NULL,
  `total_selectable_subjects` int(11) NOT NULL,
  `class_id` bigint(20) unsigned NOT NULL,
  `semester_id` bigint(20) unsigned DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `elective_subject_groups_school_id_foreign` (`school_id`),
  KEY `elective_subject_groups_class_id_foreign` (`class_id`),
  KEY `elective_subject_groups_semester_id_foreign` (`semester_id`),
  CONSTRAINT `elective_subject_groups_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `elective_subject_groups_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `elective_subject_groups_semester_id_foreign` FOREIGN KEY (`semester_id`) REFERENCES `semesters` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `exam_marks` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `exam_timetable_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `obtained_marks` double(8,2) NOT NULL,
  `teacher_review` varchar(1024) DEFAULT NULL,
  `passing_status` tinyint(1) NOT NULL COMMENT '1=Pass, 0=Fail',
  `session_year_id` bigint(20) unsigned NOT NULL,
  `grade` tinytext DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `exam_marks_school_id_foreign` (`school_id`),
  KEY `exam_marks_exam_timetable_id_foreign` (`exam_timetable_id`),
  KEY `exam_marks_student_id_foreign` (`student_id`),
  KEY `exam_marks_class_subject_id_foreign` (`class_subject_id`),
  KEY `exam_marks_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `exam_marks_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_marks_exam_timetable_id_foreign` FOREIGN KEY (`exam_timetable_id`) REFERENCES `exam_timetables` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_marks_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_marks_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_marks_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=30 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `exam_marks` VALUES ('1', '4', '382', '10', '9', NULL, '1', '1', 'D', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('2', '4', '82', '10', '16', NULL, '1', '1', 'B', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('3', '4', '80', '10', '12', NULL, '1', '1', 'C', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('4', '4', '74', '10', '10', NULL, '1', '1', 'D', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('5', '4', '72', '10', '11', NULL, '1', '1', 'C2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('6', '4', '69', '10', '14', NULL, '1', '1', 'B2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('7', '4', '68', '10', '19', NULL, '1', '1', 'A', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('8', '4', '66', '10', '5', NULL, '1', '1', 'FAIL', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('9', '4', '64', '10', '19', NULL, '1', '1', 'A', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('10', '4', '62', '10', '20', NULL, '1', '1', 'A', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('11', '4', '60', '10', '5', NULL, '1', '1', 'FAIL', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('12', '4', '58', '10', '8', NULL, '1', '1', 'D2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('13', '4', '56', '10', '9', NULL, '1', '1', 'D', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('14', '4', '54', '10', '14', NULL, '1', '1', 'B2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('15', '4', '52', '10', '13', NULL, '1', '1', 'C', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('16', '4', '50', '10', '12', NULL, '1', '1', 'C', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('17', '4', '48', '10', '17', NULL, '1', '1', 'A2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('18', '4', '46', '10', '18', NULL, '1', '1', 'A2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('19', '4', '44', '10', '15', NULL, '1', '1', 'B', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('20', '4', '42', '10', '12', NULL, '1', '1', 'C', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('21', '4', '40', '10', '18', NULL, '1', '1', 'A2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('22', '4', '38', '10', '16', NULL, '1', '1', 'B', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('23', '4', '37', '10', '17', NULL, '1', '1', 'A2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('24', '4', '35', '10', '4', NULL, '0', '1', 'FAIL', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('25', '4', '33', '10', '12', NULL, '1', '1', 'C', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('26', '4', '27', '10', '17', NULL, '1', '1', 'A2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('27', '4', '15', '10', '20', NULL, '1', '1', 'A', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('28', '4', '13', '10', '14', NULL, '1', '1', 'B2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);
INSERT INTO `exam_marks` VALUES ('29', '4', '11', '10', '11', NULL, '1', '1', 'C2', '1', '2024-08-10 07:08:43', '2024-08-10 07:08:43', NULL);

CREATE TABLE IF NOT EXISTS `exam_results` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `exam_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `total_marks` int(11) NOT NULL,
  `obtained_marks` double(8,2) NOT NULL,
  `percentage` double(8,2) NOT NULL,
  `grade` tinytext NOT NULL,
  `status` int(11) NOT NULL DEFAULT 1 COMMENT '0 -> Failed, 1 -> Pass',
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `exam_results_school_id_foreign` (`school_id`),
  KEY `exam_results_exam_id_foreign` (`exam_id`),
  KEY `exam_results_class_section_id_foreign` (`class_section_id`),
  KEY `exam_results_student_id_foreign` (`student_id`),
  KEY `exam_results_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `exam_results_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_results_exam_id_foreign` FOREIGN KEY (`exam_id`) REFERENCES `exams` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_results_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_results_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_results_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `exam_timetables` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `exam_id` bigint(20) unsigned NOT NULL,
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `total_marks` double(8,2) NOT NULL,
  `passing_marks` double(8,2) NOT NULL,
  `date` date NOT NULL,
  `start_time` time NOT NULL,
  `end_time` time NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `exam_timetables_exam_id_foreign` (`exam_id`),
  KEY `exam_timetables_school_id_foreign` (`school_id`),
  KEY `exam_timetables_class_subject_id_foreign` (`class_subject_id`),
  KEY `exam_timetables_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `exam_timetables_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_timetables_exam_id_foreign` FOREIGN KEY (`exam_id`) REFERENCES `exams` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_timetables_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_timetables_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `exam_timetables` VALUES ('1', '1', '11', '50', '35', '2024-07-10', '10:25:00', '12:30:00', '1', '1', '2024-08-06 16:55:49', '2024-08-06 16:55:49');
INSERT INTO `exam_timetables` VALUES ('2', '1', '9', '50', '35', '2024-07-17', '13:45:00', '16:05:00', '1', '1', '2024-08-06 17:35:53', '2024-08-06 17:35:53');
INSERT INTO `exam_timetables` VALUES ('3', '2', '9', '20', '5', '2024-06-12', '10:00:00', '11:00:00', '1', '1', '2024-08-08 05:46:06', '2024-08-10 05:48:41');
INSERT INTO `exam_timetables` VALUES ('4', '2', '10', '20', '5', '2024-05-22', '10:00:00', '11:00:00', '1', '1', '2024-08-09 04:19:49', '2024-08-10 05:48:41');
INSERT INTO `exam_timetables` VALUES ('5', '2', '11', '20', '5', '2024-04-16', '10:00:00', '11:00:00', '1', '1', '2024-08-09 04:19:49', '2024-08-10 05:48:41');
INSERT INTO `exam_timetables` VALUES ('6', '2', '12', '20', '5', '2024-07-25', '10:00:00', '11:00:00', '1', '1', '2024-08-09 04:19:49', '2024-08-10 05:48:41');
INSERT INTO `exam_timetables` VALUES ('7', '2', '13', '20', '5', '2024-07-25', '10:00:00', '11:00:00', '1', '1', '2024-08-09 04:19:49', '2024-08-10 05:48:41');
INSERT INTO `exam_timetables` VALUES ('8', '2', '14', '20', '5', '2024-03-11', '10:00:00', '11:00:00', '1', '1', '2024-08-09 04:19:49', '2024-08-10 05:48:41');
INSERT INTO `exam_timetables` VALUES ('9', '2', '15', '20', '5', '2024-07-17', '10:00:00', '11:00:00', '1', '1', '2024-08-09 04:19:49', '2024-08-09 04:19:49');

CREATE TABLE IF NOT EXISTS `exams` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(128) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `class_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `start_date` date DEFAULT NULL,
  `end_date` date DEFAULT NULL,
  `last_result_submission_date` date DEFAULT NULL,
  `publish` tinyint(4) NOT NULL DEFAULT 0,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `exams_school_id_foreign` (`school_id`),
  KEY `exams_class_id_foreign` (`class_id`),
  KEY `exams_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `exams_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exams_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exams_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `exams` VALUES ('1', 'Science End of Term', 'Science End of Term', '1', '1', '2024-07-10', '2024-07-17', NULL, '0', '1', '2024-08-06 16:51:52', '2024-08-06 17:35:53', NULL);
INSERT INTO `exams` VALUES ('2', 'Mid Term Exams', 'Mid Term Exams', '1', '1', '2024-03-11', '2024-07-25', NULL, '0', '1', '2024-08-08 05:43:22', '2024-08-10 05:48:41', NULL);
INSERT INTO `exams` VALUES ('3', 'Mid Term Exams', 'Mid Term Exams', '2', '1', NULL, NULL, NULL, '0', '1', '2024-08-08 05:43:22', '2024-08-08 05:43:22', NULL);
INSERT INTO `exams` VALUES ('4', 'Mid Term Exams', 'Mid Term Exams', '3', '1', NULL, NULL, NULL, '0', '1', '2024-08-08 05:43:22', '2024-08-08 05:43:22', NULL);
INSERT INTO `exams` VALUES ('5', 'Mid Term Exams', 'Mid Term Exams', '4', '1', NULL, NULL, NULL, '0', '1', '2024-08-08 05:43:22', '2024-08-08 05:43:22', NULL);
INSERT INTO `exams` VALUES ('6', 'Mid Term Exams', 'Mid Term Exams', '5', '1', NULL, NULL, NULL, '0', '1', '2024-08-08 05:43:22', '2024-08-08 05:43:22', NULL);
INSERT INTO `exams` VALUES ('7', 'Mid Term Exams', 'Mid Term Exams', '6', '1', NULL, NULL, NULL, '0', '1', '2024-08-08 05:43:22', '2024-08-08 05:43:22', NULL);

CREATE TABLE IF NOT EXISTS `expense_categories` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `description` varchar(191) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `expense_categories_school_id_foreign` (`school_id`),
  CONSTRAINT `expense_categories_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `expenses` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `category_id` bigint(20) unsigned DEFAULT NULL,
  `ref_no` varchar(191) DEFAULT NULL,
  `staff_id` bigint(20) unsigned DEFAULT NULL,
  `basic_salary` bigint(20) NOT NULL DEFAULT 0,
  `paid_leaves` double(8,2) NOT NULL DEFAULT 0.00,
  `month` bigint(20) DEFAULT NULL,
  `year` int(11) DEFAULT NULL,
  `title` varchar(512) NOT NULL,
  `description` varchar(191) DEFAULT NULL,
  `amount` double(64,2) NOT NULL,
  `date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `salary_unique_records` (`staff_id`,`month`,`year`),
  KEY `expenses_school_id_foreign` (`school_id`),
  KEY `expenses_category_id_foreign` (`category_id`),
  KEY `expenses_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `expenses_category_id_foreign` FOREIGN KEY (`category_id`) REFERENCES `expense_categories` (`id`) ON DELETE CASCADE,
  CONSTRAINT `expenses_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `expenses_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `expenses_staff_id_foreign` FOREIGN KEY (`staff_id`) REFERENCES `staffs` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `extra_user_datas` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `form_field_id` bigint(20) unsigned NOT NULL,
  `data` text DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `extra_user_datas_user_id_foreign` (`user_id`),
  KEY `extra_user_datas_form_field_id_foreign` (`form_field_id`),
  KEY `extra_user_datas_school_id_foreign` (`school_id`),
  CONSTRAINT `extra_user_datas_form_field_id_foreign` FOREIGN KEY (`form_field_id`) REFERENCES `form_fields` (`id`) ON DELETE CASCADE,
  CONSTRAINT `extra_user_datas_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `extra_user_datas_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=961 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `extra_user_datas` VALUES ('1', '11', '5', '0', '1', '2024-07-10 16:29:08', '2024-07-10 16:29:08', NULL);
INSERT INTO `extra_user_datas` VALUES ('2', '13', '5', '0', '1', '2024-07-10 16:33:06', '2024-07-10 16:33:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('3', '15', '5', '0', '1', '2024-07-10 16:35:47', '2024-07-10 16:35:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('4', '17', '5', '0', '1', '2024-07-10 16:38:41', '2024-07-10 16:38:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('5', '19', '5', '0', '1', '2024-07-10 16:41:26', '2024-07-10 16:41:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('6', '21', '5', '1', '1', '2024-07-10 16:46:20', '2024-07-10 16:46:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('7', '23', '5', '1', '1', '2024-07-10 16:50:11', '2024-07-10 16:50:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('8', '25', '5', '1', '1', '2024-07-10 16:53:19', '2024-07-10 16:53:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('9', '27', '5', '0', '1', '2024-07-10 17:27:36', '2024-07-10 17:27:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('10', '29', '5', '0', '1', '2024-07-10 17:30:22', '2024-07-10 17:30:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('11', '31', '5', '1', '1', '2024-07-10 17:33:28', '2024-07-10 17:33:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('12', '33', '5', '1', '1', '2024-07-10 17:36:07', '2024-07-10 17:36:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('13', '35', '5', '0', '1', '2024-07-10 17:38:39', '2024-07-10 17:38:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('14', '37', '5', '0', '1', '2024-07-10 17:42:25', '2024-07-10 17:42:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('15', '38', '5', '0', '1', '2024-07-10 17:45:05', '2024-07-10 17:45:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('16', '40', '5', '0', '1', '2024-07-10 17:47:46', '2024-07-10 17:47:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('17', '42', '5', '0', '1', '2024-07-10 17:51:24', '2024-07-10 17:51:24', NULL);
INSERT INTO `extra_user_datas` VALUES ('18', '44', '5', '0', '1', '2024-07-10 17:54:33', '2024-07-10 17:54:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('19', '46', '5', '0', '1', '2024-07-10 17:57:17', '2024-07-10 17:57:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('20', '48', '5', '0', '1', '2024-07-10 17:59:58', '2024-07-10 17:59:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('21', '50', '5', '0', '1', '2024-07-10 18:03:37', '2024-07-10 18:03:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('22', '52', '5', '0', '1', '2024-07-10 18:06:17', '2024-07-10 18:06:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('23', '54', '5', '0', '1', '2024-07-10 18:09:16', '2024-07-10 18:09:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('24', '56', '5', '0', '1', '2024-07-10 18:12:23', '2024-07-10 18:12:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('25', '58', '5', '0', '1', '2024-07-10 18:15:41', '2024-07-10 18:15:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('26', '60', '5', '0', '1', '2024-07-10 18:18:29', '2024-07-10 18:18:29', NULL);
INSERT INTO `extra_user_datas` VALUES ('27', '62', '5', '0', '1', '2024-07-10 18:26:35', '2024-07-10 18:26:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('28', '64', '5', '1', '1', '2024-07-10 18:29:56', '2024-07-10 18:29:56', NULL);
INSERT INTO `extra_user_datas` VALUES ('29', '66', '5', '0', '1', '2024-07-10 18:33:09', '2024-07-10 18:33:09', NULL);
INSERT INTO `extra_user_datas` VALUES ('30', '68', '5', '0', '1', '2024-07-10 18:38:06', '2024-07-10 18:38:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('31', '69', '5', '0', '1', '2024-07-10 18:41:04', '2024-07-10 18:41:04', NULL);
INSERT INTO `extra_user_datas` VALUES ('32', '70', '5', '0', '1', '2024-07-10 18:43:45', '2024-07-10 18:43:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('33', '72', '5', '0', '1', '2024-07-10 18:46:48', '2024-07-10 18:46:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('34', '74', '5', '1', '1', '2024-07-10 18:49:11', '2024-07-10 18:49:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('35', '76', '5', '0', '1', '2024-07-10 18:51:35', '2024-07-10 18:51:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('36', '78', '5', '0', '1', '2024-07-10 18:55:11', '2024-07-10 18:55:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('37', '80', '5', '0', '1', '2024-07-10 18:57:22', '2024-07-10 18:57:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('38', '82', '5', '0', '1', '2024-07-10 18:59:34', '2024-07-10 18:59:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('39', '84', '5', '0', '1', '2024-07-10 19:14:31', '2024-07-10 19:14:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('40', '86', '5', '0', '1', '2024-07-10 19:16:43', '2024-07-10 19:16:43', NULL);
INSERT INTO `extra_user_datas` VALUES ('41', '88', '5', '0', '1', '2024-07-10 19:19:48', '2024-07-10 19:19:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('42', '90', '5', '0', '1', '2024-07-10 19:22:21', '2024-07-10 19:22:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('43', '92', '5', '0', '1', '2024-07-10 19:26:16', '2024-07-10 19:26:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('44', '94', '5', '1', '1', '2024-07-10 19:28:42', '2024-07-10 19:28:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('45', '96', '5', '0', '1', '2024-07-10 19:30:37', '2024-07-10 19:30:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('46', '98', '5', '1', '1', '2024-07-10 19:32:36', '2024-07-10 19:32:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('47', '100', '5', '0', '1', '2024-07-10 19:34:37', '2024-07-10 19:34:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('48', '102', '5', '0', '1', '2024-07-10 19:37:03', '2024-07-10 19:37:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('49', '104', '5', '1', '1', '2024-07-10 19:39:21', '2024-07-10 19:39:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('50', '105', '5', '1', '1', '2024-07-10 19:49:34', '2024-07-10 19:49:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('51', '107', '5', '1', '1', '2024-07-10 19:53:11', '2024-07-10 19:53:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('52', '109', '5', '0', '1', '2024-07-10 19:55:26', '2024-07-10 19:55:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('53', '111', '5', '0', '1', '2024-07-10 19:57:51', '2024-07-10 19:57:51', NULL);
INSERT INTO `extra_user_datas` VALUES ('54', '113', '5', '0', '1', '2024-07-10 19:59:53', '2024-07-10 19:59:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('55', '115', '5', '0', '1', '2024-07-10 20:02:20', '2024-07-10 20:02:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('56', '117', '5', '0', '1', '2024-07-10 20:04:17', '2024-07-10 20:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('57', '119', '5', '1', '1', '2024-07-10 20:06:12', '2024-07-10 20:06:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('58', '121', '5', '0', '1', '2024-07-10 20:08:02', '2024-07-10 20:08:02', NULL);
INSERT INTO `extra_user_datas` VALUES ('59', '123', '5', '0', '1', '2024-07-10 20:10:06', '2024-07-10 20:10:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('60', '125', '5', '1', '1', '2024-07-10 20:14:55', '2024-07-10 20:14:55', NULL);
INSERT INTO `extra_user_datas` VALUES ('61', '127', '5', '0', '1', '2024-07-10 20:17:17', '2024-07-10 20:17:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('62', '129', '5', '0', '1', '2024-07-10 20:19:04', '2024-07-10 20:19:04', NULL);
INSERT INTO `extra_user_datas` VALUES ('63', '131', '5', '0', '1', '2024-07-10 20:21:13', '2024-07-10 20:21:13', NULL);
INSERT INTO `extra_user_datas` VALUES ('64', '133', '5', '0', '1', '2024-07-10 20:23:29', '2024-07-10 20:23:29', NULL);
INSERT INTO `extra_user_datas` VALUES ('65', '135', '5', '0', '1', '2024-07-10 20:26:18', '2024-07-10 20:26:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('66', '137', '5', '0', '1', '2024-07-10 20:28:22', '2024-07-10 20:28:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('67', '139', '5', '1', '1', '2024-07-10 20:30:22', '2024-07-10 20:30:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('68', '141', '5', '0', '1', '2024-07-10 20:32:28', '2024-07-10 20:32:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('69', '143', '5', '0', '1', '2024-07-10 20:34:39', '2024-07-10 20:34:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('70', '145', '5', '0', '1', '2024-07-11 15:09:28', '2024-07-11 15:09:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('71', '147', '5', '0', '1', '2024-07-11 15:11:58', '2024-07-11 15:11:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('72', '149', '5', '1', '1', '2024-07-11 15:14:10', '2024-07-11 15:14:10', NULL);
INSERT INTO `extra_user_datas` VALUES ('73', '151', '5', '1', '1', '2024-07-11 15:16:03', '2024-07-11 15:16:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('74', '153', '5', '0', '1', '2024-07-11 15:19:36', '2024-07-11 15:19:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('75', '155', '5', '0', '1', '2024-07-11 15:23:36', '2024-07-11 15:23:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('76', '157', '5', '0', '1', '2024-07-11 15:28:58', '2024-07-11 15:28:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('77', '159', '5', '0', '1', '2024-07-11 15:31:34', '2024-07-11 15:31:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('78', '161', '5', '0', '1', '2024-07-11 15:35:49', '2024-07-11 15:35:49', NULL);
INSERT INTO `extra_user_datas` VALUES ('79', '163', '5', '0', '1', '2024-07-11 15:39:20', '2024-07-11 15:39:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('80', '165', '5', '0', '1', '2024-07-11 15:42:19', '2024-07-11 15:42:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('81', '167', '5', '0', '1', '2024-07-11 15:55:42', '2024-07-11 15:55:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('82', '169', '5', '0', '1', '2024-07-11 15:57:54', '2024-07-11 15:57:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('83', '171', '5', '0', '1', '2024-07-11 16:00:02', '2024-07-11 16:00:02', NULL);
INSERT INTO `extra_user_datas` VALUES ('84', '173', '5', '0', '1', '2024-07-11 16:02:06', '2024-07-11 16:02:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('85', '175', '5', '0', '1', '2024-07-11 16:05:01', '2024-07-11 16:05:01', NULL);
INSERT INTO `extra_user_datas` VALUES ('86', '177', '5', '0', '1', '2024-07-11 16:07:07', '2024-07-11 16:07:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('87', '179', '5', '1', '1', '2024-07-11 16:09:25', '2024-07-11 16:09:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('88', '181', '5', '0', '1', '2024-07-11 16:11:20', '2024-07-11 16:11:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('89', '183', '5', '0', '1', '2024-07-11 16:13:20', '2024-07-11 16:13:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('90', '184', '5', '0', '1', '2024-07-11 16:15:17', '2024-07-11 16:15:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('91', '186', '5', '0', '1', '2024-07-11 16:17:11', '2024-07-11 16:17:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('92', '188', '5', '0', '1', '2024-07-11 16:19:50', '2024-07-11 16:19:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('93', '190', '5', '0', '1', '2024-07-11 16:23:52', '2024-07-11 16:23:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('94', '192', '5', '0', '1', '2024-07-11 16:25:46', '2024-07-11 16:25:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('95', '194', '5', '0', '1', '2024-07-11 16:28:31', '2024-07-11 16:28:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('96', '196', '5', '0', '1', '2024-07-11 16:31:26', '2024-07-11 16:31:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('97', '198', '5', '1', '1', '2024-07-11 16:33:37', '2024-07-11 16:33:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('98', '200', '5', '0', '1', '2024-07-11 16:35:27', '2024-07-11 16:35:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('99', '202', '5', '0', '1', '2024-07-11 16:37:18', '2024-07-11 16:37:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('100', '204', '5', '0', '1', '2024-07-11 16:39:07', '2024-07-11 16:39:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('101', '206', '5', '0', '1', '2024-07-11 16:47:42', '2024-07-11 16:47:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('102', '208', '5', '0', '1', '2024-07-11 16:54:25', '2024-07-11 16:54:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('103', '210', '5', '0', '1', '2024-07-11 16:56:10', '2024-07-11 16:56:10', NULL);
INSERT INTO `extra_user_datas` VALUES ('104', '212', '5', '0', '1', '2024-07-11 16:57:53', '2024-07-11 16:57:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('105', '214', '5', '0', '1', '2024-07-11 16:59:37', '2024-07-11 16:59:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('106', '216', '5', '0', '1', '2024-07-11 17:01:18', '2024-07-11 17:01:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('107', '218', '5', '0', '1', '2024-07-11 17:03:03', '2024-07-11 17:03:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('108', '220', '5', '0', '1', '2024-07-11 17:04:41', '2024-07-11 17:04:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('109', '222', '5', '0', '1', '2024-07-11 17:06:32', '2024-07-11 17:06:32', NULL);
INSERT INTO `extra_user_datas` VALUES ('110', '223', '5', '0', '1', '2024-07-11 17:07:45', '2024-07-11 17:07:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('111', '225', '5', '0', '1', '2024-07-11 17:14:39', '2024-07-11 17:14:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('112', '227', '5', '0', '1', '2024-07-11 17:16:30', '2024-07-11 17:16:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('113', '229', '5', '0', '1', '2024-07-11 18:01:38', '2024-07-11 18:01:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('114', '231', '5', '0', '1', '2024-07-11 18:04:41', '2024-07-11 18:04:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('115', '233', '5', '1', '1', '2024-07-11 18:07:47', '2024-07-11 18:07:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('116', '235', '5', '1', '1', '2024-07-11 18:10:37', '2024-07-11 18:10:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('117', '237', '5', '1', '1', '2024-07-11 18:15:59', '2024-07-11 18:15:59', NULL);
INSERT INTO `extra_user_datas` VALUES ('118', '239', '5', '1', '1', '2024-07-11 18:18:28', '2024-07-11 18:18:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('119', '241', '5', '1', '1', '2024-07-11 18:20:27', '2024-07-11 18:20:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('120', '243', '5', '0', '1', '2024-07-11 18:22:16', '2024-07-11 18:22:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('121', '245', '5', '1', '1', '2024-07-11 18:24:09', '2024-07-11 18:24:09', NULL);
INSERT INTO `extra_user_datas` VALUES ('122', '246', '5', '1', '1', '2024-07-11 18:30:50', '2024-07-11 18:30:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('123', '248', '5', '1', '1', '2024-07-11 18:33:05', '2024-07-11 18:33:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('124', '250', '5', '1', '1', '2024-07-11 18:38:00', '2024-07-11 18:38:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('125', '252', '5', '1', '1', '2024-07-11 18:39:54', '2024-07-11 18:39:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('126', '254', '5', '0', '1', '2024-07-11 18:49:30', '2024-07-11 18:49:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('127', '256', '5', '0', '1', '2024-07-11 18:51:50', '2024-07-11 18:51:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('128', '258', '5', '0', '1', '2024-07-11 18:53:40', '2024-07-11 18:53:40', NULL);
INSERT INTO `extra_user_datas` VALUES ('129', '260', '5', '0', '1', '2024-07-11 18:55:27', '2024-07-11 18:55:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('130', '262', '5', '0', '1', '2024-07-11 18:57:39', '2024-07-11 18:57:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('131', '264', '5', '1', '1', '2024-07-11 18:59:31', '2024-07-11 18:59:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('132', '266', '5', '0', '1', '2024-07-11 19:02:46', '2024-07-11 19:02:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('133', '268', '5', '1', '1', '2024-07-11 19:04:46', '2024-07-11 19:04:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('134', '270', '5', '1', '1', '2024-07-11 19:06:42', '2024-07-11 19:06:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('135', '272', '5', '0', '1', '2024-07-11 19:08:25', '2024-07-11 19:08:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('136', '273', '5', '0', '1', '2024-07-11 19:09:37', '2024-07-11 19:09:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('137', '275', '5', '0', '1', '2024-07-11 19:13:14', '2024-07-11 19:13:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('138', '277', '5', '0', '1', '2024-07-11 19:14:46', '2024-07-11 19:14:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('139', '279', '5', '0', '1', '2024-07-11 19:16:21', '2024-07-11 19:16:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('140', '281', '5', '1', '1', '2024-07-11 19:18:08', '2024-07-11 19:18:08', NULL);
INSERT INTO `extra_user_datas` VALUES ('141', '283', '5', '0', '1', '2024-07-11 19:19:45', '2024-07-11 19:19:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('142', '285', '5', '0', '1', '2024-07-11 19:21:27', '2024-07-11 19:21:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('143', '287', '5', '0', '1', '2024-07-11 19:23:33', '2024-07-11 19:23:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('144', '289', '5', '0', '1', '2024-07-11 19:25:45', '2024-07-11 19:25:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('145', '291', '5', '1', '1', '2024-07-11 19:31:37', '2024-07-11 19:31:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('146', '293', '5', '0', '1', '2024-07-11 19:33:38', '2024-07-11 19:33:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('147', '295', '5', '0', '1', '2024-07-11 19:35:05', '2024-07-11 19:35:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('148', '297', '5', '1', '1', '2024-07-11 19:36:53', '2024-07-11 19:36:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('149', '299', '5', '1', '1', '2024-07-11 19:38:27', '2024-07-11 19:38:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('150', '301', '5', '0', '1', '2024-07-11 19:40:48', '2024-07-11 19:40:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('151', '303', '5', '0', '1', '2024-07-11 19:42:23', '2024-07-11 19:42:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('152', '305', '5', '1', '1', '2024-07-11 19:44:19', '2024-07-11 19:44:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('153', '307', '5', '0', '1', '2024-07-11 19:45:53', '2024-07-11 19:45:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('154', '309', '5', '0', '1', '2024-07-11 19:47:45', '2024-07-11 19:47:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('155', '311', '5', '0', '1', '2024-07-11 19:51:32', '2024-07-11 19:51:32', NULL);
INSERT INTO `extra_user_datas` VALUES ('156', '313', '5', '0', '1', '2024-07-11 19:53:27', '2024-07-11 19:53:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('157', '315', '5', '0', '1', '2024-07-11 19:56:06', '2024-07-11 19:56:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('158', '317', '5', '0', '1', '2024-07-11 19:57:57', '2024-07-11 19:57:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('159', '319', '5', '0', '1', '2024-07-11 20:00:06', '2024-07-11 20:00:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('160', '321', '5', '0', '1', '2024-07-11 20:01:45', '2024-07-11 20:01:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('161', '323', '5', '0', '1', '2024-07-11 20:03:38', '2024-07-11 20:03:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('162', '325', '5', '0', '1', '2024-07-11 20:06:42', '2024-07-11 20:06:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('163', '327', '5', '0', '1', '2024-07-11 20:08:40', '2024-07-11 20:08:40', NULL);
INSERT INTO `extra_user_datas` VALUES ('164', '329', '5', '0', '1', '2024-07-11 20:10:19', '2024-07-11 20:10:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('165', '331', '5', '0', '1', '2024-07-11 20:11:59', '2024-07-11 20:11:59', NULL);
INSERT INTO `extra_user_datas` VALUES ('166', '333', '5', '0', '1', '2024-07-11 20:13:33', '2024-07-11 20:13:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('167', '334', '5', '0', '1', '2024-07-11 20:15:00', '2024-07-11 20:15:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('168', '336', '5', '0', '1', '2024-07-11 20:17:16', '2024-07-11 20:17:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('169', '338', '5', '1', '1', '2024-07-11 20:19:12', '2024-07-11 20:19:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('170', '340', '5', '0', '1', '2024-07-11 20:21:12', '2024-07-11 20:21:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('171', '342', '5', '0', '1', '2024-07-11 20:22:54', '2024-07-11 20:22:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('172', '344', '5', '0', '1', '2024-07-11 20:24:38', '2024-07-11 20:24:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('173', '346', '5', '0', '1', '2024-07-11 20:26:14', '2024-07-11 20:26:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('174', '348', '5', '0', '1', '2024-07-11 20:27:51', '2024-07-11 20:27:51', NULL);
INSERT INTO `extra_user_datas` VALUES ('175', '349', '5', '0', '1', '2024-07-11 20:29:06', '2024-07-11 20:29:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('176', '351', '5', '0', '1', '2024-07-11 20:30:42', '2024-07-11 20:30:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('177', '353', '5', '0', '1', '2024-07-11 20:32:39', '2024-07-11 20:32:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('178', '355', '5', '0', '1', '2024-07-12 12:49:57', '2024-07-12 12:49:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('179', '356', '5', '0', '1', '2024-07-12 12:52:14', '2024-07-12 12:52:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('180', '358', '5', '0', '1', '2024-07-12 12:54:03', '2024-07-12 12:54:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('181', '360', '5', '0', '1', '2024-07-12 12:55:56', '2024-07-12 12:55:56', NULL);
INSERT INTO `extra_user_datas` VALUES ('182', '362', '5', '1', '1', '2024-07-12 12:57:35', '2024-07-12 12:57:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('183', '364', '5', '0', '1', '2024-07-12 13:01:19', '2024-07-12 13:01:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('184', '366', '5', '0', '1', '2024-07-12 13:03:18', '2024-07-12 13:03:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('185', '368', '5', '0', '1', '2024-07-12 13:07:52', '2024-07-12 13:07:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('186', '370', '5', '0', '1', '2024-07-12 13:14:05', '2024-07-12 13:14:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('187', '372', '5', '0', '1', '2024-07-12 13:17:33', '2024-07-12 13:17:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('188', '374', '5', '0', '1', '2024-07-12 13:20:47', '2024-07-12 13:20:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('189', '376', '5', '0', '1', '2024-07-12 13:23:48', '2024-07-12 13:23:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('190', '378', '5', '1', '1', '2024-07-12 13:25:37', '2024-07-12 13:25:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('191', '380', '5', '0', '1', '2024-07-12 13:27:52', '2024-07-12 13:27:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('192', '382', '5', '0', '1', '2024-07-19 07:05:47', '2024-07-19 07:05:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('193', '11', '5', '0', '1', '2024-07-10 16:29:08', '2024-07-10 16:29:08', NULL);
INSERT INTO `extra_user_datas` VALUES ('194', '13', '5', '0', '1', '2024-07-10 16:33:06', '2024-07-10 16:33:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('195', '15', '5', '0', '1', '2024-07-10 16:35:47', '2024-07-10 16:35:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('196', '17', '5', '0', '1', '2024-07-10 16:38:41', '2024-07-10 16:38:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('197', '19', '5', '0', '1', '2024-07-10 16:41:26', '2024-07-10 16:41:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('198', '21', '5', '1', '1', '2024-07-10 16:46:20', '2024-07-10 16:46:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('199', '23', '5', '1', '1', '2024-07-10 16:50:11', '2024-07-10 16:50:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('200', '25', '5', '1', '1', '2024-07-10 16:53:19', '2024-07-10 16:53:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('201', '27', '5', '0', '1', '2024-07-10 17:27:36', '2024-07-10 17:27:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('202', '29', '5', '0', '1', '2024-07-10 17:30:22', '2024-07-10 17:30:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('203', '31', '5', '1', '1', '2024-07-10 17:33:28', '2024-07-10 17:33:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('204', '33', '5', '1', '1', '2024-07-10 17:36:07', '2024-07-10 17:36:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('205', '35', '5', '0', '1', '2024-07-10 17:38:39', '2024-07-10 17:38:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('206', '37', '5', '0', '1', '2024-07-10 17:42:25', '2024-07-10 17:42:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('207', '38', '5', '0', '1', '2024-07-10 17:45:05', '2024-07-10 17:45:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('208', '40', '5', '0', '1', '2024-07-10 17:47:46', '2024-07-10 17:47:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('209', '42', '5', '0', '1', '2024-07-10 17:51:24', '2024-07-10 17:51:24', NULL);
INSERT INTO `extra_user_datas` VALUES ('210', '44', '5', '0', '1', '2024-07-10 17:54:33', '2024-07-10 17:54:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('211', '46', '5', '0', '1', '2024-07-10 17:57:17', '2024-07-10 17:57:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('212', '48', '5', '0', '1', '2024-07-10 17:59:58', '2024-07-10 17:59:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('213', '50', '5', '0', '1', '2024-07-10 18:03:37', '2024-07-10 18:03:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('214', '52', '5', '0', '1', '2024-07-10 18:06:17', '2024-07-10 18:06:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('215', '54', '5', '0', '1', '2024-07-10 18:09:16', '2024-07-10 18:09:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('216', '56', '5', '0', '1', '2024-07-10 18:12:23', '2024-07-10 18:12:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('217', '58', '5', '0', '1', '2024-07-10 18:15:41', '2024-07-10 18:15:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('218', '60', '5', '0', '1', '2024-07-10 18:18:29', '2024-07-10 18:18:29', NULL);
INSERT INTO `extra_user_datas` VALUES ('219', '62', '5', '0', '1', '2024-07-10 18:26:35', '2024-07-10 18:26:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('220', '64', '5', '1', '1', '2024-07-10 18:29:56', '2024-07-10 18:29:56', NULL);
INSERT INTO `extra_user_datas` VALUES ('221', '66', '5', '0', '1', '2024-07-10 18:33:09', '2024-07-10 18:33:09', NULL);
INSERT INTO `extra_user_datas` VALUES ('222', '68', '5', '0', '1', '2024-07-10 18:38:06', '2024-07-10 18:38:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('223', '69', '5', '0', '1', '2024-07-10 18:41:04', '2024-07-10 18:41:04', NULL);
INSERT INTO `extra_user_datas` VALUES ('224', '70', '5', '0', '1', '2024-07-10 18:43:45', '2024-07-10 18:43:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('225', '72', '5', '0', '1', '2024-07-10 18:46:48', '2024-07-10 18:46:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('226', '74', '5', '1', '1', '2024-07-10 18:49:11', '2024-07-10 18:49:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('227', '76', '5', '0', '1', '2024-07-10 18:51:35', '2024-07-10 18:51:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('228', '78', '5', '0', '1', '2024-07-10 18:55:11', '2024-07-10 18:55:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('229', '80', '5', '0', '1', '2024-07-10 18:57:22', '2024-07-10 18:57:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('230', '82', '5', '0', '1', '2024-07-10 18:59:34', '2024-07-10 18:59:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('231', '84', '5', '0', '1', '2024-07-10 19:14:31', '2024-07-10 19:14:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('232', '86', '5', '0', '1', '2024-07-10 19:16:43', '2024-07-10 19:16:43', NULL);
INSERT INTO `extra_user_datas` VALUES ('233', '88', '5', '0', '1', '2024-07-10 19:19:48', '2024-07-10 19:19:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('234', '90', '5', '0', '1', '2024-07-10 19:22:21', '2024-07-10 19:22:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('235', '92', '5', '0', '1', '2024-07-10 19:26:16', '2024-07-10 19:26:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('236', '94', '5', '1', '1', '2024-07-10 19:28:42', '2024-07-10 19:28:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('237', '96', '5', '0', '1', '2024-07-10 19:30:37', '2024-07-10 19:30:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('238', '98', '5', '1', '1', '2024-07-10 19:32:36', '2024-07-10 19:32:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('239', '100', '5', '0', '1', '2024-07-10 19:34:37', '2024-07-10 19:34:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('240', '102', '5', '0', '1', '2024-07-10 19:37:03', '2024-07-10 19:37:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('241', '104', '5', '1', '1', '2024-07-10 19:39:21', '2024-07-10 19:39:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('242', '105', '5', '1', '1', '2024-07-10 19:49:34', '2024-07-10 19:49:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('243', '107', '5', '1', '1', '2024-07-10 19:53:11', '2024-07-10 19:53:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('244', '109', '5', '0', '1', '2024-07-10 19:55:26', '2024-07-10 19:55:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('245', '111', '5', '0', '1', '2024-07-10 19:57:51', '2024-07-10 19:57:51', NULL);
INSERT INTO `extra_user_datas` VALUES ('246', '113', '5', '0', '1', '2024-07-10 19:59:53', '2024-07-10 19:59:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('247', '115', '5', '0', '1', '2024-07-10 20:02:20', '2024-07-10 20:02:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('248', '117', '5', '0', '1', '2024-07-10 20:04:17', '2024-07-10 20:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('249', '119', '5', '1', '1', '2024-07-10 20:06:12', '2024-07-10 20:06:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('250', '121', '5', '0', '1', '2024-07-10 20:08:02', '2024-07-10 20:08:02', NULL);
INSERT INTO `extra_user_datas` VALUES ('251', '123', '5', '0', '1', '2024-07-10 20:10:06', '2024-07-10 20:10:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('252', '125', '5', '1', '1', '2024-07-10 20:14:55', '2024-07-10 20:14:55', NULL);
INSERT INTO `extra_user_datas` VALUES ('253', '127', '5', '0', '1', '2024-07-10 20:17:17', '2024-07-10 20:17:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('254', '129', '5', '0', '1', '2024-07-10 20:19:04', '2024-07-10 20:19:04', NULL);
INSERT INTO `extra_user_datas` VALUES ('255', '131', '5', '0', '1', '2024-07-10 20:21:13', '2024-07-10 20:21:13', NULL);
INSERT INTO `extra_user_datas` VALUES ('256', '133', '5', '0', '1', '2024-07-10 20:23:29', '2024-07-10 20:23:29', NULL);
INSERT INTO `extra_user_datas` VALUES ('257', '135', '5', '0', '1', '2024-07-10 20:26:18', '2024-07-10 20:26:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('258', '137', '5', '0', '1', '2024-07-10 20:28:22', '2024-07-10 20:28:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('259', '139', '5', '1', '1', '2024-07-10 20:30:22', '2024-07-10 20:30:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('260', '141', '5', '0', '1', '2024-07-10 20:32:28', '2024-07-10 20:32:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('261', '143', '5', '0', '1', '2024-07-10 20:34:39', '2024-07-10 20:34:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('262', '145', '5', '0', '1', '2024-07-11 15:09:28', '2024-07-11 15:09:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('263', '147', '5', '0', '1', '2024-07-11 15:11:58', '2024-07-11 15:11:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('264', '149', '5', '1', '1', '2024-07-11 15:14:10', '2024-07-11 15:14:10', NULL);
INSERT INTO `extra_user_datas` VALUES ('265', '151', '5', '1', '1', '2024-07-11 15:16:03', '2024-07-11 15:16:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('266', '153', '5', '0', '1', '2024-07-11 15:19:36', '2024-07-11 15:19:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('267', '155', '5', '0', '1', '2024-07-11 15:23:36', '2024-07-11 15:23:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('268', '157', '5', '0', '1', '2024-07-11 15:28:58', '2024-07-11 15:28:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('269', '159', '5', '0', '1', '2024-07-11 15:31:34', '2024-07-11 15:31:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('270', '161', '5', '0', '1', '2024-07-11 15:35:49', '2024-07-11 15:35:49', NULL);
INSERT INTO `extra_user_datas` VALUES ('271', '163', '5', '0', '1', '2024-07-11 15:39:20', '2024-07-11 15:39:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('272', '165', '5', '0', '1', '2024-07-11 15:42:19', '2024-07-11 15:42:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('273', '167', '5', '0', '1', '2024-07-11 15:55:42', '2024-07-11 15:55:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('274', '169', '5', '0', '1', '2024-07-11 15:57:54', '2024-07-11 15:57:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('275', '171', '5', '0', '1', '2024-07-11 16:00:02', '2024-07-11 16:00:02', NULL);
INSERT INTO `extra_user_datas` VALUES ('276', '173', '5', '0', '1', '2024-07-11 16:02:06', '2024-07-11 16:02:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('277', '175', '5', '0', '1', '2024-07-11 16:05:01', '2024-07-11 16:05:01', NULL);
INSERT INTO `extra_user_datas` VALUES ('278', '177', '5', '0', '1', '2024-07-11 16:07:07', '2024-07-11 16:07:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('279', '179', '5', '1', '1', '2024-07-11 16:09:25', '2024-07-11 16:09:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('280', '181', '5', '0', '1', '2024-07-11 16:11:20', '2024-07-11 16:11:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('281', '183', '5', '0', '1', '2024-07-11 16:13:20', '2024-07-11 16:13:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('282', '184', '5', '0', '1', '2024-07-11 16:15:17', '2024-07-11 16:15:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('283', '186', '5', '0', '1', '2024-07-11 16:17:11', '2024-07-11 16:17:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('284', '188', '5', '0', '1', '2024-07-11 16:19:50', '2024-07-11 16:19:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('285', '190', '5', '0', '1', '2024-07-11 16:23:52', '2024-07-11 16:23:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('286', '192', '5', '0', '1', '2024-07-11 16:25:46', '2024-07-11 16:25:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('287', '194', '5', '0', '1', '2024-07-11 16:28:31', '2024-07-11 16:28:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('288', '196', '5', '0', '1', '2024-07-11 16:31:26', '2024-07-11 16:31:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('289', '198', '5', '1', '1', '2024-07-11 16:33:37', '2024-07-11 16:33:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('290', '200', '5', '0', '1', '2024-07-11 16:35:27', '2024-07-11 16:35:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('291', '202', '5', '0', '1', '2024-07-11 16:37:18', '2024-07-11 16:37:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('292', '204', '5', '0', '1', '2024-07-11 16:39:07', '2024-07-11 16:39:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('293', '206', '5', '0', '1', '2024-07-11 16:47:42', '2024-07-11 16:47:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('294', '208', '5', '0', '1', '2024-07-11 16:54:25', '2024-07-11 16:54:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('295', '210', '5', '0', '1', '2024-07-11 16:56:10', '2024-07-11 16:56:10', NULL);
INSERT INTO `extra_user_datas` VALUES ('296', '212', '5', '0', '1', '2024-07-11 16:57:53', '2024-07-11 16:57:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('297', '214', '5', '0', '1', '2024-07-11 16:59:37', '2024-07-11 16:59:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('298', '216', '5', '0', '1', '2024-07-11 17:01:18', '2024-07-11 17:01:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('299', '218', '5', '0', '1', '2024-07-11 17:03:03', '2024-07-11 17:03:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('300', '220', '5', '0', '1', '2024-07-11 17:04:41', '2024-07-11 17:04:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('301', '222', '5', '0', '1', '2024-07-11 17:06:32', '2024-07-11 17:06:32', NULL);
INSERT INTO `extra_user_datas` VALUES ('302', '223', '5', '0', '1', '2024-07-11 17:07:45', '2024-07-11 17:07:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('303', '225', '5', '0', '1', '2024-07-11 17:14:39', '2024-07-11 17:14:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('304', '227', '5', '0', '1', '2024-07-11 17:16:30', '2024-07-11 17:16:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('305', '229', '5', '0', '1', '2024-07-11 18:01:38', '2024-07-11 18:01:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('306', '231', '5', '0', '1', '2024-07-11 18:04:41', '2024-07-11 18:04:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('307', '233', '5', '1', '1', '2024-07-11 18:07:47', '2024-07-11 18:07:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('308', '235', '5', '1', '1', '2024-07-11 18:10:37', '2024-07-11 18:10:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('309', '237', '5', '1', '1', '2024-07-11 18:15:59', '2024-07-11 18:15:59', NULL);
INSERT INTO `extra_user_datas` VALUES ('310', '239', '5', '1', '1', '2024-07-11 18:18:28', '2024-07-11 18:18:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('311', '241', '5', '1', '1', '2024-07-11 18:20:27', '2024-07-11 18:20:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('312', '243', '5', '0', '1', '2024-07-11 18:22:16', '2024-07-11 18:22:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('313', '245', '5', '1', '1', '2024-07-11 18:24:09', '2024-07-11 18:24:09', NULL);
INSERT INTO `extra_user_datas` VALUES ('314', '246', '5', '1', '1', '2024-07-11 18:30:50', '2024-07-11 18:30:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('315', '248', '5', '1', '1', '2024-07-11 18:33:05', '2024-07-11 18:33:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('316', '250', '5', '1', '1', '2024-07-11 18:38:00', '2024-07-11 18:38:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('317', '252', '5', '1', '1', '2024-07-11 18:39:54', '2024-07-11 18:39:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('318', '254', '5', '0', '1', '2024-07-11 18:49:30', '2024-07-11 18:49:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('319', '256', '5', '0', '1', '2024-07-11 18:51:50', '2024-07-11 18:51:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('320', '258', '5', '0', '1', '2024-07-11 18:53:40', '2024-07-11 18:53:40', NULL);
INSERT INTO `extra_user_datas` VALUES ('321', '260', '5', '0', '1', '2024-07-11 18:55:27', '2024-07-11 18:55:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('322', '262', '5', '0', '1', '2024-07-11 18:57:39', '2024-07-11 18:57:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('323', '264', '5', '1', '1', '2024-07-11 18:59:31', '2024-07-11 18:59:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('324', '266', '5', '0', '1', '2024-07-11 19:02:46', '2024-07-11 19:02:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('325', '268', '5', '1', '1', '2024-07-11 19:04:46', '2024-07-11 19:04:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('326', '270', '5', '1', '1', '2024-07-11 19:06:42', '2024-07-11 19:06:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('327', '272', '5', '0', '1', '2024-07-11 19:08:25', '2024-07-11 19:08:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('328', '273', '5', '0', '1', '2024-07-11 19:09:37', '2024-07-11 19:09:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('329', '275', '5', '0', '1', '2024-07-11 19:13:14', '2024-07-11 19:13:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('330', '277', '5', '0', '1', '2024-07-11 19:14:46', '2024-07-11 19:14:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('331', '279', '5', '0', '1', '2024-07-11 19:16:21', '2024-07-11 19:16:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('332', '281', '5', '1', '1', '2024-07-11 19:18:08', '2024-07-11 19:18:08', NULL);
INSERT INTO `extra_user_datas` VALUES ('333', '283', '5', '0', '1', '2024-07-11 19:19:45', '2024-07-11 19:19:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('334', '285', '5', '0', '1', '2024-07-11 19:21:27', '2024-07-11 19:21:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('335', '287', '5', '0', '1', '2024-07-11 19:23:33', '2024-07-11 19:23:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('336', '289', '5', '0', '1', '2024-07-11 19:25:45', '2024-07-11 19:25:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('337', '291', '5', '1', '1', '2024-07-11 19:31:37', '2024-07-11 19:31:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('338', '293', '5', '0', '1', '2024-07-11 19:33:38', '2024-07-11 19:33:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('339', '295', '5', '0', '1', '2024-07-11 19:35:05', '2024-07-11 19:35:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('340', '297', '5', '1', '1', '2024-07-11 19:36:53', '2024-07-11 19:36:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('341', '299', '5', '1', '1', '2024-07-11 19:38:27', '2024-07-11 19:38:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('342', '301', '5', '0', '1', '2024-07-11 19:40:48', '2024-07-11 19:40:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('343', '303', '5', '0', '1', '2024-07-11 19:42:23', '2024-07-11 19:42:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('344', '305', '5', '1', '1', '2024-07-11 19:44:19', '2024-07-11 19:44:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('345', '307', '5', '0', '1', '2024-07-11 19:45:53', '2024-07-11 19:45:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('346', '309', '5', '0', '1', '2024-07-11 19:47:45', '2024-07-11 19:47:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('347', '311', '5', '0', '1', '2024-07-11 19:51:32', '2024-07-11 19:51:32', NULL);
INSERT INTO `extra_user_datas` VALUES ('348', '313', '5', '0', '1', '2024-07-11 19:53:27', '2024-07-11 19:53:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('349', '315', '5', '0', '1', '2024-07-11 19:56:06', '2024-07-11 19:56:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('350', '317', '5', '0', '1', '2024-07-11 19:57:57', '2024-07-11 19:57:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('351', '319', '5', '0', '1', '2024-07-11 20:00:06', '2024-07-11 20:00:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('352', '321', '5', '0', '1', '2024-07-11 20:01:45', '2024-07-11 20:01:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('353', '323', '5', '0', '1', '2024-07-11 20:03:38', '2024-07-11 20:03:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('354', '325', '5', '0', '1', '2024-07-11 20:06:42', '2024-07-11 20:06:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('355', '327', '5', '0', '1', '2024-07-11 20:08:40', '2024-07-11 20:08:40', NULL);
INSERT INTO `extra_user_datas` VALUES ('356', '329', '5', '0', '1', '2024-07-11 20:10:19', '2024-07-11 20:10:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('357', '331', '5', '0', '1', '2024-07-11 20:11:59', '2024-07-11 20:11:59', NULL);
INSERT INTO `extra_user_datas` VALUES ('358', '333', '5', '0', '1', '2024-07-11 20:13:33', '2024-07-11 20:13:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('359', '334', '5', '0', '1', '2024-07-11 20:15:00', '2024-07-11 20:15:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('360', '336', '5', '0', '1', '2024-07-11 20:17:16', '2024-07-11 20:17:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('361', '338', '5', '1', '1', '2024-07-11 20:19:12', '2024-07-11 20:19:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('362', '340', '5', '0', '1', '2024-07-11 20:21:12', '2024-07-11 20:21:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('363', '342', '5', '0', '1', '2024-07-11 20:22:54', '2024-07-11 20:22:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('364', '344', '5', '0', '1', '2024-07-11 20:24:38', '2024-07-11 20:24:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('365', '346', '5', '0', '1', '2024-07-11 20:26:14', '2024-07-11 20:26:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('366', '348', '5', '0', '1', '2024-07-11 20:27:51', '2024-07-11 20:27:51', NULL);
INSERT INTO `extra_user_datas` VALUES ('367', '349', '5', '0', '1', '2024-07-11 20:29:06', '2024-07-11 20:29:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('368', '351', '5', '0', '1', '2024-07-11 20:30:42', '2024-07-11 20:30:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('369', '353', '5', '0', '1', '2024-07-11 20:32:39', '2024-07-11 20:32:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('370', '355', '5', '0', '1', '2024-07-12 12:49:57', '2024-07-12 12:49:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('371', '356', '5', '0', '1', '2024-07-12 12:52:14', '2024-07-12 12:52:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('372', '358', '5', '0', '1', '2024-07-12 12:54:03', '2024-07-12 12:54:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('373', '360', '5', '0', '1', '2024-07-12 12:55:56', '2024-07-12 12:55:56', NULL);
INSERT INTO `extra_user_datas` VALUES ('374', '362', '5', '1', '1', '2024-07-12 12:57:35', '2024-07-12 12:57:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('375', '364', '5', '0', '1', '2024-07-12 13:01:19', '2024-07-12 13:01:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('376', '366', '5', '0', '1', '2024-07-12 13:03:18', '2024-07-12 13:03:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('377', '368', '5', '0', '1', '2024-07-12 13:07:52', '2024-07-12 13:07:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('378', '370', '5', '0', '1', '2024-07-12 13:14:05', '2024-07-12 13:14:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('379', '372', '5', '0', '1', '2024-07-12 13:17:33', '2024-07-12 13:17:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('380', '374', '5', '0', '1', '2024-07-12 13:20:47', '2024-07-12 13:20:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('381', '376', '5', '0', '1', '2024-07-12 13:23:48', '2024-07-12 13:23:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('382', '378', '5', '1', '1', '2024-07-12 13:25:37', '2024-07-12 13:25:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('383', '380', '5', '0', '1', '2024-07-12 13:27:52', '2024-07-12 13:27:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('384', '382', '5', '0', '1', '2024-07-19 07:05:47', '2024-07-19 07:05:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('385', '11', '5', '0', '1', '2024-07-10 16:29:08', '2024-07-10 16:29:08', NULL);
INSERT INTO `extra_user_datas` VALUES ('386', '13', '5', '0', '1', '2024-07-10 16:33:06', '2024-07-10 16:33:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('387', '15', '5', '0', '1', '2024-07-10 16:35:47', '2024-07-10 16:35:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('388', '17', '5', '0', '1', '2024-07-10 16:38:41', '2024-07-10 16:38:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('389', '19', '5', '0', '1', '2024-07-10 16:41:26', '2024-07-10 16:41:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('390', '21', '5', '1', '1', '2024-07-10 16:46:20', '2024-07-10 16:46:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('391', '23', '5', '1', '1', '2024-07-10 16:50:11', '2024-07-10 16:50:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('392', '25', '5', '1', '1', '2024-07-10 16:53:19', '2024-07-10 16:53:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('393', '27', '5', '0', '1', '2024-07-10 17:27:36', '2024-07-10 17:27:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('394', '29', '5', '0', '1', '2024-07-10 17:30:22', '2024-07-10 17:30:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('395', '31', '5', '1', '1', '2024-07-10 17:33:28', '2024-07-10 17:33:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('396', '33', '5', '1', '1', '2024-07-10 17:36:07', '2024-07-10 17:36:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('397', '35', '5', '0', '1', '2024-07-10 17:38:39', '2024-07-10 17:38:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('398', '37', '5', '0', '1', '2024-07-10 17:42:25', '2024-07-10 17:42:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('399', '38', '5', '0', '1', '2024-07-10 17:45:05', '2024-07-10 17:45:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('400', '40', '5', '0', '1', '2024-07-10 17:47:46', '2024-07-10 17:47:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('401', '42', '5', '0', '1', '2024-07-10 17:51:24', '2024-07-10 17:51:24', NULL);
INSERT INTO `extra_user_datas` VALUES ('402', '44', '5', '0', '1', '2024-07-10 17:54:33', '2024-07-10 17:54:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('403', '46', '5', '0', '1', '2024-07-10 17:57:17', '2024-07-10 17:57:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('404', '48', '5', '0', '1', '2024-07-10 17:59:58', '2024-07-10 17:59:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('405', '50', '5', '0', '1', '2024-07-10 18:03:37', '2024-07-10 18:03:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('406', '52', '5', '0', '1', '2024-07-10 18:06:17', '2024-07-10 18:06:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('407', '54', '5', '0', '1', '2024-07-10 18:09:16', '2024-07-10 18:09:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('408', '56', '5', '0', '1', '2024-07-10 18:12:23', '2024-07-10 18:12:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('409', '58', '5', '0', '1', '2024-07-10 18:15:41', '2024-07-10 18:15:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('410', '60', '5', '0', '1', '2024-07-10 18:18:29', '2024-07-10 18:18:29', NULL);
INSERT INTO `extra_user_datas` VALUES ('411', '62', '5', '0', '1', '2024-07-10 18:26:35', '2024-07-10 18:26:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('412', '64', '5', '1', '1', '2024-07-10 18:29:56', '2024-07-10 18:29:56', NULL);
INSERT INTO `extra_user_datas` VALUES ('413', '66', '5', '0', '1', '2024-07-10 18:33:09', '2024-07-10 18:33:09', NULL);
INSERT INTO `extra_user_datas` VALUES ('414', '68', '5', '0', '1', '2024-07-10 18:38:06', '2024-07-10 18:38:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('415', '69', '5', '0', '1', '2024-07-10 18:41:04', '2024-07-10 18:41:04', NULL);
INSERT INTO `extra_user_datas` VALUES ('416', '70', '5', '0', '1', '2024-07-10 18:43:45', '2024-07-10 18:43:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('417', '72', '5', '0', '1', '2024-07-10 18:46:48', '2024-07-10 18:46:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('418', '74', '5', '1', '1', '2024-07-10 18:49:11', '2024-07-10 18:49:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('419', '76', '5', '0', '1', '2024-07-10 18:51:35', '2024-07-10 18:51:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('420', '78', '5', '0', '1', '2024-07-10 18:55:11', '2024-07-10 18:55:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('421', '80', '5', '0', '1', '2024-07-10 18:57:22', '2024-07-10 18:57:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('422', '82', '5', '0', '1', '2024-07-10 18:59:34', '2024-07-10 18:59:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('423', '84', '5', '0', '1', '2024-07-10 19:14:31', '2024-07-10 19:14:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('424', '86', '5', '0', '1', '2024-07-10 19:16:43', '2024-07-10 19:16:43', NULL);
INSERT INTO `extra_user_datas` VALUES ('425', '88', '5', '0', '1', '2024-07-10 19:19:48', '2024-07-10 19:19:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('426', '90', '5', '0', '1', '2024-07-10 19:22:21', '2024-07-10 19:22:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('427', '92', '5', '0', '1', '2024-07-10 19:26:16', '2024-07-10 19:26:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('428', '94', '5', '1', '1', '2024-07-10 19:28:42', '2024-07-10 19:28:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('429', '96', '5', '0', '1', '2024-07-10 19:30:37', '2024-07-10 19:30:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('430', '98', '5', '1', '1', '2024-07-10 19:32:36', '2024-07-10 19:32:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('431', '100', '5', '0', '1', '2024-07-10 19:34:37', '2024-07-10 19:34:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('432', '102', '5', '0', '1', '2024-07-10 19:37:03', '2024-07-10 19:37:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('433', '104', '5', '1', '1', '2024-07-10 19:39:21', '2024-07-10 19:39:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('434', '105', '5', '1', '1', '2024-07-10 19:49:34', '2024-07-10 19:49:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('435', '107', '5', '1', '1', '2024-07-10 19:53:11', '2024-07-10 19:53:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('436', '109', '5', '0', '1', '2024-07-10 19:55:26', '2024-07-10 19:55:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('437', '111', '5', '0', '1', '2024-07-10 19:57:51', '2024-07-10 19:57:51', NULL);
INSERT INTO `extra_user_datas` VALUES ('438', '113', '5', '0', '1', '2024-07-10 19:59:53', '2024-07-10 19:59:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('439', '115', '5', '0', '1', '2024-07-10 20:02:20', '2024-07-10 20:02:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('440', '117', '5', '0', '1', '2024-07-10 20:04:17', '2024-07-10 20:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('441', '119', '5', '1', '1', '2024-07-10 20:06:12', '2024-07-10 20:06:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('442', '121', '5', '0', '1', '2024-07-10 20:08:02', '2024-07-10 20:08:02', NULL);
INSERT INTO `extra_user_datas` VALUES ('443', '123', '5', '0', '1', '2024-07-10 20:10:06', '2024-07-10 20:10:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('444', '125', '5', '1', '1', '2024-07-10 20:14:55', '2024-07-10 20:14:55', NULL);
INSERT INTO `extra_user_datas` VALUES ('445', '127', '5', '0', '1', '2024-07-10 20:17:17', '2024-07-10 20:17:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('446', '129', '5', '0', '1', '2024-07-10 20:19:04', '2024-07-10 20:19:04', NULL);
INSERT INTO `extra_user_datas` VALUES ('447', '131', '5', '0', '1', '2024-07-10 20:21:13', '2024-07-10 20:21:13', NULL);
INSERT INTO `extra_user_datas` VALUES ('448', '133', '5', '0', '1', '2024-07-10 20:23:29', '2024-07-10 20:23:29', NULL);
INSERT INTO `extra_user_datas` VALUES ('449', '135', '5', '0', '1', '2024-07-10 20:26:18', '2024-07-10 20:26:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('450', '137', '5', '0', '1', '2024-07-10 20:28:22', '2024-07-10 20:28:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('451', '139', '5', '1', '1', '2024-07-10 20:30:22', '2024-07-10 20:30:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('452', '141', '5', '0', '1', '2024-07-10 20:32:28', '2024-07-10 20:32:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('453', '143', '5', '0', '1', '2024-07-10 20:34:39', '2024-07-10 20:34:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('454', '145', '5', '0', '1', '2024-07-11 15:09:28', '2024-07-11 15:09:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('455', '147', '5', '0', '1', '2024-07-11 15:11:58', '2024-07-11 15:11:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('456', '149', '5', '1', '1', '2024-07-11 15:14:10', '2024-07-11 15:14:10', NULL);
INSERT INTO `extra_user_datas` VALUES ('457', '151', '5', '1', '1', '2024-07-11 15:16:03', '2024-07-11 15:16:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('458', '153', '5', '0', '1', '2024-07-11 15:19:36', '2024-07-11 15:19:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('459', '155', '5', '0', '1', '2024-07-11 15:23:36', '2024-07-11 15:23:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('460', '157', '5', '0', '1', '2024-07-11 15:28:58', '2024-07-11 15:28:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('461', '159', '5', '0', '1', '2024-07-11 15:31:34', '2024-07-11 15:31:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('462', '161', '5', '0', '1', '2024-07-11 15:35:49', '2024-07-11 15:35:49', NULL);
INSERT INTO `extra_user_datas` VALUES ('463', '163', '5', '0', '1', '2024-07-11 15:39:20', '2024-07-11 15:39:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('464', '165', '5', '0', '1', '2024-07-11 15:42:19', '2024-07-11 15:42:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('465', '167', '5', '0', '1', '2024-07-11 15:55:42', '2024-07-11 15:55:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('466', '169', '5', '0', '1', '2024-07-11 15:57:54', '2024-07-11 15:57:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('467', '171', '5', '0', '1', '2024-07-11 16:00:02', '2024-07-11 16:00:02', NULL);
INSERT INTO `extra_user_datas` VALUES ('468', '173', '5', '0', '1', '2024-07-11 16:02:06', '2024-07-11 16:02:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('469', '175', '5', '0', '1', '2024-07-11 16:05:01', '2024-07-11 16:05:01', NULL);
INSERT INTO `extra_user_datas` VALUES ('470', '177', '5', '0', '1', '2024-07-11 16:07:07', '2024-07-11 16:07:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('471', '179', '5', '1', '1', '2024-07-11 16:09:25', '2024-07-11 16:09:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('472', '181', '5', '0', '1', '2024-07-11 16:11:20', '2024-07-11 16:11:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('473', '183', '5', '0', '1', '2024-07-11 16:13:20', '2024-07-11 16:13:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('474', '184', '5', '0', '1', '2024-07-11 16:15:17', '2024-07-11 16:15:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('475', '186', '5', '0', '1', '2024-07-11 16:17:11', '2024-07-11 16:17:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('476', '188', '5', '0', '1', '2024-07-11 16:19:50', '2024-07-11 16:19:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('477', '190', '5', '0', '1', '2024-07-11 16:23:52', '2024-07-11 16:23:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('478', '192', '5', '0', '1', '2024-07-11 16:25:46', '2024-07-11 16:25:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('479', '194', '5', '0', '1', '2024-07-11 16:28:31', '2024-07-11 16:28:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('480', '196', '5', '0', '1', '2024-07-11 16:31:26', '2024-07-11 16:31:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('481', '198', '5', '1', '1', '2024-07-11 16:33:37', '2024-07-11 16:33:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('482', '200', '5', '0', '1', '2024-07-11 16:35:27', '2024-07-11 16:35:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('483', '202', '5', '0', '1', '2024-07-11 16:37:18', '2024-07-11 16:37:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('484', '204', '5', '0', '1', '2024-07-11 16:39:07', '2024-07-11 16:39:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('485', '206', '5', '0', '1', '2024-07-11 16:47:42', '2024-07-11 16:47:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('486', '208', '5', '0', '1', '2024-07-11 16:54:25', '2024-07-11 16:54:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('487', '210', '5', '0', '1', '2024-07-11 16:56:10', '2024-07-11 16:56:10', NULL);
INSERT INTO `extra_user_datas` VALUES ('488', '212', '5', '0', '1', '2024-07-11 16:57:53', '2024-07-11 16:57:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('489', '214', '5', '0', '1', '2024-07-11 16:59:37', '2024-07-11 16:59:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('490', '216', '5', '0', '1', '2024-07-11 17:01:18', '2024-07-11 17:01:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('491', '218', '5', '0', '1', '2024-07-11 17:03:03', '2024-07-11 17:03:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('492', '220', '5', '0', '1', '2024-07-11 17:04:41', '2024-07-11 17:04:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('493', '222', '5', '0', '1', '2024-07-11 17:06:32', '2024-07-11 17:06:32', NULL);
INSERT INTO `extra_user_datas` VALUES ('494', '223', '5', '0', '1', '2024-07-11 17:07:45', '2024-07-11 17:07:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('495', '225', '5', '0', '1', '2024-07-11 17:14:39', '2024-07-11 17:14:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('496', '227', '5', '0', '1', '2024-07-11 17:16:30', '2024-07-11 17:16:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('497', '229', '5', '0', '1', '2024-07-11 18:01:38', '2024-07-11 18:01:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('498', '231', '5', '0', '1', '2024-07-11 18:04:41', '2024-07-11 18:04:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('499', '233', '5', '1', '1', '2024-07-11 18:07:47', '2024-07-11 18:07:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('500', '235', '5', '1', '1', '2024-07-11 18:10:37', '2024-07-11 18:10:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('501', '237', '5', '1', '1', '2024-07-11 18:15:59', '2024-07-11 18:15:59', NULL);
INSERT INTO `extra_user_datas` VALUES ('502', '239', '5', '1', '1', '2024-07-11 18:18:28', '2024-07-11 18:18:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('503', '241', '5', '1', '1', '2024-07-11 18:20:27', '2024-07-11 18:20:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('504', '243', '5', '0', '1', '2024-07-11 18:22:16', '2024-07-11 18:22:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('505', '245', '5', '1', '1', '2024-07-11 18:24:09', '2024-07-11 18:24:09', NULL);
INSERT INTO `extra_user_datas` VALUES ('506', '246', '5', '1', '1', '2024-07-11 18:30:50', '2024-07-11 18:30:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('507', '248', '5', '1', '1', '2024-07-11 18:33:05', '2024-07-11 18:33:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('508', '250', '5', '1', '1', '2024-07-11 18:38:00', '2024-07-11 18:38:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('509', '252', '5', '1', '1', '2024-07-11 18:39:54', '2024-07-11 18:39:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('510', '254', '5', '0', '1', '2024-07-11 18:49:30', '2024-07-11 18:49:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('511', '256', '5', '0', '1', '2024-07-11 18:51:50', '2024-07-11 18:51:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('512', '258', '5', '0', '1', '2024-07-11 18:53:40', '2024-07-11 18:53:40', NULL);
INSERT INTO `extra_user_datas` VALUES ('513', '260', '5', '0', '1', '2024-07-11 18:55:27', '2024-07-11 18:55:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('514', '262', '5', '0', '1', '2024-07-11 18:57:39', '2024-07-11 18:57:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('515', '264', '5', '1', '1', '2024-07-11 18:59:31', '2024-07-11 18:59:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('516', '266', '5', '0', '1', '2024-07-11 19:02:46', '2024-07-11 19:02:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('517', '268', '5', '1', '1', '2024-07-11 19:04:46', '2024-07-11 19:04:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('518', '270', '5', '1', '1', '2024-07-11 19:06:42', '2024-07-11 19:06:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('519', '272', '5', '0', '1', '2024-07-11 19:08:25', '2024-07-11 19:08:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('520', '273', '5', '0', '1', '2024-07-11 19:09:37', '2024-07-11 19:09:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('521', '275', '5', '0', '1', '2024-07-11 19:13:14', '2024-07-11 19:13:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('522', '277', '5', '0', '1', '2024-07-11 19:14:46', '2024-07-11 19:14:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('523', '279', '5', '0', '1', '2024-07-11 19:16:21', '2024-07-11 19:16:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('524', '281', '5', '1', '1', '2024-07-11 19:18:08', '2024-07-11 19:18:08', NULL);
INSERT INTO `extra_user_datas` VALUES ('525', '283', '5', '0', '1', '2024-07-11 19:19:45', '2024-07-11 19:19:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('526', '285', '5', '0', '1', '2024-07-11 19:21:27', '2024-07-11 19:21:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('527', '287', '5', '0', '1', '2024-07-11 19:23:33', '2024-07-11 19:23:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('528', '289', '5', '0', '1', '2024-07-11 19:25:45', '2024-07-11 19:25:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('529', '291', '5', '1', '1', '2024-07-11 19:31:37', '2024-07-11 19:31:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('530', '293', '5', '0', '1', '2024-07-11 19:33:38', '2024-07-11 19:33:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('531', '295', '5', '0', '1', '2024-07-11 19:35:05', '2024-07-11 19:35:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('532', '297', '5', '1', '1', '2024-07-11 19:36:53', '2024-07-11 19:36:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('533', '299', '5', '1', '1', '2024-07-11 19:38:27', '2024-07-11 19:38:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('534', '301', '5', '0', '1', '2024-07-11 19:40:48', '2024-07-11 19:40:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('535', '303', '5', '0', '1', '2024-07-11 19:42:23', '2024-07-11 19:42:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('536', '305', '5', '1', '1', '2024-07-11 19:44:19', '2024-07-11 19:44:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('537', '307', '5', '0', '1', '2024-07-11 19:45:53', '2024-07-11 19:45:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('538', '309', '5', '0', '1', '2024-07-11 19:47:45', '2024-07-11 19:47:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('539', '311', '5', '0', '1', '2024-07-11 19:51:32', '2024-07-11 19:51:32', NULL);
INSERT INTO `extra_user_datas` VALUES ('540', '313', '5', '0', '1', '2024-07-11 19:53:27', '2024-07-11 19:53:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('541', '315', '5', '0', '1', '2024-07-11 19:56:06', '2024-07-11 19:56:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('542', '317', '5', '0', '1', '2024-07-11 19:57:57', '2024-07-11 19:57:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('543', '319', '5', '0', '1', '2024-07-11 20:00:06', '2024-07-11 20:00:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('544', '321', '5', '0', '1', '2024-07-11 20:01:45', '2024-07-11 20:01:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('545', '323', '5', '0', '1', '2024-07-11 20:03:38', '2024-07-11 20:03:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('546', '325', '5', '0', '1', '2024-07-11 20:06:42', '2024-07-11 20:06:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('547', '327', '5', '0', '1', '2024-07-11 20:08:40', '2024-07-11 20:08:40', NULL);
INSERT INTO `extra_user_datas` VALUES ('548', '329', '5', '0', '1', '2024-07-11 20:10:19', '2024-07-11 20:10:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('549', '331', '5', '0', '1', '2024-07-11 20:11:59', '2024-07-11 20:11:59', NULL);
INSERT INTO `extra_user_datas` VALUES ('550', '333', '5', '0', '1', '2024-07-11 20:13:33', '2024-07-11 20:13:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('551', '334', '5', '0', '1', '2024-07-11 20:15:00', '2024-07-11 20:15:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('552', '336', '5', '0', '1', '2024-07-11 20:17:16', '2024-07-11 20:17:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('553', '338', '5', '1', '1', '2024-07-11 20:19:12', '2024-07-11 20:19:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('554', '340', '5', '0', '1', '2024-07-11 20:21:12', '2024-07-11 20:21:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('555', '342', '5', '0', '1', '2024-07-11 20:22:54', '2024-07-11 20:22:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('556', '344', '5', '0', '1', '2024-07-11 20:24:38', '2024-07-11 20:24:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('557', '346', '5', '0', '1', '2024-07-11 20:26:14', '2024-07-11 20:26:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('558', '348', '5', '0', '1', '2024-07-11 20:27:51', '2024-07-11 20:27:51', NULL);
INSERT INTO `extra_user_datas` VALUES ('559', '349', '5', '0', '1', '2024-07-11 20:29:06', '2024-07-11 20:29:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('560', '351', '5', '0', '1', '2024-07-11 20:30:42', '2024-07-11 20:30:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('561', '353', '5', '0', '1', '2024-07-11 20:32:39', '2024-07-11 20:32:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('562', '355', '5', '0', '1', '2024-07-12 12:49:57', '2024-07-12 12:49:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('563', '356', '5', '0', '1', '2024-07-12 12:52:14', '2024-07-12 12:52:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('564', '358', '5', '0', '1', '2024-07-12 12:54:03', '2024-07-12 12:54:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('565', '360', '5', '0', '1', '2024-07-12 12:55:56', '2024-07-12 12:55:56', NULL);
INSERT INTO `extra_user_datas` VALUES ('566', '362', '5', '1', '1', '2024-07-12 12:57:35', '2024-07-12 12:57:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('567', '364', '5', '0', '1', '2024-07-12 13:01:19', '2024-07-12 13:01:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('568', '366', '5', '0', '1', '2024-07-12 13:03:18', '2024-07-12 13:03:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('569', '368', '5', '0', '1', '2024-07-12 13:07:52', '2024-07-12 13:07:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('570', '370', '5', '0', '1', '2024-07-12 13:14:05', '2024-07-12 13:14:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('571', '372', '5', '0', '1', '2024-07-12 13:17:33', '2024-07-12 13:17:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('572', '374', '5', '0', '1', '2024-07-12 13:20:47', '2024-07-12 13:20:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('573', '376', '5', '0', '1', '2024-07-12 13:23:48', '2024-07-12 13:23:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('574', '378', '5', '1', '1', '2024-07-12 13:25:37', '2024-07-12 13:25:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('575', '380', '5', '0', '1', '2024-07-12 13:27:52', '2024-07-12 13:27:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('576', '382', '5', '0', '1', '2024-07-19 07:05:47', '2024-07-19 07:05:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('577', '11', '5', '0', '1', '2024-07-10 16:29:08', '2024-07-10 16:29:08', NULL);
INSERT INTO `extra_user_datas` VALUES ('578', '13', '5', '0', '1', '2024-07-10 16:33:06', '2024-07-10 16:33:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('579', '15', '5', '0', '1', '2024-07-10 16:35:47', '2024-07-10 16:35:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('580', '17', '5', '0', '1', '2024-07-10 16:38:41', '2024-07-10 16:38:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('581', '19', '5', '0', '1', '2024-07-10 16:41:26', '2024-07-10 16:41:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('582', '21', '5', '1', '1', '2024-07-10 16:46:20', '2024-07-10 16:46:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('583', '23', '5', '1', '1', '2024-07-10 16:50:11', '2024-07-10 16:50:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('584', '25', '5', '1', '1', '2024-07-10 16:53:19', '2024-07-10 16:53:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('585', '27', '5', '0', '1', '2024-07-10 17:27:36', '2024-07-10 17:27:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('586', '29', '5', '0', '1', '2024-07-10 17:30:22', '2024-07-10 17:30:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('587', '31', '5', '1', '1', '2024-07-10 17:33:28', '2024-07-10 17:33:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('588', '33', '5', '1', '1', '2024-07-10 17:36:07', '2024-07-10 17:36:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('589', '35', '5', '0', '1', '2024-07-10 17:38:39', '2024-07-10 17:38:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('590', '37', '5', '0', '1', '2024-07-10 17:42:25', '2024-07-10 17:42:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('591', '38', '5', '0', '1', '2024-07-10 17:45:05', '2024-07-10 17:45:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('592', '40', '5', '0', '1', '2024-07-10 17:47:46', '2024-07-10 17:47:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('593', '42', '5', '0', '1', '2024-07-10 17:51:24', '2024-07-10 17:51:24', NULL);
INSERT INTO `extra_user_datas` VALUES ('594', '44', '5', '0', '1', '2024-07-10 17:54:33', '2024-07-10 17:54:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('595', '46', '5', '0', '1', '2024-07-10 17:57:17', '2024-07-10 17:57:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('596', '48', '5', '0', '1', '2024-07-10 17:59:58', '2024-07-10 17:59:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('597', '50', '5', '0', '1', '2024-07-10 18:03:37', '2024-07-10 18:03:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('598', '52', '5', '0', '1', '2024-07-10 18:06:17', '2024-07-10 18:06:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('599', '54', '5', '0', '1', '2024-07-10 18:09:16', '2024-07-10 18:09:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('600', '56', '5', '0', '1', '2024-07-10 18:12:23', '2024-07-10 18:12:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('601', '58', '5', '0', '1', '2024-07-10 18:15:41', '2024-07-10 18:15:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('602', '60', '5', '0', '1', '2024-07-10 18:18:29', '2024-07-10 18:18:29', NULL);
INSERT INTO `extra_user_datas` VALUES ('603', '62', '5', '0', '1', '2024-07-10 18:26:35', '2024-07-10 18:26:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('604', '64', '5', '1', '1', '2024-07-10 18:29:56', '2024-07-10 18:29:56', NULL);
INSERT INTO `extra_user_datas` VALUES ('605', '66', '5', '0', '1', '2024-07-10 18:33:09', '2024-07-10 18:33:09', NULL);
INSERT INTO `extra_user_datas` VALUES ('606', '68', '5', '0', '1', '2024-07-10 18:38:06', '2024-07-10 18:38:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('607', '69', '5', '0', '1', '2024-07-10 18:41:04', '2024-07-10 18:41:04', NULL);
INSERT INTO `extra_user_datas` VALUES ('608', '70', '5', '0', '1', '2024-07-10 18:43:45', '2024-07-10 18:43:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('609', '72', '5', '0', '1', '2024-07-10 18:46:48', '2024-07-10 18:46:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('610', '74', '5', '1', '1', '2024-07-10 18:49:11', '2024-07-10 18:49:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('611', '76', '5', '0', '1', '2024-07-10 18:51:35', '2024-07-10 18:51:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('612', '78', '5', '0', '1', '2024-07-10 18:55:11', '2024-07-10 18:55:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('613', '80', '5', '0', '1', '2024-07-10 18:57:22', '2024-07-10 18:57:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('614', '82', '5', '0', '1', '2024-07-10 18:59:34', '2024-07-10 18:59:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('615', '84', '5', '0', '1', '2024-07-10 19:14:31', '2024-07-10 19:14:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('616', '86', '5', '0', '1', '2024-07-10 19:16:43', '2024-07-10 19:16:43', NULL);
INSERT INTO `extra_user_datas` VALUES ('617', '88', '5', '0', '1', '2024-07-10 19:19:48', '2024-07-10 19:19:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('618', '90', '5', '0', '1', '2024-07-10 19:22:21', '2024-07-10 19:22:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('619', '92', '5', '0', '1', '2024-07-10 19:26:16', '2024-07-10 19:26:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('620', '94', '5', '1', '1', '2024-07-10 19:28:42', '2024-07-10 19:28:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('621', '96', '5', '0', '1', '2024-07-10 19:30:37', '2024-07-10 19:30:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('622', '98', '5', '1', '1', '2024-07-10 19:32:36', '2024-07-10 19:32:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('623', '100', '5', '0', '1', '2024-07-10 19:34:37', '2024-07-10 19:34:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('624', '102', '5', '0', '1', '2024-07-10 19:37:03', '2024-07-10 19:37:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('625', '104', '5', '1', '1', '2024-07-10 19:39:21', '2024-07-10 19:39:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('626', '105', '5', '1', '1', '2024-07-10 19:49:34', '2024-07-10 19:49:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('627', '107', '5', '1', '1', '2024-07-10 19:53:11', '2024-07-10 19:53:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('628', '109', '5', '0', '1', '2024-07-10 19:55:26', '2024-07-10 19:55:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('629', '111', '5', '0', '1', '2024-07-10 19:57:51', '2024-07-10 19:57:51', NULL);
INSERT INTO `extra_user_datas` VALUES ('630', '113', '5', '0', '1', '2024-07-10 19:59:53', '2024-07-10 19:59:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('631', '115', '5', '0', '1', '2024-07-10 20:02:20', '2024-07-10 20:02:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('632', '117', '5', '0', '1', '2024-07-10 20:04:17', '2024-07-10 20:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('633', '119', '5', '1', '1', '2024-07-10 20:06:12', '2024-07-10 20:06:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('634', '121', '5', '0', '1', '2024-07-10 20:08:02', '2024-07-10 20:08:02', NULL);
INSERT INTO `extra_user_datas` VALUES ('635', '123', '5', '0', '1', '2024-07-10 20:10:06', '2024-07-10 20:10:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('636', '125', '5', '1', '1', '2024-07-10 20:14:55', '2024-07-10 20:14:55', NULL);
INSERT INTO `extra_user_datas` VALUES ('637', '127', '5', '0', '1', '2024-07-10 20:17:17', '2024-07-10 20:17:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('638', '129', '5', '0', '1', '2024-07-10 20:19:04', '2024-07-10 20:19:04', NULL);
INSERT INTO `extra_user_datas` VALUES ('639', '131', '5', '0', '1', '2024-07-10 20:21:13', '2024-07-10 20:21:13', NULL);
INSERT INTO `extra_user_datas` VALUES ('640', '133', '5', '0', '1', '2024-07-10 20:23:29', '2024-07-10 20:23:29', NULL);
INSERT INTO `extra_user_datas` VALUES ('641', '135', '5', '0', '1', '2024-07-10 20:26:18', '2024-07-10 20:26:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('642', '137', '5', '0', '1', '2024-07-10 20:28:22', '2024-07-10 20:28:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('643', '139', '5', '1', '1', '2024-07-10 20:30:22', '2024-07-10 20:30:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('644', '141', '5', '0', '1', '2024-07-10 20:32:28', '2024-07-10 20:32:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('645', '143', '5', '0', '1', '2024-07-10 20:34:39', '2024-07-10 20:34:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('646', '145', '5', '0', '1', '2024-07-11 15:09:28', '2024-07-11 15:09:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('647', '147', '5', '0', '1', '2024-07-11 15:11:58', '2024-07-11 15:11:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('648', '149', '5', '1', '1', '2024-07-11 15:14:10', '2024-07-11 15:14:10', NULL);
INSERT INTO `extra_user_datas` VALUES ('649', '151', '5', '1', '1', '2024-07-11 15:16:03', '2024-07-11 15:16:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('650', '153', '5', '0', '1', '2024-07-11 15:19:36', '2024-07-11 15:19:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('651', '155', '5', '0', '1', '2024-07-11 15:23:36', '2024-07-11 15:23:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('652', '157', '5', '0', '1', '2024-07-11 15:28:58', '2024-07-11 15:28:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('653', '159', '5', '0', '1', '2024-07-11 15:31:34', '2024-07-11 15:31:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('654', '161', '5', '0', '1', '2024-07-11 15:35:49', '2024-07-11 15:35:49', NULL);
INSERT INTO `extra_user_datas` VALUES ('655', '163', '5', '0', '1', '2024-07-11 15:39:20', '2024-07-11 15:39:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('656', '165', '5', '0', '1', '2024-07-11 15:42:19', '2024-07-11 15:42:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('657', '167', '5', '0', '1', '2024-07-11 15:55:42', '2024-07-11 15:55:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('658', '169', '5', '0', '1', '2024-07-11 15:57:54', '2024-07-11 15:57:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('659', '171', '5', '0', '1', '2024-07-11 16:00:02', '2024-07-11 16:00:02', NULL);
INSERT INTO `extra_user_datas` VALUES ('660', '173', '5', '0', '1', '2024-07-11 16:02:06', '2024-07-11 16:02:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('661', '175', '5', '0', '1', '2024-07-11 16:05:01', '2024-07-11 16:05:01', NULL);
INSERT INTO `extra_user_datas` VALUES ('662', '177', '5', '0', '1', '2024-07-11 16:07:07', '2024-07-11 16:07:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('663', '179', '5', '1', '1', '2024-07-11 16:09:25', '2024-07-11 16:09:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('664', '181', '5', '0', '1', '2024-07-11 16:11:20', '2024-07-11 16:11:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('665', '183', '5', '0', '1', '2024-07-11 16:13:20', '2024-07-11 16:13:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('666', '184', '5', '0', '1', '2024-07-11 16:15:17', '2024-07-11 16:15:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('667', '186', '5', '0', '1', '2024-07-11 16:17:11', '2024-07-11 16:17:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('668', '188', '5', '0', '1', '2024-07-11 16:19:50', '2024-07-11 16:19:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('669', '190', '5', '0', '1', '2024-07-11 16:23:52', '2024-07-11 16:23:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('670', '192', '5', '0', '1', '2024-07-11 16:25:46', '2024-07-11 16:25:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('671', '194', '5', '0', '1', '2024-07-11 16:28:31', '2024-07-11 16:28:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('672', '196', '5', '0', '1', '2024-07-11 16:31:26', '2024-07-11 16:31:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('673', '198', '5', '1', '1', '2024-07-11 16:33:37', '2024-07-11 16:33:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('674', '200', '5', '0', '1', '2024-07-11 16:35:27', '2024-07-11 16:35:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('675', '202', '5', '0', '1', '2024-07-11 16:37:18', '2024-07-11 16:37:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('676', '204', '5', '0', '1', '2024-07-11 16:39:07', '2024-07-11 16:39:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('677', '206', '5', '0', '1', '2024-07-11 16:47:42', '2024-07-11 16:47:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('678', '208', '5', '0', '1', '2024-07-11 16:54:25', '2024-07-11 16:54:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('679', '210', '5', '0', '1', '2024-07-11 16:56:10', '2024-07-11 16:56:10', NULL);
INSERT INTO `extra_user_datas` VALUES ('680', '212', '5', '0', '1', '2024-07-11 16:57:53', '2024-07-11 16:57:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('681', '214', '5', '0', '1', '2024-07-11 16:59:37', '2024-07-11 16:59:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('682', '216', '5', '0', '1', '2024-07-11 17:01:18', '2024-07-11 17:01:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('683', '218', '5', '0', '1', '2024-07-11 17:03:03', '2024-07-11 17:03:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('684', '220', '5', '0', '1', '2024-07-11 17:04:41', '2024-07-11 17:04:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('685', '222', '5', '0', '1', '2024-07-11 17:06:32', '2024-07-11 17:06:32', NULL);
INSERT INTO `extra_user_datas` VALUES ('686', '223', '5', '0', '1', '2024-07-11 17:07:45', '2024-07-11 17:07:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('687', '225', '5', '0', '1', '2024-07-11 17:14:39', '2024-07-11 17:14:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('688', '227', '5', '0', '1', '2024-07-11 17:16:30', '2024-07-11 17:16:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('689', '229', '5', '0', '1', '2024-07-11 18:01:38', '2024-07-11 18:01:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('690', '231', '5', '0', '1', '2024-07-11 18:04:41', '2024-07-11 18:04:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('691', '233', '5', '1', '1', '2024-07-11 18:07:47', '2024-07-11 18:07:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('692', '235', '5', '1', '1', '2024-07-11 18:10:37', '2024-07-11 18:10:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('693', '237', '5', '1', '1', '2024-07-11 18:15:59', '2024-07-11 18:15:59', NULL);
INSERT INTO `extra_user_datas` VALUES ('694', '239', '5', '1', '1', '2024-07-11 18:18:28', '2024-07-11 18:18:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('695', '241', '5', '1', '1', '2024-07-11 18:20:27', '2024-07-11 18:20:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('696', '243', '5', '0', '1', '2024-07-11 18:22:16', '2024-07-11 18:22:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('697', '245', '5', '1', '1', '2024-07-11 18:24:09', '2024-07-11 18:24:09', NULL);
INSERT INTO `extra_user_datas` VALUES ('698', '246', '5', '1', '1', '2024-07-11 18:30:50', '2024-07-11 18:30:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('699', '248', '5', '1', '1', '2024-07-11 18:33:05', '2024-07-11 18:33:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('700', '250', '5', '1', '1', '2024-07-11 18:38:00', '2024-07-11 18:38:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('701', '252', '5', '1', '1', '2024-07-11 18:39:54', '2024-07-11 18:39:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('702', '254', '5', '0', '1', '2024-07-11 18:49:30', '2024-07-11 18:49:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('703', '256', '5', '0', '1', '2024-07-11 18:51:50', '2024-07-11 18:51:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('704', '258', '5', '0', '1', '2024-07-11 18:53:40', '2024-07-11 18:53:40', NULL);
INSERT INTO `extra_user_datas` VALUES ('705', '260', '5', '0', '1', '2024-07-11 18:55:27', '2024-07-11 18:55:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('706', '262', '5', '0', '1', '2024-07-11 18:57:39', '2024-07-11 18:57:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('707', '264', '5', '1', '1', '2024-07-11 18:59:31', '2024-07-11 18:59:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('708', '266', '5', '0', '1', '2024-07-11 19:02:46', '2024-07-11 19:02:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('709', '268', '5', '1', '1', '2024-07-11 19:04:46', '2024-07-11 19:04:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('710', '270', '5', '1', '1', '2024-07-11 19:06:42', '2024-07-11 19:06:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('711', '272', '5', '0', '1', '2024-07-11 19:08:25', '2024-07-11 19:08:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('712', '273', '5', '0', '1', '2024-07-11 19:09:37', '2024-07-11 19:09:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('713', '275', '5', '0', '1', '2024-07-11 19:13:14', '2024-07-11 19:13:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('714', '277', '5', '0', '1', '2024-07-11 19:14:46', '2024-07-11 19:14:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('715', '279', '5', '0', '1', '2024-07-11 19:16:21', '2024-07-11 19:16:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('716', '281', '5', '1', '1', '2024-07-11 19:18:08', '2024-07-11 19:18:08', NULL);
INSERT INTO `extra_user_datas` VALUES ('717', '283', '5', '0', '1', '2024-07-11 19:19:45', '2024-07-11 19:19:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('718', '285', '5', '0', '1', '2024-07-11 19:21:27', '2024-07-11 19:21:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('719', '287', '5', '0', '1', '2024-07-11 19:23:33', '2024-07-11 19:23:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('720', '289', '5', '0', '1', '2024-07-11 19:25:45', '2024-07-11 19:25:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('721', '291', '5', '1', '1', '2024-07-11 19:31:37', '2024-07-11 19:31:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('722', '293', '5', '0', '1', '2024-07-11 19:33:38', '2024-07-11 19:33:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('723', '295', '5', '0', '1', '2024-07-11 19:35:05', '2024-07-11 19:35:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('724', '297', '5', '1', '1', '2024-07-11 19:36:53', '2024-07-11 19:36:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('725', '299', '5', '1', '1', '2024-07-11 19:38:27', '2024-07-11 19:38:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('726', '301', '5', '0', '1', '2024-07-11 19:40:48', '2024-07-11 19:40:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('727', '303', '5', '0', '1', '2024-07-11 19:42:23', '2024-07-11 19:42:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('728', '305', '5', '1', '1', '2024-07-11 19:44:19', '2024-07-11 19:44:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('729', '307', '5', '0', '1', '2024-07-11 19:45:53', '2024-07-11 19:45:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('730', '309', '5', '0', '1', '2024-07-11 19:47:45', '2024-07-11 19:47:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('731', '311', '5', '0', '1', '2024-07-11 19:51:32', '2024-07-11 19:51:32', NULL);
INSERT INTO `extra_user_datas` VALUES ('732', '313', '5', '0', '1', '2024-07-11 19:53:27', '2024-07-11 19:53:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('733', '315', '5', '0', '1', '2024-07-11 19:56:06', '2024-07-11 19:56:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('734', '317', '5', '0', '1', '2024-07-11 19:57:57', '2024-07-11 19:57:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('735', '319', '5', '0', '1', '2024-07-11 20:00:06', '2024-07-11 20:00:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('736', '321', '5', '0', '1', '2024-07-11 20:01:45', '2024-07-11 20:01:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('737', '323', '5', '0', '1', '2024-07-11 20:03:38', '2024-07-11 20:03:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('738', '325', '5', '0', '1', '2024-07-11 20:06:42', '2024-07-11 20:06:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('739', '327', '5', '0', '1', '2024-07-11 20:08:40', '2024-07-11 20:08:40', NULL);
INSERT INTO `extra_user_datas` VALUES ('740', '329', '5', '0', '1', '2024-07-11 20:10:19', '2024-07-11 20:10:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('741', '331', '5', '0', '1', '2024-07-11 20:11:59', '2024-07-11 20:11:59', NULL);
INSERT INTO `extra_user_datas` VALUES ('742', '333', '5', '0', '1', '2024-07-11 20:13:33', '2024-07-11 20:13:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('743', '334', '5', '0', '1', '2024-07-11 20:15:00', '2024-07-11 20:15:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('744', '336', '5', '0', '1', '2024-07-11 20:17:16', '2024-07-11 20:17:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('745', '338', '5', '1', '1', '2024-07-11 20:19:12', '2024-07-11 20:19:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('746', '340', '5', '0', '1', '2024-07-11 20:21:12', '2024-07-11 20:21:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('747', '342', '5', '0', '1', '2024-07-11 20:22:54', '2024-07-11 20:22:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('748', '344', '5', '0', '1', '2024-07-11 20:24:38', '2024-07-11 20:24:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('749', '346', '5', '0', '1', '2024-07-11 20:26:14', '2024-07-11 20:26:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('750', '348', '5', '0', '1', '2024-07-11 20:27:51', '2024-07-11 20:27:51', NULL);
INSERT INTO `extra_user_datas` VALUES ('751', '349', '5', '0', '1', '2024-07-11 20:29:06', '2024-07-11 20:29:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('752', '351', '5', '0', '1', '2024-07-11 20:30:42', '2024-07-11 20:30:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('753', '353', '5', '0', '1', '2024-07-11 20:32:39', '2024-07-11 20:32:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('754', '355', '5', '0', '1', '2024-07-12 12:49:57', '2024-07-12 12:49:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('755', '356', '5', '0', '1', '2024-07-12 12:52:14', '2024-07-12 12:52:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('756', '358', '5', '0', '1', '2024-07-12 12:54:03', '2024-07-12 12:54:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('757', '360', '5', '0', '1', '2024-07-12 12:55:56', '2024-07-12 12:55:56', NULL);
INSERT INTO `extra_user_datas` VALUES ('758', '362', '5', '1', '1', '2024-07-12 12:57:35', '2024-07-12 12:57:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('759', '364', '5', '0', '1', '2024-07-12 13:01:19', '2024-07-12 13:01:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('760', '366', '5', '0', '1', '2024-07-12 13:03:18', '2024-07-12 13:03:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('761', '368', '5', '0', '1', '2024-07-12 13:07:52', '2024-07-12 13:07:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('762', '370', '5', '0', '1', '2024-07-12 13:14:05', '2024-07-12 13:14:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('763', '372', '5', '0', '1', '2024-07-12 13:17:33', '2024-07-12 13:17:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('764', '374', '5', '0', '1', '2024-07-12 13:20:47', '2024-07-12 13:20:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('765', '376', '5', '0', '1', '2024-07-12 13:23:48', '2024-07-12 13:23:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('766', '378', '5', '1', '1', '2024-07-12 13:25:37', '2024-07-12 13:25:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('767', '380', '5', '0', '1', '2024-07-12 13:27:52', '2024-07-12 13:27:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('768', '382', '5', '0', '1', '2024-07-19 07:05:47', '2024-07-19 07:05:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('769', '11', '5', '0', '1', '2024-07-10 16:29:08', '2024-07-10 16:29:08', NULL);
INSERT INTO `extra_user_datas` VALUES ('770', '13', '5', '0', '1', '2024-07-10 16:33:06', '2024-07-10 16:33:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('771', '15', '5', '0', '1', '2024-07-10 16:35:47', '2024-07-10 16:35:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('772', '17', '5', '0', '1', '2024-07-10 16:38:41', '2024-07-10 16:38:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('773', '19', '5', '0', '1', '2024-07-10 16:41:26', '2024-07-10 16:41:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('774', '21', '5', '1', '1', '2024-07-10 16:46:20', '2024-07-10 16:46:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('775', '23', '5', '1', '1', '2024-07-10 16:50:11', '2024-07-10 16:50:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('776', '25', '5', '1', '1', '2024-07-10 16:53:19', '2024-07-10 16:53:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('777', '27', '5', '0', '1', '2024-07-10 17:27:36', '2024-07-10 17:27:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('778', '29', '5', '0', '1', '2024-07-10 17:30:22', '2024-07-10 17:30:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('779', '31', '5', '1', '1', '2024-07-10 17:33:28', '2024-07-10 17:33:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('780', '33', '5', '1', '1', '2024-07-10 17:36:07', '2024-07-10 17:36:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('781', '35', '5', '0', '1', '2024-07-10 17:38:39', '2024-07-10 17:38:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('782', '37', '5', '0', '1', '2024-07-10 17:42:25', '2024-07-10 17:42:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('783', '38', '5', '0', '1', '2024-07-10 17:45:05', '2024-07-10 17:45:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('784', '40', '5', '0', '1', '2024-07-10 17:47:46', '2024-07-10 17:47:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('785', '42', '5', '0', '1', '2024-07-10 17:51:24', '2024-07-10 17:51:24', NULL);
INSERT INTO `extra_user_datas` VALUES ('786', '44', '5', '0', '1', '2024-07-10 17:54:33', '2024-07-10 17:54:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('787', '46', '5', '0', '1', '2024-07-10 17:57:17', '2024-07-10 17:57:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('788', '48', '5', '0', '1', '2024-07-10 17:59:58', '2024-07-10 17:59:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('789', '50', '5', '0', '1', '2024-07-10 18:03:37', '2024-07-10 18:03:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('790', '52', '5', '0', '1', '2024-07-10 18:06:17', '2024-07-10 18:06:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('791', '54', '5', '0', '1', '2024-07-10 18:09:16', '2024-07-10 18:09:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('792', '56', '5', '0', '1', '2024-07-10 18:12:23', '2024-07-10 18:12:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('793', '58', '5', '0', '1', '2024-07-10 18:15:41', '2024-07-10 18:15:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('794', '60', '5', '0', '1', '2024-07-10 18:18:29', '2024-07-10 18:18:29', NULL);
INSERT INTO `extra_user_datas` VALUES ('795', '62', '5', '0', '1', '2024-07-10 18:26:35', '2024-07-10 18:26:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('796', '64', '5', '1', '1', '2024-07-10 18:29:56', '2024-07-10 18:29:56', NULL);
INSERT INTO `extra_user_datas` VALUES ('797', '66', '5', '0', '1', '2024-07-10 18:33:09', '2024-07-10 18:33:09', NULL);
INSERT INTO `extra_user_datas` VALUES ('798', '68', '5', '0', '1', '2024-07-10 18:38:06', '2024-07-10 18:38:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('799', '69', '5', '0', '1', '2024-07-10 18:41:04', '2024-07-10 18:41:04', NULL);
INSERT INTO `extra_user_datas` VALUES ('800', '70', '5', '0', '1', '2024-07-10 18:43:45', '2024-07-10 18:43:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('801', '72', '5', '0', '1', '2024-07-10 18:46:48', '2024-07-10 18:46:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('802', '74', '5', '1', '1', '2024-07-10 18:49:11', '2024-07-10 18:49:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('803', '76', '5', '0', '1', '2024-07-10 18:51:35', '2024-07-10 18:51:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('804', '78', '5', '0', '1', '2024-07-10 18:55:11', '2024-07-10 18:55:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('805', '80', '5', '0', '1', '2024-07-10 18:57:22', '2024-07-10 18:57:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('806', '82', '5', '0', '1', '2024-07-10 18:59:34', '2024-07-10 18:59:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('807', '84', '5', '0', '1', '2024-07-10 19:14:31', '2024-07-10 19:14:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('808', '86', '5', '0', '1', '2024-07-10 19:16:43', '2024-07-10 19:16:43', NULL);
INSERT INTO `extra_user_datas` VALUES ('809', '88', '5', '0', '1', '2024-07-10 19:19:48', '2024-07-10 19:19:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('810', '90', '5', '0', '1', '2024-07-10 19:22:21', '2024-07-10 19:22:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('811', '92', '5', '0', '1', '2024-07-10 19:26:16', '2024-07-10 19:26:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('812', '94', '5', '1', '1', '2024-07-10 19:28:42', '2024-07-10 19:28:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('813', '96', '5', '0', '1', '2024-07-10 19:30:37', '2024-07-10 19:30:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('814', '98', '5', '1', '1', '2024-07-10 19:32:36', '2024-07-10 19:32:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('815', '100', '5', '0', '1', '2024-07-10 19:34:37', '2024-07-10 19:34:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('816', '102', '5', '0', '1', '2024-07-10 19:37:03', '2024-07-10 19:37:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('817', '104', '5', '1', '1', '2024-07-10 19:39:21', '2024-07-10 19:39:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('818', '105', '5', '1', '1', '2024-07-10 19:49:34', '2024-07-10 19:49:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('819', '107', '5', '1', '1', '2024-07-10 19:53:11', '2024-07-10 19:53:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('820', '109', '5', '0', '1', '2024-07-10 19:55:26', '2024-07-10 19:55:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('821', '111', '5', '0', '1', '2024-07-10 19:57:51', '2024-07-10 19:57:51', NULL);
INSERT INTO `extra_user_datas` VALUES ('822', '113', '5', '0', '1', '2024-07-10 19:59:53', '2024-07-10 19:59:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('823', '115', '5', '0', '1', '2024-07-10 20:02:20', '2024-07-10 20:02:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('824', '117', '5', '0', '1', '2024-07-10 20:04:17', '2024-07-10 20:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('825', '119', '5', '1', '1', '2024-07-10 20:06:12', '2024-07-10 20:06:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('826', '121', '5', '0', '1', '2024-07-10 20:08:02', '2024-07-10 20:08:02', NULL);
INSERT INTO `extra_user_datas` VALUES ('827', '123', '5', '0', '1', '2024-07-10 20:10:06', '2024-07-10 20:10:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('828', '125', '5', '1', '1', '2024-07-10 20:14:55', '2024-07-10 20:14:55', NULL);
INSERT INTO `extra_user_datas` VALUES ('829', '127', '5', '0', '1', '2024-07-10 20:17:17', '2024-07-10 20:17:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('830', '129', '5', '0', '1', '2024-07-10 20:19:04', '2024-07-10 20:19:04', NULL);
INSERT INTO `extra_user_datas` VALUES ('831', '131', '5', '0', '1', '2024-07-10 20:21:13', '2024-07-10 20:21:13', NULL);
INSERT INTO `extra_user_datas` VALUES ('832', '133', '5', '0', '1', '2024-07-10 20:23:29', '2024-07-10 20:23:29', NULL);
INSERT INTO `extra_user_datas` VALUES ('833', '135', '5', '0', '1', '2024-07-10 20:26:18', '2024-07-10 20:26:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('834', '137', '5', '0', '1', '2024-07-10 20:28:22', '2024-07-10 20:28:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('835', '139', '5', '1', '1', '2024-07-10 20:30:22', '2024-07-10 20:30:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('836', '141', '5', '0', '1', '2024-07-10 20:32:28', '2024-07-10 20:32:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('837', '143', '5', '0', '1', '2024-07-10 20:34:39', '2024-07-10 20:34:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('838', '145', '5', '0', '1', '2024-07-11 15:09:28', '2024-07-11 15:09:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('839', '147', '5', '0', '1', '2024-07-11 15:11:58', '2024-07-11 15:11:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('840', '149', '5', '1', '1', '2024-07-11 15:14:10', '2024-07-11 15:14:10', NULL);
INSERT INTO `extra_user_datas` VALUES ('841', '151', '5', '1', '1', '2024-07-11 15:16:03', '2024-07-11 15:16:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('842', '153', '5', '0', '1', '2024-07-11 15:19:36', '2024-07-11 15:19:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('843', '155', '5', '0', '1', '2024-07-11 15:23:36', '2024-07-11 15:23:36', NULL);
INSERT INTO `extra_user_datas` VALUES ('844', '157', '5', '0', '1', '2024-07-11 15:28:58', '2024-07-11 15:28:58', NULL);
INSERT INTO `extra_user_datas` VALUES ('845', '159', '5', '0', '1', '2024-07-11 15:31:34', '2024-07-11 15:31:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('846', '161', '5', '0', '1', '2024-07-11 15:35:49', '2024-07-11 15:35:49', NULL);
INSERT INTO `extra_user_datas` VALUES ('847', '163', '5', '0', '1', '2024-07-11 15:39:20', '2024-07-11 15:39:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('848', '165', '5', '0', '1', '2024-07-11 15:42:19', '2024-07-11 15:42:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('849', '167', '5', '0', '1', '2024-07-11 15:55:42', '2024-07-11 15:55:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('850', '169', '5', '0', '1', '2024-07-11 15:57:54', '2024-07-11 15:57:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('851', '171', '5', '0', '1', '2024-07-11 16:00:02', '2024-07-11 16:00:02', NULL);
INSERT INTO `extra_user_datas` VALUES ('852', '173', '5', '0', '1', '2024-07-11 16:02:06', '2024-07-11 16:02:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('853', '175', '5', '0', '1', '2024-07-11 16:05:01', '2024-07-11 16:05:01', NULL);
INSERT INTO `extra_user_datas` VALUES ('854', '177', '5', '0', '1', '2024-07-11 16:07:07', '2024-07-11 16:07:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('855', '179', '5', '1', '1', '2024-07-11 16:09:25', '2024-07-11 16:09:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('856', '181', '5', '0', '1', '2024-07-11 16:11:20', '2024-07-11 16:11:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('857', '183', '5', '0', '1', '2024-07-11 16:13:20', '2024-07-11 16:13:20', NULL);
INSERT INTO `extra_user_datas` VALUES ('858', '184', '5', '0', '1', '2024-07-11 16:15:17', '2024-07-11 16:15:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('859', '186', '5', '0', '1', '2024-07-11 16:17:11', '2024-07-11 16:17:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('860', '188', '5', '0', '1', '2024-07-11 16:19:50', '2024-07-11 16:19:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('861', '190', '5', '0', '1', '2024-07-11 16:23:52', '2024-07-11 16:23:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('862', '192', '5', '0', '1', '2024-07-11 16:25:46', '2024-07-11 16:25:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('863', '194', '5', '0', '1', '2024-07-11 16:28:31', '2024-07-11 16:28:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('864', '196', '5', '0', '1', '2024-07-11 16:31:26', '2024-07-11 16:31:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('865', '198', '5', '1', '1', '2024-07-11 16:33:37', '2024-07-11 16:33:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('866', '200', '5', '0', '1', '2024-07-11 16:35:27', '2024-07-11 16:35:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('867', '202', '5', '0', '1', '2024-07-11 16:37:18', '2024-07-11 16:37:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('868', '204', '5', '0', '1', '2024-07-11 16:39:07', '2024-07-11 16:39:07', NULL);
INSERT INTO `extra_user_datas` VALUES ('869', '206', '5', '0', '1', '2024-07-11 16:47:42', '2024-07-11 16:47:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('870', '208', '5', '0', '1', '2024-07-11 16:54:25', '2024-07-11 16:54:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('871', '210', '5', '0', '1', '2024-07-11 16:56:10', '2024-07-11 16:56:10', NULL);
INSERT INTO `extra_user_datas` VALUES ('872', '212', '5', '0', '1', '2024-07-11 16:57:53', '2024-07-11 16:57:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('873', '214', '5', '0', '1', '2024-07-11 16:59:37', '2024-07-11 16:59:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('874', '216', '5', '0', '1', '2024-07-11 17:01:18', '2024-07-11 17:01:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('875', '218', '5', '0', '1', '2024-07-11 17:03:03', '2024-07-11 17:03:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('876', '220', '5', '0', '1', '2024-07-11 17:04:41', '2024-07-11 17:04:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('877', '222', '5', '0', '1', '2024-07-11 17:06:32', '2024-07-11 17:06:32', NULL);
INSERT INTO `extra_user_datas` VALUES ('878', '223', '5', '0', '1', '2024-07-11 17:07:45', '2024-07-11 17:07:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('879', '225', '5', '0', '1', '2024-07-11 17:14:39', '2024-07-11 17:14:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('880', '227', '5', '0', '1', '2024-07-11 17:16:30', '2024-07-11 17:16:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('881', '229', '5', '0', '1', '2024-07-11 18:01:38', '2024-07-11 18:01:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('882', '231', '5', '0', '1', '2024-07-11 18:04:41', '2024-07-11 18:04:41', NULL);
INSERT INTO `extra_user_datas` VALUES ('883', '233', '5', '1', '1', '2024-07-11 18:07:47', '2024-07-11 18:07:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('884', '235', '5', '1', '1', '2024-07-11 18:10:37', '2024-07-11 18:10:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('885', '237', '5', '1', '1', '2024-07-11 18:15:59', '2024-07-11 18:15:59', NULL);
INSERT INTO `extra_user_datas` VALUES ('886', '239', '5', '1', '1', '2024-07-11 18:18:28', '2024-07-11 18:18:28', NULL);
INSERT INTO `extra_user_datas` VALUES ('887', '241', '5', '1', '1', '2024-07-11 18:20:27', '2024-07-11 18:20:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('888', '243', '5', '0', '1', '2024-07-11 18:22:16', '2024-07-11 18:22:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('889', '245', '5', '1', '1', '2024-07-11 18:24:09', '2024-07-11 18:24:09', NULL);
INSERT INTO `extra_user_datas` VALUES ('890', '246', '5', '1', '1', '2024-07-11 18:30:50', '2024-07-11 18:30:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('891', '248', '5', '1', '1', '2024-07-11 18:33:05', '2024-07-11 18:33:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('892', '250', '5', '1', '1', '2024-07-11 18:38:00', '2024-07-11 18:38:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('893', '252', '5', '1', '1', '2024-07-11 18:39:54', '2024-07-11 18:39:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('894', '254', '5', '0', '1', '2024-07-11 18:49:30', '2024-07-11 18:49:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('895', '256', '5', '0', '1', '2024-07-11 18:51:50', '2024-07-11 18:51:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('896', '258', '5', '0', '1', '2024-07-11 18:53:40', '2024-07-11 18:53:40', NULL);
INSERT INTO `extra_user_datas` VALUES ('897', '260', '5', '0', '1', '2024-07-11 18:55:27', '2024-07-11 18:55:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('898', '262', '5', '0', '1', '2024-07-11 18:57:39', '2024-07-11 18:57:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('899', '264', '5', '1', '1', '2024-07-11 18:59:31', '2024-07-11 18:59:31', NULL);
INSERT INTO `extra_user_datas` VALUES ('900', '266', '5', '0', '1', '2024-07-11 19:02:46', '2024-07-11 19:02:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('901', '268', '5', '1', '1', '2024-07-11 19:04:46', '2024-07-11 19:04:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('902', '270', '5', '1', '1', '2024-07-11 19:06:42', '2024-07-11 19:06:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('903', '272', '5', '0', '1', '2024-07-11 19:08:25', '2024-07-11 19:08:25', NULL);
INSERT INTO `extra_user_datas` VALUES ('904', '273', '5', '0', '1', '2024-07-11 19:09:37', '2024-07-11 19:09:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('905', '275', '5', '0', '1', '2024-07-11 19:13:14', '2024-07-11 19:13:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('906', '277', '5', '0', '1', '2024-07-11 19:14:46', '2024-07-11 19:14:46', NULL);
INSERT INTO `extra_user_datas` VALUES ('907', '279', '5', '0', '1', '2024-07-11 19:16:21', '2024-07-11 19:16:21', NULL);
INSERT INTO `extra_user_datas` VALUES ('908', '281', '5', '1', '1', '2024-07-11 19:18:08', '2024-07-11 19:18:08', NULL);
INSERT INTO `extra_user_datas` VALUES ('909', '283', '5', '0', '1', '2024-07-11 19:19:45', '2024-07-11 19:19:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('910', '285', '5', '0', '1', '2024-07-11 19:21:27', '2024-07-11 19:21:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('911', '287', '5', '0', '1', '2024-07-11 19:23:33', '2024-07-11 19:23:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('912', '289', '5', '0', '1', '2024-07-11 19:25:45', '2024-07-11 19:25:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('913', '291', '5', '1', '1', '2024-07-11 19:31:37', '2024-07-11 19:31:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('914', '293', '5', '0', '1', '2024-07-11 19:33:38', '2024-07-11 19:33:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('915', '295', '5', '0', '1', '2024-07-11 19:35:05', '2024-07-11 19:35:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('916', '297', '5', '1', '1', '2024-07-11 19:36:53', '2024-07-11 19:36:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('917', '299', '5', '1', '1', '2024-07-11 19:38:27', '2024-07-11 19:38:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('918', '301', '5', '0', '1', '2024-07-11 19:40:48', '2024-07-11 19:40:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('919', '303', '5', '0', '1', '2024-07-11 19:42:23', '2024-07-11 19:42:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('920', '305', '5', '1', '1', '2024-07-11 19:44:19', '2024-07-11 19:44:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('921', '307', '5', '0', '1', '2024-07-11 19:45:53', '2024-07-11 19:45:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('922', '309', '5', '0', '1', '2024-07-11 19:47:45', '2024-07-11 19:47:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('923', '311', '5', '0', '1', '2024-07-11 19:51:32', '2024-07-11 19:51:32', NULL);
INSERT INTO `extra_user_datas` VALUES ('924', '313', '5', '0', '1', '2024-07-11 19:53:27', '2024-07-11 19:53:27', NULL);
INSERT INTO `extra_user_datas` VALUES ('925', '315', '5', '0', '1', '2024-07-11 19:56:06', '2024-07-11 19:56:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('926', '317', '5', '0', '1', '2024-07-11 19:57:57', '2024-07-11 19:57:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('927', '319', '5', '0', '1', '2024-07-11 20:00:06', '2024-07-11 20:00:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('928', '321', '5', '0', '1', '2024-07-11 20:01:45', '2024-07-11 20:01:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('929', '323', '5', '0', '1', '2024-07-11 20:03:38', '2024-07-11 20:03:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('930', '325', '5', '0', '1', '2024-07-11 20:06:42', '2024-07-11 20:06:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('931', '327', '5', '0', '1', '2024-07-11 20:08:40', '2024-07-11 20:08:40', NULL);
INSERT INTO `extra_user_datas` VALUES ('932', '329', '5', '0', '1', '2024-07-11 20:10:19', '2024-07-11 20:10:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('933', '331', '5', '0', '1', '2024-07-11 20:11:59', '2024-07-11 20:11:59', NULL);
INSERT INTO `extra_user_datas` VALUES ('934', '333', '5', '0', '1', '2024-07-11 20:13:33', '2024-07-11 20:13:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('935', '334', '5', '0', '1', '2024-07-11 20:15:00', '2024-07-11 20:15:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('936', '336', '5', '0', '1', '2024-07-11 20:17:16', '2024-07-11 20:17:16', NULL);
INSERT INTO `extra_user_datas` VALUES ('937', '338', '5', '1', '1', '2024-07-11 20:19:12', '2024-07-11 20:19:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('938', '340', '5', '0', '1', '2024-07-11 20:21:12', '2024-07-11 20:21:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('939', '342', '5', '0', '1', '2024-07-11 20:22:54', '2024-07-11 20:22:54', NULL);
INSERT INTO `extra_user_datas` VALUES ('940', '344', '5', '0', '1', '2024-07-11 20:24:38', '2024-07-11 20:24:38', NULL);
INSERT INTO `extra_user_datas` VALUES ('941', '346', '5', '0', '1', '2024-07-11 20:26:14', '2024-07-11 20:26:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('942', '348', '5', '0', '1', '2024-07-11 20:27:51', '2024-07-11 20:27:51', NULL);
INSERT INTO `extra_user_datas` VALUES ('943', '349', '5', '0', '1', '2024-07-11 20:29:06', '2024-07-11 20:29:06', NULL);
INSERT INTO `extra_user_datas` VALUES ('944', '351', '5', '0', '1', '2024-07-11 20:30:42', '2024-07-11 20:30:42', NULL);
INSERT INTO `extra_user_datas` VALUES ('945', '353', '5', '0', '1', '2024-07-11 20:32:39', '2024-07-11 20:32:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('946', '355', '5', '0', '1', '2024-07-12 12:49:57', '2024-07-12 12:49:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('947', '356', '5', '0', '1', '2024-07-12 12:52:14', '2024-07-12 12:52:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('948', '358', '5', '0', '1', '2024-07-12 12:54:03', '2024-07-12 12:54:03', NULL);
INSERT INTO `extra_user_datas` VALUES ('949', '360', '5', '0', '1', '2024-07-12 12:55:56', '2024-07-12 12:55:56', NULL);
INSERT INTO `extra_user_datas` VALUES ('950', '362', '5', '1', '1', '2024-07-12 12:57:35', '2024-07-12 12:57:35', NULL);
INSERT INTO `extra_user_datas` VALUES ('951', '364', '5', '0', '1', '2024-07-12 13:01:19', '2024-07-12 13:01:19', NULL);
INSERT INTO `extra_user_datas` VALUES ('952', '366', '5', '0', '1', '2024-07-12 13:03:18', '2024-07-12 13:03:18', NULL);
INSERT INTO `extra_user_datas` VALUES ('953', '368', '5', '0', '1', '2024-07-12 13:07:52', '2024-07-12 13:07:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('954', '370', '5', '0', '1', '2024-07-12 13:14:05', '2024-07-12 13:14:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('955', '372', '5', '0', '1', '2024-07-12 13:17:33', '2024-07-12 13:17:33', NULL);
INSERT INTO `extra_user_datas` VALUES ('956', '374', '5', '0', '1', '2024-07-12 13:20:47', '2024-07-12 13:20:47', NULL);
INSERT INTO `extra_user_datas` VALUES ('957', '376', '5', '0', '1', '2024-07-12 13:23:48', '2024-07-12 13:23:48', NULL);
INSERT INTO `extra_user_datas` VALUES ('958', '378', '5', '1', '1', '2024-07-12 13:25:37', '2024-07-12 13:25:37', NULL);
INSERT INTO `extra_user_datas` VALUES ('959', '380', '5', '0', '1', '2024-07-12 13:27:52', '2024-07-12 13:27:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('960', '382', '5', '0', '1', '2024-07-19 07:05:47', '2024-07-19 07:05:47', NULL);

CREATE TABLE IF NOT EXISTS `faqs` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(191) NOT NULL,
  `description` text NOT NULL,
  `school_id` bigint(20) unsigned DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `faqs_school_id_foreign` (`school_id`),
  CONSTRAINT `faqs_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `faqs` VALUES ('1', 'Does School offer financial aid?', 'Lorem ipsum dolor sit amet consectetur. Diam diam cras tristique varius. Sit lacus vitae augue nisl. Sed condimentum feugiat id ac ac orci massa consectetur urna.', '1', '2025-01-01 23:12:53', '2025-01-01 23:12:53');
INSERT INTO `faqs` VALUES ('2', 'What extracurricular activities are available?', 'Lorem ipsum dolor sit amet consectetur. Diam diam cras tristique varius. Sit lacus vitae augue nisl. Sed condimentum feugiat id ac ac orci massa consectetur urna.', '1', '2025-01-01 23:13:19', '2025-01-01 23:13:19');
INSERT INTO `faqs` VALUES ('3', 'What kind of curriculum does School offer?', 'Lorem ipsum dolor sit amet consectetur. Diam diam cras tristique varius. Sit lacus vitae augue nisl. Sed condimentum feugiat id ac ac orci massa consectetur urna.', '1', '2025-01-01 23:15:27', '2025-01-01 23:15:27');
INSERT INTO `faqs` VALUES ('4', 'What financial aid or scholarship options are available to students?', 'Lorem ipsum dolor sit amet consectetur. Diam diam cras tristique varius. Sit lacus vitae augue nisl. Sed condimentum feugiat id ac ac orci massa consectetur urna.', '1', '2025-01-01 23:15:54', '2025-01-01 23:15:54');
INSERT INTO `faqs` VALUES ('5', 'Waht is the the admission requirements?', 'Lorem ipsum dolor sit amet consectetur. Diam diam cras tristique varius. Sit lacus vitae augue nisl. Sed condimentum feugiat id ac ac orci massa consectetur urna.', '1', '2025-01-01 23:16:25', '2025-01-01 23:16:25');

CREATE TABLE IF NOT EXISTS `fees` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `due_date` date NOT NULL,
  `due_charges` double(8,2) NOT NULL COMMENT 'in percentage (%)',
  `due_charges_amount` double(8,2) NOT NULL,
  `class_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fees_session_year_id_foreign` (`session_year_id`),
  KEY `fees_school_id_foreign` (`school_id`),
  KEY `fees_class_id_foreign` (`class_id`),
  CONSTRAINT `fees_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `fees_advance` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `compulsory_fee_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `parent_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `amount` double(8,2) NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fees_advance_compulsory_fee_id_foreign` (`compulsory_fee_id`),
  KEY `fees_advance_student_id_foreign` (`student_id`),
  KEY `fees_advance_parent_id_foreign` (`parent_id`),
  CONSTRAINT `fees_advance_compulsory_fee_id_foreign` FOREIGN KEY (`compulsory_fee_id`) REFERENCES `compulsory_fees` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_advance_parent_id_foreign` FOREIGN KEY (`parent_id`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_advance_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `fees_class_types` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_id` bigint(20) unsigned NOT NULL,
  `fees_id` bigint(20) unsigned NOT NULL,
  `fees_type_id` bigint(20) unsigned NOT NULL,
  `amount` double(64,2) NOT NULL,
  `optional` tinyint(1) NOT NULL COMMENT '0 - No, 1 - Yes',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`class_id`,`fees_type_id`,`school_id`,`fees_id`),
  KEY `fees_class_types_fees_id_foreign` (`fees_id`),
  KEY `fees_class_types_fees_type_id_foreign` (`fees_type_id`),
  KEY `fees_class_types_school_id_foreign` (`school_id`),
  CONSTRAINT `fees_class_types_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_class_types_fees_id_foreign` FOREIGN KEY (`fees_id`) REFERENCES `fees` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_class_types_fees_type_id_foreign` FOREIGN KEY (`fees_type_id`) REFERENCES `fees_types` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_class_types_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `fees_installments` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `due_date` date NOT NULL,
  `due_charges_type` enum('fixed','percentage') NOT NULL DEFAULT 'percentage',
  `due_charges` int(11) NOT NULL,
  `fees_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fees_installments_fees_id_foreign` (`fees_id`),
  KEY `fees_installments_session_year_id_foreign` (`session_year_id`),
  KEY `fees_installments_school_id_foreign` (`school_id`),
  CONSTRAINT `fees_installments_fees_id_foreign` FOREIGN KEY (`fees_id`) REFERENCES `fees` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_installments_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_installments_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `fees_paids` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `fees_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `is_fully_paid` tinyint(1) NOT NULL COMMENT '0 - No, 1 - Yes',
  `is_used_installment` tinyint(1) NOT NULL COMMENT '0 - No, 1 - Yes',
  `amount` double(8,2) NOT NULL,
  `date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`student_id`,`fees_id`,`school_id`),
  KEY `fees_paids_school_id_foreign` (`school_id`),
  KEY `fees_paids_fees_id_foreign` (`fees_id`),
  CONSTRAINT `fees_paids_fees_id_foreign` FOREIGN KEY (`fees_id`) REFERENCES `fees` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_paids_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_paids_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `fees_types` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `description` varchar(191) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fees_types_school_id_foreign` (`school_id`),
  CONSTRAINT `fees_types_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `files` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `modal_type` varchar(191) NOT NULL,
  `modal_id` bigint(20) unsigned NOT NULL,
  `file_name` varchar(1024) DEFAULT NULL,
  `file_thumbnail` varchar(1024) DEFAULT NULL,
  `type` tinytext NOT NULL COMMENT '1 = File Upload, 2 = Youtube Link, 3 = Video Upload, 4 = Other Link',
  `file_url` varchar(1024) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `files_modal_type_modal_id_index` (`modal_type`,`modal_id`),
  KEY `files_school_id_foreign` (`school_id`),
  CONSTRAINT `files_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `form_fields` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(128) NOT NULL,
  `type` varchar(128) NOT NULL COMMENT 'text,number,textarea,dropdown,checkbox,radio,fileupload',
  `is_required` tinyint(1) NOT NULL DEFAULT 0,
  `default_values` text DEFAULT NULL COMMENT 'values of radio,checkbox,dropdown,etc',
  `other` text DEFAULT NULL COMMENT 'extra HTML attributes',
  `school_id` bigint(20) unsigned NOT NULL,
  `user_type` int(11) NOT NULL DEFAULT 1 COMMENT '1 => Student, 2 => Teacher/Staff',
  `rank` int(11) NOT NULL DEFAULT 0,
  `display_on_id` int(11) NOT NULL DEFAULT 0 COMMENT '0 => No, 1 => Yes',
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `form_fields_school_id_foreign` (`school_id`),
  CONSTRAINT `form_fields_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `form_fields` VALUES ('5', 'Religion', 'dropdown', '1', '[\"Christian\",\"Muslim\"]', NULL, '1', '1', '1', '0', '2024-06-21 12:13:11', '2024-07-10 16:23:17', NULL);

CREATE TABLE IF NOT EXISTS `galleries` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(191) NOT NULL,
  `description` varchar(191) DEFAULT NULL,
  `thumbnail` varchar(191) DEFAULT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `galleries_session_year_id_foreign` (`session_year_id`),
  KEY `galleries_school_id_foreign` (`school_id`),
  CONSTRAINT `galleries_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `galleries_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `galleries` VALUES ('1', 'Singing Competition', NULL, '1/gallery/67757fe2cc1d23.912237981735753698.png', '1', '1', '2025-01-01 23:18:18', '2025-01-01 23:18:18');
INSERT INTO `galleries` VALUES ('2', 'Dance Competition', NULL, '1/gallery/67758020489eb6.007147291735753760.png', '1', '1', '2025-01-01 23:19:20', '2025-01-01 23:19:20');
INSERT INTO `galleries` VALUES ('3', 'Class Room Decoration', NULL, '1/gallery/6775804b42aa99.234186801735753803.png', '1', '1', '2025-01-01 23:20:03', '2025-01-01 23:20:03');
INSERT INTO `galleries` VALUES ('4', 'Festival', NULL, '1/gallery/6775806de57ee9.938584641735753837.png', '1', '1', '2025-01-01 23:20:38', '2025-01-01 23:20:38');

CREATE TABLE IF NOT EXISTS `grades` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `starting_range` double(8,2) NOT NULL,
  `ending_range` double(8,2) NOT NULL,
  `grade` tinytext NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `grades_school_id_foreign` (`school_id`),
  CONSTRAINT `grades_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `grades` VALUES ('1', '0', '34', 'FAIL', '1', '2024-08-08 04:38:25', '2024-08-08 04:38:25');
INSERT INTO `grades` VALUES ('2', '34.01', '42', 'D2', '1', '2024-08-08 04:38:25', '2024-08-08 04:38:25');
INSERT INTO `grades` VALUES ('3', '42.01', '50', 'D', '1', '2024-08-08 04:38:25', '2024-08-08 04:38:25');
INSERT INTO `grades` VALUES ('4', '50.01', '58', 'C2', '1', '2024-08-08 04:38:25', '2024-08-08 04:38:25');
INSERT INTO `grades` VALUES ('5', '58.01', '66', 'C', '1', '2024-08-08 04:38:25', '2024-08-08 04:38:25');
INSERT INTO `grades` VALUES ('6', '66.01', '74', 'B2', '1', '2024-08-08 04:38:25', '2024-08-08 04:38:25');
INSERT INTO `grades` VALUES ('7', '74.01', '83', 'B', '1', '2024-08-08 04:38:25', '2024-08-08 04:38:25');
INSERT INTO `grades` VALUES ('8', '83.01', '91', 'A2', '1', '2024-08-08 04:38:25', '2024-08-08 04:38:25');
INSERT INTO `grades` VALUES ('9', '91.01', '100', 'A', '1', '2024-08-08 04:38:25', '2024-08-08 04:38:25');

CREATE TABLE IF NOT EXISTS `holidays` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `date` date NOT NULL,
  `title` varchar(128) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `holidays_school_id_foreign` (`school_id`),
  CONSTRAINT `holidays_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=16 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `holidays` VALUES ('1', '2024-01-01', 'New Year’s Day', 'New Year’s Day', '1', '2024-08-09 07:31:41', '2024-08-09 07:31:41');
INSERT INTO `holidays` VALUES ('2', '2024-01-07', 'Constitution Day', 'Constitution Day', '1', '2024-08-09 07:32:46', '2024-08-09 07:39:59');
INSERT INTO `holidays` VALUES ('3', '2024-01-08', 'Day off for Constitution Day', 'Day off for Constitution Day', '1', '2024-08-09 07:33:08', '2024-08-09 07:33:08');
INSERT INTO `holidays` VALUES ('4', '2024-03-06', 'Independence Day', 'Independence Day', '1', '2024-08-09 07:33:33', '2024-08-09 07:40:12');
INSERT INTO `holidays` VALUES ('5', '2024-03-29', 'Good Friday', 'Good Friday', '1', '2024-08-09 07:34:36', '2024-08-09 07:34:36');
INSERT INTO `holidays` VALUES ('6', '2024-04-01', 'Easter Monday', 'Easter Monday', '1', '2024-08-09 07:34:55', '2024-08-09 07:34:55');
INSERT INTO `holidays` VALUES ('7', '2024-05-01', 'May Day (Workers’ Day)', 'May Day (Workers’ Day)', '1', '2024-08-09 07:35:57', '2024-08-09 07:35:57');
INSERT INTO `holidays` VALUES ('8', '2024-05-11', 'Eid ul-Fitr', 'Eid ul-Fitr', '1', '2024-08-09 07:36:22', '2024-08-09 07:36:22');
INSERT INTO `holidays` VALUES ('9', '2024-06-16', 'Eid-Ul-Adha', 'Eid-Ul-Adha', '1', '2024-08-09 07:37:09', '2024-08-09 07:37:09');
INSERT INTO `holidays` VALUES ('10', '2024-08-04', 'Founders’ Day', 'Founders’ Day', '1', '2024-08-09 07:37:29', '2024-08-09 07:37:29');
INSERT INTO `holidays` VALUES ('11', '2024-09-21', 'Kwame Nkrumah Memorial Day', 'Kwame Nkrumah Memorial Day', '1', '2024-08-09 07:37:50', '2024-08-09 07:37:50');
INSERT INTO `holidays` VALUES ('12', '2024-09-23', 'Kwame Nkrumah Memorial Day observed', 'Kwame Nkrumah Memorial Day observed', '1', '2024-08-09 07:38:32', '2024-08-09 07:38:32');
INSERT INTO `holidays` VALUES ('13', '2024-12-06', 'Farmer’s Day', 'Farmer’s Day', '1', '2024-08-09 07:39:04', '2024-08-09 07:39:04');
INSERT INTO `holidays` VALUES ('14', '2024-12-25', 'Christmas Day', 'Christmas Day', '1', '2024-08-09 07:39:25', '2024-08-09 07:39:25');
INSERT INTO `holidays` VALUES ('15', '2024-12-26', 'Boxing Day', 'Boxing Day', '1', '2024-08-09 07:39:46', '2024-08-09 07:39:46');

CREATE TABLE IF NOT EXISTS `leave_details` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `leave_id` bigint(20) unsigned NOT NULL,
  `date` date NOT NULL,
  `type` varchar(191) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `leave_details_leave_id_foreign` (`leave_id`),
  KEY `leave_details_school_id_foreign` (`school_id`),
  CONSTRAINT `leave_details_leave_id_foreign` FOREIGN KEY (`leave_id`) REFERENCES `leaves` (`id`) ON DELETE CASCADE,
  CONSTRAINT `leave_details_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `leave_masters` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `leaves` double(8,2) NOT NULL COMMENT 'Leaves per month',
  `holiday` varchar(191) NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `leave_masters_session_year_id_foreign` (`session_year_id`),
  KEY `leave_masters_school_id_foreign` (`school_id`),
  CONSTRAINT `leave_masters_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `leave_masters_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `leaves` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL,
  `reason` varchar(191) NOT NULL,
  `from_date` date NOT NULL,
  `to_date` date NOT NULL,
  `status` int(11) NOT NULL DEFAULT 0 COMMENT '0 => Pending, 1 => Approved, 2 => Rejected',
  `school_id` bigint(20) unsigned NOT NULL,
  `leave_master_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `leaves_school_id_foreign` (`school_id`),
  KEY `leaves_leave_master_id_foreign` (`leave_master_id`),
  KEY `leaves_user_id_foreign` (`user_id`),
  CONSTRAINT `leaves_leave_master_id_foreign` FOREIGN KEY (`leave_master_id`) REFERENCES `leave_masters` (`id`) ON DELETE CASCADE,
  CONSTRAINT `leaves_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `leaves_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `lesson_commons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `lesson_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `lesson_commons_lesson_id_foreign` (`lesson_id`),
  KEY `lesson_commons_class_section_id_foreign` (`class_section_id`),
  CONSTRAINT `lesson_commons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `lesson_commons_lesson_id_foreign` FOREIGN KEY (`lesson_id`) REFERENCES `lessons` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `lesson_topics` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `lesson_id` bigint(20) unsigned NOT NULL,
  `name` varchar(128) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `lesson_topics_lesson_id_foreign` (`lesson_id`),
  KEY `lesson_topics_school_id_foreign` (`school_id`),
  CONSTRAINT `lesson_topics_lesson_id_foreign` FOREIGN KEY (`lesson_id`) REFERENCES `lessons` (`id`) ON DELETE CASCADE,
  CONSTRAINT `lesson_topics_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `lessons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `lessons_school_id_foreign` (`school_id`),
  KEY `lessons_class_section_id_foreign` (`class_section_id`),
  KEY `lessons_class_subject_id_foreign` (`class_subject_id`),
  CONSTRAINT `lessons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `lessons_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `lessons_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `mediums` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `mediums_school_id_foreign` (`school_id`),
  CONSTRAINT `mediums_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `mediums` VALUES ('1', 'English', '1', NULL, '2024-03-14 03:40:52', '2024-03-14 03:40:52');
INSERT INTO `mediums` VALUES ('2', 'Ga', '1', NULL, '2024-06-20 19:48:24', '2024-06-20 19:48:24');
INSERT INTO `mediums` VALUES ('3', 'Twi', '1', NULL, '2024-06-20 19:48:36', '2024-06-20 19:48:36');
INSERT INTO `mediums` VALUES ('4', 'French', '1', NULL, '2024-07-10 14:46:27', '2024-07-10 14:46:27');

CREATE TABLE IF NOT EXISTS `model_has_permissions` (
  `permission_id` bigint(20) unsigned NOT NULL,
  `model_type` varchar(191) NOT NULL,
  `model_id` bigint(20) unsigned NOT NULL,
  PRIMARY KEY (`permission_id`,`model_id`,`model_type`),
  KEY `model_has_permissions_model_id_model_type_index` (`model_id`,`model_type`),
  CONSTRAINT `model_has_permissions_permission_id_foreign` FOREIGN KEY (`permission_id`) REFERENCES `permissions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `model_has_permissions` VALUES ('114', 'App\\Models\\User', '8');
INSERT INTO `model_has_permissions` VALUES ('115', 'App\\Models\\User', '8');
INSERT INTO `model_has_permissions` VALUES ('123', 'App\\Models\\User', '8');

CREATE TABLE IF NOT EXISTS `model_has_roles` (
  `role_id` bigint(20) unsigned NOT NULL,
  `model_type` varchar(191) NOT NULL,
  `model_id` bigint(20) unsigned NOT NULL,
  PRIMARY KEY (`role_id`,`model_id`,`model_type`),
  KEY `model_has_roles_model_id_model_type_index` (`model_id`,`model_type`),
  CONSTRAINT `model_has_roles_role_id_foreign` FOREIGN KEY (`role_id`) REFERENCES `roles` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '2');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '3');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '4');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '5');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '7');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '10');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '12');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '14');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '16');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '18');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '20');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '22');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '24');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '26');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '28');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '30');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '32');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '34');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '36');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '39');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '41');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '43');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '45');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '47');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '49');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '51');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '53');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '55');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '57');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '59');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '61');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '63');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '65');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '67');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '71');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '73');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '75');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '77');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '79');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '81');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '83');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '85');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '87');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '89');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '91');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '93');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '95');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '97');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '99');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '101');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '103');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '106');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '108');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '110');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '112');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '114');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '116');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '118');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '120');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '122');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '124');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '126');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '128');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '130');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '132');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '134');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '136');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '138');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '140');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '142');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '144');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '146');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '148');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '150');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '152');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '154');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '156');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '158');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '160');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '162');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '164');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '166');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '168');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '170');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '172');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '174');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '176');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '178');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '180');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '182');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '185');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '187');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '189');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '191');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '193');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '195');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '197');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '199');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '201');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '203');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '205');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '207');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '209');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '211');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '213');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '215');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '217');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '219');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '221');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '224');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '226');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '228');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '230');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '232');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '234');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '236');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '238');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '240');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '242');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '244');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '247');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '249');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '251');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '253');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '255');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '257');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '259');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '261');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '263');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '265');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '267');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '269');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '271');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '274');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '276');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '278');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '280');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '282');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '284');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '286');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '288');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '290');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '292');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '294');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '296');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '298');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '300');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '302');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '304');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '306');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '308');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '310');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '312');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '314');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '316');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '318');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '320');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '322');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '324');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '326');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '328');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '330');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '332');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '335');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '337');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '339');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '341');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '343');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '345');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '347');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '350');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '352');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '354');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '357');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '359');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '361');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '363');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '365');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '367');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '369');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '371');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '373');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '375');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '377');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '379');
INSERT INTO `model_has_roles` VALUES ('5', 'App\\Models\\User', '381');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '11');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '13');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '15');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '27');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '33');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '35');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '37');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '38');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '40');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '42');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '44');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '46');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '48');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '50');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '52');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '54');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '56');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '58');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '60');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '62');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '64');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '66');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '68');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '69');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '72');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '74');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '80');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '82');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '84');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '86');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '88');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '90');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '92');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '94');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '96');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '98');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '100');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '102');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '104');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '105');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '107');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '109');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '111');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '113');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '115');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '117');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '119');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '121');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '123');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '125');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '127');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '129');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '131');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '133');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '135');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '137');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '139');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '141');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '143');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '145');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '147');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '151');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '153');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '155');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '157');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '159');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '161');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '163');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '165');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '167');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '169');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '171');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '173');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '175');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '177');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '179');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '181');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '183');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '184');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '186');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '188');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '190');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '192');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '194');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '196');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '198');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '200');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '202');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '204');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '206');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '208');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '212');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '214');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '216');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '218');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '220');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '222');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '223');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '225');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '227');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '229');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '231');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '233');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '235');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '237');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '239');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '241');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '243');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '245');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '246');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '248');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '250');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '252');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '254');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '256');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '258');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '260');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '262');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '264');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '266');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '268');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '270');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '272');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '273');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '275');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '277');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '279');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '281');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '283');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '285');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '287');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '289');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '291');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '293');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '295');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '297');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '299');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '301');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '303');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '305');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '307');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '309');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '311');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '313');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '315');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '317');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '319');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '321');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '323');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '325');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '327');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '329');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '331');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '333');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '334');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '336');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '338');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '340');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '342');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '344');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '346');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '348');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '349');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '351');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '353');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '355');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '356');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '358');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '360');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '362');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '364');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '366');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '368');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '370');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '372');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '374');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '376');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '378');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '380');
INSERT INTO `model_has_roles` VALUES ('6', 'App\\Models\\User', '382');

CREATE TABLE IF NOT EXISTS `notifications` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(191) NOT NULL,
  `message` varchar(191) DEFAULT NULL,
  `image` varchar(191) DEFAULT NULL,
  `send_to` varchar(191) NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `notifications_session_year_id_foreign` (`session_year_id`),
  KEY `notifications_school_id_foreign` (`school_id`),
  CONSTRAINT `notifications_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `notifications_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `online_exam_commons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `online_exam_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_commons_online_exam_id_foreign` (`online_exam_id`),
  KEY `online_exam_commons_class_section_id_foreign` (`class_section_id`),
  CONSTRAINT `online_exam_commons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_commons_online_exam_id_foreign` FOREIGN KEY (`online_exam_id`) REFERENCES `online_exams` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `online_exam_question_choices` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `online_exam_id` bigint(20) unsigned NOT NULL,
  `question_id` bigint(20) unsigned NOT NULL,
  `marks` int(11) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_question_choices_school_id_foreign` (`school_id`),
  KEY `online_exam_question_choices_online_exam_id_foreign` (`online_exam_id`),
  KEY `online_exam_question_choices_question_id_foreign` (`question_id`),
  CONSTRAINT `online_exam_question_choices_online_exam_id_foreign` FOREIGN KEY (`online_exam_id`) REFERENCES `online_exams` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_question_choices_question_id_foreign` FOREIGN KEY (`question_id`) REFERENCES `online_exam_questions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_question_choices_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `online_exam_question_commons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `online_exam_question_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_question_commons_online_exam_question_id_foreign` (`online_exam_question_id`),
  KEY `online_exam_question_commons_class_section_id_foreign` (`class_section_id`),
  CONSTRAINT `online_exam_question_commons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_question_commons_online_exam_question_id_foreign` FOREIGN KEY (`online_exam_question_id`) REFERENCES `online_exam_questions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `online_exam_question_options` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `question_id` bigint(20) unsigned NOT NULL,
  `option` varchar(1024) NOT NULL,
  `is_answer` tinyint(4) NOT NULL COMMENT '1 - yes, 0 - no',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_question_options_question_id_foreign` (`question_id`),
  KEY `online_exam_question_options_school_id_foreign` (`school_id`),
  CONSTRAINT `online_exam_question_options_question_id_foreign` FOREIGN KEY (`question_id`) REFERENCES `online_exam_questions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_question_options_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `online_exam_questions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `question` varchar(1024) NOT NULL,
  `image_url` varchar(1024) DEFAULT NULL,
  `note` varchar(1024) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `last_edited_by` bigint(20) unsigned NOT NULL COMMENT 'teacher_user_id',
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_questions_school_id_foreign` (`school_id`),
  KEY `online_exam_questions_class_section_id_foreign` (`class_section_id`),
  KEY `online_exam_questions_class_subject_id_foreign` (`class_subject_id`),
  KEY `online_exam_questions_last_edited_by_foreign` (`last_edited_by`),
  CONSTRAINT `online_exam_questions_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_questions_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_questions_last_edited_by_foreign` FOREIGN KEY (`last_edited_by`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_questions_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `online_exam_student_answers` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `online_exam_id` bigint(20) unsigned NOT NULL,
  `question_id` bigint(20) unsigned NOT NULL,
  `option_id` bigint(20) unsigned NOT NULL,
  `submitted_date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_student_answers_school_id_foreign` (`school_id`),
  KEY `online_exam_student_answers_student_id_foreign` (`student_id`),
  KEY `online_exam_student_answers_online_exam_id_foreign` (`online_exam_id`),
  KEY `online_exam_student_answers_question_id_foreign` (`question_id`),
  KEY `online_exam_student_answers_option_id_foreign` (`option_id`),
  CONSTRAINT `online_exam_student_answers_online_exam_id_foreign` FOREIGN KEY (`online_exam_id`) REFERENCES `online_exams` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_student_answers_option_id_foreign` FOREIGN KEY (`option_id`) REFERENCES `online_exam_question_options` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_student_answers_question_id_foreign` FOREIGN KEY (`question_id`) REFERENCES `online_exam_question_choices` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_student_answers_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_student_answers_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `online_exams` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `title` varchar(128) NOT NULL,
  `exam_key` bigint(20) NOT NULL,
  `duration` int(11) NOT NULL COMMENT 'in minutes',
  `start_date` datetime NOT NULL,
  `end_date` datetime NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exams_school_id_foreign` (`school_id`),
  KEY `online_exams_class_section_id_foreign` (`class_section_id`),
  KEY `online_exams_class_subject_id_foreign` (`class_subject_id`),
  KEY `online_exams_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `online_exams_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exams_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exams_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exams_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `optional_fees` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `class_id` bigint(20) unsigned NOT NULL,
  `payment_transaction_id` bigint(20) unsigned DEFAULT NULL,
  `fees_class_id` bigint(20) unsigned DEFAULT NULL,
  `mode` enum('Cash','Cheque','Online') NOT NULL,
  `cheque_no` varchar(191) DEFAULT NULL,
  `amount` double(8,2) NOT NULL,
  `fees_paid_id` bigint(20) unsigned DEFAULT NULL,
  `date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `status` enum('Success','Pending','Failed') NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `optional_fees_school_id_foreign` (`school_id`),
  KEY `optional_fees_student_id_foreign` (`student_id`),
  KEY `optional_fees_class_id_foreign` (`class_id`),
  KEY `optional_fees_payment_transaction_id_foreign` (`payment_transaction_id`),
  KEY `optional_fees_fees_paid_id_foreign` (`fees_paid_id`),
  KEY `optional_fees_fees_class_id_foreign` (`fees_class_id`),
  CONSTRAINT `optional_fees_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `optional_fees_fees_class_id_foreign` FOREIGN KEY (`fees_class_id`) REFERENCES `fees_class_types` (`id`) ON DELETE CASCADE,
  CONSTRAINT `optional_fees_fees_paid_id_foreign` FOREIGN KEY (`fees_paid_id`) REFERENCES `fees_paids` (`id`) ON DELETE CASCADE,
  CONSTRAINT `optional_fees_payment_transaction_id_foreign` FOREIGN KEY (`payment_transaction_id`) REFERENCES `payment_transactions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `optional_fees_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `optional_fees_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `payment_configurations` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `payment_method` varchar(191) NOT NULL,
  `api_key` varchar(191) NOT NULL,
  `secret_key` varchar(191) NOT NULL,
  `webhook_secret_key` varchar(191) NOT NULL,
  `bank_name` varchar(191) DEFAULT NULL,
  `account_name` varchar(191) DEFAULT NULL,
  `account_no` varchar(191) DEFAULT NULL,
  `currency_code` varchar(128) DEFAULT NULL,
  `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '0 - Disabled, 1 - Enabled',
  `school_id` bigint(20) unsigned DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `payment_configurations_school_id_foreign` (`school_id`),
  CONSTRAINT `payment_configurations_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `payment_transactions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL,
  `amount` double(64,2) NOT NULL,
  `payment_gateway` varchar(191) NOT NULL,
  `order_id` varchar(191) DEFAULT NULL COMMENT 'order_id / payment_intent_id',
  `payment_id` varchar(191) DEFAULT NULL,
  `payment_signature` varchar(191) DEFAULT NULL,
  `payment_status` enum('failed','succeed','pending') NOT NULL,
  `school_id` bigint(20) unsigned DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `payment_transactions_school_id_foreign` (`school_id`),
  KEY `payment_transactions_user_id_foreign` (`user_id`),
  CONSTRAINT `payment_transactions_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `payment_transactions_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `payment_transactions` VALUES ('1', '2', '210.18', 'Stripe', NULL, NULL, NULL, 'succeed', '1', '2024-08-09 14:50:22', '2024-10-24 17:34:23');

CREATE TABLE IF NOT EXISTS `payroll_settings` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `amount` double DEFAULT NULL,
  `percentage` double(8,2) DEFAULT NULL,
  `type` varchar(191) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `payroll_settings_school_id_foreign` (`school_id`),
  CONSTRAINT `payroll_settings_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `permissions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `guard_name` varchar(191) NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `permissions_name_guard_name_unique` (`name`,`guard_name`)
) ENGINE=InnoDB AUTO_INCREMENT=1328 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `permissions` VALUES ('1', 'role-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('2', 'role-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('3', 'role-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('4', 'role-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('5', 'medium-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('6', 'medium-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('7', 'medium-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('8', 'medium-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('9', 'section-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('10', 'section-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('11', 'section-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('12', 'section-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('13', 'class-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('14', 'class-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('15', 'class-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('16', 'class-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('17', 'class-section-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('18', 'class-section-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('19', 'class-section-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('20', 'class-section-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('21', 'subject-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('22', 'subject-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('23', 'subject-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('24', 'subject-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('25', 'teacher-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('26', 'teacher-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('27', 'teacher-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('28', 'teacher-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('29', 'guardian-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('30', 'guardian-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('31', 'guardian-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('32', 'guardian-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('33', 'session-year-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('34', 'session-year-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('35', 'session-year-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('36', 'session-year-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('37', 'student-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('38', 'student-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('39', 'student-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('40', 'student-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('41', 'timetable-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('42', 'timetable-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('43', 'timetable-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('44', 'timetable-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('45', 'attendance-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('46', 'attendance-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('47', 'attendance-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('48', 'attendance-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('49', 'holiday-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('50', 'holiday-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('51', 'holiday-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('52', 'holiday-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('53', 'announcement-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('54', 'announcement-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('55', 'announcement-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('56', 'announcement-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('57', 'slider-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('58', 'slider-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('59', 'slider-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('60', 'slider-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('61', 'promote-student-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('62', 'promote-student-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('63', 'promote-student-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('64', 'promote-student-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('65', 'language-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('66', 'language-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('67', 'language-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('68', 'language-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('69', 'lesson-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('70', 'lesson-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('71', 'lesson-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('72', 'lesson-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('73', 'topic-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('74', 'topic-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('75', 'topic-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('76', 'topic-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('77', 'schools-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('78', 'schools-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('79', 'schools-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('80', 'schools-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('81', 'form-fields-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('82', 'form-fields-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('83', 'form-fields-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('84', 'form-fields-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('85', 'grade-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('86', 'grade-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('87', 'grade-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('88', 'grade-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('89', 'package-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('90', 'package-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('91', 'package-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('92', 'package-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('93', 'addons-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('94', 'addons-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('95', 'addons-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('96', 'addons-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('97', 'guidance-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('98', 'guidance-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('99', 'guidance-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('100', 'guidance-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('101', 'assignment-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('102', 'assignment-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('103', 'assignment-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('104', 'assignment-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('105', 'assignment-submission', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('106', 'exam-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('107', 'exam-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('108', 'exam-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('109', 'exam-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('110', 'exam-timetable-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('111', 'exam-timetable-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('112', 'exam-timetable-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('113', 'exam-timetable-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('114', 'exam-upload-marks', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('115', 'exam-result', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('116', 'system-setting-manage', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('117', 'fcm-setting-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('118', 'email-setting-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('119', 'privacy-policy', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('120', 'contact-us', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('121', 'about-us', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('122', 'terms-condition', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('123', 'class-teacher', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('124', 'student-reset-password', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('125', 'reset-password-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('126', 'student-change-password', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('127', 'update-admin-profile', 'web', '2024-03-07 03:04:30', '2024-04-07 13:29:33');
INSERT INTO `permissions` VALUES ('128', 'fees-classes', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('129', 'fees-paid', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('130', 'fees-config', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('131', 'school-setting-manage', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('132', 'app-settings', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('133', 'subscription-view', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('134', 'online-exam-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('135', 'online-exam-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('136', 'online-exam-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('137', 'online-exam-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('138', 'online-exam-questions-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('139', 'online-exam-questions-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('140', 'online-exam-questions-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('141', 'online-exam-questions-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('142', 'online-exam-result-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('143', 'fees-type-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('144', 'fees-type-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('145', 'fees-type-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('146', 'fees-type-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('147', 'fees-class-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('148', 'fees-class-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('149', 'fees-class-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('150', 'fees-class-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('151', 'staff-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('152', 'staff-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('153', 'staff-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('154', 'staff-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('155', 'expense-category-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('156', 'expense-category-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('157', 'expense-category-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('158', 'expense-category-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('159', 'expense-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('160', 'expense-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('161', 'expense-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('162', 'expense-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('163', 'semester-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('164', 'semester-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('165', 'semester-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('166', 'semester-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('167', 'payroll-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('168', 'payroll-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('169', 'payroll-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('170', 'payroll-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('171', 'stream-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('172', 'stream-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('173', 'stream-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('174', 'stream-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('175', 'shift-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('176', 'shift-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('177', 'shift-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('178', 'shift-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('179', 'leave-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('180', 'leave-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('181', 'leave-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('182', 'leave-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('183', 'approve-leave', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('184', 'faqs-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('185', 'faqs-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('186', 'faqs-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('187', 'faqs-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('188', 'fcm-setting-manage', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('189', 'fees-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('190', 'fees-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('191', 'fees-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('192', 'fees-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('193', 'transfer-student-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('194', 'transfer-student-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('195', 'transfer-student-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('196', 'transfer-student-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('197', 'gallery-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('198', 'gallery-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('199', 'gallery-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('200', 'gallery-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('201', 'notification-list', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('202', 'notification-create', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('203', 'notification-edit', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('204', 'notification-delete', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('205', 'payment-settings', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('206', 'subscription-settings', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('207', 'subscription-change-bills', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('208', 'school-terms-condition', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('209', 'student-id-card-settings', 'web', '2024-03-07 03:04:30', '2024-05-31 06:48:04');
INSERT INTO `permissions` VALUES ('210', 'subscription-bill-payment', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('211', 'web-settings', 'web', '2024-03-07 03:04:30', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('862', 'exam-result-edit', 'web', '2024-05-27 05:39:58', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1078', 'id-card-settings', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1079', 'certificate-list', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1080', 'certificate-create', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1081', 'certificate-edit', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1082', 'certificate-delete', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1083', 'payroll-settings-list', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1084', 'payroll-settings-create', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1085', 'payroll-settings-edit', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1086', 'payroll-settings-delete', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1087', 'school-web-settings', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1088', 'class-group-list', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1089', 'class-group-create', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1090', 'class-group-edit', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1091', 'class-group-delete', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1092', 'email-template', 'web', '2024-06-29 21:35:52', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1094', 'front-site-setting', 'web', '2024-10-24 17:37:49', '2024-10-24 17:41:30');
INSERT INTO `permissions` VALUES ('1095', 'custom-school-email', 'web', '2024-10-24 17:37:49', '2024-10-24 17:41:30');
INSERT INTO `permissions` VALUES ('1096', 'database-backup', 'web', '2024-10-24 19:59:11', '2025-01-04 05:54:44');
INSERT INTO `permissions` VALUES ('1097', 'view-exam-marks', 'web', '2025-01-04 05:54:44', '2025-01-04 05:54:44');

CREATE TABLE IF NOT EXISTS `promote_students` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `class_section_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `result` tinyint(4) NOT NULL DEFAULT 1 COMMENT '1=>Pass,0=>fail',
  `status` tinyint(4) NOT NULL DEFAULT 1 COMMENT '1=>continue,0=>leave',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_columns` (`student_id`,`class_section_id`,`session_year_id`),
  KEY `promote_students_school_id_foreign` (`school_id`),
  KEY `promote_students_class_section_id_foreign` (`class_section_id`),
  KEY `promote_students_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `promote_students_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `promote_students_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `promote_students_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `promote_students_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `role_has_permissions` (
  `permission_id` bigint(20) unsigned NOT NULL,
  `role_id` bigint(20) unsigned NOT NULL,
  PRIMARY KEY (`permission_id`,`role_id`),
  KEY `role_has_permissions_role_id_foreign` (`role_id`),
  CONSTRAINT `role_has_permissions_permission_id_foreign` FOREIGN KEY (`permission_id`) REFERENCES `permissions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `role_has_permissions_role_id_foreign` FOREIGN KEY (`role_id`) REFERENCES `roles` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `role_has_permissions` VALUES ('1', '2');
INSERT INTO `role_has_permissions` VALUES ('2', '2');
INSERT INTO `role_has_permissions` VALUES ('3', '2');
INSERT INTO `role_has_permissions` VALUES ('4', '2');
INSERT INTO `role_has_permissions` VALUES ('5', '2');
INSERT INTO `role_has_permissions` VALUES ('6', '2');
INSERT INTO `role_has_permissions` VALUES ('7', '2');
INSERT INTO `role_has_permissions` VALUES ('8', '2');
INSERT INTO `role_has_permissions` VALUES ('9', '2');
INSERT INTO `role_has_permissions` VALUES ('10', '2');
INSERT INTO `role_has_permissions` VALUES ('11', '2');
INSERT INTO `role_has_permissions` VALUES ('12', '2');
INSERT INTO `role_has_permissions` VALUES ('13', '2');
INSERT INTO `role_has_permissions` VALUES ('14', '2');
INSERT INTO `role_has_permissions` VALUES ('15', '2');
INSERT INTO `role_has_permissions` VALUES ('16', '2');
INSERT INTO `role_has_permissions` VALUES ('17', '2');
INSERT INTO `role_has_permissions` VALUES ('18', '2');
INSERT INTO `role_has_permissions` VALUES ('19', '2');
INSERT INTO `role_has_permissions` VALUES ('20', '2');
INSERT INTO `role_has_permissions` VALUES ('21', '2');
INSERT INTO `role_has_permissions` VALUES ('22', '2');
INSERT INTO `role_has_permissions` VALUES ('23', '2');
INSERT INTO `role_has_permissions` VALUES ('24', '2');
INSERT INTO `role_has_permissions` VALUES ('25', '2');
INSERT INTO `role_has_permissions` VALUES ('26', '2');
INSERT INTO `role_has_permissions` VALUES ('27', '2');
INSERT INTO `role_has_permissions` VALUES ('28', '2');
INSERT INTO `role_has_permissions` VALUES ('29', '2');
INSERT INTO `role_has_permissions` VALUES ('30', '2');
INSERT INTO `role_has_permissions` VALUES ('31', '2');
INSERT INTO `role_has_permissions` VALUES ('32', '2');
INSERT INTO `role_has_permissions` VALUES ('33', '2');
INSERT INTO `role_has_permissions` VALUES ('34', '2');
INSERT INTO `role_has_permissions` VALUES ('35', '2');
INSERT INTO `role_has_permissions` VALUES ('36', '2');
INSERT INTO `role_has_permissions` VALUES ('37', '2');
INSERT INTO `role_has_permissions` VALUES ('38', '2');
INSERT INTO `role_has_permissions` VALUES ('39', '2');
INSERT INTO `role_has_permissions` VALUES ('40', '2');
INSERT INTO `role_has_permissions` VALUES ('41', '2');
INSERT INTO `role_has_permissions` VALUES ('42', '2');
INSERT INTO `role_has_permissions` VALUES ('43', '2');
INSERT INTO `role_has_permissions` VALUES ('44', '2');
INSERT INTO `role_has_permissions` VALUES ('45', '2');
INSERT INTO `role_has_permissions` VALUES ('49', '2');
INSERT INTO `role_has_permissions` VALUES ('50', '2');
INSERT INTO `role_has_permissions` VALUES ('51', '2');
INSERT INTO `role_has_permissions` VALUES ('52', '2');
INSERT INTO `role_has_permissions` VALUES ('53', '2');
INSERT INTO `role_has_permissions` VALUES ('54', '2');
INSERT INTO `role_has_permissions` VALUES ('55', '2');
INSERT INTO `role_has_permissions` VALUES ('56', '2');
INSERT INTO `role_has_permissions` VALUES ('57', '2');
INSERT INTO `role_has_permissions` VALUES ('58', '2');
INSERT INTO `role_has_permissions` VALUES ('59', '2');
INSERT INTO `role_has_permissions` VALUES ('60', '2');
INSERT INTO `role_has_permissions` VALUES ('61', '2');
INSERT INTO `role_has_permissions` VALUES ('62', '2');
INSERT INTO `role_has_permissions` VALUES ('63', '2');
INSERT INTO `role_has_permissions` VALUES ('64', '2');
INSERT INTO `role_has_permissions` VALUES ('81', '2');
INSERT INTO `role_has_permissions` VALUES ('82', '2');
INSERT INTO `role_has_permissions` VALUES ('83', '2');
INSERT INTO `role_has_permissions` VALUES ('84', '2');
INSERT INTO `role_has_permissions` VALUES ('85', '2');
INSERT INTO `role_has_permissions` VALUES ('86', '2');
INSERT INTO `role_has_permissions` VALUES ('87', '2');
INSERT INTO `role_has_permissions` VALUES ('88', '2');
INSERT INTO `role_has_permissions` VALUES ('105', '2');
INSERT INTO `role_has_permissions` VALUES ('106', '2');
INSERT INTO `role_has_permissions` VALUES ('107', '2');
INSERT INTO `role_has_permissions` VALUES ('108', '2');
INSERT INTO `role_has_permissions` VALUES ('109', '2');
INSERT INTO `role_has_permissions` VALUES ('110', '2');
INSERT INTO `role_has_permissions` VALUES ('111', '2');
INSERT INTO `role_has_permissions` VALUES ('113', '2');
INSERT INTO `role_has_permissions` VALUES ('115', '2');
INSERT INTO `role_has_permissions` VALUES ('124', '2');
INSERT INTO `role_has_permissions` VALUES ('125', '2');
INSERT INTO `role_has_permissions` VALUES ('126', '2');
INSERT INTO `role_has_permissions` VALUES ('129', '2');
INSERT INTO `role_has_permissions` VALUES ('130', '2');
INSERT INTO `role_has_permissions` VALUES ('131', '2');
INSERT INTO `role_has_permissions` VALUES ('134', '2');
INSERT INTO `role_has_permissions` VALUES ('135', '2');
INSERT INTO `role_has_permissions` VALUES ('136', '2');
INSERT INTO `role_has_permissions` VALUES ('137', '2');
INSERT INTO `role_has_permissions` VALUES ('138', '2');
INSERT INTO `role_has_permissions` VALUES ('139', '2');
INSERT INTO `role_has_permissions` VALUES ('140', '2');
INSERT INTO `role_has_permissions` VALUES ('141', '2');
INSERT INTO `role_has_permissions` VALUES ('142', '2');
INSERT INTO `role_has_permissions` VALUES ('143', '2');
INSERT INTO `role_has_permissions` VALUES ('144', '2');
INSERT INTO `role_has_permissions` VALUES ('145', '2');
INSERT INTO `role_has_permissions` VALUES ('146', '2');
INSERT INTO `role_has_permissions` VALUES ('147', '2');
INSERT INTO `role_has_permissions` VALUES ('148', '2');
INSERT INTO `role_has_permissions` VALUES ('149', '2');
INSERT INTO `role_has_permissions` VALUES ('150', '2');
INSERT INTO `role_has_permissions` VALUES ('151', '2');
INSERT INTO `role_has_permissions` VALUES ('152', '2');
INSERT INTO `role_has_permissions` VALUES ('153', '2');
INSERT INTO `role_has_permissions` VALUES ('154', '2');
INSERT INTO `role_has_permissions` VALUES ('155', '2');
INSERT INTO `role_has_permissions` VALUES ('156', '2');
INSERT INTO `role_has_permissions` VALUES ('157', '2');
INSERT INTO `role_has_permissions` VALUES ('158', '2');
INSERT INTO `role_has_permissions` VALUES ('159', '2');
INSERT INTO `role_has_permissions` VALUES ('160', '2');
INSERT INTO `role_has_permissions` VALUES ('161', '2');
INSERT INTO `role_has_permissions` VALUES ('162', '2');
INSERT INTO `role_has_permissions` VALUES ('163', '2');
INSERT INTO `role_has_permissions` VALUES ('164', '2');
INSERT INTO `role_has_permissions` VALUES ('165', '2');
INSERT INTO `role_has_permissions` VALUES ('166', '2');
INSERT INTO `role_has_permissions` VALUES ('167', '2');
INSERT INTO `role_has_permissions` VALUES ('168', '2');
INSERT INTO `role_has_permissions` VALUES ('169', '2');
INSERT INTO `role_has_permissions` VALUES ('170', '2');
INSERT INTO `role_has_permissions` VALUES ('171', '2');
INSERT INTO `role_has_permissions` VALUES ('172', '2');
INSERT INTO `role_has_permissions` VALUES ('173', '2');
INSERT INTO `role_has_permissions` VALUES ('174', '2');
INSERT INTO `role_has_permissions` VALUES ('175', '2');
INSERT INTO `role_has_permissions` VALUES ('176', '2');
INSERT INTO `role_has_permissions` VALUES ('177', '2');
INSERT INTO `role_has_permissions` VALUES ('178', '2');
INSERT INTO `role_has_permissions` VALUES ('183', '2');
INSERT INTO `role_has_permissions` VALUES ('184', '2');
INSERT INTO `role_has_permissions` VALUES ('185', '2');
INSERT INTO `role_has_permissions` VALUES ('186', '2');
INSERT INTO `role_has_permissions` VALUES ('187', '2');
INSERT INTO `role_has_permissions` VALUES ('189', '2');
INSERT INTO `role_has_permissions` VALUES ('190', '2');
INSERT INTO `role_has_permissions` VALUES ('191', '2');
INSERT INTO `role_has_permissions` VALUES ('192', '2');
INSERT INTO `role_has_permissions` VALUES ('193', '2');
INSERT INTO `role_has_permissions` VALUES ('194', '2');
INSERT INTO `role_has_permissions` VALUES ('195', '2');
INSERT INTO `role_has_permissions` VALUES ('196', '2');
INSERT INTO `role_has_permissions` VALUES ('197', '2');
INSERT INTO `role_has_permissions` VALUES ('198', '2');
INSERT INTO `role_has_permissions` VALUES ('199', '2');
INSERT INTO `role_has_permissions` VALUES ('200', '2');
INSERT INTO `role_has_permissions` VALUES ('201', '2');
INSERT INTO `role_has_permissions` VALUES ('202', '2');
INSERT INTO `role_has_permissions` VALUES ('204', '2');
INSERT INTO `role_has_permissions` VALUES ('862', '2');
INSERT INTO `role_has_permissions` VALUES ('1078', '2');
INSERT INTO `role_has_permissions` VALUES ('1079', '2');
INSERT INTO `role_has_permissions` VALUES ('1080', '2');
INSERT INTO `role_has_permissions` VALUES ('1081', '2');
INSERT INTO `role_has_permissions` VALUES ('1082', '2');
INSERT INTO `role_has_permissions` VALUES ('1083', '2');
INSERT INTO `role_has_permissions` VALUES ('1084', '2');
INSERT INTO `role_has_permissions` VALUES ('1085', '2');
INSERT INTO `role_has_permissions` VALUES ('1086', '2');
INSERT INTO `role_has_permissions` VALUES ('1087', '2');
INSERT INTO `role_has_permissions` VALUES ('1088', '2');
INSERT INTO `role_has_permissions` VALUES ('1089', '2');
INSERT INTO `role_has_permissions` VALUES ('1090', '2');
INSERT INTO `role_has_permissions` VALUES ('1091', '2');
INSERT INTO `role_has_permissions` VALUES ('1092', '2');
INSERT INTO `role_has_permissions` VALUES ('1096', '2');
INSERT INTO `role_has_permissions` VALUES ('1097', '2');
INSERT INTO `role_has_permissions` VALUES ('17', '7');
INSERT INTO `role_has_permissions` VALUES ('37', '7');
INSERT INTO `role_has_permissions` VALUES ('41', '7');
INSERT INTO `role_has_permissions` VALUES ('45', '7');
INSERT INTO `role_has_permissions` VALUES ('49', '7');
INSERT INTO `role_has_permissions` VALUES ('53', '7');
INSERT INTO `role_has_permissions` VALUES ('54', '7');
INSERT INTO `role_has_permissions` VALUES ('55', '7');
INSERT INTO `role_has_permissions` VALUES ('56', '7');
INSERT INTO `role_has_permissions` VALUES ('69', '7');
INSERT INTO `role_has_permissions` VALUES ('70', '7');
INSERT INTO `role_has_permissions` VALUES ('71', '7');
INSERT INTO `role_has_permissions` VALUES ('72', '7');
INSERT INTO `role_has_permissions` VALUES ('73', '7');
INSERT INTO `role_has_permissions` VALUES ('74', '7');
INSERT INTO `role_has_permissions` VALUES ('75', '7');
INSERT INTO `role_has_permissions` VALUES ('76', '7');
INSERT INTO `role_has_permissions` VALUES ('101', '7');
INSERT INTO `role_has_permissions` VALUES ('102', '7');
INSERT INTO `role_has_permissions` VALUES ('103', '7');
INSERT INTO `role_has_permissions` VALUES ('104', '7');
INSERT INTO `role_has_permissions` VALUES ('105', '7');
INSERT INTO `role_has_permissions` VALUES ('134', '7');
INSERT INTO `role_has_permissions` VALUES ('135', '7');
INSERT INTO `role_has_permissions` VALUES ('136', '7');
INSERT INTO `role_has_permissions` VALUES ('137', '7');
INSERT INTO `role_has_permissions` VALUES ('138', '7');
INSERT INTO `role_has_permissions` VALUES ('139', '7');
INSERT INTO `role_has_permissions` VALUES ('140', '7');
INSERT INTO `role_has_permissions` VALUES ('141', '7');
INSERT INTO `role_has_permissions` VALUES ('142', '7');
INSERT INTO `role_has_permissions` VALUES ('179', '7');
INSERT INTO `role_has_permissions` VALUES ('180', '7');
INSERT INTO `role_has_permissions` VALUES ('181', '7');
INSERT INTO `role_has_permissions` VALUES ('182', '7');

CREATE TABLE IF NOT EXISTS `roles` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `guard_name` varchar(191) NOT NULL,
  `school_id` bigint(20) unsigned DEFAULT NULL,
  `custom_role` tinyint(1) NOT NULL DEFAULT 1,
  `editable` tinyint(1) NOT NULL DEFAULT 1,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `roles_name_guard_name_school_id_unique` (`name`,`guard_name`,`school_id`),
  KEY `roles_school_id_foreign` (`school_id`),
  CONSTRAINT `roles_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `roles` VALUES ('2', 'School Admin', 'web', '1', '0', '0', NULL, NULL);
INSERT INTO `roles` VALUES ('5', 'Guardian', 'web', '1', '0', '0', '2024-03-13 05:31:12', '2024-03-13 05:31:12');
INSERT INTO `roles` VALUES ('6', 'Student', 'web', '1', '0', '0', '2024-03-13 05:31:12', '2024-03-13 05:31:12');
INSERT INTO `roles` VALUES ('7', 'Teacher', 'web', '1', '0', '1', '2024-03-13 05:31:12', '2024-03-13 05:31:12');

CREATE TABLE IF NOT EXISTS `school_settings` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `data` text NOT NULL,
  `type` varchar(191) DEFAULT NULL COMMENT 'datatype like string , file etc',
  `school_id` bigint(20) unsigned NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `school_settings_name_school_id_unique` (`name`,`school_id`),
  KEY `school_settings_school_id_foreign` (`school_id`),
  CONSTRAINT `school_settings_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=233 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `school_settings` VALUES ('1', 'school_name', 'Open Grace J.H.S', 'string', '1');
INSERT INTO `school_settings` VALUES ('2', 'school_email', 'gmacapon@gmail.com', 'string', '1');
INSERT INTO `school_settings` VALUES ('3', 'school_phone', '0244944725', 'number', '1');
INSERT INTO `school_settings` VALUES ('4', 'school_tagline', 'You build your future', 'string', '1');
INSERT INTO `school_settings` VALUES ('5', 'school_address', 'HNo. 21 Pentegost Street, New Weija.', 'string', '1');
INSERT INTO `school_settings` VALUES ('6', 'session_year', '1', 'number', '1');
INSERT INTO `school_settings` VALUES ('7', 'horizontal_logo', '1/school-settings/677585fe915724.628877411735755262.jpg', 'file', '1');
INSERT INTO `school_settings` VALUES ('8', 'vertical_logo', '1/school-settings/677585fe92d076.411191771735755262.jpg', 'file', '1');
INSERT INTO `school_settings` VALUES ('9', 'timetable_start_time', '09:00:00', 'time', '1');
INSERT INTO `school_settings` VALUES ('10', 'timetable_end_time', '18:00:00', 'time', '1');
INSERT INTO `school_settings` VALUES ('11', 'timetable_duration', '01:00:00', 'time', '1');
INSERT INTO `school_settings` VALUES ('12', 'auto_renewal_plan', '1', 'integer', '1');
INSERT INTO `school_settings` VALUES ('13', 'currency_code', 'INR', 'string', '1');
INSERT INTO `school_settings` VALUES ('14', 'currency_symbol', '₹', 'string', '1');
INSERT INTO `school_settings` VALUES ('15', 'date_format', 'd-m-Y', 'string', '1');
INSERT INTO `school_settings` VALUES ('16', 'time_format', 'h:i A', 'string', '1');
INSERT INTO `school_settings` VALUES ('86', 'email-template-parent', '&lt;p&gt;Dear {parent_name},&lt;/p&gt; &lt;p&gt;We are delighted to welcome {child_name} to {school_name}!&lt;/p&gt; &lt;p&gt;As part of our registration process, we have created accounts for both you and your child in our {school_name}. Below are the registration details you will need to access the system, along with links to download our mobile app for your convenience.&lt;/p&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;Student Credential Details:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;&lt;strong&gt;Name:&lt;/strong&gt; {child_name}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Admission No.: &lt;/strong&gt;{admission_no}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;GR No.:&lt;/strong&gt; {grno}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Password:&lt;/strong&gt; {child_password}&lt;/li&gt; &lt;/ul&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;Parent Credential Details:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;&lt;strong&gt;Name:&lt;/strong&gt; {parent_name}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Email:&lt;/strong&gt; {email}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Password:&lt;/strong&gt; {password}&lt;/li&gt; &lt;/ul&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;App Download Links:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;&lt;strong&gt;Android:&lt;/strong&gt; {android_app}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;iOS:&lt;/strong&gt; {ios_app}&lt;/li&gt; &lt;/ul&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;Steps to Complete the Registration:&lt;/strong&gt;&lt;/p&gt; &lt;ol&gt; &lt;li&gt;Download the school management app using the links above for easier access on your mobile devices.&lt;/li&gt; &lt;li&gt;Enter the email and password for either the student or parent account.&lt;/li&gt; &lt;li&gt;Follow the on-screen instructions to complete the profile setup.&lt;/li&gt; &lt;/ol&gt; &lt;p&gt;&lt;strong&gt;Important:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;For security reasons, please ensure that both the student and parent passwords are changed upon first login.&lt;/li&gt; &lt;li&gt;If you encounter any issues during the registration process, please do not hesitate to contact our support team at {support_email} or call {support_contact}.&lt;/li&gt; &lt;/ul&gt; &lt;p&gt;We look forward to an enriching educational experience for {child_name} at {school_name}. Thank you for entrusting us with your child&#039;s education.&lt;/p&gt; &lt;p&gt;Best regards,&lt;/p&gt; &lt;p&gt;{school_name}&lt;br&gt;{support_email}&lt;/p&gt;', 'text', '1');
INSERT INTO `school_settings` VALUES ('91', 'email-template-staff', '&lt;p&gt;Dear {full_name},&lt;/p&gt; &lt;p&gt;Welcome to {school_name}!&lt;/p&gt; &lt;p&gt;We are excited to have you join our team. Below are your registration details to access the {school_name}:&lt;/p&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;Your Registration Details:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;&lt;strong&gt;Registration URL:&lt;/strong&gt; {url}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Email:&lt;/strong&gt; {email}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Password:&lt;/strong&gt; {password}&lt;/li&gt; &lt;/ul&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;Steps to Complete Your Registration:&lt;/strong&gt;&lt;/p&gt; &lt;ol&gt; &lt;li&gt;Click on the registration URL provided above.&lt;/li&gt; &lt;li&gt;Enter your email and password.&lt;/li&gt; &lt;li&gt;Follow the on-screen instructions to set up your profile.&lt;/li&gt; &lt;/ol&gt; &lt;p&gt;&lt;strong&gt;Important:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;For security reasons, please change your password upon your first login.&lt;/li&gt; &lt;li&gt;If you have any questions or need assistance during the registration process, please contact our support team at {support_email} or call {support_contact}.&lt;/li&gt; &lt;/ul&gt; &lt;p&gt;&lt;strong&gt;App Download Links:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;&lt;strong&gt;Android:&lt;/strong&gt; {android_app}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;iOS:&lt;/strong&gt; {ios_app}&lt;/li&gt; &lt;/ul&gt; &lt;p&gt;We look forward to a successful academic year with you on our team. Thank you for your commitment to excellence in education.&lt;/p&gt; &lt;p&gt;Best regards,&lt;/p&gt; &lt;p&gt;{school_name}&lt;br&gt;{support_email}&lt;br&gt;{support_contact}&lt;br&gt;{url}&lt;/p&gt;', 'text', '1');
INSERT INTO `school_settings` VALUES ('96', 'domain', 'opengrace', 'string', '1');
INSERT INTO `school_settings` VALUES ('98', 'database_name', 'eschool_saas_1_open', 'text', '1');
INSERT INTO `school_settings` VALUES ('99', 'primary_color', '#22577a', 'string', '1');
INSERT INTO `school_settings` VALUES ('100', 'secondary_color', '#38a3a5', 'string', '1');
INSERT INTO `school_settings` VALUES ('101', 'primary_background_color', '#f2f5f7', 'string', '1');
INSERT INTO `school_settings` VALUES ('102', 'text_secondary_color', '#2d2c2fb5', 'string', '1');
INSERT INTO `school_settings` VALUES ('103', 'primary_hover_color', '#143449', 'string', '1');
INSERT INTO `school_settings` VALUES ('104', 'about_us_title', 'About Us', 'string', '1');
INSERT INTO `school_settings` VALUES ('105', 'about_us_heading', 'Personalized Learning for Every Student', 'string', '1');
INSERT INTO `school_settings` VALUES ('106', 'about_us_description', 'Briefly introduce your school, including its name, location, and level of 
education (elementary, high school, etc.). Highlight your school\'s 
mission statement. This concise statement captures the core purpose 
and philosophy that guides everything you do.

Briefly introduce your school, including its name, location, and level of 
education (elementary, high school, etc.). Highlight your school\'s 
mission statement. This concise statement captures the core purpose 
and philosophy that guides everything you do.', 'string', '1');
INSERT INTO `school_settings` VALUES ('107', 'about_us_image', '1/school-settings/67757a6f104029.364104601735752303.png', 'file', '1');
INSERT INTO `school_settings` VALUES ('108', 'about_us_status', '1', 'string', '1');
INSERT INTO `school_settings` VALUES ('109', 'education_program_title', 'Educational Programs', 'string', '1');
INSERT INTO `school_settings` VALUES ('110', 'education_program_heading', 'Educational Programs for every Stage', 'string', '1');
INSERT INTO `school_settings` VALUES ('111', 'education_program_description', 'Educational programs are tailored to cater to every stage of learning, ensuring comprehensive development from early childhood to adulthood.', 'string', '1');
INSERT INTO `school_settings` VALUES ('112', 'education_program_status', '1', 'string', '1');
INSERT INTO `school_settings` VALUES ('113', 'expert_teachers_title', 'Our Expert Teacher', 'string', '1');
INSERT INTO `school_settings` VALUES ('114', 'expert_teachers_heading', 'More Than Just Teachers, They\'re Mentors', 'string', '1');
INSERT INTO `school_settings` VALUES ('115', 'expert_teachers_description', 'Educational programs are tailored to cater to every stage of learning, 
ensuring comprehensive development from early childhood to adulthood', 'string', '1');
INSERT INTO `school_settings` VALUES ('116', 'expert_teachers_status', '1', 'string', '1');
INSERT INTO `school_settings` VALUES ('117', 'faqs_title', 'Frequently Asked Questions', 'string', '1');
INSERT INTO `school_settings` VALUES ('118', 'faqs_heading', 'Know More About eSchool', 'string', '1');
INSERT INTO `school_settings` VALUES ('119', 'faqs_description', 'We\'ve got answers! Explore our comprehensive collection of frequently asked 
questions to find solutions to common queries.', 'string', '1');
INSERT INTO `school_settings` VALUES ('120', 'faqs_status', '1', 'string', '1');
INSERT INTO `school_settings` VALUES ('121', 'counter_title', 'CTCA-Contes', 'string', '1');
INSERT INTO `school_settings` VALUES ('122', 'counter_heading', 'Educational Programs for every Stage', 'string', '1');
INSERT INTO `school_settings` VALUES ('123', 'counter_description', 'Educational programs are tailored to cater to every stage of learning, 
ensuring comprehensive development from early childhood to adulthood.', 'string', '1');
INSERT INTO `school_settings` VALUES ('124', 'counter_teacher', '1/school-settings/67757a6f4aa1f3.624980751735752303.jpg', 'file', '1');
INSERT INTO `school_settings` VALUES ('125', 'counter_status', '1', 'string', '1');
INSERT INTO `school_settings` VALUES ('126', 'our_mission_title', 'Who We Are', 'string', '1');
INSERT INTO `school_settings` VALUES ('127', 'our_mission_heading', 'Discover Our Mission for eSchool', 'string', '1');
INSERT INTO `school_settings` VALUES ('128', 'our_mission_description', 'Welcome to eSchool, where education meets inspiration, and every
child\'s journey is a story of growth and discovery', 'string', '1');
INSERT INTO `school_settings` VALUES ('129', 'our_mission_points', 'Educational Institutions,Educational Materials,Online Learning Platform', 'string', '1');
INSERT INTO `school_settings` VALUES ('130', 'our_mission_status', '1', 'string', '1');
INSERT INTO `school_settings` VALUES ('131', 'announcement_title', 'Announcement', 'string', '1');
INSERT INTO `school_settings` VALUES ('132', 'announcement_heading', 'Important Update', 'string', '1');
INSERT INTO `school_settings` VALUES ('133', 'announcement_description', 'Don\'t miss out on these upcoming events! Check the schedule and marks your calender.', 'string', '1');
INSERT INTO `school_settings` VALUES ('134', 'announcement_image', '1/school-settings/67757a6f4ec6b9.962058611735752303.png', 'file', '1');
INSERT INTO `school_settings` VALUES ('135', 'announcement_status', '1', 'string', '1');
INSERT INTO `school_settings` VALUES ('136', 'gallery_title', 'Our Photo Gallery', 'string', '1');
INSERT INTO `school_settings` VALUES ('137', 'gallery_heading', 'Tiny Scholars Showcase', 'string', '1');
INSERT INTO `school_settings` VALUES ('138', 'gallery_description', 'We are group of teachers who really love children\'s and enjoy every moment of teaching.', 'string', '1');
INSERT INTO `school_settings` VALUES ('139', 'gallery_status', '1', 'string', '1');
INSERT INTO `school_settings` VALUES ('140', 'contact_us_heading', 'Get In Touch', 'string', '1');
INSERT INTO `school_settings` VALUES ('141', 'contact_us_description', 'Have Any Question?', 'string', '1');
INSERT INTO `school_settings` VALUES ('142', 'contact_us_status', '1', 'string', '1');
INSERT INTO `school_settings` VALUES ('143', 'online_registration_title', 'Where Learning Takes Flight', 'string', '1');
INSERT INTO `school_settings` VALUES ('144', 'online_registration_heading', 'Cultivate Your Curiosity & Explore Endless Possibilities. Admissions Open Now!', 'string', '1');
INSERT INTO `school_settings` VALUES ('145', 'online_registration_description', 'Our admissions are now open for the 2024-25 school year.  We invite curious and enthusiastic students to join our vibrant learning community.', 'string', '1');
INSERT INTO `school_settings` VALUES ('146', 'online_registration_status', '1', 'string', '1');
INSERT INTO `school_settings` VALUES ('147', 'short_description', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna.', 'string', '1');
INSERT INTO `school_settings` VALUES ('148', 'footer_text', '© 2024 © KIXID All Rights Reserved', 'string', '1');
INSERT INTO `school_settings` VALUES ('149', 'footer_logo', '1/school-settings/67757a6f6d1830.724919631735752303.png', 'file', '1');
INSERT INTO `school_settings` VALUES ('150', 'facebook', '0', 'string', '1');
INSERT INTO `school_settings` VALUES ('151', 'instagram', '0', 'string', '1');
INSERT INTO `school_settings` VALUES ('152', 'linkedin', '0', 'string', '1');
INSERT INTO `school_settings` VALUES ('153', 'twitter', '0', 'string', '1');
INSERT INTO `school_settings` VALUES ('154', 'favicon', '1/school-settings/677585fe8b5948.224897411735755262.jpg', 'file', '1');
INSERT INTO `school_settings` VALUES ('155', 'roll_number_sort_column', 'last_name', 'string', '1');
INSERT INTO `school_settings` VALUES ('156', 'roll_number_sort_order', 'asc', 'string', '1');
INSERT INTO `school_settings` VALUES ('157', 'change_roll_number', '', 'string', '1');
INSERT INTO `school_settings` VALUES ('158', 'google_map_link', 'https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d10115.411619583787!2d-0.2458521379670499!3d5.642404152959014!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0xfdf9ecb2db67201%3A0x2f99ed48e63e1981!2sLittle%20Bud%20International%20School!5e0!3m2!1sen!2sgh!4v1735755418342!5m2!1sen!2sgh\" width=\"600\" height=\"450\" style=\"border:0;\" allowfullscreen=\"\" loading=\"lazy\" referrerpolicy=\"no-referrer-when-downgrade', 'string', '1');
INSERT INTO `school_settings` VALUES ('181', 'online_registration_image', '1/school-settings/67759984ab3807.463360621735760260.svg', 'file', '1');

CREATE TABLE IF NOT EXISTS `schools` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `address` varchar(191) NOT NULL,
  `support_phone` varchar(191) NOT NULL,
  `support_email` varchar(191) NOT NULL,
  `tagline` varchar(191) NOT NULL,
  `logo` varchar(191) NOT NULL,
  `admin_id` bigint(20) unsigned DEFAULT NULL COMMENT 'user_id',
  `status` tinyint(4) NOT NULL DEFAULT 0 COMMENT '0 => Deactivate, 1 => Active',
  `domain` varchar(191) DEFAULT NULL,
  `database_name` varchar(191) DEFAULT NULL,
  `code` varchar(191) DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `schools_admin_id_foreign` (`admin_id`),
  CONSTRAINT `schools_admin_id_foreign` FOREIGN KEY (`admin_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `schools` VALUES ('1', 'Open Grace J.H.S', 'HNo. 21 Pentegost Street, New Weija.', '0244944725', 'gmacapon@gmail.com', 'You build your future', 'school/z7Of9OZPkG6RXGbpuAIW2qzCbL0fDUQ61wR1eqkQ.jpg', '2', '1', 'opengrace', 'eschool_saas_1_open', 'SCH20241', '2024-03-13 00:01:12', '2025-01-01 23:44:22', NULL);

CREATE TABLE IF NOT EXISTS `sections` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `sections_school_id_foreign` (`school_id`),
  CONSTRAINT `sections_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `sections` VALUES ('1', 'A', '1', '2024-03-14 03:41:53', '2024-03-14 03:41:53', NULL);
INSERT INTO `sections` VALUES ('2', 'B', '1', '2024-03-14 03:42:01', '2024-03-14 03:42:01', NULL);

CREATE TABLE IF NOT EXISTS `semesters` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `start_month` tinyint(4) NOT NULL,
  `end_month` tinyint(4) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `semesters_school_id_foreign` (`school_id`),
  CONSTRAINT `semesters_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `semesters` VALUES ('1', 'First Term', '10', '12', '1', '2024-07-10 15:59:55', '2024-07-10 16:11:53', NULL);
INSERT INTO `semesters` VALUES ('2', 'Second Term', '1', '4', '1', '2024-07-10 16:12:08', '2024-07-10 16:12:08', NULL);
INSERT INTO `semesters` VALUES ('3', 'Third Term', '5', '7', '1', '2024-07-10 16:13:06', '2024-07-10 16:13:06', NULL);

CREATE TABLE IF NOT EXISTS `session_years` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `default` tinyint(4) NOT NULL DEFAULT 0,
  `start_date` date NOT NULL,
  `end_date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `session_years_name_school_id_unique` (`name`,`school_id`),
  KEY `session_years_school_id_foreign` (`school_id`),
  CONSTRAINT `session_years_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `session_years` VALUES ('1', '2023-24', '1', '2023-10-03', '2024-07-25', '1', '2024-03-13 05:31:12', '2024-07-10 16:09:29', NULL);

CREATE TABLE IF NOT EXISTS `shifts` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `start_time` time NOT NULL,
  `end_time` time NOT NULL,
  `status` int(11) NOT NULL DEFAULT 1,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `shifts_school_id_foreign` (`school_id`),
  CONSTRAINT `shifts_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `shifts` VALUES ('1', 'Morning Shift', '07:00:00', '12:00:00', '1', '1', '2025-01-01 10:50:49', '2025-01-01 10:50:49', NULL);
INSERT INTO `shifts` VALUES ('2', 'Afternoon Shift', '12:30:00', '17:30:00', '1', '1', '2025-01-01 10:51:51', '2025-01-01 10:51:51', NULL);

CREATE TABLE IF NOT EXISTS `sliders` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `image` varchar(1024) NOT NULL,
  `link` varchar(191) DEFAULT NULL,
  `type` int(11) NOT NULL DEFAULT 1 COMMENT '1 => App, 2 => web, 3 => Both',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `sliders_school_id_foreign` (`school_id`),
  CONSTRAINT `sliders_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `sliders` VALUES ('1', '1/sliders/66b4b81aa81f53.552904571723119642.jpg', 'https://www.instagram.com/umnibuyers/', '1', '1', '2024-08-08 15:50:42', '2024-10-12 04:58:34');
INSERT INTO `sliders` VALUES ('2', '1/sliders/66b4b852c73e14.367290921723119698.jpg', 'https://www.instagram.com/umnibuyers/', '1', '1', '2024-08-08 15:51:38', '2024-10-12 04:58:34');
INSERT INTO `sliders` VALUES ('3', '1/sliders/66b4b87be95bc8.353054351723119739.jpg', 'https://www.instagram.com/umnibuyers/', '1', '1', '2024-08-08 15:52:20', '2024-10-12 04:58:34');
INSERT INTO `sliders` VALUES ('4', '1/sliders/66b4b8948b32f9.811500761723119764.jpg', 'https://www.instagram.com/umnibuyers/', '1', '1', '2024-08-08 15:52:44', '2024-10-12 04:58:34');
INSERT INTO `sliders` VALUES ('5', '1/sliders/66b4b8a3b8fad5.617419381723119779.jpg', 'https://www.instagram.com/umnibuyers/', '1', '1', '2024-08-08 15:52:59', '2024-10-12 04:58:34');
INSERT INTO `sliders` VALUES ('6', '1/sliders/66b4b954518785.006955401723119956.jpg', 'https://www.instagram.com/umnibuyers/', '3', '1', '2024-08-08 15:55:56', '2025-01-04 05:58:21');
INSERT INTO `sliders` VALUES ('7', '1/sliders/67778cc10c14b1.115011441735888065.jpg', NULL, '3', '1', '2025-01-03 12:37:45', '2025-01-04 05:58:06');
INSERT INTO `sliders` VALUES ('8', '1/sliders/677881d9e7bdc9.793803391735950809.jpg', 'https://www.instagram.com/umnibuyers/', '3', '1', '2025-01-04 06:03:30', '2025-01-04 06:03:30');

CREATE TABLE IF NOT EXISTS `staff_payrolls` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `expense_id` bigint(20) unsigned DEFAULT NULL,
  `payroll_setting_id` bigint(20) unsigned DEFAULT NULL,
  `amount` double DEFAULT NULL,
  `percentage` double(8,2) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`expense_id`,`payroll_setting_id`),
  KEY `staff_payrolls_payroll_setting_id_foreign` (`payroll_setting_id`),
  KEY `staff_payrolls_school_id_foreign` (`school_id`),
  CONSTRAINT `staff_payrolls_expense_id_foreign` FOREIGN KEY (`expense_id`) REFERENCES `expenses` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_payrolls_payroll_setting_id_foreign` FOREIGN KEY (`payroll_setting_id`) REFERENCES `payroll_settings` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_payrolls_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `staff_salaries` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `staff_id` bigint(20) unsigned DEFAULT NULL,
  `payroll_setting_id` bigint(20) unsigned DEFAULT NULL,
  `amount` double DEFAULT NULL,
  `percentage` double(8,2) DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`staff_id`,`payroll_setting_id`),
  KEY `staff_salaries_payroll_setting_id_foreign` (`payroll_setting_id`),
  CONSTRAINT `staff_salaries_payroll_setting_id_foreign` FOREIGN KEY (`payroll_setting_id`) REFERENCES `payroll_settings` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_salaries_staff_id_foreign` FOREIGN KEY (`staff_id`) REFERENCES `staffs` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `staffs` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL,
  `qualification` varchar(512) DEFAULT NULL,
  `salary` double NOT NULL DEFAULT 0,
  `joining_date` date DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `staffs_user_id_foreign` (`user_id`),
  CONSTRAINT `staffs_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `staffs` VALUES ('2', '8', 'Degree', '150', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('3', '9', 'Degree', '200', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('4', '383', 'Bachelor\'s in English', '2000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('5', '384', 'Bachelor\'s in Maths', '2000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('6', '385', 'Bachelor\'s in Science', '2000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('7', '386', 'Bachelor\'s in English', '2000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('8', '387', 'Bachelor\'s in English', '2000', NULL, NULL, NULL);

CREATE TABLE IF NOT EXISTS `streams` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `streams_school_id_foreign` (`school_id`),
  CONSTRAINT `streams_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `streams` VALUES ('1', 'Science', '1', '2025-01-01 10:48:01', '2025-01-01 10:48:01', NULL);
INSERT INTO `streams` VALUES ('2', 'Arts', '1', '2025-01-01 10:48:12', '2025-01-01 10:48:12', NULL);
INSERT INTO `streams` VALUES ('3', 'Business', '1', '2025-01-01 10:48:24', '2025-01-01 10:48:24', NULL);

CREATE TABLE IF NOT EXISTS `student_online_exam_statuses` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `online_exam_id` bigint(20) unsigned NOT NULL,
  `status` tinyint(4) NOT NULL COMMENT '1 - in progress 2 - completed',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `student_online_exam_statuses_school_id_foreign` (`school_id`),
  KEY `student_online_exam_statuses_student_id_foreign` (`student_id`),
  KEY `student_online_exam_statuses_online_exam_id_foreign` (`online_exam_id`),
  CONSTRAINT `student_online_exam_statuses_online_exam_id_foreign` FOREIGN KEY (`online_exam_id`) REFERENCES `online_exams` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_online_exam_statuses_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_online_exam_statuses_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `student_subjects` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `student_subjects_school_id_foreign` (`school_id`),
  KEY `student_subjects_student_id_foreign` (`student_id`),
  KEY `student_subjects_class_subject_id_foreign` (`class_subject_id`),
  KEY `student_subjects_class_section_id_foreign` (`class_section_id`),
  KEY `student_subjects_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `student_subjects_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_subjects_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_subjects_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_subjects_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_subjects_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `students` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL,
  `class_id` bigint(20) unsigned DEFAULT NULL,
  `class_section_id` bigint(20) unsigned DEFAULT NULL,
  `application_type` varchar(191) DEFAULT 'offline',
  `admission_no` varchar(512) NOT NULL,
  `roll_number` int(11) DEFAULT NULL,
  `admission_date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `application_status` int(11) DEFAULT 1 COMMENT '1- accepted, 0- rejected',
  `guardian_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `students_school_id_foreign` (`school_id`),
  KEY `students_user_id_foreign` (`user_id`),
  KEY `students_class_section_id_foreign` (`class_section_id`),
  KEY `students_guardian_id_foreign` (`guardian_id`),
  KEY `students_session_year_id_foreign` (`session_year_id`),
  KEY `students_class_id_foreign` (`class_id`),
  CONSTRAINT `students_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `students_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `students_guardian_id_foreign` FOREIGN KEY (`guardian_id`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `students_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `students_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `students_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=193 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `students` VALUES ('1', '11', NULL, '1', 'offline', '2023-240101', '1', '2024-07-10', '1', '1', '10', '1', '2024-07-10 16:29:08', '2024-07-10 16:29:08', NULL);
INSERT INTO `students` VALUES ('2', '13', NULL, '1', 'offline', '2023-240102', '2', '2024-07-10', '1', '1', '12', '1', '2024-07-10 16:33:06', '2024-07-10 16:33:06', NULL);
INSERT INTO `students` VALUES ('3', '15', NULL, '1', 'offline', '2023-240103', '3', '2024-07-10', '1', '1', '14', '1', '2024-07-10 16:35:47', '2024-07-10 16:35:47', NULL);
INSERT INTO `students` VALUES ('4', '17', NULL, '1', 'offline', '2023-240104', '4', '2024-07-10', '1', '1', '16', '1', '2024-07-10 16:38:41', '2024-07-10 16:38:41', NULL);
INSERT INTO `students` VALUES ('5', '19', NULL, '1', 'offline', '2023-240105', '5', '2024-07-10', '1', '1', '18', '1', '2024-07-10 16:41:26', '2024-07-10 16:41:26', NULL);
INSERT INTO `students` VALUES ('6', '21', NULL, '1', 'offline', '2023-240106', '6', '2024-07-10', '1', '1', '20', '1', '2024-07-10 16:46:20', '2024-07-10 16:46:20', NULL);
INSERT INTO `students` VALUES ('7', '23', NULL, '1', 'offline', '2023-240107', '7', '2024-07-10', '1', '1', '22', '1', '2024-07-10 16:50:11', '2024-07-10 16:50:11', NULL);
INSERT INTO `students` VALUES ('8', '25', NULL, '1', 'offline', '2023-240108', '8', '2024-07-10', '1', '1', '24', '1', '2024-07-10 16:53:19', '2024-07-10 16:53:19', NULL);
INSERT INTO `students` VALUES ('9', '27', NULL, '1', 'offline', '2023-240109', '9', '2024-07-10', '1', '1', '26', '1', '2024-07-10 17:27:36', '2024-07-10 17:27:36', NULL);
INSERT INTO `students` VALUES ('10', '29', NULL, '1', 'offline', '2023-2401010', '10', '2024-07-10', '1', '1', '28', '1', '2024-07-10 17:30:22', '2024-07-10 17:30:22', NULL);
INSERT INTO `students` VALUES ('11', '31', NULL, '1', 'offline', '2023-2401011', '11', '2024-07-10', '1', '1', '30', '1', '2024-07-10 17:33:28', '2024-07-10 17:33:28', NULL);
INSERT INTO `students` VALUES ('12', '33', NULL, '1', 'offline', '2023-2401012', '12', '2024-07-10', '1', '1', '32', '1', '2024-07-10 17:36:07', '2024-07-10 17:36:07', NULL);
INSERT INTO `students` VALUES ('13', '35', NULL, '1', 'offline', '2023-2401013', '13', '2024-07-10', '1', '1', '34', '1', '2024-07-10 17:38:39', '2024-07-10 17:38:39', NULL);
INSERT INTO `students` VALUES ('14', '37', NULL, '1', 'offline', '2023-2401014', '14', '2024-07-10', '1', '1', '36', '1', '2024-07-10 17:42:25', '2024-07-10 17:42:25', NULL);
INSERT INTO `students` VALUES ('15', '38', NULL, '1', 'offline', '2023-2401015', '15', '2024-07-10', '1', '1', '36', '1', '2024-07-10 17:45:05', '2024-07-10 17:45:05', NULL);
INSERT INTO `students` VALUES ('16', '40', NULL, '1', 'offline', '2023-2401016', '16', '2024-07-10', '1', '1', '39', '1', '2024-07-10 17:47:46', '2024-07-10 17:47:46', NULL);
INSERT INTO `students` VALUES ('17', '42', NULL, '1', 'offline', '2023-2401017', '17', '2024-07-10', '1', '1', '41', '1', '2024-07-10 17:51:24', '2024-07-10 17:51:24', NULL);
INSERT INTO `students` VALUES ('18', '44', NULL, '1', 'offline', '2023-2401018', '18', '2024-07-10', '1', '1', '43', '1', '2024-07-10 17:54:33', '2024-07-10 17:54:33', NULL);
INSERT INTO `students` VALUES ('19', '46', NULL, '1', 'offline', '2023-2401019', '19', '2024-07-10', '1', '1', '45', '1', '2024-07-10 17:57:17', '2024-07-10 17:57:17', NULL);
INSERT INTO `students` VALUES ('20', '48', NULL, '1', 'offline', '2023-2401020', '20', '2024-07-10', '1', '1', '47', '1', '2024-07-10 17:59:58', '2024-07-10 17:59:58', NULL);
INSERT INTO `students` VALUES ('21', '50', NULL, '1', 'offline', '2023-2401021', '21', '2024-07-10', '1', '1', '49', '1', '2024-07-10 18:03:37', '2024-07-10 18:03:37', NULL);
INSERT INTO `students` VALUES ('22', '52', NULL, '1', 'offline', '2023-2401022', '22', '2024-07-10', '1', '1', '51', '1', '2024-07-10 18:06:17', '2024-07-10 18:06:17', NULL);
INSERT INTO `students` VALUES ('23', '54', NULL, '1', 'offline', '2023-2401023', '23', '2024-07-10', '1', '1', '53', '1', '2024-07-10 18:09:16', '2024-07-10 18:09:16', NULL);
INSERT INTO `students` VALUES ('24', '56', NULL, '1', 'offline', '2023-2401024', '24', '2024-07-10', '1', '1', '55', '1', '2024-07-10 18:12:23', '2024-07-10 18:12:23', NULL);
INSERT INTO `students` VALUES ('25', '58', NULL, '1', 'offline', '2023-2401025', '25', '2024-07-10', '1', '1', '57', '1', '2024-07-10 18:15:41', '2024-07-10 18:15:41', NULL);
INSERT INTO `students` VALUES ('26', '60', NULL, '1', 'offline', '2023-2401026', '26', '2024-07-10', '1', '1', '59', '1', '2024-07-10 18:18:29', '2024-07-10 18:18:29', NULL);
INSERT INTO `students` VALUES ('27', '62', NULL, '1', 'offline', '2023-2401027', '27', '2024-07-10', '1', '1', '61', '1', '2024-07-10 18:26:35', '2024-07-10 18:26:35', NULL);
INSERT INTO `students` VALUES ('28', '64', NULL, '1', 'offline', '2023-2401028', '28', '2024-07-10', '1', '1', '63', '1', '2024-07-10 18:29:56', '2024-07-10 18:29:56', NULL);
INSERT INTO `students` VALUES ('29', '66', NULL, '1', 'offline', '2023-2401029', '29', '2024-07-10', '1', '1', '65', '1', '2024-07-10 18:33:09', '2024-07-10 18:33:09', NULL);
INSERT INTO `students` VALUES ('30', '68', NULL, '1', 'offline', '2023-2401030', '30', '2024-07-10', '1', '1', '67', '1', '2024-07-10 18:38:06', '2024-07-10 18:38:06', NULL);
INSERT INTO `students` VALUES ('31', '69', NULL, '1', 'offline', '2023-2401031', '31', '2024-07-10', '1', '1', '67', '1', '2024-07-10 18:41:04', '2024-07-10 18:41:04', NULL);
INSERT INTO `students` VALUES ('32', '70', NULL, '1', 'offline', '2023-2401032', '32', '2024-07-10', '1', '1', '67', '1', '2024-07-10 18:43:45', '2024-07-10 18:43:45', NULL);
INSERT INTO `students` VALUES ('33', '72', NULL, '1', 'offline', '2023-2401033', '33', '2024-07-10', '1', '1', '71', '1', '2024-07-10 18:46:48', '2024-07-10 18:46:48', NULL);
INSERT INTO `students` VALUES ('34', '74', NULL, '1', 'offline', '2023-2401034', '34', '2024-07-10', '1', '1', '73', '1', '2024-07-10 18:49:11', '2024-07-10 18:49:11', NULL);
INSERT INTO `students` VALUES ('35', '76', NULL, '1', 'offline', '2023-2401035', '35', '2024-07-10', '1', '1', '75', '1', '2024-07-10 18:51:35', '2024-07-10 18:51:35', NULL);
INSERT INTO `students` VALUES ('36', '78', NULL, '1', 'offline', '2023-2401036', '36', '2024-07-10', '1', '1', '77', '1', '2024-07-10 18:55:11', '2024-07-10 18:55:11', NULL);
INSERT INTO `students` VALUES ('37', '80', NULL, '1', 'offline', '2023-2401037', '37', '2024-07-10', '1', '1', '79', '1', '2024-07-10 18:57:22', '2024-07-10 18:57:22', NULL);
INSERT INTO `students` VALUES ('38', '82', NULL, '1', 'offline', '2023-2401038', '38', '2024-07-10', '1', '1', '81', '1', '2024-07-10 18:59:34', '2024-07-10 18:59:34', NULL);
INSERT INTO `students` VALUES ('39', '84', NULL, '2', 'offline', '2023-2401039', '1', '2024-07-10', '1', '1', '83', '1', '2024-07-10 19:14:31', '2024-07-10 19:14:31', NULL);
INSERT INTO `students` VALUES ('40', '86', NULL, '2', 'offline', '2023-2401040', '2', '2024-07-10', '1', '1', '85', '1', '2024-07-10 19:16:43', '2024-07-10 19:16:43', NULL);
INSERT INTO `students` VALUES ('41', '88', NULL, '2', 'offline', '2023-2401041', '3', '2024-07-10', '1', '1', '87', '1', '2024-07-10 19:19:48', '2024-07-10 19:19:48', NULL);
INSERT INTO `students` VALUES ('42', '90', NULL, '2', 'offline', '2023-2401042', '4', '2024-07-10', '1', '1', '89', '1', '2024-07-10 19:22:21', '2024-07-10 19:22:21', NULL);
INSERT INTO `students` VALUES ('43', '92', NULL, '2', 'offline', '2023-2401043', '5', '2024-07-10', '1', '1', '91', '1', '2024-07-10 19:26:16', '2024-07-10 19:26:16', NULL);
INSERT INTO `students` VALUES ('44', '94', NULL, '2', 'offline', '2023-2401044', '6', '2024-07-10', '1', '1', '93', '1', '2024-07-10 19:28:42', '2024-07-10 19:28:42', NULL);
INSERT INTO `students` VALUES ('45', '96', NULL, '2', 'offline', '2023-2401045', '7', '2024-07-10', '1', '1', '95', '1', '2024-07-10 19:30:37', '2024-07-10 19:30:37', NULL);
INSERT INTO `students` VALUES ('46', '98', NULL, '2', 'offline', '2023-2401046', '8', '2024-07-10', '1', '1', '97', '1', '2024-07-10 19:32:36', '2024-07-10 19:32:36', NULL);
INSERT INTO `students` VALUES ('47', '100', NULL, '2', 'offline', '2023-2401047', '9', '2024-07-10', '1', '1', '99', '1', '2024-07-10 19:34:37', '2024-07-10 19:34:37', NULL);
INSERT INTO `students` VALUES ('48', '102', NULL, '2', 'offline', '2023-2401048', '10', '2024-07-10', '1', '1', '101', '1', '2024-07-10 19:37:03', '2024-07-10 19:37:03', NULL);
INSERT INTO `students` VALUES ('49', '104', NULL, '2', 'offline', '2023-2401049', '11', '2024-07-10', '1', '1', '103', '1', '2024-07-10 19:39:21', '2024-07-10 19:39:21', NULL);
INSERT INTO `students` VALUES ('50', '105', NULL, '2', 'offline', '2023-2401050', '12', '2024-07-10', '1', '1', '103', '1', '2024-07-10 19:49:34', '2024-07-10 19:49:34', NULL);
INSERT INTO `students` VALUES ('51', '107', NULL, '2', 'offline', '2023-2401051', '13', '2024-07-10', '1', '1', '106', '1', '2024-07-10 19:53:11', '2024-07-10 19:53:11', NULL);
INSERT INTO `students` VALUES ('52', '109', NULL, '2', 'offline', '2023-2401052', '14', '2024-07-10', '1', '1', '108', '1', '2024-07-10 19:55:26', '2024-07-10 19:55:26', NULL);
INSERT INTO `students` VALUES ('53', '111', NULL, '2', 'offline', '2023-2401053', '15', '2024-07-10', '1', '1', '110', '1', '2024-07-10 19:57:51', '2024-07-10 19:57:51', NULL);
INSERT INTO `students` VALUES ('54', '113', NULL, '2', 'offline', '2023-2401054', '16', '2024-07-10', '1', '1', '112', '1', '2024-07-10 19:59:53', '2024-07-10 19:59:53', NULL);
INSERT INTO `students` VALUES ('55', '115', NULL, '2', 'offline', '2023-2401055', '17', '2024-07-10', '1', '1', '114', '1', '2024-07-10 20:02:20', '2024-07-10 20:02:20', NULL);
INSERT INTO `students` VALUES ('56', '117', NULL, '2', 'offline', '2023-2401056', '18', '2024-07-10', '1', '1', '116', '1', '2024-07-10 20:04:17', '2024-07-10 20:04:17', NULL);
INSERT INTO `students` VALUES ('57', '119', NULL, '2', 'offline', '2023-2401057', '19', '2024-07-10', '1', '1', '118', '1', '2024-07-10 20:06:12', '2024-07-10 20:06:12', NULL);
INSERT INTO `students` VALUES ('58', '121', NULL, '2', 'offline', '2023-2401058', '20', '2024-07-10', '1', '1', '120', '1', '2024-07-10 20:08:02', '2024-07-10 20:08:02', NULL);
INSERT INTO `students` VALUES ('59', '123', NULL, '2', 'offline', '2023-2401059', '21', '2024-07-10', '1', '1', '122', '1', '2024-07-10 20:10:06', '2024-07-10 20:10:06', NULL);
INSERT INTO `students` VALUES ('60', '125', NULL, '2', 'offline', '2023-2401060', '22', '2024-07-10', '1', '1', '124', '1', '2024-07-10 20:14:55', '2024-07-10 20:14:55', NULL);
INSERT INTO `students` VALUES ('61', '127', NULL, '2', 'offline', '2023-2401061', '23', '2024-07-10', '1', '1', '126', '1', '2024-07-10 20:17:17', '2024-07-10 20:17:17', NULL);
INSERT INTO `students` VALUES ('62', '129', NULL, '2', 'offline', '2023-2401062', '24', '2024-07-10', '1', '1', '128', '1', '2024-07-10 20:19:04', '2024-07-10 20:19:04', NULL);
INSERT INTO `students` VALUES ('63', '131', NULL, '2', 'offline', '2023-2401063', '25', '2024-07-10', '1', '1', '130', '1', '2024-07-10 20:21:13', '2024-07-10 20:21:13', NULL);
INSERT INTO `students` VALUES ('64', '133', NULL, '2', 'offline', '2023-2401064', '26', '2024-07-10', '1', '1', '132', '1', '2024-07-10 20:23:29', '2024-07-10 20:23:29', NULL);
INSERT INTO `students` VALUES ('65', '135', NULL, '2', 'offline', '2023-2401065', '27', '2024-07-10', '1', '1', '134', '1', '2024-07-10 20:26:18', '2024-07-10 20:26:18', NULL);
INSERT INTO `students` VALUES ('66', '137', NULL, '2', 'offline', '2023-2401066', '28', '2024-07-10', '1', '1', '136', '1', '2024-07-10 20:28:22', '2024-07-10 20:28:22', NULL);
INSERT INTO `students` VALUES ('67', '139', NULL, '2', 'offline', '2023-2401067', '29', '2024-07-10', '1', '1', '138', '1', '2024-07-10 20:30:22', '2024-07-10 20:30:22', NULL);
INSERT INTO `students` VALUES ('68', '141', NULL, '2', 'offline', '2023-2401068', '30', '2024-07-10', '1', '1', '140', '1', '2024-07-10 20:32:28', '2024-07-10 20:32:28', NULL);
INSERT INTO `students` VALUES ('69', '143', NULL, '2', 'offline', '2023-2401069', '31', '2024-07-10', '1', '1', '142', '1', '2024-07-10 20:34:39', '2024-07-10 20:34:39', NULL);
INSERT INTO `students` VALUES ('70', '145', NULL, '3', 'offline', '2023-2401070', '1', '2024-07-11', '1', '1', '144', '1', '2024-07-11 15:09:28', '2024-07-11 15:09:28', NULL);
INSERT INTO `students` VALUES ('71', '147', NULL, '3', 'offline', '2023-2401071', '2', '2024-07-11', '1', '1', '146', '1', '2024-07-11 15:11:58', '2024-07-11 15:11:58', NULL);
INSERT INTO `students` VALUES ('72', '149', NULL, '3', 'offline', '2023-2401072', '3', '2024-07-11', '1', '1', '148', '1', '2024-07-11 15:14:10', '2024-07-11 15:14:10', NULL);
INSERT INTO `students` VALUES ('73', '151', NULL, '3', 'offline', '2023-2401073', '4', '2024-07-11', '1', '1', '150', '1', '2024-07-11 15:16:03', '2024-07-11 15:16:03', NULL);
INSERT INTO `students` VALUES ('74', '153', NULL, '3', 'offline', '2023-2401074', '5', '2024-07-11', '1', '1', '152', '1', '2024-07-11 15:19:36', '2024-07-11 15:19:36', NULL);
INSERT INTO `students` VALUES ('75', '155', NULL, '3', 'offline', '2023-2401075', '6', '2024-07-11', '1', '1', '154', '1', '2024-07-11 15:23:36', '2024-07-11 15:23:36', NULL);
INSERT INTO `students` VALUES ('76', '157', NULL, '3', 'offline', '2023-2401076', '7', '2024-07-11', '1', '1', '156', '1', '2024-07-11 15:28:58', '2024-07-11 15:28:58', NULL);
INSERT INTO `students` VALUES ('77', '159', NULL, '3', 'offline', '2023-2401077', '8', '2024-07-11', '1', '1', '158', '1', '2024-07-11 15:31:34', '2024-07-11 15:31:34', NULL);
INSERT INTO `students` VALUES ('78', '161', NULL, '3', 'offline', '2023-2401078', '9', '2024-07-11', '1', '1', '160', '1', '2024-07-11 15:35:49', '2024-07-11 15:35:49', NULL);
INSERT INTO `students` VALUES ('79', '163', NULL, '3', 'offline', '2023-2401079', '10', '2024-07-11', '1', '1', '162', '1', '2024-07-11 15:39:20', '2024-07-11 15:39:20', NULL);
INSERT INTO `students` VALUES ('80', '165', NULL, '3', 'offline', '2023-2401080', '11', '2024-07-11', '1', '1', '164', '1', '2024-07-11 15:42:19', '2024-07-11 15:42:19', NULL);
INSERT INTO `students` VALUES ('81', '167', NULL, '3', 'offline', '2023-2401081', '12', '2024-07-11', '1', '1', '166', '1', '2024-07-11 15:55:42', '2024-07-11 15:55:42', NULL);
INSERT INTO `students` VALUES ('82', '169', NULL, '3', 'offline', '2023-2401082', '13', '2024-07-11', '1', '1', '168', '1', '2024-07-11 15:57:54', '2024-07-11 15:57:54', NULL);
INSERT INTO `students` VALUES ('83', '171', NULL, '3', 'offline', '2023-2401083', '14', '2024-07-11', '1', '1', '170', '1', '2024-07-11 16:00:02', '2024-07-11 16:00:02', NULL);
INSERT INTO `students` VALUES ('84', '173', NULL, '3', 'offline', '2023-2401084', '15', '2024-07-11', '1', '1', '172', '1', '2024-07-11 16:02:06', '2024-07-11 16:02:06', NULL);
INSERT INTO `students` VALUES ('85', '175', NULL, '3', 'offline', '2023-2401085', '16', '2024-07-11', '1', '1', '174', '1', '2024-07-11 16:05:01', '2024-07-11 16:05:01', NULL);
INSERT INTO `students` VALUES ('86', '177', NULL, '3', 'offline', '2023-2401086', '17', '2024-07-11', '1', '1', '176', '1', '2024-07-11 16:07:07', '2024-07-11 16:07:07', NULL);
INSERT INTO `students` VALUES ('87', '179', NULL, '3', 'offline', '2023-2401087', '18', '2024-07-11', '1', '1', '178', '1', '2024-07-11 16:09:25', '2024-07-11 16:09:25', NULL);
INSERT INTO `students` VALUES ('88', '181', NULL, '3', 'offline', '2023-2401088', '19', '2024-07-11', '1', '1', '180', '1', '2024-07-11 16:11:20', '2024-07-11 16:11:20', NULL);
INSERT INTO `students` VALUES ('89', '183', NULL, '3', 'offline', '2023-2401089', '20', '2024-07-11', '1', '1', '182', '1', '2024-07-11 16:13:20', '2024-07-11 16:13:20', NULL);
INSERT INTO `students` VALUES ('90', '184', NULL, '3', 'offline', '2023-2401090', '21', '2024-07-11', '1', '1', '182', '1', '2024-07-11 16:15:17', '2024-07-11 16:15:17', NULL);
INSERT INTO `students` VALUES ('91', '186', NULL, '3', 'offline', '2023-2401091', '22', '2024-07-11', '1', '1', '185', '1', '2024-07-11 16:17:11', '2024-07-11 16:17:11', NULL);
INSERT INTO `students` VALUES ('92', '188', NULL, '3', 'offline', '2023-2401092', '23', '2024-07-11', '1', '1', '187', '1', '2024-07-11 16:19:50', '2024-07-11 16:19:50', NULL);
INSERT INTO `students` VALUES ('93', '190', NULL, '3', 'offline', '2023-2401093', '24', '2024-07-11', '1', '1', '189', '1', '2024-07-11 16:23:52', '2024-07-11 16:23:52', NULL);
INSERT INTO `students` VALUES ('94', '192', NULL, '3', 'offline', '2023-2401094', '25', '2024-07-11', '1', '1', '191', '1', '2024-07-11 16:25:46', '2024-07-11 16:25:46', NULL);
INSERT INTO `students` VALUES ('95', '194', NULL, '3', 'offline', '2023-2401095', '26', '2024-07-11', '1', '1', '193', '1', '2024-07-11 16:28:31', '2024-07-11 16:28:31', NULL);
INSERT INTO `students` VALUES ('96', '196', NULL, '3', 'offline', '2023-2401096', '27', '2024-07-11', '1', '1', '195', '1', '2024-07-11 16:31:26', '2024-07-11 16:31:26', NULL);
INSERT INTO `students` VALUES ('97', '198', NULL, '3', 'offline', '2023-2401097', '28', '2024-07-11', '1', '1', '197', '1', '2024-07-11 16:33:37', '2024-07-11 16:33:37', NULL);
INSERT INTO `students` VALUES ('98', '200', NULL, '3', 'offline', '2023-2401098', '29', '2024-07-11', '1', '1', '199', '1', '2024-07-11 16:35:27', '2024-07-11 16:35:27', NULL);
INSERT INTO `students` VALUES ('99', '202', NULL, '3', 'offline', '2023-2401099', '30', '2024-07-11', '1', '1', '201', '1', '2024-07-11 16:37:18', '2024-07-11 16:37:18', NULL);
INSERT INTO `students` VALUES ('100', '204', NULL, '3', 'offline', '2023-24010100', '31', '2024-07-11', '1', '1', '203', '1', '2024-07-11 16:39:07', '2024-07-11 16:39:07', NULL);
INSERT INTO `students` VALUES ('101', '206', NULL, '4', 'offline', '2023-24010101', '1', '2024-07-11', '1', '1', '205', '1', '2024-07-11 16:47:42', '2024-07-11 16:47:42', NULL);
INSERT INTO `students` VALUES ('102', '208', NULL, '4', 'offline', '2023-24010102', '2', '2024-07-11', '1', '1', '207', '1', '2024-07-11 16:54:25', '2024-07-11 16:54:25', NULL);
INSERT INTO `students` VALUES ('103', '210', NULL, '4', 'offline', '2023-24010103', '3', '2024-07-11', '1', '1', '209', '1', '2024-07-11 16:56:10', '2024-07-11 16:56:10', NULL);
INSERT INTO `students` VALUES ('104', '212', NULL, '4', 'offline', '2023-24010104', '4', '2024-07-11', '1', '1', '211', '1', '2024-07-11 16:57:53', '2024-07-11 16:57:53', NULL);
INSERT INTO `students` VALUES ('105', '214', NULL, '4', 'offline', '2023-24010105', '5', '2024-07-11', '1', '1', '213', '1', '2024-07-11 16:59:37', '2024-07-11 16:59:37', NULL);
INSERT INTO `students` VALUES ('106', '216', NULL, '4', 'offline', '2023-24010106', '6', '2024-07-11', '1', '1', '215', '1', '2024-07-11 17:01:18', '2024-07-11 17:01:18', NULL);
INSERT INTO `students` VALUES ('107', '218', NULL, '4', 'offline', '2023-24010107', '7', '2024-07-11', '1', '1', '217', '1', '2024-07-11 17:03:03', '2024-07-11 17:03:03', NULL);
INSERT INTO `students` VALUES ('108', '220', NULL, '4', 'offline', '2023-24010108', '8', '2024-07-11', '1', '1', '219', '1', '2024-07-11 17:04:41', '2024-07-11 17:04:41', NULL);
INSERT INTO `students` VALUES ('109', '222', NULL, '4', 'offline', '2023-24010109', '9', '2024-07-11', '1', '1', '221', '1', '2024-07-11 17:06:32', '2024-07-11 17:06:32', NULL);
INSERT INTO `students` VALUES ('110', '223', NULL, '4', 'offline', '2023-24010110', '10', '2024-07-11', '1', '1', '221', '1', '2024-07-11 17:07:45', '2024-07-11 17:07:45', NULL);
INSERT INTO `students` VALUES ('111', '225', NULL, '4', 'offline', '2023-24010111', '11', '2024-07-11', '1', '1', '224', '1', '2024-07-11 17:14:39', '2024-07-11 17:14:39', NULL);
INSERT INTO `students` VALUES ('112', '227', NULL, '4', 'offline', '2023-24010112', '12', '2024-07-11', '1', '1', '226', '1', '2024-07-11 17:16:30', '2024-07-11 17:16:30', NULL);
INSERT INTO `students` VALUES ('113', '229', NULL, '4', 'offline', '2023-24010113', '13', '2024-07-11', '1', '1', '228', '1', '2024-07-11 18:01:38', '2024-07-11 18:01:38', NULL);
INSERT INTO `students` VALUES ('114', '231', NULL, '4', 'offline', '2023-24010114', '14', '2024-07-11', '1', '1', '230', '1', '2024-07-11 18:04:41', '2024-07-11 18:04:41', NULL);
INSERT INTO `students` VALUES ('115', '233', NULL, '4', 'offline', '2023-24010115', '15', '2024-07-11', '1', '1', '232', '1', '2024-07-11 18:07:47', '2024-07-11 18:07:47', NULL);
INSERT INTO `students` VALUES ('116', '235', NULL, '4', 'offline', '2023-24010116', '16', '2024-07-11', '1', '1', '234', '1', '2024-07-11 18:10:37', '2024-07-11 18:10:37', NULL);
INSERT INTO `students` VALUES ('117', '237', NULL, '4', 'offline', '2023-24010117', '17', '2024-07-11', '1', '1', '236', '1', '2024-07-11 18:15:59', '2024-07-11 18:15:59', NULL);
INSERT INTO `students` VALUES ('118', '239', NULL, '4', 'offline', '2023-24010118', '18', '2024-07-11', '1', '1', '238', '1', '2024-07-11 18:18:28', '2024-07-11 18:18:28', NULL);
INSERT INTO `students` VALUES ('119', '241', NULL, '4', 'offline', '2023-24010119', '19', '2024-07-11', '1', '1', '240', '1', '2024-07-11 18:20:27', '2024-07-11 18:20:27', NULL);
INSERT INTO `students` VALUES ('120', '243', NULL, '4', 'offline', '2023-24010120', '20', '2024-07-11', '1', '1', '242', '1', '2024-07-11 18:22:16', '2024-07-11 18:22:16', NULL);
INSERT INTO `students` VALUES ('121', '245', NULL, '4', 'offline', '2023-24010121', '21', '2024-07-11', '1', '1', '244', '1', '2024-07-11 18:24:09', '2024-07-11 18:24:09', NULL);
INSERT INTO `students` VALUES ('122', '246', NULL, '4', 'offline', '2023-24010122', '22', '2024-07-11', '1', '1', '244', '1', '2024-07-11 18:30:50', '2024-07-11 18:30:50', NULL);
INSERT INTO `students` VALUES ('123', '248', NULL, '4', 'offline', '2023-24010123', '23', '2024-07-11', '1', '1', '247', '1', '2024-07-11 18:33:05', '2024-07-11 18:33:05', NULL);
INSERT INTO `students` VALUES ('124', '250', NULL, '4', 'offline', '2023-24010124', '24', '2024-07-11', '1', '1', '249', '1', '2024-07-11 18:38:00', '2024-07-11 18:38:00', NULL);
INSERT INTO `students` VALUES ('125', '252', NULL, '4', 'offline', '2023-24010125', '25', '2024-07-11', '1', '1', '251', '1', '2024-07-11 18:39:54', '2024-07-11 18:39:54', NULL);
INSERT INTO `students` VALUES ('126', '254', NULL, '4', 'offline', '2023-24010126', '26', '2024-07-11', '1', '1', '253', '1', '2024-07-11 18:49:30', '2024-07-11 18:49:30', NULL);
INSERT INTO `students` VALUES ('127', '256', NULL, '4', 'offline', '2023-24010127', '27', '2024-07-11', '1', '1', '255', '1', '2024-07-11 18:51:50', '2024-07-11 18:51:50', NULL);
INSERT INTO `students` VALUES ('128', '258', NULL, '4', 'offline', '2023-24010128', '28', '2024-07-11', '1', '1', '257', '1', '2024-07-11 18:53:40', '2024-07-11 18:53:40', NULL);
INSERT INTO `students` VALUES ('129', '260', NULL, '4', 'offline', '2023-24010129', '29', '2024-07-11', '1', '1', '259', '1', '2024-07-11 18:55:27', '2024-07-11 18:55:27', NULL);
INSERT INTO `students` VALUES ('130', '262', NULL, '4', 'offline', '2023-24010130', '30', '2024-07-11', '1', '1', '261', '1', '2024-07-11 18:57:39', '2024-07-11 18:57:39', NULL);
INSERT INTO `students` VALUES ('131', '264', NULL, '4', 'offline', '2023-24010131', '31', '2024-07-11', '1', '1', '263', '1', '2024-07-11 18:59:31', '2024-07-11 18:59:31', NULL);
INSERT INTO `students` VALUES ('132', '266', NULL, '5', 'offline', '2023-24010132', '1', '2024-07-11', '1', '1', '265', '1', '2024-07-11 19:02:46', '2024-07-11 19:02:46', NULL);
INSERT INTO `students` VALUES ('133', '268', NULL, '5', 'offline', '2023-24010133', '2', '2024-07-11', '1', '1', '267', '1', '2024-07-11 19:04:46', '2024-07-11 19:04:46', NULL);
INSERT INTO `students` VALUES ('134', '270', NULL, '5', 'offline', '2023-24010134', '3', '2024-07-11', '1', '1', '269', '1', '2024-07-11 19:06:42', '2024-07-11 19:06:42', NULL);
INSERT INTO `students` VALUES ('135', '272', NULL, '5', 'offline', '2023-24010135', '4', '2024-07-11', '1', '1', '271', '1', '2024-07-11 19:08:25', '2024-07-11 19:08:25', NULL);
INSERT INTO `students` VALUES ('136', '273', NULL, '5', 'offline', '2023-24010136', '5', '2024-07-11', '1', '1', '271', '1', '2024-07-11 19:09:37', '2024-07-11 19:09:37', NULL);
INSERT INTO `students` VALUES ('137', '275', NULL, '5', 'offline', '2023-24010137', '6', '2024-07-11', '1', '1', '274', '1', '2024-07-11 19:13:14', '2024-07-11 19:13:14', NULL);
INSERT INTO `students` VALUES ('138', '277', NULL, '5', 'offline', '2023-24010138', '7', '2024-07-11', '1', '1', '276', '1', '2024-07-11 19:14:46', '2024-07-11 19:14:46', NULL);
INSERT INTO `students` VALUES ('139', '279', NULL, '5', 'offline', '2023-24010139', '8', '2024-07-11', '1', '1', '278', '1', '2024-07-11 19:16:21', '2024-07-11 19:16:21', NULL);
INSERT INTO `students` VALUES ('140', '281', NULL, '5', 'offline', '2023-24010140', '9', '2024-07-11', '1', '1', '280', '1', '2024-07-11 19:18:08', '2024-07-11 19:18:08', NULL);
INSERT INTO `students` VALUES ('141', '283', NULL, '5', 'offline', '2023-24010141', '10', '2024-07-11', '1', '1', '282', '1', '2024-07-11 19:19:45', '2024-07-11 19:19:45', NULL);
INSERT INTO `students` VALUES ('142', '285', NULL, '5', 'offline', '2023-24010142', '11', '2024-07-11', '1', '1', '284', '1', '2024-07-11 19:21:27', '2024-07-11 19:21:27', NULL);
INSERT INTO `students` VALUES ('143', '287', NULL, '5', 'offline', '2023-24010143', '12', '2024-07-11', '1', '1', '286', '1', '2024-07-11 19:23:33', '2024-07-11 19:23:33', NULL);
INSERT INTO `students` VALUES ('144', '289', NULL, '5', 'offline', '2023-24010144', '13', '2024-07-11', '1', '1', '288', '1', '2024-07-11 19:25:45', '2024-07-11 19:25:45', NULL);
INSERT INTO `students` VALUES ('145', '291', NULL, '5', 'offline', '2023-24010145', '14', '2024-07-11', '1', '1', '290', '1', '2024-07-11 19:31:37', '2024-07-11 19:31:37', NULL);
INSERT INTO `students` VALUES ('146', '293', NULL, '5', 'offline', '2023-24010146', '15', '2024-07-11', '1', '1', '292', '1', '2024-07-11 19:33:38', '2024-07-11 19:33:38', NULL);
INSERT INTO `students` VALUES ('147', '295', NULL, '5', 'offline', '2023-24010147', '16', '2024-07-11', '1', '1', '294', '1', '2024-07-11 19:35:05', '2024-07-11 19:35:05', NULL);
INSERT INTO `students` VALUES ('148', '297', NULL, '5', 'offline', '2023-24010148', '17', '2024-07-11', '1', '1', '296', '1', '2024-07-11 19:36:53', '2024-07-11 19:36:53', NULL);
INSERT INTO `students` VALUES ('149', '299', NULL, '5', 'offline', '2023-24010149', '18', '2024-07-11', '1', '1', '298', '1', '2024-07-11 19:38:27', '2024-07-11 19:38:27', NULL);
INSERT INTO `students` VALUES ('150', '301', NULL, '5', 'offline', '2023-24010150', '19', '2024-07-11', '1', '1', '300', '1', '2024-07-11 19:40:48', '2024-07-11 19:40:48', NULL);
INSERT INTO `students` VALUES ('151', '303', NULL, '5', 'offline', '2023-24010151', '20', '2024-07-11', '1', '1', '302', '1', '2024-07-11 19:42:23', '2024-07-11 19:42:23', NULL);
INSERT INTO `students` VALUES ('152', '305', NULL, '5', 'offline', '2023-24010152', '21', '2024-07-11', '1', '1', '304', '1', '2024-07-11 19:44:19', '2024-07-11 19:44:19', NULL);
INSERT INTO `students` VALUES ('153', '307', NULL, '5', 'offline', '2023-24010153', '22', '2024-07-11', '1', '1', '306', '1', '2024-07-11 19:45:53', '2024-07-11 19:45:53', NULL);
INSERT INTO `students` VALUES ('154', '309', NULL, '5', 'offline', '2023-24010154', '23', '2024-07-11', '1', '1', '308', '1', '2024-07-11 19:47:45', '2024-07-11 19:47:45', NULL);
INSERT INTO `students` VALUES ('155', '311', NULL, '5', 'offline', '2023-24010155', '24', '2024-07-11', '1', '1', '310', '1', '2024-07-11 19:51:32', '2024-07-11 19:51:32', NULL);
INSERT INTO `students` VALUES ('156', '313', NULL, '5', 'offline', '2023-24010156', '25', '2024-07-11', '1', '1', '312', '1', '2024-07-11 19:53:27', '2024-07-11 19:53:27', NULL);
INSERT INTO `students` VALUES ('157', '315', NULL, '5', 'offline', '2023-24010157', '26', '2024-07-11', '1', '1', '314', '1', '2024-07-11 19:56:06', '2024-07-11 19:56:06', NULL);
INSERT INTO `students` VALUES ('158', '317', NULL, '5', 'offline', '2023-24010158', '27', '2024-07-11', '1', '1', '316', '1', '2024-07-11 19:57:57', '2024-07-11 19:57:57', NULL);
INSERT INTO `students` VALUES ('159', '319', NULL, '5', 'offline', '2023-24010159', '28', '2024-07-11', '1', '1', '318', '1', '2024-07-11 20:00:06', '2024-07-11 20:00:06', NULL);
INSERT INTO `students` VALUES ('160', '321', NULL, '5', 'offline', '2023-24010160', '29', '2024-07-11', '1', '1', '320', '1', '2024-07-11 20:01:45', '2024-07-11 20:01:45', NULL);
INSERT INTO `students` VALUES ('161', '323', NULL, '5', 'offline', '2023-24010161', '30', '2024-07-11', '1', '1', '322', '1', '2024-07-11 20:03:38', '2024-07-11 20:03:38', NULL);
INSERT INTO `students` VALUES ('162', '325', NULL, '6', 'offline', '2023-24010162', '1', '2024-07-11', '1', '1', '324', '1', '2024-07-11 20:06:42', '2024-07-11 20:06:42', NULL);
INSERT INTO `students` VALUES ('163', '327', NULL, '6', 'offline', '2023-24010163', '2', '2024-07-11', '1', '1', '326', '1', '2024-07-11 20:08:40', '2024-07-11 20:08:40', NULL);
INSERT INTO `students` VALUES ('164', '329', NULL, '6', 'offline', '2023-24010164', '3', '2024-07-11', '1', '1', '328', '1', '2024-07-11 20:10:19', '2024-07-11 20:10:19', NULL);
INSERT INTO `students` VALUES ('165', '331', NULL, '6', 'offline', '2023-24010165', '4', '2024-07-11', '1', '1', '330', '1', '2024-07-11 20:11:59', '2024-07-11 20:11:59', NULL);
INSERT INTO `students` VALUES ('166', '333', NULL, '6', 'offline', '2023-24010166', '5', '2024-07-11', '1', '1', '332', '1', '2024-07-11 20:13:33', '2024-07-11 20:13:33', NULL);
INSERT INTO `students` VALUES ('167', '334', NULL, '6', 'offline', '2023-24010167', '6', '2024-07-11', '1', '1', '330', '1', '2024-07-11 20:15:00', '2024-07-11 20:15:00', NULL);
INSERT INTO `students` VALUES ('168', '336', NULL, '6', 'offline', '2023-24010168', '7', '2024-07-11', '1', '1', '335', '1', '2024-07-11 20:17:16', '2024-07-11 20:17:16', NULL);
INSERT INTO `students` VALUES ('169', '338', NULL, '6', 'offline', '2023-24010169', '8', '2024-07-11', '1', '1', '337', '1', '2024-07-11 20:19:12', '2024-07-11 20:19:12', NULL);
INSERT INTO `students` VALUES ('170', '340', NULL, '6', 'offline', '2023-24010170', '9', '2024-07-11', '1', '1', '339', '1', '2024-07-11 20:21:12', '2024-07-11 20:21:12', NULL);
INSERT INTO `students` VALUES ('171', '342', NULL, '6', 'offline', '2023-24010171', '10', '2024-07-11', '1', '1', '341', '1', '2024-07-11 20:22:54', '2024-07-11 20:22:54', NULL);
INSERT INTO `students` VALUES ('172', '344', NULL, '6', 'offline', '2023-24010172', '11', '2024-07-11', '1', '1', '343', '1', '2024-07-11 20:24:38', '2024-07-11 20:24:38', NULL);
INSERT INTO `students` VALUES ('173', '346', NULL, '6', 'offline', '2023-24010173', '12', '2024-07-11', '1', '1', '345', '1', '2024-07-11 20:26:14', '2024-07-11 20:26:14', NULL);
INSERT INTO `students` VALUES ('174', '348', NULL, '6', 'offline', '2023-24010174', '13', '2024-07-11', '1', '1', '347', '1', '2024-07-11 20:27:51', '2024-07-11 20:27:51', NULL);
INSERT INTO `students` VALUES ('175', '349', NULL, '6', 'offline', '2023-24010175', '14', '2024-07-11', '1', '1', '347', '1', '2024-07-11 20:29:06', '2024-07-11 20:29:06', NULL);
INSERT INTO `students` VALUES ('176', '351', NULL, '6', 'offline', '2023-24010176', '15', '2024-07-11', '1', '1', '350', '1', '2024-07-11 20:30:42', '2024-07-11 20:30:42', NULL);
INSERT INTO `students` VALUES ('177', '353', NULL, '6', 'offline', '2023-24010177', '16', '2024-07-11', '1', '1', '352', '1', '2024-07-11 20:32:39', '2024-07-11 20:32:39', NULL);
INSERT INTO `students` VALUES ('178', '355', NULL, '6', 'offline', '2023-24010178', '17', '2024-07-12', '1', '1', '354', '1', '2024-07-12 12:49:57', '2024-07-12 12:49:57', NULL);
INSERT INTO `students` VALUES ('179', '356', NULL, '6', 'offline', '2023-24010179', '18', '2024-07-12', '1', '1', '326', '1', '2024-07-12 12:52:14', '2024-07-12 12:52:14', NULL);
INSERT INTO `students` VALUES ('180', '358', NULL, '6', 'offline', '2023-24010180', '19', '2024-07-12', '1', '1', '357', '1', '2024-07-12 12:54:03', '2024-07-12 12:54:03', NULL);
INSERT INTO `students` VALUES ('181', '360', NULL, '6', 'offline', '2023-24010181', '20', '2024-07-12', '1', '1', '359', '1', '2024-07-12 12:55:56', '2024-07-12 12:55:56', NULL);
INSERT INTO `students` VALUES ('182', '362', NULL, '6', 'offline', '2023-24010182', '21', '2024-07-12', '1', '1', '361', '1', '2024-07-12 12:57:35', '2024-07-12 12:57:35', NULL);
INSERT INTO `students` VALUES ('183', '364', NULL, '6', 'offline', '2023-24010183', '22', '2024-07-12', '1', '1', '363', '1', '2024-07-12 13:01:19', '2024-07-12 13:01:19', NULL);
INSERT INTO `students` VALUES ('184', '366', NULL, '6', 'offline', '2023-24010184', '23', '2024-07-12', '1', '1', '365', '1', '2024-07-12 13:03:18', '2024-07-12 13:03:18', NULL);
INSERT INTO `students` VALUES ('185', '368', NULL, '6', 'offline', '2023-24010185', '24', '2024-07-12', '1', '1', '367', '1', '2024-07-12 13:07:52', '2024-07-12 13:07:52', NULL);
INSERT INTO `students` VALUES ('186', '370', NULL, '6', 'offline', '2023-24010186', '25', '2024-07-12', '1', '1', '369', '1', '2024-07-12 13:14:05', '2024-07-12 13:14:05', NULL);
INSERT INTO `students` VALUES ('187', '372', NULL, '6', 'offline', '2023-24010187', '26', '2024-07-12', '1', '1', '371', '1', '2024-07-12 13:17:33', '2024-07-12 13:17:33', NULL);
INSERT INTO `students` VALUES ('188', '374', NULL, '6', 'offline', '2023-24010188', '27', '2024-07-12', '1', '1', '373', '1', '2024-07-12 13:20:47', '2024-07-12 13:20:47', NULL);
INSERT INTO `students` VALUES ('189', '376', NULL, '6', 'offline', '2023-24010189', '28', '2024-07-12', '1', '1', '375', '1', '2024-07-12 13:23:48', '2024-07-12 13:23:48', NULL);
INSERT INTO `students` VALUES ('190', '378', NULL, '6', 'offline', '2023-24010190', '29', '2024-07-12', '1', '1', '377', '1', '2024-07-12 13:25:37', '2024-07-12 13:25:37', NULL);
INSERT INTO `students` VALUES ('191', '380', NULL, '6', 'offline', '2023-24010191', '30', '2024-07-12', '1', '1', '379', '1', '2024-07-12 13:27:52', '2024-07-12 13:27:52', NULL);
INSERT INTO `students` VALUES ('192', '382', NULL, '1', 'offline', '2023-24010192', '39', '2024-07-19', '1', '1', '381', '1', '2024-07-19 07:05:47', '2024-07-19 07:05:47', NULL);

CREATE TABLE IF NOT EXISTS `subject_teachers` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `subject_id` bigint(20) unsigned NOT NULL,
  `teacher_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`class_section_id`,`class_subject_id`,`teacher_id`),
  KEY `subject_teachers_school_id_foreign` (`school_id`),
  KEY `subject_teachers_subject_id_foreign` (`subject_id`),
  KEY `subject_teachers_teacher_id_foreign` (`teacher_id`),
  KEY `subject_teachers_class_subject_id_foreign` (`class_subject_id`),
  CONSTRAINT `subject_teachers_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subject_teachers_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subject_teachers_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subject_teachers_subject_id_foreign` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subject_teachers_teacher_id_foreign` FOREIGN KEY (`teacher_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=36 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `subject_teachers` VALUES ('1', '1', '1', '9', '9', '1', '2024-07-10 14:59:58', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('2', '1', '2', '8', '10', '1', '2024-07-10 14:59:58', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('3', '1', '3', '9', '11', '1', '2024-07-10 14:59:58', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('4', '1', '4', '9', '12', '1', '2024-07-10 14:59:58', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('5', '1', '5', '9', '13', '1', '2024-07-10 14:59:58', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('6', '1', '8', '9', '14', '1', '2024-07-10 14:59:58', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('7', '1', '9', '9', '15', '1', '2024-07-10 14:59:58', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('8', '1', '10', '9', '16', '1', '2024-07-10 14:59:58', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('10', '6', '1', '8', '41', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('11', '6', '3', '8', '43', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('12', '6', '3', '9', '43', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('13', '6', '4', '383', '44', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('14', '6', '5', '8', '45', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('15', '6', '5', '9', '45', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('16', '6', '8', '8', '46', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('17', '6', '8', '385', '46', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('18', '6', '9', '8', '47', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('19', '6', '9', '387', '47', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('20', '6', '10', '8', '48', '1', '2024-08-06 05:02:19', '2024-08-06 05:02:19', NULL);
INSERT INTO `subject_teachers` VALUES ('21', '5', '1', '8', '33', '1', '2024-08-06 05:03:02', '2024-08-06 05:03:02', NULL);
INSERT INTO `subject_teachers` VALUES ('22', '5', '2', '8', '34', '1', '2024-08-06 05:03:02', '2024-08-06 05:03:02', NULL);
INSERT INTO `subject_teachers` VALUES ('23', '5', '3', '8', '35', '1', '2024-08-06 05:03:02', '2024-08-06 05:03:02', NULL);
INSERT INTO `subject_teachers` VALUES ('24', '5', '4', '8', '36', '1', '2024-08-06 05:03:02', '2024-08-06 05:03:02', NULL);
INSERT INTO `subject_teachers` VALUES ('25', '5', '5', '385', '37', '1', '2024-08-06 05:03:02', '2024-08-06 05:03:02', NULL);
INSERT INTO `subject_teachers` VALUES ('26', '5', '8', '386', '38', '1', '2024-08-06 05:03:02', '2024-08-06 05:03:02', NULL);
INSERT INTO `subject_teachers` VALUES ('27', '5', '9', '386', '39', '1', '2024-08-06 05:03:02', '2024-08-06 05:03:02', NULL);
INSERT INTO `subject_teachers` VALUES ('28', '5', '10', '385', '40', '1', '2024-08-06 05:03:02', '2024-08-06 05:03:02', NULL);
INSERT INTO `subject_teachers` VALUES ('29', '1', '1', '8', '9', '1', '2024-08-10 05:29:22', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('30', '1', '3', '8', '11', '1', '2024-08-10 05:29:22', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('31', '1', '4', '8', '12', '1', '2024-08-10 05:29:22', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('32', '1', '5', '8', '13', '1', '2024-08-10 05:29:22', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('33', '1', '8', '8', '14', '1', '2024-08-10 05:29:22', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('34', '1', '9', '8', '15', '1', '2024-08-10 05:29:22', '2024-08-10 05:29:22', NULL);
INSERT INTO `subject_teachers` VALUES ('35', '1', '10', '8', '16', '1', '2024-08-10 05:29:22', '2024-08-10 05:29:22', NULL);

CREATE TABLE IF NOT EXISTS `subjects` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `code` varchar(64) DEFAULT NULL,
  `bg_color` varchar(32) NOT NULL,
  `image` varchar(512) NOT NULL,
  `medium_id` bigint(20) unsigned NOT NULL,
  `type` varchar(64) NOT NULL COMMENT 'Theory / Practical',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `subjects_school_id_foreign` (`school_id`),
  KEY `subjects_medium_id_foreign` (`medium_id`),
  CONSTRAINT `subjects_medium_id_foreign` FOREIGN KEY (`medium_id`) REFERENCES `mediums` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subjects_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `subjects` VALUES ('1', 'English Language', 'ENG1', '#cfbcbc', '1/subject/668e6beb7e62e0.325723371720609771.jpg', '1', 'Theory', '1', '2024-07-10 14:39:31', '2024-10-12 04:58:34', NULL);
INSERT INTO `subjects` VALUES ('2', 'Mathematics', 'MATH', '#634d4d', '1/subject/668e6c2a0e9180.366626661720609834.jpg', '1', 'Theory', '1', '2024-07-10 14:40:34', '2024-10-12 04:58:34', NULL);
INSERT INTO `subjects` VALUES ('3', 'Science', 'SCE', '#d650d0', '1/subject/668e6c8bc46314.250071801720609931.jpg', '1', 'Theory', '1', '2024-07-10 14:42:11', '2024-10-12 04:58:34', NULL);
INSERT INTO `subjects` VALUES ('4', 'Social Studies', 'SS1', '#20f267', '1/subject/668e6cc6bedee2.073186671720609990.jpg', '1', 'Theory', '1', '2024-07-10 14:43:10', '2024-10-12 04:58:34', NULL);
INSERT INTO `subjects` VALUES ('5', 'Basic Technology and Design', 'BTD', '#1c0ff7', '1/subject/668e6d21210d09.005361321720610081.jpg', '1', 'Theory', '1', '2024-07-10 14:44:41', '2024-10-12 04:58:34', NULL);
INSERT INTO `subjects` VALUES ('6', 'Ghanaian Language', 'TWI', '#f5cd0b', '1/subject/668e6d5f1c1c40.200928401720610143.jpg', '3', 'Theory', '1', '2024-07-10 14:45:43', '2024-10-12 04:58:34', NULL);
INSERT INTO `subjects` VALUES ('7', 'French', 'FCH', '#294c95', '1/subject/668e6dbf746d58.763601901720610239.jpg', '4', 'Theory', '1', '2024-07-10 14:47:19', '2024-10-12 04:58:34', NULL);
INSERT INTO `subjects` VALUES ('8', 'I.C.T', 'ICT', '#889645', '1/subject/668e6dee4f5116.937405131720610286.jpg', '1', 'Theory', '1', '2024-07-10 14:48:06', '2024-10-12 04:58:34', NULL);
INSERT INTO `subjects` VALUES ('9', 'Religious and Moral Education', 'RME', '#b19b7d', '1/subject/668e6e23756216.998645211720610339.jpg', '1', 'Theory', '1', '2024-07-10 14:48:59', '2024-10-12 04:58:34', NULL);
INSERT INTO `subjects` VALUES ('10', 'P.E', 'PE', '#0ef81d', '1/subject/668e6e4df00369.062051331720610381.jpg', '1', 'Practical', '1', '2024-07-10 14:49:42', '2024-10-12 04:58:34', NULL);

CREATE TABLE IF NOT EXISTS `subscription_bills` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `subscription_id` bigint(20) unsigned NOT NULL,
  `description` varchar(191) DEFAULT NULL,
  `amount` double(64,4) NOT NULL,
  `total_student` bigint(20) NOT NULL,
  `total_staff` bigint(20) NOT NULL,
  `payment_transaction_id` bigint(20) unsigned DEFAULT NULL,
  `due_date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `subscription_bill` (`subscription_id`,`school_id`),
  KEY `subscription_bills_school_id_foreign` (`school_id`),
  KEY `subscription_bills_payment_transaction_id_foreign` (`payment_transaction_id`),
  CONSTRAINT `subscription_bills_payment_transaction_id_foreign` FOREIGN KEY (`payment_transaction_id`) REFERENCES `payment_transactions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subscription_bills_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subscription_bills_subscription_id_foreign` FOREIGN KEY (`subscription_id`) REFERENCES `subscriptions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `subscription_features` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `subscription_id` bigint(20) unsigned NOT NULL,
  `feature_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique` (`subscription_id`,`feature_id`),
  KEY `subscription_features_feature_id_foreign` (`feature_id`),
  CONSTRAINT `subscription_features_feature_id_foreign` FOREIGN KEY (`feature_id`) REFERENCES `features` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subscription_features_subscription_id_foreign` FOREIGN KEY (`subscription_id`) REFERENCES `subscriptions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `subscriptions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `school_id` bigint(20) unsigned NOT NULL,
  `package_id` bigint(20) unsigned NOT NULL,
  `name` varchar(191) NOT NULL,
  `student_charge` double(8,4) NOT NULL,
  `staff_charge` double(8,4) NOT NULL,
  `start_date` date NOT NULL,
  `end_date` date NOT NULL,
  `package_type` int(11) NOT NULL DEFAULT 1 COMMENT '0 => Prepaid, 1 => Postpaid',
  `no_of_students` int(11) NOT NULL DEFAULT 0,
  `no_of_staffs` int(11) NOT NULL DEFAULT 0,
  `charges` double(64,4) NOT NULL DEFAULT 0.0000,
  `billing_cycle` int(11) NOT NULL DEFAULT 0,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `subscriptions_school_id_foreign` (`school_id`),
  KEY `subscriptions_package_id_foreign` (`package_id`),
  CONSTRAINT `subscriptions_package_id_foreign` FOREIGN KEY (`package_id`) REFERENCES `packages` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subscriptions_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `timetables` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `subject_teacher_id` bigint(20) unsigned DEFAULT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `subject_id` bigint(20) unsigned DEFAULT NULL,
  `start_time` time NOT NULL,
  `end_time` time NOT NULL,
  `note` varchar(1024) DEFAULT NULL,
  `day` enum('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday') NOT NULL,
  `type` enum('Lecture','Break') NOT NULL,
  `semester_id` bigint(20) unsigned DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `timetables_subject_teacher_id_foreign` (`subject_teacher_id`),
  KEY `timetables_school_id_foreign` (`school_id`),
  KEY `timetables_class_section_id_foreign` (`class_section_id`),
  KEY `timetables_subject_id_foreign` (`subject_id`),
  KEY `timetables_semester_id_foreign` (`semester_id`),
  CONSTRAINT `timetables_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `timetables_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `timetables_semester_id_foreign` FOREIGN KEY (`semester_id`) REFERENCES `semesters` (`id`) ON DELETE CASCADE,
  CONSTRAINT `timetables_subject_id_foreign` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `timetables_subject_teacher_id_foreign` FOREIGN KEY (`subject_teacher_id`) REFERENCES `subject_teachers` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=77 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `timetables` VALUES ('22', '6', '1', '8', '09:00:00', '10:00:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:44:40', '2024-08-06 04:44:40');
INSERT INTO `timetables` VALUES ('23', NULL, '1', NULL, '10:30:00', '11:00:00', 'Break', 'Monday', 'Break', NULL, '1', '2024-08-06 04:45:04', '2024-08-06 04:45:04');
INSERT INTO `timetables` VALUES ('24', NULL, '1', NULL, '10:30:00', '11:00:00', 'Break', 'Tuesday', 'Break', NULL, '1', '2024-08-06 04:45:19', '2024-08-06 04:45:19');
INSERT INTO `timetables` VALUES ('25', NULL, '1', NULL, '10:30:00', '11:00:00', 'Break', 'Wednesday', 'Break', NULL, '1', '2024-08-06 04:45:24', '2024-08-06 04:45:24');
INSERT INTO `timetables` VALUES ('26', NULL, '1', NULL, '10:30:00', '11:00:00', 'Break', 'Thursday', 'Break', NULL, '1', '2024-08-06 04:45:32', '2024-08-06 04:45:32');
INSERT INTO `timetables` VALUES ('27', NULL, '1', NULL, '10:29:00', '10:59:00', 'Break', 'Friday', 'Break', NULL, '1', '2024-08-06 04:45:36', '2024-08-06 04:45:36');
INSERT INTO `timetables` VALUES ('28', '3', '1', '3', '10:01:00', '10:30:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:45:42', '2024-08-06 04:46:12');
INSERT INTO `timetables` VALUES ('29', '5', '1', '5', '09:00:00', '10:00:00', NULL, 'Wednesday', 'Lecture', NULL, '1', '2024-08-06 04:46:25', '2024-08-06 04:46:25');
INSERT INTO `timetables` VALUES ('30', '2', '1', '2', '09:00:00', '10:00:00', NULL, 'Monday', 'Lecture', NULL, '1', '2024-08-06 04:46:32', '2024-08-06 04:46:32');
INSERT INTO `timetables` VALUES ('31', '8', '1', '10', '09:00:00', '10:00:00', NULL, 'Thursday', 'Lecture', NULL, '1', '2024-08-06 04:46:37', '2024-08-06 04:46:37');
INSERT INTO `timetables` VALUES ('32', '7', '1', '9', '10:00:00', '10:30:00', NULL, 'Thursday', 'Lecture', NULL, '1', '2024-08-06 04:46:41', '2024-08-06 04:46:46');
INSERT INTO `timetables` VALUES ('33', '1', '1', '1', '11:00:00', '12:00:00', NULL, 'Monday', 'Lecture', NULL, '1', '2024-08-06 04:47:04', '2024-08-06 04:47:12');
INSERT INTO `timetables` VALUES ('34', '6', '1', '8', '11:02:00', '12:02:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:47:08', '2024-08-06 04:47:08');
INSERT INTO `timetables` VALUES ('35', '5', '1', '5', '11:00:00', '12:00:00', NULL, 'Wednesday', 'Lecture', NULL, '1', '2024-08-06 04:47:16', '2024-08-06 04:47:16');
INSERT INTO `timetables` VALUES ('36', '3', '1', '3', '11:01:00', '11:29:00', NULL, 'Thursday', 'Lecture', NULL, '1', '2024-08-06 04:47:20', '2024-08-06 04:47:27');
INSERT INTO `timetables` VALUES ('37', '1', '1', '1', '11:29:00', '11:58:00', NULL, 'Thursday', 'Lecture', NULL, '1', '2024-08-06 04:47:34', '2024-08-06 04:47:37');
INSERT INTO `timetables` VALUES ('38', '1', '1', '1', '12:03:00', '12:31:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:47:49', '2024-08-06 04:47:54');
INSERT INTO `timetables` VALUES ('39', '8', '1', '10', '12:00:00', '13:00:00', NULL, 'Friday', 'Lecture', NULL, '1', '2024-08-06 04:48:02', '2024-08-06 04:48:02');
INSERT INTO `timetables` VALUES ('40', '7', '1', '9', '13:01:00', '14:01:00', NULL, 'Wednesday', 'Lecture', NULL, '1', '2024-08-06 04:48:05', '2024-08-06 04:48:05');
INSERT INTO `timetables` VALUES ('41', '6', '1', '8', '13:01:00', '14:01:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:48:08', '2024-08-06 04:48:08');
INSERT INTO `timetables` VALUES ('42', '5', '1', '5', '13:00:00', '14:00:00', NULL, 'Monday', 'Lecture', NULL, '1', '2024-08-06 04:48:12', '2024-08-06 04:48:12');
INSERT INTO `timetables` VALUES ('43', '3', '1', '3', '12:03:00', '13:03:00', NULL, 'Wednesday', 'Lecture', NULL, '1', '2024-08-06 04:48:48', '2024-08-06 04:48:48');
INSERT INTO `timetables` VALUES ('44', NULL, '5', NULL, '10:30:00', '11:00:00', 'Break', 'Monday', 'Break', NULL, '1', '2024-08-06 04:50:18', '2024-08-06 04:50:18');
INSERT INTO `timetables` VALUES ('45', NULL, '5', NULL, '10:30:00', '11:00:00', 'Break', 'Tuesday', 'Break', NULL, '1', '2024-08-06 04:50:22', '2024-08-06 04:50:22');
INSERT INTO `timetables` VALUES ('46', NULL, '5', NULL, '10:30:00', '11:00:00', 'Break', 'Wednesday', 'Break', NULL, '1', '2024-08-06 04:50:27', '2024-08-06 04:50:27');
INSERT INTO `timetables` VALUES ('47', NULL, '5', NULL, '10:30:00', '11:00:00', 'Break', 'Thursday', 'Break', NULL, '1', '2024-08-06 04:50:31', '2024-08-06 04:50:31');
INSERT INTO `timetables` VALUES ('48', NULL, '5', NULL, '10:30:00', '11:00:00', 'Break', 'Friday', 'Break', NULL, '1', '2024-08-06 04:50:39', '2024-08-06 04:50:39');
INSERT INTO `timetables` VALUES ('49', '10', '5', '1', '09:03:00', '10:03:00', NULL, 'Monday', 'Lecture', NULL, '1', '2024-08-06 04:50:44', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('50', '22', '5', '2', '10:00:00', '10:27:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:50:48', '2024-08-06 05:03:03');
INSERT INTO `timetables` VALUES ('51', '11', '5', '3', '10:00:00', '10:28:00', NULL, 'Wednesday', 'Lecture', NULL, '1', '2024-08-06 04:51:10', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('52', '16', '5', '8', '09:04:00', '10:04:00', NULL, 'Thursday', 'Lecture', NULL, '1', '2024-08-06 04:51:23', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('53', '14', '5', '5', '09:00:00', '10:00:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:51:26', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('54', '11', '5', '3', '09:01:00', '09:58:00', NULL, 'Wednesday', 'Lecture', NULL, '1', '2024-08-06 04:51:32', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('55', '20', '5', '10', '11:00:00', '13:01:00', NULL, 'Friday', 'Lecture', NULL, '1', '2024-08-06 04:51:43', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('56', '18', '5', '9', '12:01:00', '13:01:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:51:52', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('57', '18', '5', '9', '12:00:00', '13:00:00', NULL, 'Monday', 'Lecture', NULL, '1', '2024-08-06 04:51:53', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('58', '16', '5', '8', '11:04:00', '12:04:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:51:56', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('59', '11', '5', '3', '10:58:00', '11:58:00', NULL, 'Wednesday', 'Lecture', NULL, '1', '2024-08-06 04:51:59', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('60', NULL, '6', NULL, '10:30:00', '11:00:00', 'Break', 'Monday', 'Break', NULL, '1', '2024-08-06 04:52:34', '2024-08-06 04:52:40');
INSERT INTO `timetables` VALUES ('61', NULL, '6', NULL, '10:30:00', '11:00:00', 'Break', 'Tuesday', 'Break', NULL, '1', '2024-08-06 04:52:42', '2024-08-06 04:52:48');
INSERT INTO `timetables` VALUES ('62', NULL, '6', NULL, '10:30:00', '11:00:00', 'Break', 'Wednesday', 'Break', NULL, '1', '2024-08-06 04:52:45', '2024-08-06 04:53:02');
INSERT INTO `timetables` VALUES ('63', NULL, '6', NULL, '10:30:00', '11:00:00', 'Break', 'Thursday', 'Break', NULL, '1', '2024-08-06 04:52:57', '2024-08-06 04:52:57');
INSERT INTO `timetables` VALUES ('64', NULL, '6', NULL, '10:30:00', '11:00:00', 'Break', 'Friday', 'Break', NULL, '1', '2024-08-06 04:53:06', '2024-08-06 04:53:06');
INSERT INTO `timetables` VALUES ('65', '20', '6', '10', '11:00:00', '12:00:00', NULL, 'Friday', 'Lecture', NULL, '1', '2024-08-06 04:53:11', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('66', '16', '6', '8', '09:01:00', '10:01:00', NULL, 'Thursday', 'Lecture', NULL, '1', '2024-08-06 04:53:14', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('67', '13', '6', '4', '09:01:00', '10:01:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:53:17', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('68', '11', '6', '3', '09:01:00', '10:01:00', NULL, 'Monday', 'Lecture', NULL, '1', '2024-08-06 04:53:22', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('69', '10', '6', '1', '11:03:00', '12:03:00', NULL, 'Monday', 'Lecture', NULL, '1', '2024-08-06 04:53:26', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('70', '22', '6', '2', '11:06:00', '11:59:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:53:29', '2024-08-06 05:03:03');
INSERT INTO `timetables` VALUES ('71', '18', '6', '9', '12:02:00', '13:02:00', NULL, 'Wednesday', 'Lecture', NULL, '1', '2024-08-06 04:53:32', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('72', '18', '6', '9', '12:01:00', '13:01:00', NULL, 'Thursday', 'Lecture', NULL, '1', '2024-08-06 04:53:36', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('73', '11', '6', '3', '11:02:00', '12:02:00', NULL, 'Thursday', 'Lecture', NULL, '1', '2024-08-06 04:53:42', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('74', '16', '6', '8', '12:04:00', '13:04:00', NULL, 'Monday', 'Lecture', NULL, '1', '2024-08-06 04:53:46', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('75', '16', '6', '8', '13:02:00', '14:02:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:53:50', '2024-08-06 05:02:19');
INSERT INTO `timetables` VALUES ('76', '11', '6', '3', '12:01:00', '13:00:00', NULL, 'Tuesday', 'Lecture', NULL, '1', '2024-08-06 04:53:57', '2024-08-06 05:02:19');

CREATE TABLE IF NOT EXISTS `topic_commons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `lesson_topics_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `topic_commons_lesson_topics_id_foreign` (`lesson_topics_id`),
  KEY `topic_commons_class_section_id_foreign` (`class_section_id`),
  CONSTRAINT `topic_commons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `topic_commons_lesson_topics_id_foreign` FOREIGN KEY (`lesson_topics_id`) REFERENCES `lesson_topics` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `users` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `first_name` varchar(128) NOT NULL,
  `last_name` varchar(128) NOT NULL,
  `mobile` varchar(191) DEFAULT NULL,
  `email` varchar(191) NOT NULL,
  `password` varchar(191) NOT NULL,
  `gender` varchar(16) DEFAULT NULL,
  `image` varchar(512) DEFAULT NULL,
  `dob` date DEFAULT NULL,
  `current_address` varchar(191) DEFAULT NULL,
  `permanent_address` varchar(191) DEFAULT NULL,
  `occupation` varchar(128) DEFAULT NULL,
  `status` tinyint(4) NOT NULL DEFAULT 1,
  `reset_request` tinyint(4) NOT NULL DEFAULT 0,
  `fcm_id` varchar(1024) DEFAULT NULL,
  `school_id` bigint(20) unsigned DEFAULT NULL,
  `language` varchar(191) NOT NULL DEFAULT 'en',
  `remember_token` varchar(100) DEFAULT NULL,
  `email_verified_at` timestamp NULL DEFAULT NULL,
  `two_factor_enabled` tinyint(4) NOT NULL DEFAULT 1,
  `two_factor_secret` varchar(191) DEFAULT NULL,
  `two_factor_expires_at` varchar(191) DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `users_email_unique` (`email`),
  KEY `users_school_id_foreign` (`school_id`),
  CONSTRAINT `users_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=388 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `users` VALUES ('2', 'Michael', 'Amponsah', '0244944725', 'gmacapon@gmail.com', '$2y$10$YCYNznUcbBceGWubZyYw7exsH5YQPcxKXJDt0E9clPUxLuos0Aqg.', NULL, '', NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', 'miFrwutuW0AVmFQTCOSk7eruBfSi58phm0E4xpl08UwSJ9u08DYFFf7FROlt', '2024-10-12 05:04:16', '1', 'bzXRYt', NULL, '2024-03-13 05:31:12', '2025-01-01 09:27:55', NULL);
INSERT INTO `users` VALUES ('8', 'Michael', 'Amponsah', '0244980127', 'kixidcloud@gmail.com', '$2y$10$EEUY49w2IxSclt.XhrOgNumw5WOlN8ZzQqWbiZrcPJcKcyiepp9aS', 'male', NULL, '2020-07-23', 'Malshegu', 'Accra', NULL, '1', '0', 'eKA9UwBWQD-nmDFltiuMkP:APA91bGu9Ch1ww9QsScoXFKfeAtT8dgZr7cllHbYKC8gogYIC3T4OK4OVj31wZdtiLHYv0Iprvni4OOG-_ZLlKuTh3fM2X6a1X7vEBhjwmMhPGDkQeuoVocjOnplK_9MGZG1nOLo8kAr', '1', 'en', 'PHp3aq3P3Z3e7SVs0RIhM3o2chtrNRTgjx0lTZIm6opV0EELocNAGGrW8uJd', NULL, '1', NULL, NULL, '2024-07-10 14:30:22', '2025-01-01 09:30:09', NULL);
INSERT INTO `users` VALUES ('9', 'Asmawu', 'Kanyi', '0559875203', 'asmawbae@gmail.com', '$2y$10$ZSnjz6qeovQN5gFasEMly.V4MQrjz53lzxQ4QmYnpQFrnBbL/SQ52', 'male', NULL, '2000-12-24', 'Sognaayili', 'Tamale', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 14:32:36', '2024-07-10 14:32:36', NULL);
INSERT INTO `users` VALUES ('10', 'Osei', 'Boamah', '0240000000', 'guardian1@gmail.com', '$2y$10$7Khe4NC2YiTy33IKUYCHhe1NHGJx5PS1PFWLzkWh9o.EjnZuuKx.u', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:29:07', '2024-07-10 16:29:07', NULL);
INSERT INTO `users` VALUES ('11', 'Bernad', 'Darko', NULL, '2023-240101', '$2y$10$thDfsTEId5dszaVAWAv5Fu/bDcIaHBltLSigaztyIO7KinRTN0vW2', 'male', '1/1/1/1/1/1/user/668e859c056928.726785931720616348.jpg', '2010-05-25', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:29:08', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('12', 'Boamah', 'Issac', '0240000000', 'guardian2@gmail.com', '$2y$10$njLMaIkZH3IH.GlP44UpR.aUTuppgnNoo5ks/bCXpbr1gUwdBKf1S', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:33:06', '2024-07-10 16:33:06', NULL);
INSERT INTO `users` VALUES ('13', 'Samuel', 'Boamah', NULL, '2023-240102', '$2y$10$kqAEFD.qKwBGZK1fPY/LzuRPCFQpTRJrAuJ.EDfBePhsyirv4q8sK', 'male', '1/1/1/1/1/1/user/668e868a22d254.473374841720616586.jpg', '2010-11-01', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:33:06', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('14', 'Boamah', 'Issac', '0240000000', 'guardian3@gmail.com', '$2y$10$R.3mRbHvQ/nhijiNCONK1uaH8shJpPS49YrO.cDhRDW/nIpuwqmwi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:35:47', '2024-07-10 16:35:47', NULL);
INSERT INTO `users` VALUES ('15', 'Prince', 'Boamah', NULL, '2023-240103', '$2y$10$yyy3.LJQeDxeCbvCPo5NUuO4zDnv.mFrjGOctvvo1pYeTPFHqUfte', 'male', '1/1/1/1/1/1/user/668e872bc87767.478801511720616747.jpg', '2010-11-01', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:35:47', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('16', 'Solomon', 'Brafi', '0240000000', 'guardian4@gmail.com', '$2y$10$yS1GHvwJW3E2W0wDg28RD.lFku.GrrMhmWH3640IBJymcTRvboHhO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:38:41', '2024-07-10 16:38:41', NULL);
INSERT INTO `users` VALUES ('17', 'Brafi', 'Comfort', NULL, '2023-240104', '$2y$10$WHrkyJzVbwGlvxwvzzK2KuH3ZsKMqTuvXSCR9rOa8yAd6viH4/CUm', 'female', '1/1/1/1/1/1/user/668e87d9ba9238.905514081720616921.jpg', '2010-01-15', 'Ablekuma', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:38:41', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('18', 'Owusu', 'Banabas', '0240000000', 'guardian5@gmail.com', '$2y$10$6JodeLGCGHzNORBjofkcle5zlsVGIC8h9VJPQ/CiBNGU9/Bk8QWcK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:41:26', '2024-07-10 16:41:26', NULL);
INSERT INTO `users` VALUES ('19', 'Jeremiah', 'Owusu', NULL, '2023-240105', '$2y$10$KNZonIouRuCnkqIYCDEomOKlwYqEALzi4/h8528JQwsQOO..UI5t.', 'male', '1/1/1/1/1/1/user/668e887e64c3d5.419426431720617086.jpg', '2010-12-20', 'Lapaz', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:41:26', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('20', 'Salamatu', 'Yakubu', '0244800999', 'guardian6@gmail.com', '$2y$10$AECMG24LXfFhZsqcZ7a7wuXFVbMcSBxG5TPnhVg/CFC3ljM74LpYu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:46:20', '2024-07-10 16:46:20', NULL);
INSERT INTO `users` VALUES ('21', 'Rashida', 'Seidu', NULL, '2023-240106', '$2y$10$ehcIJIdhdLlFSrCvYEgIhuypyhmcrOKR.CNZsZCJQ8wyL9.v18NEa', 'female', '1/1/1/1/1/1/user/668e89a4b68317.226179381720617380.jpg', '2010-11-23', 'Lapaz', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:46:20', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('22', 'Inusa', 'Abdulai', '0244470010', 'guardian7@gmail.com', '$2y$10$eU3nSTrrnzgIe0nQ8q7vju0qruEc1Iq8jlzc9CMsdggVc2BDCnZVS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:50:10', '2024-07-10 16:50:10', NULL);
INSERT INTO `users` VALUES ('23', 'Bukari', 'Bashiru', NULL, '2023-240107', '$2y$10$WuvVJqDcQwSvRivpO0rIE.nljYiEE1t9ahEjbWOicT8khPqbkRoY.', 'male', '1/1/1/1/1/1/user/668e8a8b086671.428647741720617611.jpg', '2010-08-16', 'Ablekuma', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:50:11', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('24', 'Sumaila', 'Botie', '0200666155', 'guardian8@gmail.com', '$2y$10$7mgoArxIKhFytPzV/O7LieTzVMw76vaBfXmgn8.Qo1wI1WJwawFxK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:53:19', '2024-07-10 16:53:19', NULL);
INSERT INTO `users` VALUES ('25', 'Basira', 'Botie', NULL, '2023-240108', '$2y$10$9A1bmv07sph9Q7aV5HgtM.pvAV6pl4cVSfFu3Zfv0uWLSvJ5KpHY2', 'female', '1/1/1/1/1/1/user/668e8b47baaeb3.226328891720617799.jpg', '2010-10-22', 'Dansoman', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 16:53:19', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('26', 'Dogbatse', 'Evans', '0206017299', 'guardian9@gmail.com', '$2y$10$4Punr.fnfVOEX1KiJ03ANexOOKnQ8MOD4iJksfucmfNbEREpag39u', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:27:36', '2024-07-10 17:27:36', NULL);
INSERT INTO `users` VALUES ('27', 'Zynator', 'Dogbatse', NULL, '2023-240109', '$2y$10$R58QTaar0q5bvxywedLecOIxvIjKMruyz3j8Bi7BQ8/cPDkRfAGda', 'female', '1/1/1/1/1/1/user/668e9350ba9474.198347681720619856.jpg', '2010-06-30', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:27:36', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('28', 'Binoli', 'Mawutor', '0593006211', 'guardian10@gmail.com', '$2y$10$xPKS7uv26aVE/pZiMy9WK.9zIHEU.dCpI.t8YW5IxYFZCxxVchtF2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:30:22', '2024-07-10 17:30:22', NULL);
INSERT INTO `users` VALUES ('29', 'Abraham', 'Binoli', NULL, '2023-2401010', '$2y$10$ChHTWFwAPdnMMz3Y/v6RT.1hkSqFmTsziQ6g0TlxOozV2cd70LjsG', 'male', '1/1/1/1/1/1/user/668e93f637f709.570790171720620022.jpg', '2010-02-13', 'Lapaz', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:30:22', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('30', 'Abudu', 'Nurudeen', '0553033111', 'guardian11@gmail.com', '$2y$10$C8NYKWub91rRbcRPX1.vNumx0kE9E48rYU6dTITGg54RGQGDk6Are', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:33:28', '2024-07-10 17:33:28', NULL);
INSERT INTO `users` VALUES ('31', 'Firdaus', 'Abudu', NULL, '2023-2401011', '$2y$10$VMln6ngwpdler9VB1uowbuejWhut6lBIa01e1JrRi2dqgyZhfIXGS', 'female', '1/1/1/1/1/1/user/668e94b07e1812.219047691720620208.jpg', '2010-10-22', 'Lapaz', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:33:28', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('32', 'Issaka', 'Fuseini', '0200999232', 'guardian12@gmail.com', '$2y$10$5I92nz8f9kJG5m2T5rosz.ry6I4ERzM4yLmLKV1KQRT1v7peTb67S', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:36:07', '2024-07-10 17:36:07', NULL);
INSERT INTO `users` VALUES ('33', 'Issaka', 'Mariyama', NULL, '2023-2401012', '$2y$10$oofWmSp1y8eHjR7almbz1.kk/fwzq6WqNT6RaYTK3/rbVsLPAp4DS', 'female', '1/1/1/1/1/1/user/668e954f4d2197.233459571720620367.jpg', '2010-12-29', 'Dansoman', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:36:07', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('34', 'Moses', 'Serwaa', '0262254900', 'guardian13@gmail.com', '$2y$10$Jm9lh4z1RaQzKJrQblWhZeDq2ombViTI9AYZ165zh7Bfirxgr5WS6', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:38:38', '2024-07-10 17:38:38', NULL);
INSERT INTO `users` VALUES ('35', 'Abigail', 'Razark', NULL, '2023-2401013', '$2y$10$tG7m8SAmgGy0tI/vCpq0ietBbIZpEX0M5IRAGUsYtPONY25bpup3y', 'female', '1/1/1/1/1/1/user/668e95e70ecbc0.614624841720620519.jpg', '2010-02-18', 'Dansoman', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:38:39', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('36', 'Samuel', 'Opoku', '0544881233', 'guard14@gmail.com', '$2y$10$GP8s3aZUQ3.cOMy4ORzvXuFsTsK9NpOtRb3n4qrIA9ktNC5zDEdr6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:42:24', '2024-10-24 19:54:17', NULL);
INSERT INTO `users` VALUES ('37', 'Victoria', 'Opoku', NULL, '2023-2401014', '$2y$10$2T1We3ifrU7a6ovpAt6s.Or5Lsfr/5ynYBG3fnO9MmwCXkm4tszM.', 'female', '1/1/1/1/1/1/user/668e96c9105ca8.946377561720620745.jpg', '2010-09-07', 'Dansoman', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:42:25', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('38', 'David', 'Opoku', NULL, '2023-2401015', '$2y$10$gUCOLM2QkzgX7OZTXc8PLeGQndGJnoKvqhfAO4SO61TDxHCGJ3loy', 'male', '1/1/1/1/1/1/user/668e9769cf9986.570142141720620905.jpg', '2010-09-07', 'Dansoman', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:45:05', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('39', 'Gadose', 'Mawuli', '0555111021', 'guard15@gmail.com', '$2y$10$SXDPF1vyNoSfkRQMP72Uku1vdoJ7OgV4OsSYTHVVYD6VjWioJcvU.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:47:46', '2024-07-10 17:47:46', NULL);
INSERT INTO `users` VALUES ('40', 'Richmond', 'Gadose', NULL, '2023-2401016', '$2y$10$kEXxTjkrJ8/lccHj1GFCCuzL/.lPAxHj1xsQLCW1l/5KiuAUJiKSC', 'male', '1/1/1/1/1/1/user/668e980a7e7e78.756260281720621066.jpg', '2010-04-22', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:47:46', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('41', 'Obubuafo', 'Evans', '0244420001', 'guardian16@gmail.com', '$2y$10$dpFWElnMiDnd1KMwAb8ghOp9sxqI8wgU5v6R/u6OAt7uZ4Evagq8y', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:51:23', '2024-07-10 17:51:23', NULL);
INSERT INTO `users` VALUES ('42', 'Raphel', 'Obubuafo', NULL, '2023-2401017', '$2y$10$02FN/vftiGVGISDQsM5hNuux4nBj6cuwpCkHb9lbpVYjG13C7FLt6', 'male', '1/1/1/1/1/1/user/668e98e4053b41.725585061720621284.jpg', '2010-12-30', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:51:24', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('43', 'Raphael', 'Abeiku', '0244000000', 'guardian17@gmail.com', '$2y$10$Oy2etYsVrc3sP9yndeWz7e0LboLHXztsWXNS0xHwCLw3r0wjWO5r2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:54:33', '2024-07-10 17:54:33', NULL);
INSERT INTO `users` VALUES ('44', 'Boatemaa', 'Erica', NULL, '2023-2401018', '$2y$10$MYi4Chm9jTMlKGsX5fVUbuM6WOazq2G0Kejby.lhhmfnT3SqOfSy.', 'female', '1/1/1/1/1/1/user/668e99a1ad3a47.425654811720621473.jpg', '2010-08-16', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:54:33', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('45', 'Sahyourn', 'Evans', '0200919119', 'guardian18@gmail.com', '$2y$10$E1k0EM2PtrcQRnHFcsVlVuYgWls8WCpAkSTZDYDD0HlMr3yMnbne2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:57:16', '2024-07-10 17:57:16', NULL);
INSERT INTO `users` VALUES ('46', 'Sahyourn', 'Joseph', NULL, '2023-2401019', '$2y$10$uCz0bTbyaebMlJn2WHp1Xum1QoHdMIX1o2TAXMgPyLy41MwpQpZSy', 'male', '1/1/1/1/1/1/user/668e9a450e4a08.629350281720621637.jpg', '2010-03-13', 'Circle', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:57:17', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('47', 'Mensah', 'Christopher', '0260882112', 'guard19@gmail.com', '$2y$10$gzj5Am7HvEnVnxpRDuw2l.SQKFv9l8PJ69y9J/8eErITMGiVKiKGm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:59:58', '2024-07-10 17:59:58', NULL);
INSERT INTO `users` VALUES ('48', 'Elizabeth', 'Mensah', NULL, '2023-2401020', '$2y$10$/0fOQ8I/T1QiuZckdvcxVei9e8Rfd.XN4SZyIAdwQ4ZSezynIiISO', 'female', '1/1/1/1/1/1/user/668e9ae6968340.595854671720621798.jpg', '2010-10-25', 'Circle', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 17:59:58', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('49', 'Bismark', 'Ofori', '0545477711', 'guard20@gmail.com', '$2y$10$R/PZqiPvq6D4QQ3Xx5tuJu8xyWyrcueEDJSS4p5GURKdREakRbK.q', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:03:37', '2024-07-10 18:03:37', NULL);
INSERT INTO `users` VALUES ('50', 'Rapheal', 'Ofori', NULL, '2023-2401021', '$2y$10$oSjsmkI5Ke36V7XCzf7MFeWQ2UTvBS3dgfiwz35QpF/fUi5tOMKYe', 'male', '1/1/1/1/1/1/user/668e9bc1209146.862952781720622017.jpg', '2010-10-11', 'Circle', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:03:37', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('51', 'Paul', 'Nyarku', '0244600567', 'guard21@gmail.com', '$2y$10$.3nIJg2WdL3/zvYwbBVkY.e4XQkIZr.o8qvm.VUiRQ6pscYe9LyB2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:06:17', '2024-07-10 18:06:17', NULL);
INSERT INTO `users` VALUES ('52', 'Priscilla', 'Nyarko', NULL, '2023-2401022', '$2y$10$thckN.RNtqF6dVIXVsV2auqiJP6mvoIiiFLNznQaZF81H/vlYCidS', 'female', '1/1/1/1/1/1/user/668e9c6157a035.548292011720622177.jpg', '2010-10-21', 'Circle', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:06:17', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('53', 'Ntim', 'Nyarku', '0205112334', 'guard22@gmail.com', '$2y$10$Zd7lDuPYxZp4VKL1Yes6MOpVixfnd14M.dzkHlIJCPJ86ttfjWqtC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:09:16', '2024-07-10 18:09:16', NULL);
INSERT INTO `users` VALUES ('54', 'Cindy', 'Nyarko', NULL, '2023-2401023', '$2y$10$e7RHXaFm.tKzyT0kFCNhOerVMjZiddiq5tTBaiYzgTL4YLlwe3exO', 'female', '1/1/1/1/1/1/user/668e9d143df7b0.814141971720622356.jpg', '2010-01-14', 'Circle', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:09:16', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('55', 'Quartey', 'Okai', '0243090000', 'guardian23@gmail.com', '$2y$10$9Oee59o9sc1h0P/oEnXPReTqRWJn.tMDU49x9iHe8e45u0Gcqt0PC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:12:22', '2024-07-10 18:12:22', NULL);
INSERT INTO `users` VALUES ('56', 'Emmanuel', 'Quartey', NULL, '2023-2401024', '$2y$10$kf18aV5R7GsCq0eZqk2zpepShItAKeZCsCLteafs0qORyTxwbb.D6', 'male', '1/1/1/1/1/1/user/668e9dcf006c85.424846211720622543.jpg', '2010-11-29', 'Lapaz', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:12:23', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('57', 'Enoch', 'Adjei', '0568802121', 'guardian24@gmail.com', '$2y$10$G.msXJS.vq5LK6vmlde/K.VBNPCjqK3PxciCHqEVHVKjztAPZRTwS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:15:41', '2024-07-10 18:15:41', NULL);
INSERT INTO `users` VALUES ('58', 'Princessable', 'Adjei', NULL, '2023-2401025', '$2y$10$SXGDq/JljNvZCrWU65QWK.4y8exjJIr842hip9UuB9q6ROR8Z4Xs.', 'female', '1/1/1/1/1/1/user/668e9e957e6217.809484801720622741.jpg', '2010-07-17', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:15:41', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('59', 'Etuaful', 'Mawutor', '0243000000', 'guardian26@gmail.com', '$2y$10$GY5/iR6nAG3OGxG9NQsU/OpIRo0SbduLz661.ftTQJqNvulIp/d3e', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:18:29', '2024-07-10 18:18:29', NULL);
INSERT INTO `users` VALUES ('60', 'Regina', 'Etuaful', NULL, '2023-2401026', '$2y$10$lfqX1PUgpVS54gQN4zWmJeRwathUEdViVJ0E5Me1MJ/XsNLygZSEG', 'female', '1/1/1/1/1/1/user/668e9f3dcd5b78.977987481720622909.jpg', '2010-11-25', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:18:29', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('61', 'Christian', 'Owusu', '0243000000', 'guardian27@gmail.com', '$2y$10$GL0W9uZPe1Rl4PCKzvrci.7XnFsOnJ3vjQ6Tay.qKM1sKN6PRgXXa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:26:35', '2024-07-10 18:26:35', NULL);
INSERT INTO `users` VALUES ('62', 'Owusu', 'Princess', NULL, '2023-2401027', '$2y$10$UjuwJvF8Pn8nZ/pIDx8oveRqim1LYDCb4yXyNk2NpqSxWsjkBfTfG', 'female', '1/1/1/1/1/1/user/668ea1237401d3.902420991720623395.jpg', '2010-12-23', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:26:35', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('63', 'Mahama', 'Abass', '0240244262', 'guardian28@gmail.com', '$2y$10$9XfliDd0Gq5G46p4yvzoP.PXAWJddMRLHY33Eht1t6gVUIL2LxggS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:29:56', '2024-07-10 18:29:56', NULL);
INSERT INTO `users` VALUES ('64', 'Abass', 'Ayisha', NULL, '2023-2401028', '$2y$10$m1HEnMVSoAjU8Lg4nvaHWeySm8b2/aMif3vVw0j/h6gxr6a8SPnw2', 'female', '1/1/1/1/1/1/user/668ea1ec136758.825602191720623596.jpg', '2010-03-22', 'Lapaz', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:29:56', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('65', 'Akuffo', 'Aidoo', '0554443000', 'guardian29@gmail.com', '$2y$10$HQUDY.tLXETDLHoZmYxtKOTerYILUI4FQcBZ2gxjeCnmcQ700GTau', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:33:09', '2024-07-10 18:33:09', NULL);
INSERT INTO `users` VALUES ('66', 'Aidoo', 'Samuel', NULL, '2023-2401029', '$2y$10$CjSB3NzLSg94IC3bDOO9f.d/dU1zdVKXMQdzpfttjfTlS2QzQDbQu', 'male', '1/1/1/1/1/1/user/668ea2ad79c075.292122021720623789.jpg', '2010-12-31', 'Circle', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:33:09', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('67', 'Christian', 'Asante', '0243000000', 'guardian30@gmail.com', '$2y$10$HxA/tOR2OSYGW87vOEGPkuR9jtzoER9OnKWjoiihPKnOGgPX0f9GW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:38:06', '2024-10-24 19:54:17', NULL);
INSERT INTO `users` VALUES ('68', 'Christian', 'Smith', NULL, '2023-2401030', '$2y$10$SKZQG793RbmewVqEqpXQSe9aeGw1rhA5JSO.PLqnvIJNowbHF7B6y', 'male', '1/1/1/1/1/1/user/668ea3d648e2f0.191996241720624086.jpg', '2010-09-18', 'Circle', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:38:06', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('69', 'Gifty', 'Smith Gifty', NULL, '2023-2401031', '$2y$10$BOVqWzaRm9YZKxN8VHAzGOtXKPDwL9IFmoIJ.KdF7RVQ.YkqM5ZVy', 'female', '1/1/1/1/1/1/user/668ea4885a6ee4.351245251720624264.jpg', '2010-11-13', 'Circle', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:41:04', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('70', 'Gabriel', 'Smith', NULL, '2023-2401032', '$2y$10$kMaXVrjyP1qzpumagFJyd.kYO897IRxvKdvk29BVgrLVB4lxvP2qO', 'male', '1/1/1/1/1/1/user/668ea529621cf0.693581651720624425.jpg', '2010-10-24', 'Circle', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:43:45', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('71', 'Stephen', 'Noah', '024447002', 'guard31@gmail.com', '$2y$10$fsVi2jH7W9jWnaWvacSFSOe8x5ENkka.Mx1g58L30zXrAHmU2rWAi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:46:48', '2024-07-10 18:46:48', NULL);
INSERT INTO `users` VALUES ('72', 'Precious', 'Yeboah', NULL, '2023-2401033', '$2y$10$J4Sx6z9PM4zt7lvl/EV4VOU82IGUG4sO4MGvFLUSl2bOZOd2e9/9e', 'female', '1/1/1/1/1/1/user/668ea5e04698c0.921378271720624608.jpg', '2010-09-18', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:46:48', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('73', 'Munkaila', 'Ahmed', '0244399977', 'guard32@gmail.com', '$2y$10$cNfijTHeIVEYqYtv3YSDFO3kK2f8nLFYLNmqbhqPNm7gVFN8RhS/u', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:49:11', '2024-07-10 18:49:11', NULL);
INSERT INTO `users` VALUES ('74', 'Mohammed', 'Kasim', NULL, '2023-2401034', '$2y$10$Ip2l9p9NOV/iTsysXVvWlufCZzBhsIR4SNmNHSGFfTSXFFLcqPCqW', 'male', '1/1/1/1/1/1/user/668ea66fd32c56.475120511720624751.jpg', '2010-03-11', 'Lapaz', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:49:11', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('75', 'Eshun', 'Kortey', '0559091101', 'guard33@gmail.com', '$2y$10$fvsIcmnh1n7AzCBQD1RkGe1q7388s9DEvZ0dpT2jRaxFIYTorVUkm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:51:35', '2024-07-10 18:51:35', NULL);
INSERT INTO `users` VALUES ('76', 'Desmond', 'Kortey', NULL, '2023-2401035', '$2y$10$mVYqAlojKWDJiwVZFrwUNe64JvirZ67kBCnh/sgJ2emvwImv4d4Ju', 'male', '1/1/1/1/1/1/user/668ea6ff77d004.356765241720624895.jpg', '2010-01-22', 'Lapaz', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:51:35', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('77', 'Ohemeng', 'Justice', '0547710111', 'guardian34@gmail.com', '$2y$10$1aRGPRgQRDhzUq/22Y9TG.gDKeNSF76eQM5NbwSqySPeVwV4XiNeK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:55:11', '2024-07-10 18:55:11', NULL);
INSERT INTO `users` VALUES ('78', 'Ohemeng', 'Rockline', NULL, '2023-2401036', '$2y$10$5hFbyBoLlPIaiVrs1dm22efAxfZjOc6YrzCGTlxLcEKx6l1hfUa7K', 'male', '1/1/1/1/1/1/user/668ea7d7bc3b75.810125741720625111.jpg', '2010-02-20', 'Ablekuma', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:55:11', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('79', 'Appah', 'Gyansi', '0244498880', 'guardian35@gmail.com', '$2y$10$VIqUfwxtWk/b85/Z.BlAX.vaI.dqg5hyvF/sJDAgG/FCblwfFbOzq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:57:22', '2024-07-10 18:57:22', NULL);
INSERT INTO `users` VALUES ('80', 'Appah', 'Micheal', NULL, '2023-2401037', '$2y$10$Of7SAO3uCWhr3m5PNHi2wOZBTG7YbyS/NtinPTsutuJudRI6KshTG', 'male', '1/1/1/1/1/1/user/668ea85ac39646.041953101720625242.jpg', '2010-08-16', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:57:22', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('81', 'Acheampong', 'Francis', '0243000000', 'guardian36@gmail.com', '$2y$10$KMQA.0R8NHxQDller6z6Ue2CvFkHIXh2NMOELnQpHk0iJjvfjl0CO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:59:34', '2024-07-10 18:59:34', NULL);
INSERT INTO `users` VALUES ('82', 'Gyamfi', 'Adu', NULL, '2023-2401038', '$2y$10$hVnyowx8V4dGevISiNW.0.gEL96gfwYrIcYkoo/IBE5vTUzKc3Gyi', 'male', '1/1/1/1/1/1/user/668ea8ded09b08.779855721720625374.jpg', '2010-04-02', 'Ablekuma', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 18:59:34', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('83', 'Wilfred', 'Joseph', '0200091122', 'kixidguard1@gmail.com', '$2y$10$tZyH4nZPPxvbySE97rvdS.jn1OibrxcSElm5d9fE7DTBO4bKBqWb6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:14:31', '2024-07-10 19:14:31', NULL);
INSERT INTO `users` VALUES ('84', 'Obese', 'Joseph', NULL, '2023-2401039', '$2y$10$7.XNG0GfNU0As1el8BPz..vIRSu8nOqPvJWsvOgxpqg/ghPYknFju', 'male', '1/1/1/1/1/1/user/668eac5feb5f24.897888291720626271.jpg', '2010-01-02', 'Cantonment', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:14:31', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('85', 'Yeboah', 'Alfred', '0244300000', 'kixidguard2@gmail.com', '$2y$10$KIto./GLrB6voa4kXhS07OtSYjhEhZlEH1Fj3vzATSLnT36OAeEV.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:16:43', '2024-07-10 19:16:43', NULL);
INSERT INTO `users` VALUES ('86', 'Yeboah', 'Derrick', NULL, '2023-2401040', '$2y$10$JnCmJdgWF05XW.7hXDqA8eII1s8afw4CcqDtOF/zTWSPowwajg5Gu', 'male', '1/1/1/1/1/1/user/668eace3421968.525944901720626403.jpg', '2010-10-11', 'Cantonment', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:16:43', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('87', 'Bentum', 'Edward', '020066620', 'kixidguard3@gmail.com', '$2y$10$SkC5SwvK030ymfwyxEmAievBJ0no.OniMFV.3TddKTLQ4VRT4BVbC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:19:47', '2024-07-10 19:19:47', NULL);
INSERT INTO `users` VALUES ('88', 'Bentum', 'Peace', NULL, '2023-2401041', '$2y$10$A/nKWFdVHnQBKUlKYHIg6eHh5awIt/sPNYCqXnBhTk0sZZ3DLlqLC', 'female', '1/1/1/1/1/1/user/668ead9c102069.416754281720626588.jpg', '2010-08-21', 'Cantonment', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:19:48', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('89', 'Acquah', 'Emmanuel', '0244330000', 'kixidguard4@gmail.com', '$2y$10$FxHHkOdXScs9puzn7ZRB4eGS2IPFRGtaqJTrOgfjlDVSPV7ZgnP96', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:22:21', '2024-07-10 19:22:21', NULL);
INSERT INTO `users` VALUES ('90', 'Acquah', 'Ebenezer', NULL, '2023-2401042', '$2y$10$qLId7AJoD.0WoIl.4ED.veh7.DY.mTobuhHUWpxs8kGo2GAPxrs2G', 'male', '1/1/1/1/1/1/user/668eae3582d3f4.238376401720626741.jpg', '2010-03-19', 'Nima', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:22:21', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('91', 'Austin', 'Amissah', '024003000', 'kixidguard5@gmail.com', '$2y$10$L8qAF.XJl4mP1Um3F2sOxOQn3ilvzT4XF8FN5OTnkSQ8pt7O5gdBy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:26:16', '2024-07-10 19:26:16', NULL);
INSERT INTO `users` VALUES ('92', 'Helina', 'Amisah', NULL, '2023-2401043', '$2y$10$KHA/FKxuIx.WrOgQTVAtduDzeGJonHQ7QA8SfqmY2FypEtE07q8wu', 'female', '1/1/1/1/1/1/user/668eaf20870a07.109943001720626976.jpg', '2010-06-12', 'Nima', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:26:16', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('93', 'Adam', 'Bansi', '0244822009', 'fixidguard6@gmail.com', '$2y$10$gd6RLNk2lPl0K37Ie04So.Jv3L8hgHQOtN40ewVWCSKvICr5Xj/je', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:28:42', '2024-07-10 19:28:42', NULL);
INSERT INTO `users` VALUES ('94', 'Bansi', 'Musah', NULL, '2023-2401044', '$2y$10$.1JPu.puAf6DoUiBdpfKMO1WT/Gd19rb8bxe2g9sM6cxIVPSD.CUm', 'male', '1/1/1/1/1/1/user/668eafb2a23b23.824996121720627122.jpg', '2010-09-17', 'Mamobi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:28:42', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('95', 'Botchway', 'Arthur', '0244000700', 'fixidguard7@gmail.com', '$2y$10$uB50h.Krfzox3PumoPOPC.yqYUYzuOop0DHMD3FT9xQ9jsJkrPic2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:30:37', '2024-07-10 19:30:37', NULL);
INSERT INTO `users` VALUES ('96', 'Botchway', 'Rolland', NULL, '2023-2401045', '$2y$10$YWfC87Gq7JQhRPLrqnK9JO1qnnv7eueLMcMHV6u.KN.owLUprjetu', 'male', '1/1/1/1/1/1/user/668eb025c03426.873007861720627237.jpg', '2010-11-23', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:30:37', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('97', 'Mohammed', 'Iddisa', '024577241', 'fixidguard8@gmail.com', '$2y$10$/4AG2RPLxXgFzdt/KaoiX.8vM54YvV5FThHyp1wRurypp1Y1zY1g6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:32:36', '2024-07-10 19:32:36', NULL);
INSERT INTO `users` VALUES ('98', 'Mohammed', 'Yussif', NULL, '2023-2401046', '$2y$10$s5Zam1NVGKDGZomhXUrQuuBVBX4ud09PauYHyAay4QQjXbxho.axy', 'male', '1/1/1/1/1/1/user/668eb09ce21d99.905171701720627356.jpg', '2010-05-15', 'Nima', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:32:36', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('99', 'Obodai', 'Lamptey', '0203006544', 'fixidguard9@gmail.com', '$2y$10$uf0ygqwcxiQa0/g/2ywEoO49gdFUmBB8R58zssd2./V9ik3xjPU5y', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:34:37', '2024-07-10 19:34:37', NULL);
INSERT INTO `users` VALUES ('100', 'Ruth', 'Lamtey', NULL, '2023-2401047', '$2y$10$fLikxuevqYOwwuipUyNkcOFmmTCq32W6awELKbXTNzM5.v0qBvohi', 'female', '1/1/1/1/1/1/user/668eb115777d19.810908221720627477.jpg', '2010-05-14', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:34:37', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('101', 'Oduro', 'Evans', '0549542292', 'fixidguard10@gmail.com', '$2y$10$77jKcgFhak0H8X7UvWTmJeGOh2/iCOF2A11PvtbMz9C3VlQaD8Dxq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:37:02', '2024-07-10 19:37:02', NULL);
INSERT INTO `users` VALUES ('102', 'Oduro', 'Sammuel', NULL, '2023-2401048', '$2y$10$w7LmSJlcCMk3APgsuv0Sf.SJt6LBANf0gPPbmRxmwRZRNz.rXe6a2', 'male', '1/1/1/1/1/1/user/668eb1a7155c97.011032021720627623.jpg', '2010-11-10', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:37:03', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('103', 'Rahman', 'Yussif', '0244055311', 'fixidguard11@gmail.com', '$2y$10$hrP2IAEof8JaTfNv4/uod.XjZFkRtPQwjte.p8SmA42ud.OBeoyce', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:39:21', '2024-10-24 19:54:17', NULL);
INSERT INTO `users` VALUES ('104', 'Zenabu', 'Naziru', NULL, '2023-2401049', '$2y$10$JR1xF8iw/6.RVHisIPKmneG.k1QFbWcNufFIDCr/o4I49nB9PdjDe', 'female', '1/1/1/1/1/1/user/668eb2315104c1.982152331720627761.jpg', '2010-01-30', 'Nima', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:39:21', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('105', 'Safuratu', 'Yussif', NULL, '2023-2401050', '$2y$10$D2/lINA4MOlV.JVP0tuuBuOyLPw9RTdyr/KLCaxVDljjmXXDm.agC', 'female', '1/1/1/1/1/1/user/668eb496c01717.798674401720628374.jpg', '2010-07-25', 'Mamobi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:49:34', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('106', 'Dewortor', 'Mawuli', '024569002', 'fixidguard12@gmail.com', '$2y$10$rDlJWtJyD7Tli7gyBBQrheNGo7TktTVKsIM01J6UG8HMqYOGfEseC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:53:11', '2024-07-10 19:53:11', NULL);
INSERT INTO `users` VALUES ('107', 'Dewortor', 'Felicia', NULL, '2023-2401051', '$2y$10$dRpCuGRPOFNq71p/F8h5S.oz9NYo4WiNtl2vVLwmfLWRzuAyTZRMi', 'female', '1/1/1/1/1/1/user/668eb56f31ee87.886650991720628591.jpg', '2010-06-16', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:53:11', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('108', 'Achiamaa', 'Amponsah', '055033217', 'fixidguard13@gmail.com', '$2y$10$3rrwqQZq2IQgfkMVOL8Zl.csel3vKReTldzG/Ql7iwfZOsS28Xz/K', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:55:26', '2024-07-10 19:55:26', NULL);
INSERT INTO `users` VALUES ('109', 'Achiamaa', 'Shiella', NULL, '2023-2401052', '$2y$10$wGq0rAZCbfvaHPpa/OLhQOs5eR34U4WW3LtBpmeXyz2a96WYs8gV2', 'female', '1/1/1/1/1/1/user/668eb5f61caaa2.715266771720628726.jpg', '2010-04-23', 'Cantonment', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:55:26', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('110', 'Michael', 'Acheampong', '0206012999', 'fixidguard14@gmail.com', '$2y$10$.BOoxZkHy.IvdZ3tiSFkpePbk7iOi3k7gIfHlDtAyA9l5L0VwBVL6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:57:51', '2024-07-10 19:57:51', NULL);
INSERT INTO `users` VALUES ('111', 'Micheal', 'Brenya', NULL, '2023-2401053', '$2y$10$RgVhripYwdf.dID9.yudHuyVg.rZjqjw13gDWW0Q1VKOD7/zj/A.W', 'male', '1/1/1/1/1/1/user/668eb6879428f6.898091051720628871.jpg', '2010-05-11', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:57:51', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('112', 'Efful', 'Kumah', '0244002322', 'fixidguard15@gmail.com', '$2y$10$eRxieNG/9ptPIl95Z65Nu.mumbNGqCP8Kn93NkXZu.tAUnc9.YfxS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:59:53', '2024-07-10 19:59:53', NULL);
INSERT INTO `users` VALUES ('113', 'Ekumah', 'Diana', NULL, '2023-2401054', '$2y$10$jDadVLIc3bKhHbVn0YWAG.LytLCzKNoN/KNYy4oTOdQunp0sINN/u', 'female', '1/1/1/1/1/1/user/668eb7014fc059.839516831720628993.jpg', '2010-06-18', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 19:59:53', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('114', 'Arthur', 'Issac', '0244500202', 'fixidguard16@gmail.com', '$2y$10$z8jUcTTzc.EQ8A36Nwe.Q.0VtWXDcvbpSy15x1nWKJP81ExW16amy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:02:20', '2024-07-10 20:02:20', NULL);
INSERT INTO `users` VALUES ('115', 'Princess', 'Awoye', NULL, '2023-2401055', '$2y$10$o.Io1s7HgbxSQy.XSPZMoOUcRzTliWOLnMq936WsnpZYgoVPiOxb.', 'female', '1/1/1/1/1/1/user/668eb7946efbc4.630735861720629140.jpg', '2010-03-14', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:02:20', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('116', 'Emmanuel', 'Afari', '0550442021', 'fixidguard17@gmail.com', '$2y$10$XEIp3E1v.0EaGv0la5lYzOVGKsVbQSbzpeJMr16TzOJia6yrMo3ui', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:04:17', '2024-07-10 20:04:17', NULL);
INSERT INTO `users` VALUES ('117', 'Emmanuel', 'Appiah', NULL, '2023-2401056', '$2y$10$VvWYYmEVsWpyqqWEG6TlP.5PXuxI0vs2SRYH4Ej0xnadL8WzbFLdC', 'male', '1/1/1/1/1/1/user/668eb8097767d2.563889011720629257.jpg', '2010-02-19', 'Nima', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:04:17', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('118', 'Yussif', 'Ibrahim', '0260662004', 'fixidguard18@gmail.com', '$2y$10$O/Wcbb6ReWTWXyIblhRnpOPeOeo9gBujXxBIpzS6p0.KkCj1Lteoq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:06:12', '2024-07-10 20:06:12', NULL);
INSERT INTO `users` VALUES ('119', 'Lattif', 'Yussif', NULL, '2023-2401057', '$2y$10$QTu2MVjr1ieB2dCS5mzPXurn9hrFdbsh4tz/HkZ2IKjAfqb.71X1i', 'male', '1/1/1/1/1/1/user/668eb87cbe3a96.172888611720629372.jpg', '2010-02-27', 'Nima', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:06:12', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('120', 'Ofosu', 'Richard', '0553003230', 'fixidguard19@gmail.com', '$2y$10$aiY4gJ4K0lrhsKCQNePKmu6nwuzevnnDmrGuM5if10Nd7vLjxOPGW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:08:02', '2024-07-10 20:08:02', NULL);
INSERT INTO `users` VALUES ('121', 'Ofosu', 'Enock', NULL, '2023-2401058', '$2y$10$9UN8JewA255tga1tUpqrnuy4swE0zLJnqyNGXSg/jzcrPFDP.HtzS', 'male', '1/1/1/1/1/1/user/668eb8eaa49878.101112281720629482.jpg', '2010-04-01', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:08:02', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('122', 'Theophilus', 'Prosper', '0244000399', 'fixidguard20@gmail.com', '$2y$10$CxcvlqZ80uy/8WEGbWHpiOL1DOlTS6Wh0QqaoDxhMxPj5DqmYkA4K', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:10:05', '2024-07-10 20:10:05', NULL);
INSERT INTO `users` VALUES ('123', 'Theophilus', 'Kwaning', NULL, '2023-2401059', '$2y$10$V/ri7.U.JNqGuBEm0IeZ5eLeljcF/N/p5rmZGUkEtyz1YoySFj.Sa', 'male', '1/1/1/1/1/1/user/668eb965efc304.046499051720629605.jpg', '2010-05-06', 'Cantonment', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:10:05', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('124', 'Sumaru', 'Mustapha', '0249022432', 'fixidguard21@gmail.com', '$2y$10$8sCI5byedG3CViWLh8Gov.Sl0/ruBkS825jlu6pBk40EUOLML.iEy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:14:55', '2024-07-10 20:14:55', NULL);
INSERT INTO `users` VALUES ('125', 'Sumaru', 'Kamal', NULL, '2023-2401060', '$2y$10$eUcVqT.gwyR1QuGgBeXqc.LIfG/AgFtsMxCHO72bB0Dba5q8oT7.K', 'male', '1/1/1/1/1/1/user/668eba873b3e91.633034461720629895.jpg', '2010-06-28', 'Nima', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:14:55', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('126', 'Amankrah', 'Boamah', '0243336008', 'fixidguard22@gmail.com', '$2y$10$V8dRZDFxRU3Ih5qqUE6S9.lbRL/ogBh8QRWOeZYHelcJHk57BYa0G', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:17:16', '2024-07-10 20:17:16', NULL);
INSERT INTO `users` VALUES ('127', 'Amankrah', 'Samuel', NULL, '2023-2401061', '$2y$10$9NalOZU2fCtQcwj5.nkCh.zucsc5CXpBXLSJHT3HXNgGTTnENLAQS', 'male', '1/1/1/1/1/1/user/668ebb150e0b85.448660581720630037.jpg', '2010-09-17', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:17:17', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('128', 'Solomon', 'Okai', '0245599954', 'fixidguard23@gmail.com', '$2y$10$fHuwrAeRB8rJkIOSEDpFh.iy0Wt5ZoEQMxvrJo2bV1S57Vloleefu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:19:03', '2024-07-10 20:19:03', NULL);
INSERT INTO `users` VALUES ('129', 'Okai', 'Samuel', NULL, '2023-2401062', '$2y$10$biVYs7OegJ3LCyooO11R3et/6lEQ195xkIxjGssyPOQb..UlqPRYC', 'male', '1/1/1/1/1/1/user/668ebb800ebfb6.934773041720630144.jpg', '2010-12-24', 'Cantonment', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:19:04', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('130', 'Glegg', 'Rowland', '0550336110', 'fixidguard24@gmail.com', '$2y$10$zymU2XX/xq7cE/eDEZsqT.Y6uYGApSzOWWU2CSTylKha7SP7K78zu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:21:13', '2024-07-10 20:21:13', NULL);
INSERT INTO `users` VALUES ('131', 'Portia', 'Glegg', NULL, '2023-2401063', '$2y$10$Gc3rrAbI4MKKABe3g1ABB.eZ0gyYlwxKPmxh6ClpBs4pGU85T6/WG', 'female', '1/1/1/1/1/1/user/668ebc0152b088.553226931720630273.jpg', '2010-10-26', 'Cantonment', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:21:13', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('132', 'Dankwah', 'Samuel', '0267734599', 'fixidguard25@gmail.com', '$2y$10$cotuXsui3FxD76AM8tJhDOKDEF2dfAEapVyJB0TIy8TjqeCYYN9zu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:23:29', '2024-07-10 20:23:29', NULL);
INSERT INTO `users` VALUES ('133', 'Dankwah', 'Albert', NULL, '2023-2401064', '$2y$10$wQLLvQnRsh01BlkU1NCh2eT7nWZcj3948iVvmaZQki/OZCjfLqLye', 'male', '1/1/1/1/1/1/user/668ebc89794263.353300051720630409.jpg', '2010-07-31', 'Circle', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:23:29', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('134', 'Paul', 'Michael', '0559867233', 'fixidguard26@gmail.com', '$2y$10$6JP0hHRtqgomGW8HQZyniOE1JXD/z4BGX1wrm3pAD0abMoZQzblkC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:26:18', '2024-07-10 20:26:18', NULL);
INSERT INTO `users` VALUES ('135', 'Paul', 'Hama', NULL, '2023-2401065', '$2y$10$HwpZ/j9YPE.MlNRDCZVIHenQXuMGsFlLFLicGhntPInk1UFeARzy6', 'male', '1/1/1/1/1/1/user/668ebd3268b345.595967871720630578.jpg', '2010-02-28', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:26:18', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('136', 'Duah', 'Gyamfi', '020229912', 'fixidguard27@gmail.com', '$2y$10$hRuZGUhDaZ8/OHCrKc4A6uhtp37vG2mvsn82UyFAK1FXeXtuMokTa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:28:22', '2024-07-10 20:28:22', NULL);
INSERT INTO `users` VALUES ('137', 'Adolf', 'Gyamfi', NULL, '2023-2401066', '$2y$10$VkzYS1cbIRwBnEVVPPXlBOC8XtfHri.tSOF6lTBKY7zzN/c9pLsSK', 'male', '1/1/1/1/1/1/user/668ebdae174df0.872603601720630702.jpg', '2010-11-14', 'Circle', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:28:22', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('138', 'Rauf', 'Fuseini', '024400989', 'fixidguard28@gmail.com', '$2y$10$q8fVkMVYRe5ardyiVc6Auu1CPTUAuuG6tJ/byqXt.SptXdgVs6nF2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:30:22', '2024-07-10 20:30:22', NULL);
INSERT INTO `users` VALUES ('139', 'Ikmatu', 'Fusana', NULL, '2023-2401067', '$2y$10$jPs7ayKU2n1T5m3If4wukuTkiOt.V0YCHexrhOP5ZGL5hCyIHrXYC', 'female', '1/1/1/1/1/1/user/668ebe2689e4e8.638497531720630822.jpg', '2010-11-21', 'Nima', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:30:22', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('140', 'Clement', 'Maxwell', '0544877202', 'fixidguard29@gmail.com', '$2y$10$iWkJfy2YOOJnQ.WgVxn3Jeeb//4.BkIW48Ras.crQjnJFYwBNR9VG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:32:28', '2024-07-10 20:32:28', NULL);
INSERT INTO `users` VALUES ('141', 'Clement', 'Musah', NULL, '2023-2401068', '$2y$10$lRMhvQghbAnGli4IFXsmIejyUVOxjevLnCJfnZ9ie4TjIdB5LvMtu', 'male', '1/1/1/1/1/1/user/668ebea47f03e6.092616991720630948.jpg', '2010-12-17', 'Cantonment', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:32:28', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('142', 'Crentsil', 'Emmanuel', '0244731414', 'fixidguard30@gmail.com', '$2y$10$0KyITB646JdHf17DX2CcfeZR0OgRqLbBBWLtBqIu1dPb0tym.nOiG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:34:39', '2024-07-10 20:34:39', NULL);
INSERT INTO `users` VALUES ('143', 'Crentsil', 'Doris', NULL, '2023-2401069', '$2y$10$vacbGzYcHNRHBKr4X.Kyr.NftWiJfSI1VxlmEievgOq0cSRv4j33y', 'female', '1/1/1/1/1/1/user/668ebf279e87c2.264801951720631079.jpg', '2010-09-07', 'Kaneshie', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-10 20:34:39', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('144', 'Christian', 'Maxwell', '0244000300', 'stephfixid@gmail.com', '$2y$10$mQSod7BKWTPG1IxlJPGLZeYWIUhxchVcZ1YTJADjE.SL/ehLfJstO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:09:28', '2024-07-11 15:09:28', NULL);
INSERT INTO `users` VALUES ('145', 'Asieduwaa', 'Stephanie', NULL, '2023-2401070', '$2y$10$RsG65A3uGfOt/NbR3PYlnOYIsbZeboOpW5Qw2vHPK6yU3X0iUGfZm', 'female', '1/1/1/1/1/1/user/668fc4709b3fe9.248963741720697968.jpg', '2010-11-21', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:09:28', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('146', 'Benson', 'Pokuwaa', '0201003220', 'dictablefixid@gmail.com', '$2y$10$6tzK2rGc0jWOyZ0CPaAYyOjC7LbOAHGCBlzcgaADoBg4jCz1vc2fW', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:11:58', '2024-07-11 15:11:58', NULL);
INSERT INTO `users` VALUES ('147', 'Pokuwaa', 'Benedicta', NULL, '2023-2401071', '$2y$10$J2k9NL0HBgq7LafIofGDOudgWnQL0sPH9oGGZBVMiX/QbWnTJg.M.', 'female', '1/1/1/1/1/1/user/668fc506c7c3a0.918707411720698118.jpg', '2010-03-17', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:11:58', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('148', 'Ibrahim', 'Kassim', '0244300099', 'kassimfixid@gmail.com', '$2y$10$7EF/vp25dNGvNkIxC7YjReBY6fbvnxGYCWP3drpsnGBH3NCeb17NW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:14:10', '2024-07-11 15:14:10', NULL);
INSERT INTO `users` VALUES ('149', 'Kasim', 'Faridatu', NULL, '2023-2401072', '$2y$10$64VzNPUi.cgnj7LlHNnkkOmIGEwpUw9yVyignlJkgLY0Fdd9jE7K6', 'female', '1/1/1/1/1/1/user/668fc58a238b10.587296681720698250.jpg', '2010-08-23', 'Madina', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:14:10', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('150', 'Seidu', 'Inusah', '054421120', 'inusahfixid@gmail.com', '$2y$10$EnDUjZtFD49WIDxoZAaMNeDJhOZblKrSes12tAdu5yUWLfsjCJ296', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:16:03', '2024-07-11 15:16:03', NULL);
INSERT INTO `users` VALUES ('151', 'Inusah', 'Ibrahim', NULL, '2023-2401073', '$2y$10$am1GYzVuTWU73uAIRipenOp0X6chcmssYgqNIq0kHurJkgsgJJ0Py', 'male', '1/1/1/1/1/1/user/668fc5fb9b4dd9.472781551720698363.jpg', '2010-11-10', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:16:03', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('152', 'Isaiah', 'Lucky', '0544822888', 'luckyfixid@gmail.com', '$2y$10$StgXL.kGjr4RLh1FWwReHOYQBY0v2SO1i5oHDV.on36Ta.cAfAz1q', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:19:36', '2024-07-11 15:19:36', NULL);
INSERT INTO `users` VALUES ('153', 'Oppong', 'Lucky', NULL, '2023-2401074', '$2y$10$jjaX4poVBqioXfaOqIuQeONLdso8XCH8EjgnjkFp/wFtKLTmEK.Ba', 'male', '1/1/1/1/1/1/user/668fc6d0d056a1.829713371720698576.jpg', '2010-04-25', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:19:36', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('154', 'Stephanie', 'Wilson', '054553000', 'netteyfixid@gmail.com', '$2y$10$kCV5fq7B8yLy4rzvPKYrre0eqzH.fgk21L5bjUqTrn8nFRmlYH1jy', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:23:36', '2024-07-11 15:23:36', NULL);
INSERT INTO `users` VALUES ('155', 'Nettey', 'Abigail', NULL, '2023-2401075', '$2y$10$ZRGIBNOJvAsPaSt/I6C5.eXTpeYMCYACpyav6HTga9u/rMp5ChZGi', 'female', '1/1/1/1/1/1/user/668fc7c04e2680.482184581720698816.jpg', '2010-01-26', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:23:36', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('156', 'Gyamfi', 'Victor', '0260274004', 'adulffixid@gmail.com', '$2y$10$4gsmKr/7qjEpRxIgd6BdJ.F4l0EHLAWBnsZNTBe004EmEwwy95kcO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:28:58', '2024-07-11 15:28:58', NULL);
INSERT INTO `users` VALUES ('157', 'Adolf', 'Gyamfi', NULL, '2023-2401076', '$2y$10$k7bVcwiGWil08m43AfNnnuSAN5mgeRdLUSEuvXtUhtUzvEoX4sw6m', 'male', '1/1/1/1/1/1/user/668fc902b84957.496806871720699138.jpg', '2010-12-08', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:28:58', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('158', 'Rawlings', 'Caleb', '024002002', 'calebfixid@gmail.com', '$2y$10$aKHMETWKoiF/goKocWpm/ONP.ffUDtNYlU9qWBjVNc9EKazzxnEku', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:31:33', '2024-07-11 15:31:33', NULL);
INSERT INTO `users` VALUES ('159', 'Emmanuel', 'Konadu', NULL, '2023-2401077', '$2y$10$kIUy6lOByxLRtezLteqlE.4/XqCd7KzoTKeX8CbKX/IHhv7ucEmja', 'female', '1/1/1/1/1/1/user/668fc99e062572.171378831720699294.jpg', '2010-02-17', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:31:34', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('160', 'Bright', 'Nyarko', '024412389', 'nyarkofixid@gmail.com', '$2y$10$JYZmpFcuhJDjSEFAEpAan.tdkPycRcE1rSAYsGfWFLseHtdGr4xra', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:35:49', '2024-07-11 15:35:49', NULL);
INSERT INTO `users` VALUES ('161', 'Nyarko', 'Ernestina', NULL, '2023-2401078', '$2y$10$d7PdreCWkbZPMuzDhy21tufgi6i8o1qK6qOw7X/TuENDqVenfKUTe', 'female', '1/1/1/1/1/1/user/668fca9d76ced4.360689841720699549.jpg', '2010-07-30', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:35:49', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('162', 'Asante', 'Rowland', '0271007645', 'mrasanetefixid@gmail.com', '$2y$10$37hcGtS/tncNxVyNFrBV.eCNT5ZmSL0f3OnT9ESCs/c7AF85QhYfi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:39:19', '2024-07-11 15:39:19', NULL);
INSERT INTO `users` VALUES ('163', 'Solomon', 'Asante', NULL, '2023-2401079', '$2y$10$XSgotiiwJ3bKTOj2.708R.PEB.dSktUYJp./fSC.9ZEHtR0PHQ5Li', 'male', '1/1/1/1/1/1/user/668fcb6ff035a2.102841551720699759.jpg', '2010-03-28', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:39:19', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('164', 'Isaac', 'Botchway', '0555678921', 'isaacfixid@gmail.com', '$2y$10$hX3k7wLNSMwJkixcdlwlVe2FJqbNKAyXE1k2UiJ/Su98IEv7MnytG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:42:19', '2024-07-11 15:42:19', NULL);
INSERT INTO `users` VALUES ('165', 'Martey', 'Botchway', NULL, '2023-2401080', '$2y$10$y0KOTPpG6JOjK7Q6gtEXUuz.80Om/ZQnkjazRwtfyZpxWubyuq98e', 'male', '1/1/1/1/1/1/user/668fcc23ad9f46.424208861720699939.jpg', '2010-01-22', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:42:19', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('166', 'Samuel', 'Bio', '0243000000', 'biofixid@gmail.com', '$2y$10$0HSvfkxUix7L7atN./0R5u.I9oCMIDpgsuYWMY2Z4g1KdRxer7zm.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:55:42', '2024-07-11 15:55:42', NULL);
INSERT INTO `users` VALUES ('167', 'Bio', 'Benedicta', NULL, '2023-2401081', '$2y$10$gLlVjQOO.J0Yl/r0nRs43u040BiXfvm9WGOq7yTEiLbT7lGOtvP9.', 'female', '1/1/1/1/1/1/user/668fcf4651d8d4.089050761720700742.jpg', '2010-09-21', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:55:42', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('168', 'Amissah', 'Amoah', '0244300000', 'amissahfixid@gmail.com', '$2y$10$iDN1yR0e2apiZij9ZdtDyufPIJ1epFnB4W/8KF2bBxnErZfOz1Q5.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:57:54', '2024-07-11 15:57:54', NULL);
INSERT INTO `users` VALUES ('169', 'Addae', 'Nathaniel', NULL, '2023-2401082', '$2y$10$KmWQmXWkzu1hCW9f.VamPuJwEj/Q8RHBR9w/ukWEpuYWSt/IqU3eq', 'male', '1/1/1/1/1/1/user/668fcfca5d0610.000523581720700874.jpg', '2010-12-27', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 15:57:54', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('170', 'Victory', 'Mawume', '0244433000', 'victoryfixid@gmail.com', '$2y$10$ldxA238KnPG3/dpXPcGjjOnc2ddNCfZR5FOQlip.5BAOqUqnDn6IG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:00:02', '2024-07-11 16:00:02', NULL);
INSERT INTO `users` VALUES ('171', 'Mawume', 'Comfort', NULL, '2023-2401083', '$2y$10$Lwi/2E64zegzjsH/Uzlbzu51V.K7QFvL/YnwC/YN10jOTnqZnPzOG', 'female', '1/1/1/1/1/1/user/668fd04a69ce43.260006981720701002.jpg', '2010-03-23', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:00:02', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('172', 'Acheampong', 'Addo', '0244304000', 'acheafixid@gmail.com', '$2y$10$cTQ8o.ib5xVEYO5OJ3DM7.smTM.b5ao9Kn8EPiOXko1ou0MokwmdK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:02:06', '2024-07-11 16:02:06', NULL);
INSERT INTO `users` VALUES ('173', 'Addo', 'Rita', NULL, '2023-2401084', '$2y$10$uYtRDcPUE51fzzXcye2XgusVLw5/3pcpwywhJ/63.3uBXeAU3yHpW', 'female', '1/1/1/1/1/1/user/668fd0c634e341.798216341720701126.jpg', '2001-01-31', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:02:06', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('174', 'Walker', 'Nyarko', '0243009110', 'maclinafixid@gmail.com', '$2y$10$cc/0njRuibFVhfDsYIqzhO3RL48jmegwGX2od3EutLKSqtONpJyU6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:05:01', '2024-07-11 16:05:01', NULL);
INSERT INTO `users` VALUES ('175', 'Nyarko', 'Maclina', NULL, '2023-2401085', '$2y$10$9ptkOkCdQjOuf26gQNCdNu3KrLPSlv277r9Xvs2USh9IvHQMkF1tS', 'female', '1/1/1/1/1/1/user/668fd175144623.961870761720701301.jpg', '2010-12-16', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:05:01', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('176', 'Prosper', 'Gidisu', '0544711980', 'prosperfixid@gmail.com', '$2y$10$HZsp/EcV1CKHF9JWoZ8baO.nQMtx0IuVtDUibBCnQL8li4s.YNOGe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:07:07', '2024-07-11 16:07:07', NULL);
INSERT INTO `users` VALUES ('177', 'Gidisu', 'Getrude', NULL, '2023-2401086', '$2y$10$mpW5YR0z.leQAQcSqX3IPudhbDVa79dz0nUCeyTHfjmxztVEKT25K', 'female', '1/1/1/1/1/1/user/668fd1f3baf005.055349451720701427.jpg', '2010-04-09', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:07:07', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('178', 'Salisu', 'Mohammed', '0548999999', 'salisufixid@gmail.com', '$2y$10$M15Eze7S89rULr8wx7OqrumIw54ZLsh.jRNYtLLHgbcdq6WBGHCOa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:09:25', '2024-07-11 16:09:25', NULL);
INSERT INTO `users` VALUES ('179', 'Mohammed', 'Tafa', NULL, '2023-2401087', '$2y$10$73exFlwXaHG/EIFqJmuJhO9SFzC98dy1dODuYXS90QvLhAM1Kr7fS', 'female', '1/1/1/1/1/1/user/668fd27d6b7474.525783661720701565.jpg', '2010-03-14', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:09:25', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('180', 'Daniel', 'Amartey', '0243300098', 'amarteyfixid@gmail.com', '$2y$10$vLK3pafIql4khMiq0ytzveLyQtOU5c4kBVu7ynCQBjAd5D/CTt0KC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:11:20', '2024-07-11 16:11:20', NULL);
INSERT INTO `users` VALUES ('181', 'Addae', 'Daniel', NULL, '2023-2401088', '$2y$10$55IAgsV3jIZiQzSFSlhsXeekE6WHG5mx/Y9Mj9/Mt9SIEVqL0z9JC', 'male', '1/1/1/1/1/1/user/668fd2f0195968.353710241720701680.jpg', '2010-04-27', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:11:20', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('182', 'Asamoah', 'Gyan', '0240006980', 'asamoahfixid@gmail.com', '$2y$10$ntg/51WXHGCAJHd.we3Ude9tfvcXvW/YjNac5SOSu4o2dVuVS1IFu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:13:19', '2024-10-24 19:54:17', NULL);
INSERT INTO `users` VALUES ('183', 'Winefred', 'Gyan', NULL, '2023-2401089', '$2y$10$.K7m3B5ydXjgEVR0e2sCyuQT85f5MJCq0we/78uTdZIKm5f0b8CGi', 'male', '1/1/1/1/1/1/user/668fd3680bf5b8.821479101720701800.jpg', '2010-02-28', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:13:20', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('184', 'Benedicta', 'Gyan', NULL, '2023-2401090', '$2y$10$X.ZXVVRn8wZGVXuvqyGSGezrOZpIicMrt8P9Iq3p/u63YWc9cCFyC', 'female', '1/1/1/1/1/1/user/668fd3dd034661.435916521720701917.jpg', '2010-02-28', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:15:17', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('185', 'Appiah', 'Atieku', '0245590033', 'appiahfixid@gmail.com', '$2y$10$F5t/C7ZJ5VaMN4CvEv7Bmu90TrcR1pqYPvIyHECmUkRwXcSPNCKNC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:17:11', '2024-07-11 16:17:11', NULL);
INSERT INTO `users` VALUES ('186', 'Atieku', 'Maxwell', NULL, '2023-2401091', '$2y$10$ucWzS0xfYKiChKAr9r0wlOoU086B0c7qFzw8wucpEzV6v1uzI4VpW', 'male', '1/1/1/1/1/1/user/668fd44f5a8b74.215564001720702031.jpg', '2010-02-20', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:17:11', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('187', 'Agyemang', 'Emmanuel', '0200311200', 'kunadufixid@gmail.com', '$2y$10$g7zG3K1rJlHZlrKQBJweyeYx66YQxO.w.Ca7tk/4H2FRvnJfwnW.m', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:19:50', '2024-07-11 16:19:50', NULL);
INSERT INTO `users` VALUES ('188', 'Konadu', 'Bernice', NULL, '2023-2401092', '$2y$10$AsUAtlSH22K0D35pYbqn7etrchqrxY/gK0lKRD8.VayARQ3LGHGUi', 'female', '1/1/1/1/1/1/user/668fd4ee482f87.043833001720702190.jpg', '2010-08-11', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:19:50', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('189', 'Benedict', 'Yeboah', '024403003', 'ben10fixid@gmail.com', '$2y$10$pRy2UjcM8ASSefdq.CSjOufjyFwt1yGhnt0TNsctyEQdy91Kjk8k2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:23:51', '2024-07-11 16:23:51', NULL);
INSERT INTO `users` VALUES ('190', 'Yeboah', 'Isaac', NULL, '2023-2401093', '$2y$10$xF6eq4pJImJqxv3wC6liv.br7nOl3V4QtnpjnwMvljgXuuIua6I2O', 'male', '1/1/1/1/1/1/user/668fd5e0018633.269221381720702432.jpg', '2010-07-14', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:23:52', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('191', 'William', 'Emmanuel', '0244202022', 'williamfixid@gmail.com', '$2y$10$NPYsUi7nYe3vMKFGM44.dO5zo4rxHjvel6TofogiBi/VxoKq3LAPa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:25:46', '2024-07-11 16:25:46', NULL);
INSERT INTO `users` VALUES ('192', 'Asante', 'Emmanuel', NULL, '2023-2401094', '$2y$10$NQ4hogaemInz1MIUTTU/QOBBDhcgYP2p9KsAUJ.S.a9599ei7mAAW', 'male', '1/1/1/1/1/1/user/668fd652daeba5.840764771720702546.jpg', '2010-09-19', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:25:46', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('193', 'Ferdinand', 'Addo', '056674434', 'ferdinandfixid@gmail.com', '$2y$10$x/ATkcWypOeWDlU3ShJIje6.tFaLQiV1BjoKHREOcm/F/Gy0SQrRW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:28:31', '2024-07-11 16:28:31', NULL);
INSERT INTO `users` VALUES ('194', 'Addo', 'Sarfowaa', NULL, '2023-2401095', '$2y$10$qcluEijHed019c850GrsteWp7BLgukq30m6aCtH2NXc6KNPVbPEP2', 'female', '1/1/1/1/1/1/user/668fd6f7da0767.610512811720702711.jpg', '2010-01-10', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:28:31', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('195', 'Elisha', 'Dzenu', '0200200101', 'elishafixid@gmail.com', '$2y$10$sHhkoUkIayACW2vBOuYmgua1KZ2fmTp55boELk7FPu8q6isaLXJUa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:31:25', '2024-07-11 16:31:25', NULL);
INSERT INTO `users` VALUES ('196', 'Dzenu', 'James', NULL, '2023-2401096', '$2y$10$d0mE7SLpveMBYhOQSaTaluevgV1.5YoZu0PWQsvEsxoUIbf3R4CQS', 'male', '1/1/1/1/1/1/user/668fd7a6141ad2.102168281720702886.jpg', '2010-12-06', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:31:26', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('197', 'Illiasu', 'Abdulhayu', '020300400', 'illiasufixid@gmail.com', '$2y$10$tLS/U4NHFWVL.uPlJy2l0eSmepDGgtDMCgiVkt5fCmvSvO3tvPDgK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:33:36', '2024-07-11 16:33:36', NULL);
INSERT INTO `users` VALUES ('198', 'Abdulhayu', 'Samad', NULL, '2023-2401097', '$2y$10$C3b7fIyS1i1ifH2W8JLh.e0jtnaWzdbZPtFq0VR.hFsnmb2.fTIKO', 'male', '1/1/1/1/1/1/user/668fd828e59084.844997721720703016.jpg', '2010-08-18', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:33:37', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('199', 'Oppong', 'Isaac', '024400302', 'oppongfixid@gmail.com', '$2y$10$jPLllser6A6gjxIW6AVHpOtrsROJ62SolLLUr6UETfReHT3p1txs.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:35:27', '2024-07-11 16:35:27', NULL);
INSERT INTO `users` VALUES ('200', 'Oteng', 'Isaac', NULL, '2023-2401098', '$2y$10$vxn655U//4vW5S64toGOberCVod1sGUuQgZtYsI/UykIn0E2oQBwO', 'male', '1/1/1/1/1/1/user/668fd897243318.633158801720703127.jpg', '2010-01-05', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:35:27', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('201', 'Francis', 'Okran', '0244490032', 'francisfixid@gmail.com', '$2y$10$o.aWFJJBN1nQB6qd9EuSKO84Ettfi96Bv4qe3WakxmtVhrn2TTZka', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:37:18', '2024-07-11 16:37:18', NULL);
INSERT INTO `users` VALUES ('202', 'Micheal', 'Okran', NULL, '2023-2401099', '$2y$10$Fa6r0XfSBxH26JWDqOAwMuxHGUBnp.CA9HGVVpfQP7Fd.DeBNnqPC', 'male', '1/1/1/1/1/1/user/668fd9067cfe57.436861881720703238.jpg', '2010-03-03', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:37:18', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('203', 'Ernest', 'Ampah', '0243000033', 'ernestfixid@gmail.com', '$2y$10$qREc8fzil1QfiB3JujhzB.lwat/./zfUs1QZs3d3ys6exg70GMls2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:39:07', '2024-07-11 16:39:07', NULL);
INSERT INTO `users` VALUES ('204', 'Akosua', 'Ampah', NULL, '2023-24010100', '$2y$10$VM0Vdj4rT5hjigoZs.G7WeIlXVmKViUj.BwZwNPh3xm5cNWcak66S', 'female', '1/1/1/1/1/1/user/668fd973d1d835.040210551720703347.jpg', '2010-01-20', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:39:07', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('205', 'Justin', 'Asaah', '0244823477', 'jessicafixid@gmail.com', '$2y$10$YgCyFH9UIPk6QDU1q1rIBeI0.TtL9Az9dWNL2NuaBN1TwlcHDXQea', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:47:42', '2024-07-11 16:47:42', NULL);
INSERT INTO `users` VALUES ('206', 'Asaah', 'Jessica', NULL, '2023-24010101', '$2y$10$bDaXLtJQ5mm28wuq6ylbD.mI8neS4GlNhgdDbies5NPVDMm7c.HD2', 'female', '1/1/1/1/1/1/user/668fdb76934e54.086205731720703862.jpg', '2010-01-01', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:47:42', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('207', 'Isaac', 'Yeboah', '0243000000', 'mefimiahfixid@gmail.com', '$2y$10$rPqN3t9o7QH75pfZRoggcOIbCp3Y5fIpPgZN64trOurxeSgJXYeoW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:54:25', '2024-07-11 16:54:25', NULL);
INSERT INTO `users` VALUES ('208', 'Yeboah', 'Mefimiah', NULL, '2023-24010102', '$2y$10$8x7HP8RWUyMIBVflTv2qhu/U/GW/y.3GywOLXi26uiWcw/6jNybgC', 'male', '1/1/1/1/1/1/user/668fdd0983d4b4.099697881720704265.jpg', '2010-01-13', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:54:25', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('209', 'Kufoour', 'Aidoo', '0243000000', 'kuffourfixid@gmail.com', '$2y$10$2G1iFMRxmGv/oEDiDMvFB.kw/rVBbJo0j7wRTUEQsPdlXO24epYnW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:56:10', '2024-07-11 16:56:10', NULL);
INSERT INTO `users` VALUES ('210', 'Aidoo', 'Selina', NULL, '2023-24010103', '$2y$10$MXb9DsNvonixHVjKY2xgRuQOJulwu009j3aDmXIn4FT1ilNn9Fv.W', 'female', '1/1/1/1/1/1/user/668fdd72b55061.940282601720704370.jpg', '2010-02-03', 'Adenta', 'Accra', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:56:10', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('211', 'Larry', 'Yeboah', '0240030022', 'larryfixid@gmail.com', '$2y$10$ROje6K9D/LDjK84yDSel/eyVNWCJVl7cQCwzsWgnUmuJrlVr9ds0O', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:57:52', '2024-07-11 16:57:52', NULL);
INSERT INTO `users` VALUES ('212', 'Yeboah', 'Kelvin', NULL, '2023-24010104', '$2y$10$QXqmWmmuAlnb8fw.uSzhC.K.8oLpwHHbEl9ar2e86RTR7G4L3XhVu', 'male', '1/1/1/1/1/1/user/668fddd90ece56.217718341720704473.jpg', '2010-06-29', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:57:53', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('213', 'Canos', 'Avenyo', '0244933001', 'canosfixid@gmail.com', '$2y$10$wfOem0UiRmG0PJ9NqkZjzOa6rQUUk08fXFu1EzsaaAFVBRCEgDlqG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:59:37', '2024-07-11 16:59:37', NULL);
INSERT INTO `users` VALUES ('214', 'Emmanuel', 'Avenyo', NULL, '2023-24010105', '$2y$10$ELPWagCR8BDhpXOfVnwJO.SMigc1OKxDT6AO20htaEBVi0Ub2CLk.', 'male', '1/1/1/1/1/1/user/668fde41346482.500850521720704577.jpg', '2010-07-18', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 16:59:37', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('215', 'Essel', 'Ohenewaa', '0244665895', 'esselfixid@gmail.com', '$2y$10$QAJG5gijTQfoRebF8nj5eOXi0cww/Sc/9LB6mWsFn8nSdcaCiNGaC', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:01:18', '2024-07-11 17:01:18', NULL);
INSERT INTO `users` VALUES ('216', 'Ohenewaa', 'Mary', NULL, '2023-24010106', '$2y$10$KwpfpNNQXiKsmXHKS9AXjOYZk8D0VSAUw18/XKf.RQWfeFxEcms3.', 'female', '1/1/1/1/1/1/user/668fdea69027b1.150332491720704678.jpg', '2010-06-23', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:01:18', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('217', 'Atta', 'Samuel', '0244039933', 'attafixid@gmail.com', '$2y$10$EHfuhN/IwgqCvuuaZGLm3euZ2D.xQrtitWbZnbuTuENrHo.O9xlra', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:03:03', '2024-07-11 17:03:03', NULL);
INSERT INTO `users` VALUES ('218', 'Abrah', 'Samuel', NULL, '2023-24010107', '$2y$10$7.XyryMpYAubErfkOF7sze.82DKB3HqYJD8rxERo9JxoSlXL8TwSS', 'male', '1/1/1/1/1/1/user/668fdf0f28a3c1.869063851720704783.jpg', '2010-11-22', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:03:03', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('219', 'Roman', 'Tawiah', '0243000000', 'romanfixid@gmail.com', '$2y$10$g/5McFCxSTxrVYa914b4EeUVns0vM24pi1VzCRKw2iQoOxOW0YGyq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:04:41', '2024-07-11 17:04:41', NULL);
INSERT INTO `users` VALUES ('220', 'Tawiah', 'Constance', NULL, '2023-24010108', '$2y$10$5Pw7OL1i1yJQVtYh7/ngJuCAvrw1D7C/7m..5PWtGxYHydfvrsKku', 'male', '1/1/1/1/1/1/user/668fdf71e653d7.304443481720704881.jpg', '2010-05-20', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:04:41', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('221', 'Addo', 'Evans', '0243000000', 'addofixid@gmail.com', '$2y$10$OIxxCGCERxJFNGHPXb5Tv.AjQiV9FO/UvV70KDV8EknCAebi8oTRS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:06:31', '2024-10-24 19:54:17', NULL);
INSERT INTO `users` VALUES ('222', 'Adu', 'Mary', NULL, '2023-24010109', '$2y$10$RHwF9SPje/ZlBOMYbGXIJ.cdg1ZgEfhg1Z2aobqaHRAx81zZCQGQa', 'female', '1/1/1/1/1/1/user/668fdfe00a8659.309382081720704992.jpg', '2010-03-27', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:06:32', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('223', 'Adu', 'Sarah', NULL, '2023-24010110', '$2y$10$eLty3CwDkBCvaTPI1DzTIuoZPwvZ.vMToynuGwAli15G0pwiKvKWa', 'female', '1/1/1/1/1/1/user/668fe02923e560.425961641720705065.jpg', '2010-03-27', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:07:45', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('224', 'Mensah', 'Osei', '0249930000', 'mensahfixid@gmail.com', '$2y$10$v35fPVMyN8YWfRzRMpqoievdHMQroKtcnPWk5vf66SALGJbfTLSEW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:14:39', '2024-07-11 17:14:39', NULL);
INSERT INTO `users` VALUES ('225', 'Kofi', 'Bismark', NULL, '2023-24010111', '$2y$10$HcgJ35FvkAR3Zb81qDwVTu6xWHnKz4AuwR0W.nSvRx2cJ6VSt/r8.', 'male', '1/1/1/1/1/1/user/668fe1c7bdf6b1.897342681720705479.jpg', '2010-09-29', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:14:39', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('226', 'Abdulai', 'Karim', '0244301721', 'abdulaifixid@gmail.com', '$2y$10$cn/gbaeLc19IM.eG/md3TuMR5PgNzPBdixlFPkYEGyEJikcYTxtMi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:16:29', '2024-07-11 17:16:29', NULL);
INSERT INTO `users` VALUES ('227', 'Aziz', 'Karim', NULL, '2023-24010112', '$2y$10$gf9SYaN28Y8hqQEmbSgVr.MTfK2v39i2cjjXQ1sEc..s6H96316zi', 'male', '1/1/1/1/1/1/user/668fe235dc3fe2.541677951720705589.jpg', '2010-11-20', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 17:16:29', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('228', 'Koseyere', 'Dagno', '0249933300', 'koseyerekixid@gmail.com', '$2y$10$2wOWvKjn9Obn5r/pS7kDf.81w5LFBZAArrne4mn1grHgdE/CPlr3S', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:01:38', '2024-07-11 18:01:38', NULL);
INSERT INTO `users` VALUES ('229', 'Dagno', 'Claudia', NULL, '2023-24010113', '$2y$10$r04Sp3kpuqWu72Aob2xsZ.BbN0NoC9f.PSp2zC9JOBvU5ILG/dWne', 'female', '1/1/1/1/1/1/user/668feccadb8335.102394171720708298.jpg', '2010-01-18', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:01:38', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('230', 'Raymond', 'Piesie', '0200666492', 'raymondkixid@gmail.com', '$2y$10$82RMyQB/N1jRgc0g9jXz1.S1RqUG4.Rfov2Lt49zyyWQryRlzrhDC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:04:41', '2024-07-11 18:04:41', NULL);
INSERT INTO `users` VALUES ('231', 'Owusuaa', 'Mary', NULL, '2023-24010114', '$2y$10$OIe5sv5sJZkz6o7Uf5VsQeDszpGmdabsyyhWK9XttBbA1TIgUl3Wq', 'female', '1/1/1/1/1/1/user/668fed81460525.027785161720708481.jpg', '2010-09-01', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:04:41', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('232', 'Umar', 'Ahmed', '0243000000', 'umarkixid@gmail.com', '$2y$10$tSrHy/0d.7oPYtX13lSP0uBZTcw.a4gpMn7KOOPnVYZ4lc7OzNxf2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:07:47', '2024-07-11 18:07:47', NULL);
INSERT INTO `users` VALUES ('233', 'Umar', 'Sulemana', NULL, '2023-24010115', '$2y$10$vPBXQEFg6YuGReXfXY9Z7Od1swNoQS5VqNnYmPWjPql.cAKsu3GzK', 'male', '1/1/1/1/1/1/user/668fee3b9f9db3.505733951720708667.jpg', '2010-09-07', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:07:47', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('234', 'Sulemana', 'Sulemana Muntari', '0243000876', 'sulemanakixid@gmail.com', '$2y$10$pLj2PilhpKQQ3EJU8jzwXO2RypA/hgZJro5uisxfdGcj4XBW7AWZe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:10:37', '2024-07-11 18:10:37', NULL);
INSERT INTO `users` VALUES ('235', 'Ahmed', 'Sulemana', NULL, '2023-24010116', '$2y$10$TCbSjP1.vQw7YUtAEP/02OWFxZv1g/M4OA3sJMFI2kF78.wDatTP2', 'male', '1/1/1/1/1/1/user/668feee5bcdc03.916427951720708837.jpg', '2010-06-08', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:10:37', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('236', 'Sadik', 'Abubakar', '024355600', 'sadikkixid@gmail.com', '$2y$10$vTfI4mRBTBX5mq5PjGHbFOQrrdXZTzQUfj57rmGQSpsm9IhZzbIhy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:15:59', '2024-07-11 18:15:59', NULL);
INSERT INTO `users` VALUES ('237', 'Sulemana', 'Abubakar', NULL, '2023-24010117', '$2y$10$IGZyzb0Ok.ruit3or9qbUuug0LGS//j/Es./S0cV1RVCG3BqRSwy2', 'male', '1/1/1/1/1/1/user/668ff027a4da69.794012261720709159.jpg', '2010-01-15', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:15:59', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('238', 'Issahaku', 'Sulemana', '0243667234', 'adeenakixid@gmail.com', '$2y$10$Jb48UT9LjCrVr9vgwKO5LeKL77G2RxEPUnkmhlNaEVKgS5aAuBXIS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:18:28', '2024-07-11 18:18:28', NULL);
INSERT INTO `users` VALUES ('239', 'Sulemana', 'Adeena', NULL, '2023-24010118', '$2y$10$RbudndWcSOLNGEzoaRU9au/HRWTrTM0kozQGv.hxplCXKV/8TgDTG', 'female', '1/1/1/1/1/1/user/668ff0bc71ae31.280646131720709308.jpg', '2010-04-07', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:18:28', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('240', 'Yahaya', 'Sulemana', '0244300656', 'asmawukixid@gmail.com', '$2y$10$ZKFx7IcqHxTQgjlfGzSkuONy2IsMgkQBPP5v2DVERCw6dpku00BxW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:20:27', '2024-07-11 18:20:27', NULL);
INSERT INTO `users` VALUES ('241', 'Sulemana', 'Asmawu', NULL, '2023-24010119', '$2y$10$aeTNreo2Mqy2jMQ6rHyM9ukFfZ/RjSBK9nIHGDyg.FcaHkcaM46/y', 'female', '1/1/1/1/1/1/user/668ff133d208f0.844814001720709427.jpg', '2010-12-24', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:20:27', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('242', 'Abraham', 'Sarbeng', '0240003222', 'abrahamkixid@gmail.com', '$2y$10$3ZmhkDYZ7j91M.f.1ZpLPOA7FjRKG4Wk6Flh9pA5RfvUAFsSu/y9y', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:22:16', '2024-07-11 18:22:16', NULL);
INSERT INTO `users` VALUES ('243', 'Sarbeng', 'Raymond', NULL, '2023-24010120', '$2y$10$eRShsitotcvCoFdch7FKROa0sqyG7gK50zx6vJuVVZXWM4w5DGNem', 'male', '1/1/1/1/1/1/user/668ff1a09fc065.436838121720709536.jpg', '2010-05-27', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:22:16', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('244', 'Malik', 'Karim', '0248874320', 'malikkixid@gmail.com', '$2y$10$1Jb8k3xzTqmc..eGeqltfeCRhCOAvWXwgybmjxvvAxVKqlAGu9NbS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:24:09', '2024-10-24 19:54:17', NULL);
INSERT INTO `users` VALUES ('245', 'Salimatu', 'Karim', NULL, '2023-24010121', '$2y$10$YCTcAu7tl4UCbweB/CC3COPDmyyJ5ALxVJd56.qRG9lGv.CgLvl1W', 'female', '1/1/1/1/1/1/user/668ff211547bb9.326104741720709649.jpg', '2010-12-12', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:24:09', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('246', 'Karim', 'Mariam', NULL, '2023-24010122', '$2y$10$zOkrPFLKrPMwI8R2xm3cRu0JUrn3E3RY4HIhWol1Edbdz9iFeItqS', 'female', '1/1/1/1/1/1/user/668ff3a2b34c57.467010311720710050.jpg', '2010-04-23', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:30:50', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('247', 'Abass', 'Musah', '0244377410', 'abasskixid@gmail.com', '$2y$10$OBbAvhM6lUX4bGMeUHGhHuCqJZVzEagnoMvbm9IVg/4w7OH/ovXai', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:33:05', '2024-07-11 18:33:05', NULL);
INSERT INTO `users` VALUES ('248', 'Abass', 'Acquah', NULL, '2023-24010123', '$2y$10$iML.IaxWvUGE8AxR4GVJ3OwHPO0NctuAZL37ub/kU1fa1g7v22W2u', 'male', '1/1/1/1/1/1/user/668ff429ec28e0.389633841720710185.jpg', '2010-07-27', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:33:05', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('249', 'Blessing', 'Anaman', '0544790097', 'blessingkixid@gmail.com', '$2y$10$Ei2xEeiqo3EW2c1hUOVhwOHs5Gn3wJCOMxs2xuy7LlmPRBI698bwO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:38:00', '2024-07-11 18:38:00', NULL);
INSERT INTO `users` VALUES ('250', 'Anaman', 'Nancy', NULL, '2023-24010124', '$2y$10$I4Sxpi.LfeJwANSKsO7bLOaeTwYLeTI3TK.r2IJI1U.clXZlQAbaG', 'female', '1/1/1/1/1/1/user/668ff55018ffa9.441387411720710480.jpg', '2010-07-19', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:38:00', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('251', 'Issahaku', 'Dawuda', '0538779457', 'dawudakixid@gmail.com', '$2y$10$9YVaVZ5JlmAqctFG/s95Fuur7VxzWLc98TwOnXNg4nlWO.rEKLCFa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:39:54', '2024-07-11 18:39:54', NULL);
INSERT INTO `users` VALUES ('252', 'Fatawu', 'Dawuda', NULL, '2023-24010125', '$2y$10$irwjp80..TdCNOwg2bgY1eF.nV0k/3K.TSqex1i6KD8f.eVlyJwe.', 'male', '1/1/1/1/1/1/user/668ff5c2995c41.133008591720710594.jpg', '2010-07-13', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:39:54', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('253', 'Daniel', 'Antwi', '0555341211', 'antwikixid@gmail.com', '$2y$10$dJQU2cRxTDOcBvi5n1eBC.BmVE9tG3qbqImTuwAJSj5gH7BYaXmbi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:49:30', '2024-07-11 18:49:30', NULL);
INSERT INTO `users` VALUES ('254', 'Antwi', 'Lawrence', NULL, '2023-24010126', '$2y$10$dNPVDfSx.50xRIV.pvd5t.s13U1zRKGVBtGmg5EsXm2qeIWU.ygKC', 'female', '1/1/1/1/1/1/user/668ff8026bb1f7.823694081720711170.jpg', '2010-11-06', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:49:30', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('255', 'Ndalefo', 'Kpeje', '0244222100', 'ndalefokixid@gmail.com', '$2y$10$H7Ed87QXybCmVHULnl/opeKAVzGg9Lg51sSMo5hjyzT2/AmEHJbXu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:51:50', '2024-07-11 18:51:50', NULL);
INSERT INTO `users` VALUES ('256', 'Anita', 'Kpeje', NULL, '2023-24010127', '$2y$10$.PrO.JVpsQypps6vfINQM.vNiW6r4In/8uFqeTNrEHE2Xx2fVxibi', 'female', '1/1/1/1/1/1/user/668ff88e466540.977145461720711310.jpg', '2010-10-17', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:51:50', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('257', 'Aseidu', 'Ayisu', '0243000000', 'aseidukixid@gmail.com', '$2y$10$kFwlEjOQsy972j71WxgPpeHi/RMsRyT4BQm44UNUhlitEXPHoyhKm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:53:40', '2024-07-11 18:53:40', NULL);
INSERT INTO `users` VALUES ('258', 'Ayisu', 'Mercy', NULL, '2023-24010128', '$2y$10$/rJLj1j2prs0z5CGwIHvg.HDUfpTl8kr0OjIQU7PTYFVi14IGCNtO', 'female', '1/1/1/1/1/1/user/668ff8fc6e0fd3.543345541720711420.jpg', '2010-10-22', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:53:40', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('259', 'Eshun', 'Bismark', '0244002111', 'sablahkixid@gmail.com', '$2y$10$7oCYKXQelZBnqYafzI2/LOcfEpCTK76GNeslCuJunWCjstq4ebWTe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:55:27', '2024-07-11 18:55:27', NULL);
INSERT INTO `users` VALUES ('260', 'Sablah', 'Bismark', NULL, '2023-24010129', '$2y$10$ReViFc2mVBQs4RgCg88A/O.gKRBbFZ3GjoSVDxt8uTrQRrEwhE0o.', 'male', '1/1/1/1/1/1/user/668ff967dd38f8.948977581720711527.jpg', '2010-10-28', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:55:27', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('261', 'Ntim', 'Asomaah', '0200370020', 'ntimkixid@gmail.com', '$2y$10$9X2io853XO3QeInJqJ3ybeGsiW.Gu4eNIZ90BhFlu4/gOmHidx3pW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:57:39', '2024-07-11 18:57:39', NULL);
INSERT INTO `users` VALUES ('262', 'Asoma', 'Cindy', NULL, '2023-24010130', '$2y$10$BygK8yPHVgsHmk2xeUN7QurFzdTPUGENVn6TJt7MfxrmyjKLLxFk.', 'female', '1/1/1/1/1/1/user/668ff9eb975072.904524731720711659.jpg', '2010-11-29', 'Madina', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:57:39', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('263', 'Iddrisu', 'Osman', '0244555923', 'iddrisukixid@gmail.com', '$2y$10$yNWWyB7oKWH6XMWKT.OdruXbZfriJYyW4wRVQguwavC9eoMG0GWpC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:59:30', '2024-07-11 18:59:30', NULL);
INSERT INTO `users` VALUES ('264', 'Abdul', 'Hakeem', NULL, '2023-24010131', '$2y$10$DWBzznT39nN7UIJSBe2GResnF5baQoalYYCq0tvBeM4RR0/p3GIA6', 'male', '1/1/1/1/1/1/user/668ffa5b0e7696.520709321720711771.jpg', '2010-02-03', 'Adenta', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 18:59:31', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('265', 'Obodai', 'Mantey', '0555022987', 'obodaikixid@gmail.com', '$2y$10$u4vS3nRiz.lc.gCAvxBJAugZ7MmIM8/qbgAiqAfk4bRtoL4Q0lX4y', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:02:46', '2024-07-11 19:02:46', NULL);
INSERT INTO `users` VALUES ('266', 'Dorcas', 'Mantey', NULL, '2023-24010132', '$2y$10$Oqbgc7fAGnbAZ9ECAMplze2HhbPhNAO4zrBIkbIGKpoeIfbxbCu26', 'female', '1/1/1/1/1/1/user/668ffb1ec1d153.841594471720711966.jpg', '2010-11-26', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:02:46', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('267', 'Jarah', 'Haruna', '0272290202', 'jarahkixid@gmail.com', '$2y$10$AZFUJvOMZ4k.A9Ep3WyA4.RgEy9A17j2vz/9tO/hxPst5Lc8NLaKG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:04:45', '2024-07-11 19:04:45', NULL);
INSERT INTO `users` VALUES ('268', 'Haruna', 'Rahman', NULL, '2023-24010133', '$2y$10$1xAJ7vuE1CPrt5Qz/PpfHuaZcqV20aJ1uK1yQHASE7sGk19.kqMWS', 'male', '1/1/1/1/1/1/user/668ffb960daa48.147672851720712086.jpg', '2010-04-09', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:04:46', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('269', 'Wayo', 'Inusah', '0240004333', 'wayokixid@gmail.com', '$2y$10$ABqhquePHo5zS6E3l4G2wu1ukx.5hDoswAXVGgnjkzsODgxo909hu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:06:42', '2024-07-11 19:06:42', NULL);
INSERT INTO `users` VALUES ('270', 'Seidu', 'Inusah', NULL, '2023-24010134', '$2y$10$J1rNoZCV9OJGqH2byi1Rvu5Zdn1BiWKzN48msfTbsW2AT7fYKXRhq', 'male', '1/1/1/1/1/1/user/668ffc0a2a9989.883213201720712202.jpg', '2010-05-11', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:06:42', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('271', 'Dela', 'Kpedze', '0243300000', 'delakixid@gmail.com', '$2y$10$NnYXpZjD2ui.JlDEBxG60O/ws6QEg0Bzunhs60g.RSGa8frIspP.K', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:08:24', '2024-10-24 19:54:17', NULL);
INSERT INTO `users` VALUES ('272', 'Kpedze', 'Christabel', NULL, '2023-24010135', '$2y$10$b66x3PxuR4ccE/vHLDPI6ewaDSm7sOTqpte1CwoTHvTm3mYA6VBLe', 'female', '1/1/1/1/1/1/user/668ffc7105f1f4.755429081720712305.jpg', '2010-11-04', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:08:25', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('273', 'Maxwell', 'Kpedze', NULL, '2023-24010136', '$2y$10$Fvm5gyGb8LKsVbstHVqpa./VxFHdiE5MWurE6Nhm0iPfqEJmOaUcy', 'male', '1/1/1/1/1/1/user/668ffcb9def494.539570641720712377.jpg', '2010-03-22', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:09:37', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('274', 'Serwaa', 'Ampem', '0245678933', 'serwaakixid@gmail.com', '$2y$10$nlfRqVSetOmYFjRQ7vOgdOa8L1H.fKd9Hy41hAduDt172fMepjDQ.', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:13:14', '2024-07-11 19:13:14', NULL);
INSERT INTO `users` VALUES ('275', 'Spendilove', 'Ampem', NULL, '2023-24010137', '$2y$10$2jO3/EsN/8hzOXbosvhXC.CsupPoE3M5ekaDSyj4pApVNs0tXXfvO', 'female', '1/1/1/1/1/1/user/668ffd92dde3c6.256888411720712594.jpg', '2010-01-14', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:13:14', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('276', 'Angel', 'Awuku', '0245321132', 'angelkixid@gmail.com', '$2y$10$UEF1qiAmYcKqFclcH4Yd6e7bhKasmL9fabHsaSR2jhiy4wrgAIpX.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:14:46', '2024-07-11 19:14:46', NULL);
INSERT INTO `users` VALUES ('277', 'Vivian', 'Awuku', NULL, '2023-24010138', '$2y$10$..CgKvNKhc13pHrabUQBDOo/yyfSTeHNWmxifRjQf4OPVTS7qG4y.', 'female', '1/1/1/1/1/1/user/668ffdee4e4d71.233408881720712686.jpg', '2010-09-06', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:14:46', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('278', 'John', 'Dziwornu', '0243000112', 'johnkixid@gmail.com', '$2y$10$G9JxjU/0ezEz1mzZDT1JGuyxNeBc4x1QdfwG6JJeMWXbuGQ1Nta/O', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:16:21', '2024-07-11 19:16:21', NULL);
INSERT INTO `users` VALUES ('279', 'Dziwornu', 'Eric', NULL, '2023-24010139', '$2y$10$h72IfIj/ZPnY1.5puT1mXeKInVcCOZFMG5YpKXDh9U0Xw32suaZ.a', 'male', '1/1/1/1/1/1/user/668ffe4d8f7070.028463481720712781.jpg', '2010-10-22', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:16:21', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('280', 'Amshawu', 'Musah', '0240003332', 'amshawukixid@gmail.com', '$2y$10$Q5QOyd6fVEWUR2lqOKDxcemQbVjj3erlh0MxUzFVDKDtyAjm3NIEq', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:18:07', '2024-07-11 19:18:07', NULL);
INSERT INTO `users` VALUES ('281', 'Asmawu', 'Musah', NULL, '2023-24010140', '$2y$10$7jp.2vDRDIGJnBQZucybUeVleWCB/shftYybJ6lcDBBLpKCImrTVm', 'female', '1/1/1/1/1/1/user/668ffeb7f08982.149244321720712887.jpg', '2010-11-21', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:18:07', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('282', 'Edward', 'Gyasi', '0540678772', 'nanakixid@gmail.com', '$2y$10$Pi7pkOXR0lYCK1HAATUiJ.vj88aXaWBFzw7DMbLhrUV5YmXGNiY6y', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:19:45', '2024-07-11 19:19:45', NULL);
INSERT INTO `users` VALUES ('283', 'Ernest', 'Gyasi', NULL, '2023-24010141', '$2y$10$P4YIRUUDoIf0nwxGgJlbsuiitarickVrA3BHUx/LfHE4pKFINcsqa', 'male', '1/1/1/1/1/1/user/668fff192f44b8.441340471720712985.jpg', '2010-02-24', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:19:45', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('284', 'Dugbatey', 'Godfred', '0240224440', 'dugbateykixid@gmail.com', '$2y$10$vZbxov66lWvAV4p9x7MEFeheLHCFpyuwH9HRpPobpTXgELQmTwnny', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:21:27', '2024-07-11 19:21:27', NULL);
INSERT INTO `users` VALUES ('285', 'Godfred', 'Tiboah', NULL, '2023-24010142', '$2y$10$Og.VfWJkAOvH4GS0GAfApO.j/WFmPtBV/T/C79NhWGesdtthOzsjG', 'male', '1/1/1/1/1/1/user/668fff7f149ff1.881173361720713087.jpg', '2010-05-28', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:21:27', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('286', 'Aaron', 'Osei', '0545887522', 'aaronkixid@gmail.com', '$2y$10$se0vIZgJ9HTaN/HFmcudj.puq/3ExuK5QTQNeHxgT128Cjgl5Gt56', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:23:33', '2024-07-11 19:23:33', NULL);
INSERT INTO `users` VALUES ('287', 'Osei', 'Juliet', NULL, '2023-24010143', '$2y$10$VzXXI/eSdWGchyt5QuI9x.SNPt76zvPjIHosk6QtqAXU3N81SGmnG', 'female', '1/1/1/1/1/1/user/668ffffd4fcd63.895952161720713213.jpg', '2010-05-11', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:23:33', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('288', 'Adrigbate', 'Godson', '0249923365', 'adigbatikixid@gmail.com', '$2y$10$G8E5JISiYkQ7OfHeHUnbMuH7EXCJe688M3IfSvnczJ7EYylLWLQIq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:25:45', '2024-07-11 19:25:45', NULL);
INSERT INTO `users` VALUES ('289', 'Koblah', 'Godson', NULL, '2023-24010144', '$2y$10$jj7Tx4yfg4RyvEhWtqLx9OE6Ii97jsBd1ddZVdDO6HcALcAbVNpIW', 'male', '1/1/1/1/1/1/user/66900081871a32.083527861720713345.jpg', '2010-10-18', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:25:45', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('290', 'Muntaka', 'Adamu', '0243000000', 'muntakakixid@gmail.com', '$2y$10$BP3djgq8LQpBM9T4i0sOm.UaPGaxW/pX2mDtf4tdheXHrrtiEJpzu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:31:37', '2024-07-11 19:31:37', NULL);
INSERT INTO `users` VALUES ('291', 'Adamu', 'Fadilatu', NULL, '2023-24010145', '$2y$10$xLTRrq2TLdiclzthwTiPUuyPHujrFFOBd4wRNKjtyRwOtHnEX04KC', 'female', '1/1/1/1/1/1/user/669001e1385449.787929881720713697.jpg', '2010-07-07', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:31:37', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('292', 'Esianyo', 'Godwin', '0206298220', 'kofikixid@gmail.com', '$2y$10$YtwxnCzTBflV5s.P/SKQmeI5xl5H56pmoclNPooSIDYvNss.fJrvG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:33:38', '2024-07-11 19:33:38', NULL);
INSERT INTO `users` VALUES ('293', 'Esianyo', 'Confidence', NULL, '2023-24010146', '$2y$10$XmQYUsB.CmVrir.ukNdrQ.lXo8Wjpf7RGH9Vo8Fg/uWXr0DNUSVtK', 'male', '1/1/1/1/1/1/user/6690025a39dd93.887958311720713818.jpg', '2010-01-13', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:33:38', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('294', 'George', 'Elton', '0558229454', 'georgekixid@gmail.com', '$2y$10$Flt9gEA5viaWyS7rDbR9oeV7TSMkU.EHGvDApbv8n5nB84LlWUe8O', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:35:05', '2024-07-11 19:35:05', NULL);
INSERT INTO `users` VALUES ('295', 'Boateng', 'Elton', NULL, '2023-24010147', '$2y$10$tY.J1xpYrnuzTKjXcE6uGO2/a.p1PjyMLzkfAvHbFl8RYs3UMxHPi', 'male', '1/1/1/1/1/1/user/669002b1c0cc09.971309031720713905.jpg', '2010-10-02', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:35:05', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('296', 'Yussif', 'Yakubu', '0240035558', 'yussifkixid@gmail.com', '$2y$10$LXTbD15wJQa.PdAnpyri4OvUiH9qZhJcAqLZ9yk0/d0S3Kaqjr582', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:36:53', '2024-07-11 19:36:53', NULL);
INSERT INTO `users` VALUES ('297', 'Yakubu', 'Rukaya', NULL, '2023-24010148', '$2y$10$YvTi0y4WNK4lFasbmAIJgO71mrAhlZ3AirKjgJFLuZ6C4OxPOgqPC', 'female', '1/1/1/1/1/1/user/6690031de67821.342874881720714013.jpg', '2010-04-28', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:36:53', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('298', 'Yahaya', 'Osmanu', '0242555800', 'yahayakixid@gmail.com', '$2y$10$BCOQ8NTf8Aw4EOtSTaLbZe4VyHskqR/NEvkl8bw/N0T7u27H4rExu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:38:27', '2024-07-11 19:38:27', NULL);
INSERT INTO `users` VALUES ('299', 'Ibrahim', 'Osmanu', NULL, '2023-24010149', '$2y$10$pmH/DrnveF1JELv1.XDOWeHtRYCTJ.rZaopcXuFOnjsSsOF7o2pSi', 'male', '1/1/1/1/1/1/user/6690037b9269c4.160754361720714107.jpg', '2010-10-11', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:38:27', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('300', 'Samuel', 'Akuffo', '0596668021', 'helinakixid@gmail.com', '$2y$10$cGdSqk1fcjHeylJxBIcRe.NIEnmh1B04ktAbvRBlfP0tFVoJo6PsK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:40:48', '2024-07-11 19:40:48', NULL);
INSERT INTO `users` VALUES ('301', 'Akuffo', 'Helina', NULL, '2023-24010150', '$2y$10$VuMRkQHqGm5hrtwOGKWRdOMvhLroFVdpG/qkQzCQOYDAkph9bjg12', 'female', '1/1/1/1/1/1/user/66900408359ae8.639889561720714248.jpg', '2010-10-15', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:40:48', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('302', 'Essien', 'Akoto', '02499055878', 'essienkixid@gmail.com', '$2y$10$omnhHax/pQ9v.9mB289wt.pE3qRIC2GvkybE.ebuQWRnNL/0ICXc.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:42:22', '2024-07-11 19:42:22', NULL);
INSERT INTO `users` VALUES ('303', 'Akoto', 'Peter', NULL, '2023-24010151', '$2y$10$sDo0vCS7bwnoAGBbdekNze1K2WsWCcf39d5orB3oX2F4.ScLHdMFS', 'male', '1/1/1/1/1/1/user/66900466eb9e18.607583311720714342.jpg', '2010-02-27', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:42:22', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('304', 'Sanda', 'Abdullah', '0277737713', 'firdauskixid@gmail.com', '$2y$10$M6p8/KE175eoi3JiIpNmBuvp26fUPqK4LZ5hJt3H0c1mOrZBAkD52', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:44:18', '2024-07-11 19:44:18', NULL);
INSERT INTO `users` VALUES ('305', 'Fidaus', 'Abdullah', NULL, '2023-24010152', '$2y$10$UlZT2SNvErS5qIOzqvF4CecXp1aOksxRipa/9L4f3yvXr5yeh4upi', 'female', '1/1/1/1/1/1/user/669004db02a4c5.632496401720714459.jpg', '2010-11-23', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:44:19', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('306', 'Douglas', 'Osei', '0245582201', 'douglaskixid@gmail.com', '$2y$10$YdYJc7H/Sd5OP.3LYaHlX.Ub1ZOAqqJE5o8ma5B1Z6Sx3mwEFgZ4W', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:45:53', '2024-07-11 19:45:53', NULL);
INSERT INTO `users` VALUES ('307', 'Elizabeth', 'Osei', NULL, '2023-24010153', '$2y$10$Qk8UtG/.v/KfzhsPCLWjG.spM7sZZto1EmwmsWp2DuwI0ngP1KqRq', 'female', '1/1/1/1/1/1/user/66900539835fc1.371656831720714553.jpg', '2010-06-26', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:45:53', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('308', 'Taylor', 'Felix', '0554447220', 'taylorkixid@gmail.com', '$2y$10$d9yVtpih0ldAXGG0mNs/S..6q/HUC3qI8vCbEIEM1eVFWi2gkhOJ.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:47:45', '2024-07-11 19:47:45', NULL);
INSERT INTO `users` VALUES ('309', 'Taylor', 'Felix', NULL, '2023-24010154', '$2y$10$GfC4oh/rs87gmdr2p9BPZeY5dyjrqZQ6dNLtu2is0Ex69HRFe8cr2', 'male', '1/1/1/1/1/1/user/669005a9bc08e6.355939551720714665.jpg', '2010-11-27', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:47:45', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('310', 'Kobina', 'Tetteh', '0265446022', 'kobinakixid@gmil.com', '$2y$10$nS5lEBRwk8NaKCrLGXpt7O4lz4rJriGZNArg5gM7m48nLRzvXuUL6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:51:32', '2024-07-11 19:51:32', NULL);
INSERT INTO `users` VALUES ('311', 'Kobina', 'Stephenus', NULL, '2023-24010155', '$2y$10$dtyYANoL.pJ4DF7cy346LeNaa5FjlKdwu/XHkErfLWTYuSO.gqD7C', 'male', '1/1/1/1/1/1/user/6690068c22c528.351602821720714892.jpg', '2010-07-26', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:51:32', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('312', 'Saviour', 'Agbeli', '0554998788', 'saviourkixid@gmail.com', '$2y$10$eBIUj.RXJtw5DFwLMli9geMtDUg5ZILF8JEJRNZ2O5lzXncuxVFR2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:53:27', '2024-07-11 19:53:27', NULL);
INSERT INTO `users` VALUES ('313', 'Agbeli', 'Elisha', NULL, '2023-24010156', '$2y$10$D/vjZBpT7eYkNx6TqM..kO.yqzWN8mibiLg1JiX7LkxBq2zF5Wz8i', 'male', '1/1/1/1/1/1/user/669006ff8118f0.143680191720715007.jpg', '2010-09-30', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:53:27', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('314', 'Oware', 'Opoku', '0277371935', 'judithkixid@gmail.com', '$2y$10$4mkjzN3Pu3O1Ow5PzbcpYeLDa5SKWUccb4m.akzYeWcqKLgG1Irpq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:56:06', '2024-07-11 19:56:06', NULL);
INSERT INTO `users` VALUES ('315', 'Opoku', 'Judith', NULL, '2023-24010157', '$2y$10$DgjBsmSf.Hp7NfJTKpdWI.XynANMAK2aCuxAGqIYJu8Sjl6VrdH7y', 'female', '1/1/1/1/1/1/user/6690079ee315b5.926275881720715166.jpg', '2010-01-15', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:56:06', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('316', 'Addo', 'Kwabena', '0570265454', 'nancykixid@gmail.com', '$2y$10$EDSXqG0IZ4XDo/cIRqEtMuSmZWhl/2k0cs1QiDT73yLEZKWAUikrK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:57:57', '2024-07-11 19:57:57', NULL);
INSERT INTO `users` VALUES ('317', 'Adu', 'Nancy', NULL, '2023-24010158', '$2y$10$sS7co8gskBjEjSKlTSZvZeEM918Ma.28LzLryxfhcADyJC3fbZXku', 'female', '1/1/1/1/1/1/user/6690080deecec5.982634181720715277.jpg', '2010-06-06', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 19:57:57', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('318', 'Kyei', 'Asante', '0552112533', 'yaakixid@gmail.com', '$2y$10$ra5taaAMEvedWR8XFviwvuj0OfdSBmdsi60AymND/sr..3PFpxSKu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:00:06', '2024-07-11 20:00:06', NULL);
INSERT INTO `users` VALUES ('319', 'Boahemaa', 'Kyei', NULL, '2023-24010159', '$2y$10$X31owfxd11becEMis9bSvOxW.1cQA.1Y.lmOgP9yHCtSa5u4.zTky', 'female', '1/1/1/1/1/1/user/6690088ece7404.659209451720715406.jpg', '2010-09-09', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:00:06', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('320', 'Larbi', 'Emmanuel', '02454424487', 'larbikixid@gmail.com', '$2y$10$9Sy1xujvmocukJbTdV2OpOHSa4wJY2HlyvFtMuixQC8qYyPLPAHMK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:01:44', '2024-07-11 20:01:44', NULL);
INSERT INTO `users` VALUES ('321', 'Larbi', 'Philip', NULL, '2023-24010160', '$2y$10$jHwtyeP.vBQn6oMwmToIpuFs8m0rwnYG1czzZyGnYBOjDd3c0NMdO', 'male', '1/1/1/1/1/1/user/669008f104d167.131350391720715505.jpg', '2010-07-10', 'Mempeasem', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:01:45', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('322', 'Addo', 'Kwakye', '0500500258', 'joycelinekixid@gmail.com', '$2y$10$t0QGbMBjVpaakJZ35nMzyOvBVAEMkLlRBM40vqPSy2r1dw7lB7GTa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:03:38', '2024-07-11 20:03:38', NULL);
INSERT INTO `users` VALUES ('323', 'Joycelin', 'Addo', NULL, '2023-24010161', '$2y$10$XkDi10NRXp.9dLXM6.tQZO3M7tQVlCfr7/aHyuM4NqZqNSMT8uZJS', 'female', '1/1/1/1/1/1/user/66900962d29363.142389661720715618.jpg', '2010-10-17', 'Trinity', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:03:38', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('324', 'Willaims', 'Andy', '0244212002', 'andykixid@gmail.com', '$2y$10$Ghd2RWds0JcQoweC1hFtvOW./upTXPqROjgMquWHQexXd0BApYkTe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:06:42', '2024-07-11 20:06:42', NULL);
INSERT INTO `users` VALUES ('325', 'Appiah', 'Andy', NULL, '2023-24010162', '$2y$10$ePeOZrlDPCMD.r6HuufPeuiUPMCSv0zfENdPUOWW6xWbZvsN4fCqa', 'male', '1/1/1/1/1/1/user/66900a1ae70ea7.653626021720715802.jpg', '2010-02-01', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:06:42', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('326', 'Amu', 'Hayford', '0545520022', 'amukixid@gmail.com', '$2y$10$5np9AV5Q3.OZCY6LsDYP9O901tiMlXWWj3FqfNXwydeI8d79d9xcS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:08:40', '2024-10-24 19:54:18', NULL);
INSERT INTO `users` VALUES ('327', 'Amu', 'Richmond', NULL, '2023-24010163', '$2y$10$uqLhKQ0.aj.S.uHIn7w0peaxatBGH4Cb.M5N6N41zrMjbcvIFnBl6', 'male', '1/1/1/1/1/1/user/66900a901b72d5.776378601720715920.jpg', '2010-09-19', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:08:40', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('328', 'Amissah', 'Owusu', '0503006298', 'ginakixid@gmail.com', '$2y$10$hrD0dW7KwPTI26OaNOJkUOK90.BTtEstxDad9jnzVmYhWdOCztUxS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:10:19', '2024-07-11 20:10:19', NULL);
INSERT INTO `users` VALUES ('329', 'Owusu', 'Georgina', NULL, '2023-24010164', '$2y$10$hdM.8J1bghpfLl8BUOjX1uLi1Ss1YZdHOZYsbqyag13YliheL60gi', 'female', '1/1/1/1/1/1/user/66900af3a86ed8.423258401720716019.jpg', '2010-09-08', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:10:19', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('330', 'Addison', 'Rowland', '0245825252', 'addisonkixid@gmail.com', '$2y$10$k/BIRN0NZYSuOlrgJQtQOenw4c5/tN/WDQNK/31F3XBfnyI7XFhQi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:11:59', '2024-10-24 19:54:18', NULL);
INSERT INTO `users` VALUES ('331', 'Addison', 'Mitchell', NULL, '2023-24010165', '$2y$10$SFEZzta47HwkB4U1XTlJku22tueoMRNNcEyYsIdKYfm/2Yc50S4eC', 'female', '1/1/1/1/1/1/user/66900b579145e6.941160211720716119.jpg', '2010-01-27', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:11:59', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('332', 'Sofo', 'Osei', '0500250085', 'sofokixid@gmail.com', '$2y$10$gvpvSnxyTnYb9ooY.HK2o.GRe05dhDcSbkNtPLzq5EKMrYaX1jA/C', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:13:32', '2024-07-11 20:13:32', NULL);
INSERT INTO `users` VALUES ('333', 'Osei', 'Charles', NULL, '2023-24010166', '$2y$10$eWtnLQRkKqcOpIbd21ePF.z5FNceGE9RgXH5O33Uz7kuxP0Wglaui', 'male', '1/1/1/1/1/1/user/66900bb51cd523.284897261720716213.jpg', '2010-12-31', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:13:33', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('334', 'Addison', 'Benjamin', NULL, '2023-24010167', '$2y$10$w/bCf2SNxogMt6.ViCRDtOXeQtneK.GiSnDOVRHfpjNI5StQdjSn2', 'male', '1/1/1/1/1/1/user/66900c0c1ab082.149372091720716300.jpg', '2010-08-28', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:15:00', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('335', 'Obenewaa', 'Kessi', '0204568255', 'obenewaakixid@gmail.com', '$2y$10$XYJQ/Z5FUWXvVwJ7uerR1uhBlKEcewbTbJQtj6PHkUkFPcNlbaGzC', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:17:16', '2024-07-11 20:17:16', NULL);
INSERT INTO `users` VALUES ('336', 'Kessi', 'Grace', NULL, '2023-24010168', '$2y$10$lMlB221LD1VH3YSGT8mu3uKpcynUngDHV3ZMiMBBv2fwF/4SMuBmy', 'female', '1/1/1/1/1/1/user/66900c945c3756.580521861720716436.jpg', '2010-04-20', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:17:16', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('337', 'Hamza', 'Benso', '0500256363', 'anzakixid@gmail.com', '$2y$10$.drWM7SWvC/bFYdJB9SiMeQxJkgHucXeJLw4kSa/KXfHJuLg3Z5ky', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:19:11', '2024-07-11 20:19:11', NULL);
INSERT INTO `users` VALUES ('338', 'Benso', 'Wasim', NULL, '2023-24010169', '$2y$10$FmBR.cPSbFFTBvoFsl.uDOa4qG5P.sBy.E9pg7nJAu58e856TNHUa', 'male', '1/1/1/1/1/1/user/66900d08035314.890556461720716552.jpg', '2010-06-26', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:19:12', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('339', 'Kennedy', 'Ankomah', '0240066630', 'giftykixid@gmail.com', '$2y$10$5OqwOn6ah/EsAFyfUOc3r.fFvfJr1XrvFJRtKXMZFQqWgwWBrQavu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:21:12', '2024-07-11 20:21:12', NULL);
INSERT INTO `users` VALUES ('340', 'Ankomah', 'Gifty', NULL, '2023-24010170', '$2y$10$BmJBBMsGBqBtBTHFijtj4egsBnGA8V/SPhYHYTzgv5FI0UmxAz53i', 'female', '1/1/1/1/1/1/user/66900d80955317.624036331720716672.jpg', '2010-07-10', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:21:12', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('341', 'Aboagye', 'Hagar', '0555048775', 'davidkixid@gmail.com', '$2y$10$9pL9d6aK9U2MGmu1r5bUxu6nGWJaRLMHSXBzMNkl2epmCBmAoyj.2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:22:54', '2024-07-11 20:22:54', NULL);
INSERT INTO `users` VALUES ('342', 'Aboagye', 'David', NULL, '2023-24010171', '$2y$10$pboPrzQY1IrZEeVuyPAhzetL8fl7tcARII3SILCjqe96DR3m.pyZa', 'male', '1/1/1/1/1/1/user/66900de68d5ed0.456058561720716774.jpg', '2010-12-10', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:22:54', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('343', 'Aboagye', 'Dankwah', '0242212322', 'yawkixid@gmail.com', '$2y$10$cyOh875mTa.MyYVoP6TmJeTCjTZ7l8nvmBifAEQYhhcWvZhvq4yyC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:24:38', '2024-07-11 20:24:38', NULL);
INSERT INTO `users` VALUES ('344', 'Dankwah', 'Christopher', NULL, '2023-24010172', '$2y$10$20Ty1NIGPJF7QlQ73vHKmueI6tB9gzOuskK7v7tWdX//NX7T2u/fm', 'male', '1/1/1/1/1/1/user/66900e4edf0232.317402771720716878.jpg', '2010-08-24', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:24:38', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('345', 'Edward', 'Webb', '0244430000', 'webbkixid@gmail.com', '$2y$10$yMxxgRivfNibYobyRFVI0OI2m0bkIiBLawOsgRuX5Wng0XoVFoM9e', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:26:14', '2024-07-11 20:26:14', NULL);
INSERT INTO `users` VALUES ('346', 'Webb', 'Juannita', NULL, '2023-24010173', '$2y$10$o9vnGtiiqr5u7SJmsaxOIeqyxqiXfsFSjT8U10Mho9tejR1IkrlgK', 'female', '1/1/1/1/1/1/user/66900eaee50729.727449611720716974.jpg', '2010-02-04', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:26:14', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('347', 'Solomon', 'Baafi', '0552228552', 'baafikixid@gmail.com', '$2y$10$KYFjVTSCySDjEY3/FWWsm.Nhs0PqCOx23IJkTpztp/SQInND0jEbO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:27:51', '2024-10-24 19:54:18', NULL);
INSERT INTO `users` VALUES ('348', 'King', 'Solomon', NULL, '2023-24010174', '$2y$10$51M35UYl24PR0/UIUMxqUetdT0jiE3WqFdydQF1masFt2JKMiJkKO', 'male', '1/1/1/1/1/1/user/66900f0f226098.488923691720717071.jpg', '2010-10-02', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:27:51', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('349', 'Bafi', 'Paul', NULL, '2023-24010175', '$2y$10$ZzHSn8dZp2hTQSinitJonuYQUNkIa0ANO5xOGflOOSJaDEroamKt6', 'male', '1/1/1/1/1/1/user/66900f5a33dc28.066773581720717146.jpg', '2010-02-04', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:29:06', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('350', 'Dake', 'Kusi', '0240049990', 'kusikixid@gmail.com', '$2y$10$1DMlJznHiXsjp99lbT7ov.XiNjo83wBV7pGc2pQ9wAKTNL.WFoU1y', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:30:41', '2024-07-11 20:30:41', NULL);
INSERT INTO `users` VALUES ('351', 'Kusi', 'Alex', NULL, '2023-24010176', '$2y$10$ms3xo5S4S1Bkz/mtH175YOBckVB5thhUVFOFB54BRxNm/wlvAIU0q', 'male', '1/1/1/1/1/1/user/66900fba0b1215.177512831720717242.jpg', '2010-05-05', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:30:42', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('352', 'John', 'Mensah', '0565582215', 'juniorkixid@gmail.com', '$2y$10$JN49y5P2OEj9Lh10qm84A.1pIp4vJwBRY/FewJtAy3XoEDRVy93rm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:32:39', '2024-07-11 20:32:39', NULL);
INSERT INTO `users` VALUES ('353', 'John', 'Taylor', NULL, '2023-24010177', '$2y$10$QUIIRenLaWqzch1GEjvR3OhA78d4uj35k5ybmAnxL6RGBzCH.6jou', 'male', '1/1/1/1/1/1/user/6690102f454229.971187671720717359.jpg', '2010-07-29', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-11 20:32:39', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('354', 'Godfred', 'Anokye', '0242287636', 'godfredkixid@gmail.com', '$2y$10$0RmYciZxkOAWcgDwTnSMLuiXRc1.Z9A.c8GI8ime0ZVaeV7ZuMUFS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 12:49:57', '2024-07-12 12:49:57', NULL);
INSERT INTO `users` VALUES ('355', 'Ampomaa', 'Godfred', NULL, '2023-24010178', '$2y$10$kUcS4gFoSoFu.7s1w1mvv.rXNA7YAE0UjQ.7kRWboCLpJmSVES/Fi', 'female', '1/1/1/1/1/1/user/6690f53d15a229.019680591720775997.jpg', '2010-08-27', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 12:49:57', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('356', 'Amu', 'Joseph', NULL, '2023-24010179', '$2y$10$j0rG66Cih5rXBJsl15jLh.Qm1vWEFb7K1au9OKr.S0LX7WnR46Ugi', 'male', '1/1/1/1/1/1/user/6690f5c6162d43.126036811720776134.jpg', '2010-09-13', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 12:52:14', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('357', 'Donkor', 'Adu', '0552008520', 'adukixid@gmail.com', '$2y$10$ARO/mJtI6ACVJMJa14ynO.LBh1ZskaEfOUMlVjPRQwRejx3sfMNgu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 12:54:03', '2024-07-12 12:54:03', NULL);
INSERT INTO `users` VALUES ('358', 'Adu', 'Christable', NULL, '2023-24010180', '$2y$10$F..aEU6TQz4OeiP3Yq1TYutRA3mpAJkd015ajAUTWQjht.tBJkzJO', 'female', '1/1/1/1/1/1/user/6690f633c88697.722747921720776243.jpg', '2010-01-22', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 12:54:03', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('359', 'Addo', 'Ohene', '0278445211', 'addokixid@gmail.com', '$2y$10$OUV7LR.jAy1o6gOR4BBWSeBHUYFD3PQHL0btTVdJQJ888W3pPzQpy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 12:55:56', '2024-07-12 12:55:56', NULL);
INSERT INTO `users` VALUES ('360', 'Ohene', 'Challote', NULL, '2023-24010181', '$2y$10$MSHpi1m2E.pnD9RSUXBxr.7j.j.3aVhQ58vG73mhm2c5JrKbkJoUu', 'female', '1/1/1/1/1/1/user/6690f6a460b546.168455881720776356.jpg', '2010-11-30', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 12:55:56', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('361', 'Inusah', 'Haruna', '0202052200', 'jumaikixid@gmail.com', '$2y$10$a5yN.JyNEDvolu3W7wREYebtiD7/VPTveh9w8CkUYLvZloM.HIxaK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 12:57:34', '2024-07-12 12:57:34', NULL);
INSERT INTO `users` VALUES ('362', 'Jumai', 'Inusah', NULL, '2023-24010182', '$2y$10$wGx.qRK5Y/821kBKywHFBeF1jOs3Rs5qTpSgetp84ZDS6EoNuii3a', 'female', '1/1/1/1/1/1/user/6690f70706aeb5.135493131720776455.jpg', '2010-05-28', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 12:57:35', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('363', 'Agbemenu', 'Jacob', '0244055287', 'elizabethkixid@gmail.com', '$2y$10$rS8qU2Fxw7lkP7f0XxhAT.whhPo7nBqDT/ORza6M2lqwqZnr0EMpe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:01:18', '2024-07-12 13:01:18', NULL);
INSERT INTO `users` VALUES ('364', 'Agbemenu', 'Elizabeth', NULL, '2023-24010183', '$2y$10$vU/IZHnVpNvnmbzdAgX2Ke9.lXZM4m5yWWwqkqRVr5SqVXqVQdTlO', 'female', '1/1/1/1/1/1/user/6690f7e6f39ce5.670841651720776678.jpg', '2010-05-25', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:01:19', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('365', 'Ofori', 'Obed', '0244600655', 'obedkixid@gmail.com', '$2y$10$D1grNM3RYlgqPk1oEuSiOO/nCE3VDsw5SzO9Rjw.wKhChZZJ5/p7a', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:03:18', '2024-07-12 13:03:18', NULL);
INSERT INTO `users` VALUES ('366', 'Obed', 'Ayim', NULL, '2023-24010184', '$2y$10$MGc.NWzpZpazcRF6MfBi5u2MkGjLhhjESACWSIm402Vdz6tOrCnFe', 'male', '1/1/1/1/1/1/user/6690f85e555b19.670974901720776798.jpg', '2010-11-12', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:03:18', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('367', 'Penel', 'Oscar', '0244544520', 'penelkixid@gmail.com', '$2y$10$YOxui6G1jNU/RwYsCHwvwu3X9NvVhTuliI7eC7a27o9iQUfOXQo1.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:07:52', '2024-07-12 13:07:52', NULL);
INSERT INTO `users` VALUES ('368', 'Nkyira', 'Adu', NULL, '2023-24010185', '$2y$10$ko8Sb.WbVtICgcKaEP8yhu9/NFgimXLbttiCT9c/QxncFAMIHPxVS', 'male', '1/1/1/1/1/1/user/6690f97040b295.037812041720777072.jpg', '2010-07-26', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:07:52', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('369', 'Antwi', 'Osei', '0553118752', 'christodia@gmail.com', '$2y$10$ZhMW62Yk.heIrHngSxdESeL2ccPnZvrqpYS18ALeIhewXStEtDpiq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:14:05', '2024-07-12 13:14:05', NULL);
INSERT INTO `users` VALUES ('370', 'Antwi', 'Christodia', NULL, '2023-24010186', '$2y$10$NALjPBLMQ74I3emu6B1REenn2Bja0K4Rzvv.r7dYMuV2zJnXp3cNK', 'female', '1/1/1/1/1/1/user/6690fae5642c16.547652021720777445.jpg', '2010-02-28', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:14:05', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('371', 'Jonathan', 'Abraham', '0248825512', 'jonathankixid@gmail.com', '$2y$10$bNp8lg2cYP5P76K/YwETzOG7j7ndcajV/F8vkU7T1GQBiDhoYJj6O', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:17:33', '2024-07-12 13:17:33', NULL);
INSERT INTO `users` VALUES ('372', 'Abraham', 'Bernard', NULL, '2023-24010187', '$2y$10$IPKq5mE1Sa4adj6FywOsz.7WGQlzkwFDA3C0TRYJXWNclLgeR3GdC', 'male', '1/1/1/1/1/1/user/6690fbb5d6c790.967697391720777653.jpg', '2010-08-11', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:17:33', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('373', 'Gyimah', 'Boamah', '0544855010', 'gyimahkixid@gmail.com', '$2y$10$YROtnZOc0LynfflYXBXnz.F0WjnOGlksbzHJVcLntKaMk7zZtToFu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:20:47', '2024-07-12 13:20:47', NULL);
INSERT INTO `users` VALUES ('374', 'Gyimah', 'Philip', NULL, '2023-24010188', '$2y$10$guOmHT.7E2v2X0neKWO/EegvDGjZrDE42H855R8nvhTAY7cZIh4Ie', 'male', '1/1/1/1/1/1/user/6690fc7727adb7.316857781720777847.jpg', '2010-08-09', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:20:47', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('375', 'Samuel', 'Kelly', '0542258820', 'ashleykixid@gmail.com', '$2y$10$Rx/.FDb6rQ4eEZmPyFa3f.YhPrCBwwtyjX0eMAgHadzYSZoylehue', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:23:48', '2024-07-12 13:23:48', NULL);
INSERT INTO `users` VALUES ('376', 'Ashley', 'Kelly', NULL, '2023-24010189', '$2y$10$BsyWDxU8y0/YhvRklJi6lO3n2bZ4Y9IGTOB38gieEBlSf9utxM0TO', 'female', '1/1/1/1/1/1/user/6690fd2cb8fc65.232649381720778028.jpg', '2010-04-03', 'Okponglo', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:23:48', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('377', 'Fatawu', 'Shaibu', '0547737731', 'fatawukixid@gmail.com', '$2y$10$FHeLM0fe2n2JUcrQ.z6Nzu.5i0gj5kLPEG83uhk8q.euAe26UR6MW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:25:37', '2024-07-12 13:25:37', NULL);
INSERT INTO `users` VALUES ('378', 'Shaibu', 'Majid', NULL, '2023-24010190', '$2y$10$WAYNEpGygZRHUY61BMkab.3HKyJjYuerNyjzSk/7rNK2SgMyHgpw.', 'male', '1/1/1/1/1/1/user/6690fd9996ffd2.120464811720778137.jpg', '2010-04-29', 'Shiashi', 'Accra', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:25:37', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('379', 'Adjei', 'Emmanuel', '0202002585', 'adjeikixid@gmail.com', '$2y$10$B2R99s3NeNmc9VQThZ5uAeoB7FRVMPqiEVagn9EnIp4W1VH/1vlh2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:27:52', '2024-07-12 13:27:52', NULL);
INSERT INTO `users` VALUES ('380', 'Emmanuel', 'Adjei', NULL, '2023-24010191', '$2y$10$AwcU6n2aD1.vt3QNFmv8pep9pkQZ26PIRFNqNbpY6xGJs83EwG54e', 'male', '1/1/1/1/1/1/user/6690fe20e43a30.180980881720778272.jpg', '2010-10-20', 'Okponglo', 'Accra', NULL, '1', '0', '', '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-12 13:27:52', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('381', 'Mike', 'Davis', '0244980127', 'umnisbooks@gmail.com', '$2y$10$5vTnkZ4w6QjGmKpd/7Mtju.ldUQzDOpsfLXEAcaSWM2/gj03mfMrG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', 'dUWB6N4TQzWwsMFVW8XyXK:APA91bHNgFUTlUfx6prxTP5-hymIkD3JUHfv0PwJNBpJMP2PN69PXmXNkf38D2zBk7Ywp0zTUE26XP2rWue74qxp29TyBSWaKK5K1S_ttlhi9avbCRq9S3jeU7KVhjdbpNl2oL88uWi-', '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-19 07:05:47', '2024-09-02 18:42:01', NULL);
INSERT INTO `users` VALUES ('382', 'Yaw', 'Adom', NULL, '2023-24010192', '$2y$10$olXgFveyiubq/q7RYTaKPON2nS4f9guZzOcyCKLu0Y6MlQy86IuDK', 'male', '1/1/1/1/1/1/user/6699df135fa904.208985931721360147.jpg', '2010-10-20', 'Kaneshie', 'Accra', NULL, '1', '0', '', '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-07-19 07:05:47', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('383', 'George', 'Appiah', '02449345432', 'teachertest@kixid.com', '$2y$10$i7BXjAi86Dtosi2V30SfGeXnN4Z3JA1ubl1BrIKV.aSI28b4v1elW', 'male', '1/1/1/1/1/1/user/66b174c1232464.080529571722905793.jpg', '1990-06-20', 'HNo. 21 Pentegost Street, New Weija.', 'HNo. 21 Pentegost Street, New Weija.', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-08-06 04:26:33', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('384', 'Mavis', 'Danso', '024495656', 'teachertest2@kixid.com', '$2y$10$3vO622uPlKeOA3Yire0GpORu6I313gQs3DbODxj9eIiTCScV0df3e', 'female', '1/1/1/1/1/1/user/66b17596cb69b7.724307861722906006.jpg', '1995-07-05', 'HNo. 21 Pentegost Street, New Weija.', 'HNo. 21 Pentegost Street, New Weija.', NULL, '0', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-08-06 04:30:07', '2024-10-24 17:37:43', '0000-00-00 00:00:00');
INSERT INTO `users` VALUES ('385', 'James', 'Gorden', '0244980342', 'teachertest3@kixid.com', '$2y$10$XaLaJE13PeAK6GreM5KhZuYwbcEr80DVbQaUOJpWhLFUnDvcchxXC', 'male', '1/1/1/1/1/1/user/66b176cc1a7046.292191381722906316.jpg', '1995-10-18', 'HNo. 21 Pentegost Street, New Weija.', 'HNo. 21 Pentegost Street, New Weija.', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-08-06 04:35:16', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('386', 'Solomon', 'Danso', '0244445452', 'teachertest4@kixid.com', '$2y$10$GHBHcvT06DZHaFUW7cufYuox8njJZ9.0ueexT9hkNjfbn/KiqPyzm', 'male', '1/1/1/1/1/1/user/66b17772d2b161.695222741722906482.jpg', '1990-11-07', 'HNo. 21 Pentegost Street, New Weija.', 'HNo. 21 Pentegost Street, New Weija.', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-08-06 04:38:02', '2024-10-24 17:37:43', NULL);
INSERT INTO `users` VALUES ('387', 'Mavis', 'Yeboah', '0244332210', 'teachertest5@kixid.com', '$2y$10$RLYDrhgMNmSDUFLbwfuO4.6HJanZEZ300d/lbYQtaMUvWTPvNxNPW', 'female', '1/1/1/1/1/1/user/66b1782925ff09.923747571722906665.jpg', '1994-08-27', 'HNo. 21 Pentegost Street, New Weija.', 'HNo. 21 Pentegost Street, New Weija.', NULL, '1', '0', NULL, '1', 'en', NULL, NULL, '1', NULL, NULL, '2024-08-06 04:41:05', '2024-10-24 17:37:43', NULL);

